/*
*
* An XmlReader implementation for loading SGML (including HTML) converting it
* to well formed XML, by adding missing quotes, empty attribute values, ignoring
* duplicate attributes, case folding on tag names, adding missing closing tags
* based on SGML DTD information, and so on.
*
* Copyright (c) 2002 Microsoft Corporation. All rights reserved.
*
* Chris Lovett
*
*/
import * as tslib_1 from "tslib";
import { ValueType, markEnum, Type, Base, BaseError, markType, Stream, IDisposable_$type, fromEn, EnumUtil, fromEnum, IEnumerable_$type, String_$type, getEnumerator, NotSupportedException, typeCast, runOn, markStruct, Nullable$1, Number_$type, Boolean_$type, typeCastObjTo$t, toEnum, Array_$type, getBoxIfEnum, enumGetBox, typeGetValue, Date_$type } from "igniteui-angular-core/ES5/type";
import { Uri } from "igniteui-angular-core/ES5/Uri";
import { TextReader } from "igniteui-angular-core/ES5/TextReader";
import { StringUtilities, IPackagePart_$type, IPackage_$type, ExternalEventWorkItem$1, WorkItem, ExternalEventWorkItem, IPackageRelationship_$type, IInvalidPackageRelationshipTarget_$type, WorkItemExtensions, Async, RelationshipTargetMode_$type, IPackagePartEx_$type, IPackageFactory_$type, UriUtilities, ST_Angle, CT_Transform2D, CT_GroupTransform2D, DocCoreUtils, ST_PositiveCoordinate, ST_Coordinate, ST_UniversalMeasure, CT_TextBodyPropertiesBase, IShallowCloneable_$type, RoundTripControlData, ContextStack, ImageData, ImageFormat, CT_PositiveSize2D, CT_Point2D, IgnoreChildrenMarker, BinaryData, RoundTripPartData, ST_ShapeType_$type, ST_IconSetType_$type, ST_CellType_$type, ST_FilterOperator_$type, ST_DateTimeGrouping_$type, ST_DynamicFilterType_$type, ST_SortBy_$type, ST_TotalsRowFunction_$type, ST_TableStyleType_$type } from "./documents.core";
import { StringReader } from "igniteui-angular-core/ES5/StringReader";
import { Encoding } from "igniteui-angular-core/ES5/Encoding";
import { StringBuilder } from "igniteui-angular-core/ES5/StringBuilder";
import { Convert } from "igniteui-angular-core/ES5/Convert";
import { stringCompare1, isLetter, stringFormat, isLetterOrDigit, stringFormat1, startsWith1, b64toUint8Array, stringSplit, trimStart, trimEnd } from "igniteui-angular-core/ES5/stringExtended";
import { Decoder } from "igniteui-angular-core/ES5/Decoder";
import { MemoryStream } from "igniteui-angular-core/ES5/MemoryStream";
import { UnicodeEncoding } from "igniteui-angular-core/ES5/UnicodeEncoding";
import { u32LS, u32BitwiseOr, intToString1, parseInt32_2, tryParseInt32_2, numberToString, tryParseNumber1, parseInt32_1, parseUInt32_2, tryParseUInt32_2, tryParseUInt64_2, parseUInt8_2, parseUInt16_2, parseInt8_1, parseNumber, parseInt64_1, parseInt16_1, parseUInt8_1, parseUInt32_1, parseUInt64_1, parseUInt16_1 } from "igniteui-angular-core/ES5/numberExtended";
import { arrayCopy1, arrayCopy2 } from "igniteui-angular-core/ES5/arrayExtended";
import { stringCreateFromCharArraySlice, stringEmpty, stringReplace, stringIsNullOrEmpty, stringStartsWith, stringEndsWith, stringConcat, stringJoin1, stringToString$1, stringIsNullOrWhiteSpace, stringToLocaleUpper } from "igniteui-angular-core/ES5/string";
import { intDivide, truncate } from "igniteui-angular-core/ES5/number";
import { List$1 } from "igniteui-angular-core/ES5/List$1";
import { Dictionary$2 } from "igniteui-angular-core/ES5/Dictionary$2";
import { NotImplementedException } from "igniteui-angular-core/ES5/NotImplementedException";
import { XmlReader } from "igniteui-angular-core/ES5/XmlReader";
import { NameTable } from "igniteui-angular-core/ES5/NameTable";
import { XmlNamespaceManager } from "igniteui-angular-core/ES5/XmlNamespaceManager";
import { IndexOutOfRangeException } from "igniteui-angular-core/ES5/IndexOutOfRangeException";
import { InvalidOperationException } from "igniteui-angular-core/ES5/InvalidOperationException";
import { StringWriter } from "igniteui-angular-core/ES5/StringWriter";
import { XmlWriter } from "igniteui-angular-core/ES5/XmlWriter";
import { XmlTextWriter } from "igniteui-angular-core/ES5/XmlTextWriter";
import { IOPath } from "igniteui-angular-core/ES5/IOPath";
import { ArgumentException } from "igniteui-angular-core/ES5/ArgumentException";
import { Enumerable } from "igniteui-angular-core/ES5/Enumerable";
import { XmlTextReader } from "igniteui-angular-core/ES5/XmlTextReader";
import { StringComparer } from "igniteui-angular-core/ES5/StringComparer";
import { Regex } from "igniteui-angular-core/ES5/Regex";
import { toUniversalTime, dateToStringFormat, dateParseExact, toLocalTime, dateParse, dateToString } from "igniteui-angular-core/ES5/dateExtended";
import { dateNow } from "igniteui-angular-core/ES5/date";
import { Tuple$2 } from "igniteui-angular-core/ES5/Tuple$2";
import { Tuple } from "igniteui-angular-core/ES5/Tuple";
import { nullableNotEquals, nullableEquals } from "igniteui-angular-core/ES5/nullable";
import { CultureInfo } from "igniteui-angular-core/ES5/culture";
import { Stack$1 } from "igniteui-angular-core/ES5/Stack$1";
import { HashSet$1 } from "igniteui-angular-core/ES5/HashSet$1";
import { Color } from "igniteui-angular-core/ES5/Color";
import { parseBool, tryParseBool } from "igniteui-angular-core/ES5/bool";
import { ArgumentOutOfRangeException } from "igniteui-angular-core/ES5/ArgumentOutOfRangeException";
import { StreamReader } from "igniteui-angular-core/ES5/StreamReader";
import { EqualityComparer$1 } from "igniteui-angular-core/ES5/EqualityComparer$1";
import { Guid } from "igniteui-angular-core/ES5/Guid";
import * as JSZip from "jszip/dist/jszip";
export var ST_DataBarAxisPosition_$type = markEnum('ST_DataBarAxisPosition', 'automatic,0|middle,1|none,2');
export var ST_DataBarDirection_$type = markEnum('ST_DataBarDirection', 'context,0|leftToRight,1|rightToLeft,2');
export var ST_Visibility_$type = markEnum('ST_Visibility', 'visible,0|hidden,1|veryHidden,2');
export var ST_VerticalAlignment_$type = markEnum('ST_VerticalAlignment', 'top,0|center,1|bottom,2|justify,3|distributed,4');
export var ST_UpdateLinks_$type = markEnum('ST_UpdateLinks', 'userSet,0|never,1|always,2');
export var ST_UnderlineValues_$type = markEnum('ST_UnderlineValues', '_single,0|_double,1|singleAccounting,2|doubleAccounting,3|none,4');
export var ST_TimePeriod_$type = markEnum('ST_TimePeriod', 'today,0|yesterday,1|tomorrow,2|last7Days,3|thisMonth,4|lastMonth,5|nextMonth,6|thisWeek,7|lastWeek,8|nextWeek,9');
export var ST_TableType_$type = markEnum('ST_TableType', 'worksheet,0|xml,1|queryTable,2');
export var ST_SortMethod_$type = markEnum('ST_SortMethod', 'none,0|pinYin,1|stroke,2');
export var ST_SheetViewType_$type = markEnum('ST_SheetViewType', 'normal,0|pageBreakPreview,1|pageLayout,2');
export var ST_SheetState_$type = markEnum('ST_SheetState', 'visible,0|hidden,1|veryHidden,2');
export var ST_RefMode_$type = markEnum('ST_RefMode', 'A1,0|R1C1,1');
export var ST_PrintError_$type = markEnum('ST_PrintError', 'displayed,0|blank,1|dash,2|NA,3');
export var ST_PatternType_$type = markEnum('ST_PatternType', 'none,0|solid,1|mediumGray,2|darkGray,3|lightGray,4|darkHorizontal,5|darkVertical,6|darkDown,7|darkUp,8|darkGrid,9|darkTrellis,10|lightHorizontal,11|lightVertical,12|lightDown,13|lightUp,14|lightGrid,15|lightTrellis,16|gray125,17|gray0625,18');
export var ST_PaneState_$type = markEnum('ST_PaneState', 'split,0|frozen,1|frozenSplit,2');
export var ST_Pane_$type = markEnum('ST_Pane', 'bottomRight,0|topRight,1|bottomLeft,2|topLeft,3');
export var ST_PageOrder_$type = markEnum('ST_PageOrder', 'downThenOver,0|overThenDown,1');
export var ST_Orientation_$type = markEnum('ST_Orientation', '_default,0|portrait,1|landscape,2|minMax,3|maxMin,4');
export var ST_ObjectType_$type = markEnum('ST_ObjectType', 'Button,0|Checkbox,1|Dialog,2|Drop,3|Edit,4|GBox,5|Label,6|LineA,7|List,8|Movie,9|Note,10|Pict,11|Radio,12|RectA,13|Scroll,14|Spin,15|Shape,16|Group,17|Rect,18');
export var ST_Objects_$type = markEnum('ST_Objects', 'all,0|placeholders,1|none,2');
export var ST_HorizontalAlignment_$type = markEnum('ST_HorizontalAlignment', 'general,0|left,1|center,2|right,3|fill,4|justify,5|centerContinuous,6|distributed,7');
export var ST_GradientType_$type = markEnum('ST_GradientType', 'linear,0|path,1');
export var ST_FontScheme_$type = markEnum('ST_FontScheme', 'none,0|major,1|minor,2');
export var ST_EditAs_$type = markEnum('ST_EditAs', 'twoCell,0|oneCell,1|absolute,2');
export var ST_DataValidationType_$type = markEnum('ST_DataValidationType', 'none,0|whole,1|_decimal,2|list,3|date,4|time,5|textLength,6|custom,7');
export var ST_DataValidationOperator_$type = markEnum('ST_DataValidationOperator', 'between,0|notBetween,1|equal,2|notEqual,3|lessThan,4|lessThanOrEqual,5|greaterThan,6|greaterThanOrEqual,7');
export var ST_DataValidationImeMode_$type = markEnum('ST_DataValidationImeMode', 'noControl,0|off,1|on,2|disabled,3|hiragana,4|fullKatakana,5|halfKatakana,6|fullAlpha,7|halfAlpha,8|fullHangul,9|halfHangul,10');
export var ST_DataValidationErrorStyle_$type = markEnum('ST_DataValidationErrorStyle', 'stop,0|warning,1|information,2');
export var ST_ConditionalFormattingOperator_$type = markEnum('ST_ConditionalFormattingOperator', 'lessThan,0|lessThanOrEqual,1|equal,2|notEqual,3|greaterThanOrEqual,4|greaterThan,5|between,6|notBetween,7|containsText,8|notContains,9|beginsWith,10|endsWith,11');
export var ST_Comments_$type = markEnum('ST_Comments', 'commNone,0|commIndicator,1|commIndAndComment,2');
export var ST_CfvoType_$type = markEnum('ST_CfvoType', 'num,0|percent,1|max,2|min,3|formula,4|percentile,5|autoMin,6|autoMax,7');
export var ST_CfType_$type = markEnum('ST_CfType', 'expression,0|cellIs,1|colorScale,2|dataBar,3|iconSet,4|top10,5|uniqueValues,6|duplicateValues,7|containsText,8|notContainsText,9|beginsWith,10|endsWith,11|containsBlanks,12|notContainsBlanks,13|containsErrors,14|notContainsErrors,15|timePeriod,16|aboveAverage,17');
export var ST_CellFormulaType_$type = markEnum('ST_CellFormulaType', 'normal,0|array,1|dataTable,2|shared,3');
export var ST_CellComments_$type = markEnum('ST_CellComments', 'none,0|asDisplayed,1|atEnd,2');
export var ST_CalendarType_$type = markEnum('ST_CalendarType', 'gregorian,0|gregorianArabic,1|gregorianMeFrench,2|gregorianUs,3|gregorianXlitEnglish,4|gregorianXlitFrench,5|hebrew,6|hijri,7|japan,8|korea,9|none,10|saka,11|taiwan,12|thai,13');
export var ST_CalcMode_$type = markEnum('ST_CalcMode', 'manual,0|auto,1|autoNoTable,2');
export var ST_BorderStyle_$type = markEnum('ST_BorderStyle', 'none,0|thin,1|medium,2|dashed,3|dotted,4|thick,5|_double,6|hair,7|mediumDashed,8|dashDot,9|mediumDashDot,10|dashDotDot,11|mediumDashDotDot,12|slantDashDot,13');
export var XmlNamespaceDefinitionBase_PreserveSpaceMode_$type = markEnum('XmlNamespaceDefinitionBase_PreserveSpaceMode', 'None,0|HonorLeadingWhitespace,2|HonorTrailingWhitespace,4|HonorBoth,6');
export var ST_VerticalAlignRun_$type = markEnum('ST_VerticalAlignRun', 'baseline,0|superscript,1|subscript,2');
export var ST_VectorBaseType_$type = markEnum('ST_VectorBaseType', 'variant,0|i1,1|i2,2|i4,3|i8,4|ui1,5|ui2,6|ui4,7|ui8,8|r4,9|r8,10|lpstr,11|lpwstr,12|bstr,13|date,14|filetime,15|_bool,16|cy,17|error,18|clsid,19');
export var ST_TileFlipMode_$type = markEnum('ST_TileFlipMode', 'none,0|x,1|y,2|xy,3');
export var ST_TextWrappingType_$type = markEnum('ST_TextWrappingType', 'none,0|square,1');
export var ST_TextVertOverflowType_$type = markEnum('ST_TextVertOverflowType', 'overflow,0|ellipsis,1|clip,2');
export var ST_TextVerticalType_$type = markEnum('ST_TextVerticalType', 'horz,0|vert,1|vert270,2|wordArtVert,3|eaVert,4|mongolianVert,5|wordArtVertRtl,6');
export var ST_TextUnderlineType_$type = markEnum('ST_TextUnderlineType', 'none,0|words,1|sng,2|dbl,3|heavy,4|dotted,5|dottedHeavy,6|dash,7|dashHeavy,8|dashLong,9|dashLongHeavy,10|dotDash,11|dotDashHeavy,12|dotDotDash,13|dotDotDashHeavy,14|wavy,15|wavyHeavy,16|wavyDbl,17');
export var ST_TextStrikeType_$type = markEnum('ST_TextStrikeType', 'noStrike,0|sngStrike,1|dblStrike,2');
export var ST_TextHorzOverflowType_$type = markEnum('ST_TextHorzOverflowType', 'overflow,0|clip,1');
export var ST_TextFontAlignType_$type = markEnum('ST_TextFontAlignType', 'auto,0|t,1|ctr,2|_base,3|b,4');
export var ST_TextCapsType_$type = markEnum('ST_TextCapsType', 'none,0|small,1|all,2');
export var ST_TextAnchoringType_$type = markEnum('ST_TextAnchoringType', 't,0|ctr,1|b,2|just,3|dist,4');
export var ST_TextAlignType_$type = markEnum('ST_TextAlignType', 'l,0|ctr,1|r,2|just,3|justLow,4|dist,5|thaiDist,6');
export var ST_SystemColorVal_$type = markEnum('ST_SystemColorVal', 'activeBorder,0|activeCaption,1|captionText,2|appWorkspace,3|btnFace,4|_3dDkShadow,5|btnShadow,6|_3dLight,7|btnHighlight,8|btnText,9|background,10|gradientActiveCaption,11|gradientInactiveCaption,12|grayText,13|highlight,14|highlightText,15|hotLight,16|inactiveBorder,17|inactiveCaption,18|inactiveCaptionText,19|infoText,20|infoBk,21|menu,22|menuBar,23|menuHighlight,24|menuText,25|scrollBar,26|window,27|windowFrame,28|windowText,29');
export var ST_StrokeLineStyle_$type = markEnum('ST_StrokeLineStyle', 'single,0|thinThin,1|thinThick,2|thickThin,3|thickBetweenThin,4');
export var ST_StrokeJoinStyle_$type = markEnum('ST_StrokeJoinStyle', 'round,0|bevel,1|miter,2');
export var ST_StrokeEndCap_$type = markEnum('ST_StrokeEndCap', 'flat,0|square,1|round,2');
export var ST_StrokeArrowWidth_$type = markEnum('ST_StrokeArrowWidth', 'narrow,0|medium,1|wide,2');
export var ST_StrokeArrowType_$type = markEnum('ST_StrokeArrowType', 'none,0|block,1|classic,2|oval,3|diamond,4|open,5');
export var ST_StrokeArrowLength_$type = markEnum('ST_StrokeArrowLength', '_short,0|medium,1|_long,2');
export var ST_ShadowType_$type = markEnum('ST_ShadowType', 'single,0|_double,1|emboss,2|perspective,3');
export var ST_SchemeColorVal_$type = markEnum('ST_SchemeColorVal', 'bg1,0|tx1,1|bg2,2|tx2,3|accent1,4|accent2,5|accent3,6|accent4,7|accent5,8|accent6,9|hlink,10|folHlink,11|phClr,12|dk1,13|lt1,14|dk2,15|lt2,16');
export var ST_RectAlignment_$type = markEnum('ST_RectAlignment', 'tl,0|t,1|tr,2|l,3|ctr,4|r,5|bl,6|b,7|br,8');
export var ST_PresetPatternVal_$type = markEnum('ST_PresetPatternVal', 'pct5,0|pct10,1|pct20,2|pct25,3|pct30,4|pct40,5|pct50,6|pct60,7|pct70,8|pct75,9|pct80,10|pct90,11|horz,12|vert,13|ltHorz,14|ltVert,15|dkHorz,16|dkVert,17|narHorz,18|narVert,19|dashHorz,20|dashVert,21|cross,22|dnDiag,23|upDiag,24|ltDnDiag,25|ltUpDiag,26|dkDnDiag,27|dkUpDiag,28|wdDnDiag,29|wdUpDiag,30|dashDnDiag,31|dashUpDiag,32|diagCross,33|smCheck,34|lgCheck,35|smGrid,36|lgGrid,37|dotGrid,38|smConfetti,39|lgConfetti,40|horzBrick,41|diagBrick,42|solidDmnd,43|openDmnd,44|dotDmnd,45|plaid,46|sphere,47|weave,48|divot,49|shingle,50|wave,51|trellis,52|zigZag,53');
export var ST_PresetLineDashVal_$type = markEnum('ST_PresetLineDashVal', 'solid,0|dot,1|dash,2|lgDash,3|dashDot,4|lgDashDot,5|lgDashDotDot,6|sysDash,7|sysDot,8|sysDashDot,9|sysDashDotDot,10');
export var ST_PresetColorVal_$type = markEnum('ST_PresetColorVal', 'aliceBlue,0|antiqueWhite,1|aqua,2|aquamarine,3|azure,4|beige,5|bisque,6|black,7|blanchedAlmond,8|blue,9|blueViolet,10|brown,11|burlyWood,12|cadetBlue,13|chartreuse,14|chocolate,15|coral,16|cornflowerBlue,17|cornsilk,18|crimson,19|cyan,20|dkBlue,21|dkCyan,22|dkGoldenrod,23|dkGray,24|dkGreen,25|dkKhaki,26|dkMagenta,27|dkOliveGreen,28|dkOrange,29|dkOrchid,30|dkRed,31|dkSalmon,32|dkSeaGreen,33|dkSlateBlue,34|dkSlateGray,35|dkTurquoise,36|dkViolet,37|deepPink,38|deepSkyBlue,39|dimGray,40|dodgerBlue,41|firebrick,42|floralWhite,43|forestGreen,44|fuchsia,45|gainsboro,46|ghostWhite,47|gold,48|goldenrod,49|gray,50|green,51|greenYellow,52|honeydew,53|hotPink,54|indianRed,55|indigo,56|ivory,57|khaki,58|lavender,59|lavenderBlush,60|lawnGreen,61|lemonChiffon,62|ltBlue,63|ltCoral,64|ltCyan,65|ltGoldenrodYellow,66|ltGray,67|ltGreen,68|ltPink,69|ltSalmon,70|ltSeaGreen,71|ltSkyBlue,72|ltSlateGray,73|ltSteelBlue,74|ltYellow,75|lime,76|limeGreen,77|linen,78|magenta,79|maroon,80|medAquamarine,81|medBlue,82|medOrchid,83|medPurple,84|medSeaGreen,85|medSlateBlue,86|medSpringGreen,87|medTurquoise,88|medVioletRed,89|midnightBlue,90|mintCream,91|mistyRose,92|moccasin,93|navajoWhite,94|navy,95|oldLace,96|olive,97|oliveDrab,98|orange,99|orangeRed,100|orchid,101|paleGoldenrod,102|paleGreen,103|paleTurquoise,104|paleVioletRed,105|papayaWhip,106|peachPuff,107|peru,108|pink,109|plum,110|powderBlue,111|purple,112|red,113|rosyBrown,114|royalBlue,115|saddleBrown,116|salmon,117|sandyBrown,118|seaGreen,119|seaShell,120|sienna,121|silver,122|skyBlue,123|slateBlue,124|slateGray,125|snow,126|springGreen,127|steelBlue,128|tan,129|teal,130|thistle,131|tomato,132|turquoise,133|violet,134|wheat,135|white,136|whiteSmoke,137|yellow,138|yellowGreen,139');
export var ST_PenAlignment_$type = markEnum('ST_PenAlignment', 'ctr,0|_in,1');
export var ST_PathFillMode_$type = markEnum('ST_PathFillMode', 'none,0|norm,1|lighten,2|lightenLess,3|darken,4|darkenLess,5');
export var ST_LineEndType_$type = markEnum('ST_LineEndType', 'none,0|triangle,1|stealth,2|diamond,3|oval,4|arrow,5');
export var ST_LineEndWidth_$type = markEnum('ST_LineEndWidth', 'sm,0|med,1|lg,2');
export var ST_LineEndLength_$type = markEnum('ST_LineEndLength', 'sm,0|med,1|lg,2');
export var ST_LineCap_$type = markEnum('ST_LineCap', 'rnd,0|sq,1|flat,2');
export var ST_InsetMode_$type = markEnum('ST_InsetMode', 'auto,0|custom,1');
export var ST_ImageAspect_$type = markEnum('ST_ImageAspect', 'ignore,0|atMost,1|atLeast,2');
export var ST_HrAlign_$type = markEnum('ST_HrAlign', 'left,0|right,1|center,2');
export var ST_FontCollectionIndex_$type = markEnum('ST_FontCollectionIndex', 'major,0|minor,1|none,2');
export var ST_FillType_$type = markEnum('ST_FillType', 'gradientCenter,0|solid,1|pattern,2|tile,3|frame,4|gradientUnscaled,5|gradientRadial,6|gradient,7|background,8');
export var ST_FillMethod_$type = markEnum('ST_FillMethod', 'none,0|linear,1|sigma,2|any,3|linearsigma,4');
export var ST_Ext_$type = markEnum('ST_Ext', 'view,0|edit,1|backwardCompatible,2');
export var ST_ConnectType_$type = markEnum('ST_ConnectType', 'none,0|rect,1|segments,2|custom,3');
export var ST_ConnectorType_$type = markEnum('ST_ConnectorType', 'none,0|straight,1|elbow,2|curved,3');
export var ST_ConformanceClass_$type = markEnum('ST_ConformanceClass', 'transitional,0|strict,1');
export var ST_CompoundLine_$type = markEnum('ST_CompoundLine', 'sng,0|dbl,1|thickThin,2|thinThick,3|tri,4');
export var ST_CF_$type = markEnum('ST_CF', 'PictOld,0|Pict,1|Bitmap,2|PictPrint,3|PictScreen,4');
export var ST_BWMode_$type = markEnum('ST_BWMode', 'color,0|auto,1|grayScale,2|lightGrayscale,3|inverseGray,4|grayOutline,5|highContrast,6|black,7|white,8|hide,9|undrawn,10|blackTextAndLines,11');
export var ST_BlipCompression_$type = markEnum('ST_BlipCompression', 'none,0|email,1|hqprint,2|print,3|screen,4');
export var ST_BlackWhiteMode_$type = markEnum('ST_BlackWhiteMode', 'clr,0|auto,1|gray,2|ltGray,3|invGray,4|grayWhite,5|blackGray,6|blackWhite,7|black,8|white,9|hidden,10');
export var XmlReadManager_AlternateContentStatus_$type = markEnum('XmlReadManager_AlternateContentStatus', 'NotInAlternateContent,0|InAlternateContentPendingAcceptableChoice,1|InAlternateContentChoiceAccepted,2');
export var ElementPropertyIds_$type = markEnum('ElementPropertyIds', 'AbbreviatedCaseNumber,0|AbsSizeAnchor,1|AbsoluteAnchor,2|AbstractNum,3|AbstractNumId,4|Acc,5|AccPr,6|Accent1,7|Accent2,8|Accent3,9|Accent4,10|Accent5,11|Accent6,12|Active,13|ActiveRecord,14|ActiveTabTopLevelEntity,15|ActiveWritingStyle,16|AdditionalCharacteristics,17|Address,18|AddressFieldName,19|Adj,20|AdjustRightInd,21|Aggregation,22|AhLst,23|AlbumTitle,24|Align,25|AlignBordersAndEdges,26|Alignment,27|AllowPNG,28|Aln,29|AlnScr,30|Alpha,31|AlphaBiLevel,32|AlphaCeiling,33|AlphaFloor,34|AlphaInv,35|AlphaMod,36|AlphaModFix,37|AlphaOff,38|AlphaOutset,39|AlphaRepl,40|AltChunk,41|AltChunkPr,42|AlwaysMergeEmptyNamespace,43|AlwaysShowPlaceholderText,44|Anchor,45|Anchorlock,46|AnimLvl,47|AnimOne,48|AnnotationRef,49|ApplyToEnd,50|ApplyToFront,51|ApplyToSides,52|Arc,53|Area3DChart,54|AreaChart,55|ArgPr,56|ArgSz,57|Array,58|Artist,59|AttachedSchema,60|AttachedTemplate,61|Attr,62|AttrName,63|AttrNameLst,64|AudioCd,65|AudioFile,66|Author,67|Authors,68|Auto,69|AutoCaption,70|AutoCaptions,71|AutoFilter,72|AutoFormatOverride,73|AutoHyphenation,74|AutoSpaceDE,75|AutoSpaceDN,76|AutoSortScope,77|AutoTitleDeleted,78|AutoUpdate,79|AvLst,80|AxId,81|AxPos,82|AxisColor,83|AxisId,84|AxisTitle,85|B,86|BCs,87|BackWall,88|Backdrop,89|Background,90|Backward,91|Band1H,92|Band1V,93|Band2H,94|Band2V,95|BandFmt,96|BandFmts,97|Bar,98|Bar3DChart,99|BarChart,100|BarDir,101|BarPr,102|BaseJc,103|BaseTimeUnit,104|Bdr,105|BegChr,106|Between,107|Bevel,108|BevelB,109|BevelT,110|Bg,111|BgClr,112|BgColor,113|BgFillStyleLst,114|BgPr,115|BgRef,116|BiLevel,117|Bidi,118|BidiVisual,119|Binning,120|Bk,121|BldChart,122|BldDgm,123|BldLst,124|Blend,125|Blinds,126|Blip,127|BlipFill,128|Blob,129|BlockQuote,130|Blue,131|BlueMod,132|BlueOff,133|Blur,134|BodyDiv,135|BodyPr,136|BodyStyle,137|Bold,138|BoldItalic,139|BookAuthor,140|BookFoldPrinting,141|BookFoldPrintingSheets,142|BookFoldRevPrinting,143|BookTitle,144|BookViews,145|BookmarkEnd,146|BookmarkStart,147|Bool,148|Border,149|BorderBox,150|BorderBoxPr,151|BorderColor,152|Borderbottom,153|Borderleft,154|Borderright,155|Borders,156|BordersDoNotSurroundFooter,157|BordersDoNotSurroundHeader,158|Bordertop,159|Bottom,160|Bounds,161|Box,162|BoxPr,163|Br,164|Brk,165|BrkBin,166|BrkBinSub,167|BroadcastTitle,168|Broadcaster,169|Browse,170|Bstr,171|BuAutoNum,172|BuBlip,173|BuChar,174|BuClr,175|BuClrTx,176|BuFont,177|BuFontTx,178|BuNone,179|BuSzPct,180|BuSzPts,181|BuSzTx,182|Bubble3D,183|BubbleChart,184|BubbleScale,185|BubbleSize,186|BuiltInUnit,187|BulletEnabled,188|By,189|C,190|CalculatedItems,191|CalculatedMembers,192|CBhvr,193|CGp,194|CGpRule,195|CMediaNode,196|CNvCxnSpPr,197|CNvGraphicFramePr,198|CNvGrpSpPr,199|CNvPicPr,200|CNvPr,201|CNvSpPr,202|CSld,203|CSldViewPr,204|CSp,205|CTn,206|CViewPr,207|CacheField,208|CacheFields,209|CacheHierarchy,210|CacheHierarchies,211|CacheSource,212|CachedUniqueName,213|CachedUniqueNames,214|CalcChain,215|CalcPr,216|CalculatedColumnFormula,217|CalculatedItem,218|CalculatedMember,219|CalculatedTimeColumn,220|Calendar,221|Callout,222|Camera,223|Caps,224|Caption,225|Captions,226|CaseNumber,227|Cat,228|CatAx,229|CatLst,230|CatScaling,231|CategoryAxis,232|Cell,233|Cell3D,234|CellDel,235|CellIns,236|CellMerge,237|CellMetadata,238|CellSmartTag,239|CellSmartTags,240|CellSmartTagPr,241|CellStyle,242|CellStyleXfs,243|CellStyles,244|CellWatch,245|CellWatches,246|CellXfs,247|Cf,248|CfIcon,249|CfRule,250|Cfvo,251|ChExt,252|ChMax,253|ChOff,254|ChPref,255|ChapterNumber,256|CharacterSpacingControl,257|Characteristic,258|Charset,259|Chart,260|ChartArea,261|ChartFormat,262|ChartFormats,263|ChartObject,264|ChartSpace,265|ChartStyle,266|Chartsheet,267|CheckErrors,268|Checked,269|Checker,270|ChildTnLst,271|Chr,272|Circle,273|City,274|ClickAndTypeStyle,275|ClientData,276|Clippath,277|ClrChange,278|ClrData,279|ClrFrom,280|ClrMap,281|ClrMapOvr,282|ClrMru,283|ClrRepl,284|ClrScheme,285|ClrSchemeMapping,286|ClrTo,287|Clsid,288|Cm,289|CmAuthor,290|CmAuthorLst,291|CmLst,292|CnfStyle,293|Col,294|ColBreaks,295|ColDelim,296|ColFields,297|ColHierarchiesUsage,298|ColHierarchyUsage,299|ColItems,300|Color,301|ColorAxis,302|ColorFirst,303|ColorHigh,304|ColorLast,305|ColorLow,306|ColorMarkers,307|ColorNegative,308|ColorScale,309|ColorSeries,310|ColorStyle,311|Colors,312|ColorsDef,313|ColorsDefHdr,314|ColorsDefHdrLst,315|Cols,316|Column,317|Comb,318|Comment,319|CommentList,320|CommentRangeEnd,321|CommentRangeStart,322|CommentReference,323|Comments,324|Comp,325|Compat,326|Compiler,327|Complex,328|Composer,329|Cond,330|Condense,331|ConditionalFormat,332|ConditionalFormats,333|ConditionalFormatting,334|ConditionalFormattings,335|Conductor,336|ConferenceName,337|ConnectString,338|Connection,339|Connections,340|ConsecutiveHyphenLimit,341|Constr,342|Cont,343|ContextualSpacing,344|ContinuationSeparator,345|ContourClr,346|Control,347|Controls,348|Copyright,349|Copyrights,350|Corporate,351|Counsel,352|Count,353|CountryRegion,354|Court,355|Cover,356|Cr,357|CrossAx,358|CrossBetween,359|Crosses,360|CrossesAt,361|Cs,362|CtrlPr,363|Curve,364|CustClr,365|CustClrLst,366|CustDash,367|CustData,368|CustDataLst,369|CustGeom,370|CustShow,371|CustShowLst,372|CustSplit,373|CustUnit,374|CustomFilter,375|CustomFilters,376|CustomPr,377|CustomProperties,378|CustomSheetView,379|CustomSheetViews,380|CustomWorkbookView,381|CustomWorkbookViews,382|CustomXmlDelRangeEnd,383|CustomXmlDelRangeStart,384|CustomXmlInsRangeEnd,385|CustomXmlInsRangeStart,386|CustomXmlMoveFromRangeEnd,387|CustomXmlMoveFromRangeStart,388|CustomXmlMoveToRangeEnd,389|CustomXmlMoveToRangeStart,390|CustomXmlPr,391|Cut,392|Cxn,393|CxnLst,394|CxnSp,395|CxnSpLocks,396|Cy,397|D,398|DdeLink,399|DLbl,400|DLblPos,401|DLbls,402|DPr,403|DPt,404|DTable,405|Data,406|DataBar,407|DataBinding,408|DataConsolidate,409|DataField,410|DataFields,411|DataId,412|DataLabel,413|DataLabelCallout,414|DataLabelHidden,415|DataLabels,416|DataModel,417|DataPoint,418|DataPoint3D,419|DataPointLine,420|DataPointMarker,421|DataPointMarkerLayout,422|DataPointWireframe,423|DataPt,424|DataRef,425|DataRefs,426|DataSource,427|DataTable,428|DataType,429|DataValidation,430|DataValidations,431|DatastoreItem,432|Date,433|Date1904,434|DateAx,435|DateFormat,436|DateGroupItem,437|Day,438|DayAccessed,439|DayLong,440|DayShort,441|DbTable,442|DbTables,443|DdeItem,444|DdeItems,445|Decimal,446|DecimalSymbol,447|DefJc,448|DefPPr,449|DefRPr,450|Default,451|DefaultTabStop,452|DefaultTableStyle,453|DefaultTextStyle,454|DefinedName,455|DefinedNames,456|Deg,457|DegHide,458|Del,459|DelInstrText,460|DelText,461|Delete:del,462|DeletedField,463|Den,464|Department,465|DepthPercent,466|Desc,467|DescriptionPr,468|Destination,469|Dgm,470|Diagonal,471|Diagram,472|Dialogsheet,473|Diamond,474|Diff,475|Dimension,476|Dimensions,477|Dir,478|Director,479|Dirty,480|DiscretePr,481|DispBlanksAs,482|DispDef,483|DispEq,484|DispRSqr,485|DispUnits,486|DispUnitsLbl,487|DisplayBackgroundShape,488|DisplayHorizontalDrawingGridEvery,489|DisplayVerticalDrawingGridEvery,490|Dissolve,491|Distributor,492|Div,493|DivBdr,494|DivId,495|Divs,496|DivsChild,497|Dk1,498|Dk2,499|DoNotAutoCompressPictures,500|DoNotDemarcateInvalidXml,501|DoNotDisplayPageBoundaries,502|DoNotEmbedSmartTags,503|DoNotHyphenateCaps,504|DoNotIncludeSubdocsInStats,505|DoNotOrganizeInFolder,506|DoNotRelyOnCSS,507|DoNotSaveAsSingleFile,508|DoNotShadeFormData,509|DoNotSuppressBlankLines,510|DoNotTrackFormatting,511|DoNotTrackMoves,512|DoNotUseLongFileNames,513|DoNotUseMarginsForDrawingGridOrigin,514|DoNotValidateAgainstSchema,515|DocDefaults,516|DocGrid,517|DocPartBody,518|DocPartCategory,519|DocPartGallery,520|DocPartPr,521|DocPartUnique,522|DocPr,523|DocVar,524|DocVars,525|Document,526|DocumentProtection,527|DocumentType,528|DoughnutChart,529|DownBar,530|DownBars,531|Drawing,532|DrawingGridHorizontalOrigin,533|DrawingGridHorizontalSpacing,534|DrawingGridVerticalOrigin,535|DrawingGridVerticalSpacing,536|DropLine,537|DropLines,538|Ds,539|Dstrike,540|Duotone,541|Dxf,542|Dxfs,543|DynamicAddress,544|E,545|Ea,546|EastAsianLayout,547|EditValue,548|Edition,549|Editor,550|Effect,551|EffectClrLst,552|EffectDag,553|EffectExtent,554|EffectLst,555|EffectRef,556|EffectStyle,557|EffectStyleLst,558|Else,559|Em,560|EmbedSystemFonts,561|EmbedTrueTypeFonts,562|EmbeddedFont,563|EmbeddedFontLst,564|Emboss,565|Empty,566|Encoding,567|End,568|EndChr,569|EndCondLst,570|EndCxn,571|EndParaRPr,572|EndSync,573|Endnote,574|EndnotePr,575|EndnoteRef,576|EndnoteReference,577|Endnotes,578|EntityType,579|Entries,580|Entry,581|EqArr,582|EqArrPr,583|ErrBarType,584|ErrBars,585|ErrDir,586|ErrValType,587|Error,588|ErrorBar,589|EvenAndOddHeaders,590|EvenFooter,591|EvenHeader,592|Explosion,593|Ext,594|Extend,595|ExtLst,596|Extent,597|ExternalBook,598|ExternalData,599|ExternalLink,600|ExternalReference,601|ExternalReferences,602|ExtraClrScheme,603|ExtraClrSchemeLst,604|Extrusion,605|ExtrusionClr,606|F,607|FHdr,608|FName,609|FPr,610|Fade,611|Family,612|FgClr,613|FgColor,614|Field,615|FieldCodes,616|FieldGroup,617|FieldMapData,618|FieldUsage,619|FieldsUsage,620|FileRecoveryPr,621|FileSharing,622|FileVersion,623|Filetime,624|Fill,625|FillClrLst,626|FillColor,627|FillOverlay,628|FillRect,629|FillRef,630|FillStyleLst,631|FillToRect,632|Fills,633|Filter,634|FilterColumn,635|Filters,636|First,637|FirstCol,638|FirstFooter,639|FirstHeader,640|FirstRow,641|FirstSliceAng,642|FitText,643|FlatBorders,644|FlatTx,645|Fld,646|FldChar,647|FldData,648|Floor,649|FmtId,650|FmtOvr,651|FmtScheme,652|FolHlink,653|Font,654|FontRef,655|FontScheme,656|Fonts,657|FooterReference,658|Footnote,659|FootnotePr,660|FootnoteRef,661|FootnoteReference,662|Footnotes,663|ForceUpgrade,664|FormControlPr,665|FormProt,666|Format,667|FormatCode,668|Formats,669|Formatting,670|FormsDesign,671|Formula,672|Formula1,673|Formula2,674|Formulas,675|Forward,676|Frame,677|FrameLayout,678|FramePr,679|Frameset,680|FramesetSplitbar,681|From,682|Ftr,683|Func,684|FuncPr,685|FunctionGroup,686|FunctionGroups,687|FutureMetadata,688|Gallery,689|Gamma,690|GapDepth,691|GapWidth,692|Gd,693|GdLst,694|GeoCache,695|GeoChildEntities,696|GeoChildEntitiesQuery,697|GeoChildEntitiesQueryResult,698|GeoChildEntitiesQueryResults,699|GeoChildTypes,700|GeoData,701|GeoDataEntityQuery,702|GeoDataEntityQueryResult,703|GeoDataEntityQueryResults,704|GeoDataPointQuery,705|GeoDataPointToEntityQuery,706|GeoDataPointToEntityQueryResult,707|GeoDataPointToEntityQueryResults,708|GeoHierarchyEntity,709|GeoLocation,710|GeoLocationQuery,711|GeoLocationQueryResult,712|GeoLocationQueryResults,713|GeoLocations,714|GeoPolygon,715|GeoPolygons,716|Geography,717|GlossaryDocument,718|Glow,719|GradFill,720|GradientFill,721|Graphic,722|GraphicData,723|GraphicFrame,724|GraphicFrameLocks,725|Gray,726|Grayscl,727|Green,728|GreenMod,729|GreenOff,730|GridCol,731|GridSpacing,732|GridSpan,733|GridlineMajor,734|GridlineMinor,735|Group,736|GroupChr,737|GroupChrPr,738|GroupItems,739|GroupLevel,740|GroupLevels,741|GroupMember,742|GroupMembers,743|Grouping,744|Groups,745|Grow,746|GrpFill,747|GrpSp,748|GrpSpLocks,749|GrpSpPr,750|Gs,751|GsLst,752|Guid,753|Guide,754|GuideLst,755|GutterAtTop,756|H,757|HMerge,758|HMode,759|HPercent,760|Handles,761|HandoutMaster,762|HandoutMasterId,763|HandoutMasterIdLst,764|Hdr,765|HdrShapeDefaults,766|HeadEnd,767|Header,768|HeaderFooter,769|HeaderReference,770|HeaderSource,771|Headers,772|Hf,773|HiLoLine,774|HiLowLines,775|HideBot,776|HideGrammaticalErrors,777|HideLeft,778|HideMark,779|HideRight,780|HideSpellingErrors,781|HideTop,782|HierBranch,783|Highlight,784|Hlink,785|HlinkClick,786|HlinkHover,787|HlinkMouseOver,788|HoleSize,789|Horizontal,790|Hps,791|HpsBaseText,792|HpsRaise,793|Hsl,794|HslClr,795|HtmlPubPr,796|Hue,797|HueMod,798|HueOff,799|Hyperlink,800|Hyperlinks,801|HyphenationZone,802|I,803|I1,804|I2,805|I4,806|I8,807|ICs,808|IconFilter,809|IconSet,810|Id,811|Idx,812|If,813|IgnoreMixedContent,814|IgnoredError,815|IgnoredErrors,816|Ilvl,817|Image,818|Imagedata,819|Imprint,820|Ind,821|IndexedColors,822|Ink,823|Inline,824|InnerShdw,825|InputCells,826|Ins,827|InsideH,828|InsideV,829|Institution,830|InstrText,831|Int,832|IntLim,833|InterSp,834|Intercept,835|InternetSiteTitle,836|Interviewee,837|Interviewer,838|IntraSp,839|Inv,840|InvGamma,841|Inventor,842|InvertIfNegative,843|Is,844|Iscomment,845|Issue,846|Italic,847|Item,848|ItemLst,849|Items,850|Iterate,851|Jc,852|JournalName,853|K,854|KeepLines,855|KeepNext,856|Kern,857|Kinsoku,858|Kiosk,859|Kpi,860|Kpis,861|LCID,862|LMargin,863|Lang,864|Last,865|LastCol,866|LastRenderedPageBreak,867|LastRow,868|LatentStyles,869|Latin,870|Layout,871|LayoutDef,872|LayoutDefHdr,873|LayoutDefHdrLst,874|LayoutNode,875|LayoutPr,876|LayoutTarget,877|LblAlgn,878|LblOffset,879|LeaderLine,880|LeaderLines,881|Left,882|LegacyDrawing,883|LegacyDrawingHF,884|Legend,885|LegendEntry,886|LegendPos,887|Level,888|Levels,889|Lid,890|LightRig,891|Lim,892|LimLoc,893|LimLow,894|LimLowPr,895|LimUpp,896|LimUppPr,897|Lin,898|LinClrLst,899|Line,900|Line3DChart,901|LineChart,902|LineTo,903|LineWidthScale,904|LinkStyles,905|LinkToQuery,906|LinkType,907|LinkedToFile,908|ListEntry,909|ListItem,910|ListSeparator,911|Lit,912|Ln,913|LnB,914|LnBlToTr,915|LnDef,916|LnL,917|LnNumType,918|LnR,919|LnRef,920|LnSpc,921|LnStyleLst,922|LnT,923|LnTlToBr,924|Location,925|Lock,926|LockedCanvas,927|LockedField,928|LogBase,929|Lpstr,930|Lpwstr,931|LsdException,932|LstStyle,933|Lt1,934|Lt2,935|Lum,936|LumMod,937|LumOff,938|Lvl,939|Lvl1pPr,940|Lvl2pPr,941|Lvl3pPr,942|Lvl4pPr,943|Lvl5pPr,944|Lvl6pPr,945|Lvl7pPr,946|Lvl8pPr,947|Lvl9pPr,948|LvlOverride,949|M,950|MPr,951|MailAsAttachment,952|MailMerge,953|MailSubject,954|Main,955|MainDocumentType,956|MajorFont,957|MajorGridlines,958|MajorTickMark,959|MajorTickMarks,960|MajorTimeUnit,961|MajorUnit,962|ManualLayout,963|Map,964|Maps,965|MapInfo,966|MappedName,967|MarBottom,968|MarH,969|MarLeft,970|MarRight,971|MarTop,972|MarW,973|Marker,974|MasterClrMapping,975|MatchSrc,976|MathFont,977|MathPr,978|Max,979|MaxColor,980|MaxDist,981|MaxLength,982|Mc,983|McJc,984|McPr,985|Mcs,986|Mdx,987|MdxMetadata,988|MeasureGroup,989|MeasureGroups,990|Medium,991|Member,992|Members,993|MergeCell,994|MergeCells,995|Metadata,996|MetadataStrings,997|MetadataType,998|MetadataTypes,999|Mid,1000|MidColor,1001|Middle,1002|Min,1003|MinColor,1004|MinorFont,1005|MinorGridlines,1006|MinorTickMark,1007|MinorTickMarks,1008|MinorTimeUnit,1009|MinorUnit,1010|Minus,1011|MirrorIndents,1012|MirrorMargins,1013|Miter,1014|ModelRelationship,1015|ModelTable,1016|ModelTimeGrouping,1017|ModelTimeGroupings,1018|ModifyVerifier,1019|Month,1020|MonthAccessed,1021|MonthLong,1022|MonthShort,1023|MoveFrom,1024|MoveFromRangeEnd,1025|MoveFromRangeStart,1026|MoveTo,1027|MoveToRangeEnd,1028|MoveToRangeStart,1029|Mp,1030|Mps,1031|MpMap,1032|Mr,1033|MruColors,1034|Ms,1035|MultiLevelType,1036|MultiLvlStrCache,1037|MultiLvlStrRef,1038|N,1039|Name:Name1,1040|NameList,1041|Nary,1042|NaryLim,1043|NaryPr,1044|Nc,1045|Ndxf,1046|NeCell,1047|NegativeBorderColor,1048|NegativeFillColor,1049|Newsflash,1050|NextCondLst,1051|NoAutofit,1052|NoBorder,1053|NoBreak,1054|NoBreakHyphen,1055|NoEndCap,1056|NoEndnote,1057|NoFill,1058|NoLineBreaksAfter,1059|NoLineBreaksBefore,1060|NoMultiLvlLbl,1061|NoProof,1062|NoPunctuationKerning,1063|NoResizeAllowed,1064|NoWrap,1065|Nor,1066|Norm,1067|NormAutofit,1068|NormalViewPr,1069|Notes,1070|NotesMaster,1071|NotesMasterId,1072|NotesMasterIdLst,1073|NotesStyle,1074|NotesSz,1075|NotesTextViewPr,1076|NotesViewPr,1077|Nsid,1078|Null,1079|Num,1080|NumCache,1081|NumDim,1082|NumFmt,1083|NumFmts,1084|NumId,1085|NumIdMacAtCleanup,1086|NumLit,1087|NumPicBullet,1088|NumPr,1089|NumRef,1090|NumRestart,1091|NumStart,1092|NumStyleLink,1093|NumberVolumes,1094|Numbering,1095|NumberingChange,1096|NvCxnSpPr,1097|NvGraphicFramePr,1098|NvGrpSpPr,1099|NvPicPr,1100|NvSpPr,1101|NwCell,1102|OLEObject,1103|OMath,1104|OMathPara,1105|OMathParaPr,1106|ObjDist,1107|Object:object1,1108|ObjectDefaults,1109|Oblob,1110|Oc,1111|OddFooter,1112|OddHeader,1113|Odso,1114|Odxf,1115|OfPieChart,1116|OfPieType,1117|Off,1118|OldFormula,1119|OleItem,1120|OleItems,1121|OleLink,1122|OleObj,1123|OleObject,1124|OleObjects,1125|OleSize,1126|OneCellAnchor,1127|OpEmu,1128|OptimizeForBrowser,1129|Order,1130|OrgChart,1131|Orientation,1132|Origin,1133|Ostorage,1134|Ostream,1135|OtherStyle,1136|OuterShdw,1137|Outline,1138|OutlineLvl,1139|OutlinePr,1140|OutlineViewPr,1141|Oval,1142|OverflowPunct,1143|Overlap,1144|Overlay,1145|OverrideClrMapping,1146|P,1147|PBdr,1148|PPr,1149|PPrDefault,1150|PStyle,1151|Page,1152|PageBreakBefore,1153|PageField,1154|PageFields,1155|PageItem,1156|PageMargins,1157|PageSetUpPr,1158|PageSetup,1159|Pages,1160|Pane,1161|PaperSrc,1162|Param,1163|Parameter,1164|ParentLabelLayout,1165|PatentNumber,1166|Path,1167|PathLst,1168|PattFill,1169|PatternFill,1170|PenClr,1171|Performer,1172|Period,1173|PeriodicalTitle,1174|PermEnd,1175|PermStart,1176|Person,1177|Perspective,1178|PgBorders,1179|PgMar,1180|PgNum,1181|PgNumType,1182|PgSz,1183|Ph,1184|Phant,1185|PhantPr,1186|PhoneticPr,1187|PhotoAlbum,1188|Pic,1189|PicLocks,1190|Pict,1191|Picture,1192|PictureFormat,1193|PictureOptions,1194|PictureStackUnit,1195|Pie3DChart,1196|PieChart,1197|PivotArea,1198|PivotAreas,1199|PivotCache,1200|PivotCacheDefinition,1201|PivotCacheIdVersion,1202|PivotCacheRecords,1203|PivotCaches,1204|PivotChange,1205|PivotChanges,1206|PivotEdit,1207|PivotEdits,1208|PivotField,1209|PivotFields,1210|PivotFilter,1211|PivotFmt,1212|PivotFmts,1213|PivotHierarchies,1214|PivotHierarchy,1215|PivotRow,1216|PivotSelection,1217|PivotSource,1218|PivotTable,1219|PivotTableData,1220|PivotTableDefinition,1221|PivotTableReference,1222|PivotTableReferences,1223|PivotTableStyleInfo,1224|PivotTableUISettings,1225|PivotTables,1226|PixelsPerInch,1227|Placeholder,1228|PlcHide,1229|PlotArea,1230|PlotArea3D,1231|PlotSurface,1232|PlotVisOnly,1233|Plus,1234|Polyline,1235|Pos,1236|PosOffset,1237|Position,1238|PositionH,1239|PositionV,1240|PostSp,1241|PrSet,1242|PreSp,1243|PresLayoutVars,1244|Present,1245|Presentation,1246|PresentationPr,1247|PrevCondLst,1248|PrintFormsData,1249|PrintFractionalCharacterWidth,1250|PrintOptions,1251|PrintPostScriptOverText,1252|PrintSettings,1253|PrintTwoOnOne,1254|PrinterSettings,1255|PrnPr,1256|ProducerName,1257|ProductionCompany,1258|Progress,1259|ProofErr,1260|ProofState,1261|Properties,1262|Property,1263|ProtectedRange,1264|ProtectedRanges,1265|Protection,1266|PrstClr,1267|PrstDash,1268|PrstGeom,1269|PrstShdw,1270|PrstTxWarp,1271|Pt,1272|PtCount,1273|PtLst,1274|Ptab,1275|PublicationTitle,1276|Publisher,1277|Pull,1278|Push,1279|Query,1280|QueryCache,1281|QueryTable,1282|QueryTableDeletedFields,1283|QueryTableField,1284|QueryTableFields,1285|QueryTableRefresh,1286|Question,1287|QuestionPr,1288|Questions,1289|QuestionsPr,1290|QuickTimeFile,1291|R,1292|R4,1293|R8,1294|RAngAx,1295|RCtr,1296|RFonts,1297|RMargin,1298|RPh,1299|RPr,1300|RPrChange,1301|RPrDefault,1302|RSp,1303|RSpRule,1304|RStyle,1305|Rad,1306|RadPr,1307|RadarChart,1308|RadarStyle,1309|Random,1310|RandomBar,1311|Range,1312|RangePr,1313|RangeSet,1314|RangeSets,1315|Ranges,1316|Rc,1317|Rcc,1318|Rcmt,1319|Rcv,1320|ReadModeInkLockDown,1321|RecipientData,1322|Recipients,1323|RecordingNumber,1324|Rect,1325|Red,1326|RedMod,1327|RedOff,1328|Ref,1329|RefOrder,1330|Reference,1331|References,1332|Reflection,1333|RegionLabelLayout,1334|Regular,1335|Rel,1336|RelIds,1337|RelOff,1338|RelSizeAnchor,1339|Relationtable,1340|RelyOnVML,1341|RemoveDateAndTime,1342|RemovePersonalInformation,1343|Reporter,1344|ResizeHandles,1345|RestoredLeft,1346|RestoredTop,1347|Result,1348|Reviewed,1349|ReviewedList,1350|RevisionPtr,1351|RevisionView,1352|Revisions,1353|Rfmt,1354|RFont,1355|RgbColor,1356|Rich,1357|Right,1358|Ris,1359|Raf,1360|Rdn,1361|Rcft,1362|Rqt,1363|Rm,1364|Rot,1365|RotX,1366|RotY,1367|Round,1368|RoundedCorners,1369|Roundrect,1370|Row,1371|RowBreaks,1372|RowFields,1373|RowHierarchiesUsage,1374|RowHierarchyUsage,1375|RowItem,1376|RowItems,1377|Rows,1378|Rrc,1379|Rsid,1380|RsidRoot,1381|Rsids,1382|Rsnm,1383|Rt,1384|Rtl,1385|RtlGutter,1386|Ruby,1387|RubyAlign,1388|RubyBase,1389|RubyPr,1390|Rule,1391|S,1392|SPre,1393|SPrePr,1394|SSub,1395|SSubPr,1396|SSubSup,1397|SSubSupPr,1398|SSup,1399|SSupPr,1400|SampData,1401|Sat,1402|SatMod,1403|SatOff,1404|SaveFormsData,1405|SaveInvalidXml,1406|SavePreviewPicture,1407|SaveSmartTagsAsXml,1408|SaveSubsetFonts,1409|SaveThroughXslt,1410|SaveXmlDataOnly,1411|Scale,1412|Scaling,1413|ScatterChart,1414|ScatterStyle,1415|Scenario,1416|Scenarios,1417|Scene3d,1418|Schema,1419|SchemaLibrary,1420|SchemaRef,1421|SchemaRefs,1422|Scheme,1423|SchemeClr,1424|Scr,1425|ScrgbClr,1426|Scrollbar,1427|Sdt,1428|SdtContent,1429|SdtEndPr,1430|SdtPr,1431|SeCell,1432|SecondPiePt,1433|SecondPieSize,1434|SectPr,1435|SectPrChange,1436|Selection,1437|Selections,1438|SepChr,1439|Separator,1440|Ser,1441|SerAx,1442|SerLines,1443|Series,1444|SeriesAxis,1445|SeriesLine,1446|ServerFormat,1447|ServerFormats,1448|Set,1449|SetLevel,1450|SetLevels,1451|Sets,1452|Settings,1453|Shade,1454|Shadow,1455|Shape,1456|ShapeDefaults,1457|Shapedefaults,1458|Shapelayout,1459|Shapetype,1460|SharedItems,1461|Shd,1462|Sheet,1463|SheetCalcPr,1464|SheetData,1465|SheetDataSet,1466|SheetFormatPr,1467|SheetId,1468|SheetIdMap,1469|SheetName,1470|SheetNames,1471|SheetPr,1472|SheetProtection,1473|SheetView,1474|SheetViews,1475|Sheets,1476|ShortTitle,1477|Show,1478|ShowBubbleSize,1479|ShowCatName,1480|ShowDLblsOverMax,1481|ShowEnvelope,1482|ShowHorzBorder,1483|ShowKeys,1484|ShowLeaderLines,1485|ShowLegendKey,1486|ShowNegBubbles,1487|ShowOutline,1488|ShowPercent,1489|ShowPr,1490|ShowSerName,1491|ShowVal,1492|ShowVertBorder,1493|ShowXMLTags,1494|Shp,1495|Si,1496|SideWall,1497|Signatureline,1498|SimplePos,1499|SingleXmlCell,1500|SingleXmlCells,1501|Size,1502|SizeAuto,1503|SizeRepresents,1504|Skew,1505|Sld,1506|SldAll,1507|SldId,1508|SldIdLst,1509|SldLayout,1510|SldLayoutId,1511|SldLayoutIdLst,1512|SldLst,1513|SldMaster,1514|SldMasterId,1515|SldMasterIdLst,1516|SldRg,1517|SldSyncPr,1518|SldSz,1519|Slicer,1520|SlicerCache,1521|SlicerCacheDefinition,1522|SlicerCacheHideItemsWithNoData,1523|SlicerCacheOlapLevelName,1524|SlicerCachePivotTables,1525|SlicerCaches,1526|SlicerList,1527|SlicerStyle,1528|SlicerStyleElement,1529|SlicerStyleElements,1530|SlicerStyles,1531|Slicers,1532|SlideViewPr,1533|SmallCaps,1534|SmallFrac,1535|SmartTag,1536|SmartTagPr,1537|SmartTagType,1538|SmartTagTypes,1539|SmartTags,1540|Smooth,1541|SnapToGrid,1542|Snd,1543|SndAc,1544|SoftEdge,1545|SoftHyphen,1546|SolidFill,1547|SortByTuple,1548|SortCondition,1549|SortState,1550|SorterViewPr,1551|Source,1552|SourceConnection,1553|SourceFileName,1554|SourceType,1555|Sources,1556|Sp,1557|Sp3d,1558|SpAutoFit,1559|SpcPct,1560|SpcPts,1561|SpDef,1562|SpLocks,1563|SpPr,1564|SpTree,1565|Spacing,1566|Sparkline,1567|SparklineGroup,1568|SparklineGroups,1569|Sparklines,1570|SpcAft,1571|SpcBef,1572|SpecVanish,1573|Split,1574|SplitPos,1575|SplitType,1576|Sqref,1577|Src,1578|SrcRect,1579|SrgbClr,1580|Sst,1581|St,1582|StCondLst,1583|StCxn,1584|StandardNumber,1585|Start,1586|StartOverride,1587|State,1588|StateProvince,1589|Station,1590|Statistics,1591|StockChart,1592|Stop,1593|Storage,1594|StoreMappedDataAs,1595|Stp,1596|StrCache,1597|StrDim,1598|StrLit,1599|StrRef,1600|Stream,1601|Stretch,1602|StrictFirstAndLastChars,1603|Strike,1604|StrikeBLTR,1605|StrikeH,1606|StrikeTLBR,1607|StrikeV,1608|Strips,1609|Stroke,1610|Sty,1611|Style,1612|StyleClr,1613|StyleData,1614|StyleDef,1615|StyleDefHdr,1616|StyleDefHdrLst,1617|StyleLbl,1618|StyleLink,1619|StyleLockQFSet,1620|StyleLockTheme,1621|StylePaneFormatFilter,1622|StylePaneSortMethod,1623|StyleSheet,1624|Styles,1625|Sub,1626|SubDoc,1627|SubHide,1628|SubTnLst,1629|Subtotals,1630|SummaryLength,1631|Sup,1632|SupHide,1633|SuppressAutoHyphens,1634|SuppressLineNumbers,1635|SuppressOverlap,1636|Surface3DChart,1637|SurfaceChart,1638|Survey,1639|SurveyPr,1640|SwCell,1641|Sx,1642|Sy,1643|Sym,1644|Symbol,1645|SysClr,1646|Sz,1647|SzCs,1648|T,1649|Tab,1650|TabColor,1651|TabLst,1652|Table,1653|TableColumn,1654|TableColumns,1655|TablePart,1656|TableParts,1657|TableSlicerCache,1658|TableStyle,1659|TableStyleElement,1660|TableStyleId,1661|TableStyleInfo,1662|TableStyles,1663|Tables,1664|Tabs,1665|Tag,1666|TagLst,1667|Tags,1668|TailEnd,1669|TargetScreenSz,1670|Tav,1671|TavLst,1672|Tbl,1673|TblBg,1674|TblBorders,1675|TblCellMar,1676|TblCellSpacing,1677|TblGrid,1678|TblInd,1679|TblLayout,1680|TblLook,1681|TblOverlap,1682|TblPr,1683|TblStyle,1684|TblStyleColBandSize,1685|TblStyleLst,1686|TblStyleRowBandSize,1687|TblW,1688|TblpPr,1689|Tc,1690|TcBdr,1691|TcBorders,1692|TcFitText,1693|TcMar,1694|TcPr,1695|TcStyle,1696|TcTxStyle,1697|TcW,1698|Text,1699|TextAlignment,1700|TextDirection,1701|TextField,1702|TextFields,1703|Textbox,1704|TextboxTightWrap,1705|Textdata,1706|Textpath,1707|TgtEl,1708|Theater,1709|Theme,1710|ThemeElements,1711|ThemeFontLang,1712|ThemeManager,1713|ThemeOverride,1714|ThesisType,1715|Thickness,1716|TickLabels,1717|TickLblPos,1718|TickLblSkip,1719|TickMarkSkip,1720|Tile,1721|TileRect,1722|Timeline,1723|TimelineCacheDefinition,1724|TimelineCachePivotCaches,1725|TimelineCacheRef,1726|TimelineCacheRefs,1727|TimelinePivotCacheDefinition,1728|TimelinePivotFilter,1729|TimelineRef,1730|TimelineRefs,1731|TimelineStyle,1732|TimelineStyleElement,1733|TimelineStyleElements,1734|TimelineStyles,1735|Timelines,1736|Timing,1737|Tint,1738|Title,1739|TitlePg,1740|TitlePr,1741|TitleStyle,1742|Tl2br,1743|Tmpl,1744|TmplLst,1745|TnLst,1746|To,1747|Top,1748|TopLinePunct,1749|TotalsRowFormula,1750|Tp,1751|Tpl,1752|Tpls,1753|Tr,1754|Tr2bl,1755|TrPr,1756|TrackRevisions,1757|Transition,1758|Translator,1759|Transp,1760|Trendline,1761|TrendlineLabel,1762|TrendlineLbl,1763|TrendlineType,1764|TupleCache,1765|TupleItem,1766|TupleItems,1767|TupleSet,1768|TwoCellAnchor,1769|Tx,1770|TxBody,1771|TxData,1772|TxDef,1773|TxEffectClrLst,1774|TxFillClrLst,1775|TxLinClrLst,1776|TxPr,1777|TxSp,1778|TxStyles,1779|TxbxContent,1780|Type,1781|U,1782|UFill,1783|UFillTx,1784|ULn,1785|ULnTx,1786|Undo,1787|URL,1788|Udl,1789|Ui1,1790|Ui2,1791|Ui4,1792|Ui8,1793|UiCompat97To2003,1794|Uint,1795|UniqueTag,1796|Units,1797|UnitsLabel,1798|Up,1799|UpBar,1800|UpBars,1801|UpDownBars,1802|UpdateFields,1803|UseSpRect,1804|UseXSLTWhenSaving,1805|UserEdit,1806|UserInfo,1807|UserInterface,1808|UserShapes,1809|Users,1810|V,1811|VAlign,1812|VMerge,1813|Val,1814|ValAx,1815|ValScaling,1816|Value,1817|ValueAxis,1818|ValueColorPositions,1819|ValueColors,1820|ValueMetadata,1821|Values,1822|Vanish,1823|Variant,1824|Variation,1825|VaryColors,1826|Vector,1827|Version,1828|VertAlign,1829|VertJc,1830|Vertical,1831|VideoFile,1832|View,1833|View3D,1834|ViewMergedData,1835|ViewPr,1836|Visibility,1837|VolType,1838|VolTypes,1839|Volume,1840|Vstream,1841|W,1842|WMode,1843|Wall,1844|WavAudioFile,1845|WebExtension,1846|WebExtensions,1847|WebHidden,1848|WebPr,1849|WebPublishItem,1850|WebPublishItems,1851|WebPublishObject,1852|WebPublishObjects,1853|WebPublishing,1854|WebSettings,1855|Wedge,1856|Wheel,1857|Whole,1858|WholeTbl,1859|WidowControl,1860|Wipe,1861|Wireframe,1862|WordWrap,1863|Workbook,1864|WorkbookPr,1865|WorkbookProtection,1866|WorkbookView,1867|Worksheet,1868|Wrap,1869|WrapIndent,1870|WrapNone,1871|WrapPolygon,1872|WrapRight,1873|WrapSquare,1874|WrapThrough,1875|WrapTight,1876|WrapTopAndBottom,1877|WriteProtection,1878|Writer,1879|WsDr,1880|X,1881|XMode,1882|XVal,1883|Xf,1884|Xfrm,1885|XmlCellPr,1886|XmlColumnPr,1887|XmlPr,1888|Y,1889|YMode,1890|YVal,1891|Year,1892|YearAccessed,1893|YearLong,1894|YearShort,1895|ZeroAsc,1896|ZeroDesc,1897|ZeroWid,1898|Zoom,1899');
export var UnknownElementAction_$type = markEnum('UnknownElementAction', 'Ignore,0|CacheXml,1|CacheStructure,2|LoadChildrenNormally,3');
export var ShapeType_$type = markEnum('ShapeType', 'NotPrimitive,0|Rectangle,1|RoundRectangle,2|Ellipse,3|Diamond,4|IsocelesTriangle,5|RightTriangle,6|Parallelogram,7|Trapezoid,8|Hexagon,9|Octagon,10|Plus,11|Star,12|Arrow,13|ThickArrow,14|HomePlate,15|Cube,16|Balloon,17|Seal,18|Arc,19|Line,20|Plaque,21|Can,22|Donut,23|TextSimple,24|TextOctagon,25|TextHexagon,26|TextCurve,27|TextWave,28|TextRing,29|TextOnCurve,30|TextOnRing,31|StraightConnector1,32|BentConnector2,33|BentConnector3,34|BentConnector4,35|BentConnector5,36|CurvedConnector2,37|CurvedConnector3,38|CurvedConnector4,39|CurvedConnector5,40|Callout1,41|Callout2,42|Callout3,43|AccentCallout1,44|AccentCallout2,45|AccentCallout3,46|BorderCallout1,47|BorderCallout2,48|BorderCallout3,49|AccentBorderCallout1,50|AccentBorderCallout2,51|AccentBorderCallout3,52|Ribbon,53|Ribbon2,54|Chevron,55|Pentagon,56|NoSmoking,57|Seal8,58|Seal16,59|Seal32,60|WedgeRectCallout,61|WedgeRRectCallout,62|WedgeEllipseCallout,63|Wave,64|FoldedCorner,65|LeftArrow,66|DownArrow,67|UpArrow,68|LeftRightArrow,69|UpDownArrow,70|IrregularSeal1,71|IrregularSeal2,72|LightningBolt,73|Heart,74|PictureFrame,75|QuadArrow,76|LeftArrowCallout,77|RightArrowCallout,78|UpArrowCallout,79|DownArrowCallout,80|LeftRightArrowCallout,81|UpDownArrowCallout,82|QuadArrowCallout,83|Bevel,84|LeftBracket,85|RightBracket,86|LeftBrace,87|RightBrace,88|LeftUpArrow,89|BentUpArrow,90|BentArrow,91|Seal24,92|StripedRightArrow,93|NotchedRightArrow,94|BlockArc,95|SmileyFace,96|VerticalScroll,97|HorizontalScroll,98|CircularArrow,99|NotchedCircularArrow,100|UturnArrow,101|CurvedRightArrow,102|CurvedLeftArrow,103|CurvedUpArrow,104|CurvedDownArrow,105|CloudCallout,106|EllipseRibbon,107|EllipseRibbon2,108|FlowChartProcess,109|FlowChartDecision,110|FlowChartInputOutput,111|FlowChartPredefinedProcess,112|FlowChartInternalStorage,113|FlowChartDocument,114|FlowChartMultidocument,115|FlowChartTerminator,116|FlowChartPreparation,117|FlowChartManualInput,118|FlowChartManualOperation,119|FlowChartConnector,120|FlowChartPunchedCard,121|FlowChartPunchedTape,122|FlowChartSummingJunction,123|FlowChartOr,124|FlowChartCollate,125|FlowChartSort,126|FlowChartExtract,127|FlowChartMerge,128|FlowChartOfflineStorage,129|FlowChartOnlineStorage,130|FlowChartMagneticTape,131|FlowChartMagneticDisk,132|FlowChartMagneticDrum,133|FlowChartDisplay,134|FlowChartDelay,135|TextPlainText,136|TextStop,137|TextTriangle,138|TextTriangleInverted,139|TextChevron,140|TextChevronInverted,141|TextRingInside,142|TextRingOutside,143|TextArchUpCurve,144|TextArchDownCurve,145|TextCircleCurve,146|TextButtonCurve,147|TextArchUpPour,148|TextArchDownPour,149|TextCirclePour,150|TextButtonPour,151|TextCurveUp,152|TextCurveDown,153|TextCascadeUp,154|TextCascadeDown,155|TextWave1,156|TextWave2,157|TextWave3,158|TextWave4,159|TextInflate,160|TextDeflate,161|TextInflateBottom,162|TextDeflateBottom,163|TextInflateTop,164|TextDeflateTop,165|TextDeflateInflate,166|TextDeflateInflateDeflate,167|TextFadeRight,168|TextFadeLeft,169|TextFadeUp,170|TextFadeDown,171|TextSlantUp,172|TextSlantDown,173|TextCanUp,174|TextCanDown,175|FlowChartAlternateProcess,176|FlowChartOffpageConnector,177|Callout90,178|AccentCallout90,179|BorderCallout90,180|AccentBorderCallout90,181|LeftRightUpArrow,182|Sun,183|Moon,184|BracketPair,185|BracePair,186|Seal4,187|DoubleWave,188|ActionButtonBlank,189|ActionButtonHome,190|ActionButtonHelp,191|ActionButtonInformation,192|ActionButtonForwardNext,193|ActionButtonBackPrevious,194|ActionButtonEnd,195|ActionButtonBeginning,196|ActionButtonReturn,197|ActionButtonDocument,198|ActionButtonSound,199|ActionButtonMovie,200|HostControl,201|TextBox,202');
export var OverwriteRoundTripDataResult_$type = markEnum('OverwriteRoundTripDataResult', 'NothingWritten,0|ElementStartWritten,1|ElementAndDescendantsWritten,2');
export var OfficeApplication_$type = markEnum('OfficeApplication', 'Excel,0|Word,1|PowerPoint,2');
export var State_$type = markEnum('State', 'Initial,0|Markup,1|EndTag,2|Attr,3|AttrValue,4|Text,5|PartialTag,6|AutoClose,7|CData,8|PartialText,9|PseudoStartTag,10|Eof,11');
export var CaseFolding_$type = markEnum('CaseFolding', 'None,0|ToUpper,1|ToLower,2');
export var AttributePresence_$type = markEnum('AttributePresence', 'DEFAULT,0|FIXED,1|REQUIRED,2|IMPLIED,3');
export var AttributeType_$type = markEnum('AttributeType', 'DEFAULT,0|CDATA,1|ENTITY,2|ENTITIES,3|ID,4|IDREF,5|IDREFS,6|NAME,7|NAMES,8|NMTOKEN,9|NMTOKENS,10|NUMBER,11|NUMBERS,12|NUTOKEN,13|NUTOKENS,14|NOTATION,15|ENUMERATION,16');
export var Occurrence_$type = markEnum('Occurrence', 'Required,0|Optional,1|ZeroOrMore,2|OneOrMore,3');
export var GroupType_$type = markEnum('GroupType', 'None,0|And,1|Or,2|Sequence,3');
export var DeclaredContent_$type = markEnum('DeclaredContent', 'Default,0|CDATA,1|RCDATA,2|EMPTY,3');
export var LiteralType_$type = markEnum('LiteralType', 'CDATA,0|SDATA,1|PI,2');
var Entity = /** @class */ (function (_super) {
    tslib_1.__extends(Entity, _super);
    function Entity(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.v = null;
        _this.u = null;
        _this.e = false;
        _this.w = null;
        _this.aa = null;
        _this.t = null;
        _this.c = 0;
        _this.b = null;
        _this.d = false;
        _this.n = 0;
        _this.j = '\0';
        _this.g = false;
        _this.ab = null;
        _this.ad = null;
        _this.q = null;
        _this.h = false;
        _this.p = 0;
        _this.m = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    var e = _rest[2];
                    var f = _rest[3];
                    _this.u = c;
                    _this.w = d;
                    _this.aa = e;
                    _this.v = f;
                    _this.d = (c != null && StringUtilitiesSgml.a(c, "html"));
                }
                break;
            case 1:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    _this.u = c;
                    _this.t = d;
                    _this.e = true;
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    var e = _rest[2];
                    var f = _rest[3];
                    _this.u = c;
                    _this.e = true;
                    _this.q = e;
                    _this.ad = d;
                    _this.v = f;
                    _this.d = (stringCompare1(c, "html", StringUtilities.g) == 0);
                }
                break;
        }
        return _this;
    }
    Object.defineProperty(Entity.prototype, "ae", {
        get: function () {
            if (this.ad != null) {
                return this.ad;
            }
            else if (this.b != null) {
                return this.b.ae;
            }
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Entity.prototype, "o", {
        get: function () {
            return this.m - this.p + 1;
        },
        enumerable: true,
        configurable: true
    });
    Entity.prototype.k = function () {
        var a = String.fromCharCode(this.q.b());
        if (a.charCodeAt(0) == 0) {
            a = ' ';
        }
        this.m++;
        if (a.charCodeAt(0) == 10) {
            this.g = true;
            this.p = this.m + 1;
            this.n++;
        }
        else if (a == ' ' || a == '\t') {
            this.g = true;
            if (this.j.charCodeAt(0) == 13) {
                this.p = this.m;
                this.n++;
            }
        }
        else if (a.charCodeAt(0) == 13) {
            this.g = true;
        }
        else {
            this.g = false;
            if (this.j.charCodeAt(0) == 13) {
                this.n++;
                this.p = this.m;
            }
        }
        this.j = a;
        return a;
    };
    Entity.prototype.ak = function (a, b) {
        this.b = a;
        if (a != null) {
            this.d = a.d;
        }
        this.n = 1;
        if (this.e) {
            if (this.t != null) {
                this.q = new StringReader(this.t);
            }
        }
        else if (this.aa == null) {
            this.aj("Unresolvable entity '{0}'", this.u);
        }
        else {
            this.aj("Unresolvable entity '{0}'", this.u);
        }
    };
    Entity.prototype.ac = function () {
        return this.ab;
    };
    Entity.prototype.af = function () {
        if (this.h) {
            this.q.i();
        }
    };
    Entity.prototype.l = function () {
        var a = this.j;
        while (a != "\uffff" && (a == ' ' || a == '\r' || a == '\n' || a == '\t')) {
            a = this.k();
        }
        return a;
    };
    Entity.prototype.z = function (a, b, c) {
        a.c = 0;
        var d = this.j;
        if (c && d != '_' && !isLetter(d)) {
            throw new BaseError(1, stringFormat("Invalid name start character '{0}'", d));
        }
        while (d != "\uffff" && b.indexOf(d) < 0) {
            if (!c || d == '_' || d == '.' || d == '-' || d == ':' || isLetterOrDigit(d)) {
                a.h(d);
            }
            else {
                throw new BaseError(1, stringFormat("Invalid name character '{0}'", d));
            }
            d = this.k();
        }
        return a.toString();
    };
    Entity.prototype.x = function (a, b) {
        a.c = 0;
        var c = this.k();
        while (c != "\uffff" && c != b) {
            if (c == '&') {
                c = this.k();
                if (c == '#') {
                    var d = this.s();
                    a.l(d);
                    c = this.j;
                }
                else {
                    a.h('&');
                    a.h(c);
                    c = this.k();
                }
            }
            else {
                a.h(c);
                c = this.k();
            }
        }
        this.k();
        return a.toString();
    };
    Entity.prototype.y = function (a, b, c) {
        if (a != null) {
            a.c = 0;
        }
        var d = this.n;
        var e = this.k();
        var f = 0;
        var g = c.charAt(f);
        while (e != "\uffff") {
            if (e == g) {
                f++;
                if (f >= c.length) {
                    break;
                }
                g = c.charAt(f);
            }
            else if (f > 0) {
                var h = f - 1;
                var i = 0;
                while (h >= 0 && i == 0) {
                    if (c.charAt(h) == e) {
                        var j = 1;
                        while (h - j >= 0) {
                            if (c.charAt(h - j) != c.charAt(f - j)) {
                                break;
                            }
                            j++;
                        }
                        if (j > h) {
                            i = h + 1;
                        }
                    }
                    else {
                        h--;
                    }
                }
                if (a != null) {
                    h = (h < 0) ? 1 : 0;
                    for (var k = 0; k <= f - i - h; k++) {
                        a.h(c.charAt(k));
                    }
                    if (h > 0) {
                        a.h(e);
                    }
                }
                f = i;
                g = c.charAt(i);
            }
            else {
                if (a != null) {
                    a.h(e);
                }
            }
            e = this.k();
        }
        if (e.charCodeAt(0) == 0) {
            this.ai(b + " starting on line {0} was never closed", d);
        }
        this.k();
        if (a != null) {
            return a.toString();
        }
        return "";
    };
    Entity.prototype.s = function () {
        var a = this.k();
        var b = 0;
        if (a == 'x') {
            a = this.k();
            for (; a != "\uffff" && a != ';'; a = this.k()) {
                var c = 0;
                if (a.charCodeAt(0) >= '0'.charCodeAt(0) && a.charCodeAt(0) <= '9'.charCodeAt(0)) {
                    c = (a.charCodeAt(0) - '0'.charCodeAt(0));
                }
                else if (a.charCodeAt(0) >= 'a'.charCodeAt(0) && a.charCodeAt(0) <= 'f'.charCodeAt(0)) {
                    c = (a.charCodeAt(0) - 'a'.charCodeAt(0)) + 10;
                }
                else if (a.charCodeAt(0) >= 'A'.charCodeAt(0) && a.charCodeAt(0) <= 'F'.charCodeAt(0)) {
                    c = (a.charCodeAt(0) - 'A'.charCodeAt(0)) + 10;
                }
                else {
                    break;
                }
                b = (b * 16) + c;
            }
        }
        else {
            for (; a != "\uffff" && a != ';'; a = this.k()) {
                if (a.charCodeAt(0) >= '0'.charCodeAt(0) && a.charCodeAt(0) <= '9'.charCodeAt(0)) {
                    b = (b * 10) + (a.charCodeAt(0) - '0'.charCodeAt(0));
                }
                else {
                    break;
                }
            }
        }
        if (a.charCodeAt(0) == 0) {
            this.ah("Premature {0} parsing entity reference", a);
        }
        else if (a == ';') {
            this.k();
        }
        if (this.d && b >= 128 && b <= 159) {
            var d = Entity.a.length;
            var e = b - 128;
            var f = Entity.a[e];
            return Convert.toChar1(f).toString();
        }
        return Convert.toChar1(b).toString();
    };
    Entity.prototype.ag = function (a) {
        throw new BaseError(1, a);
    };
    Entity.prototype.ah = function (a, b) {
        var c = (b == "\uffff") ? "EOF" : b.toString();
        throw new BaseError(1, stringFormat(a, c));
    };
    Entity.prototype.ai = function (a, b) {
        throw new BaseError(1, stringFormat(a, b));
    };
    Entity.prototype.aj = function (a, b) {
        throw new BaseError(1, stringFormat(a, b));
    };
    Entity.prototype.r = function () {
        var a = this;
        var b = new StringBuilder(0);
        while (a != null) {
            var c = void 0;
            if (a.e) {
                c = stringFormat("\nReferenced on line {0}, position {1} of internal entity '{2}'", a.n, a.o, a.u);
            }
            else {
                c = stringFormat1("\nReferenced on line {0}, position {1} of '{2}' entity at [{3}]", a.n, a.o, a.u, a.ae.absolutePath);
            }
            b.l(c);
            a = a.b;
        }
        return b.toString();
    };
    Entity.f = function (a) {
        return (a == "CDATA" || a == "SDATA" || a == "PI");
    };
    Entity.prototype.al = function (a) {
        switch (a) {
            case "CDATA":
                this.c = 0;
                break;
            case "SDATA":
                this.c = 1;
                break;
            case "PI":
                this.c = 2;
                break;
        }
    };
    Entity.$t = markType(Entity, 'Entity');
    Entity.a = [8364, 129, 8218, 402, 8222, 8230, 8224, 8225, 710, 8240, 352, 8249, 338, 141, 381, 143, 144, 8216, 8217, 8220, 8221, 8226, 8211, 8212, 732, 8482, 353, 8250, 339, 157, 382, 376];
    return Entity;
}(Base));
export { Entity };
var HtmlStream = /** @class */ (function (_super) {
    tslib_1.__extends(HtmlStream, _super);
    function HtmlStream(a, b) {
        var _this = _super.call(this) || this;
        _this._x = null;
        _this._l = null;
        _this._r = 0;
        _this._s = 0;
        _this._ah = null;
        _this._ae = null;
        _this._k = null;
        _this._v = 0;
        _this._q = 0;
        if (b == null) {
            b = Encoding.uTF8;
        }
        if (!a.canSeek) {
            a = _this._w(a);
        }
        _this._x = a;
        _this._l = new Array(16384);
        _this._s = a.read(_this._l, 0, 4);
        _this._k = new Array(16384);
        _this._ae = ((function () { var c = HtmlStream._ad(_this._l, _this._r, _this._s); _this._r = c.p1; return c.ret; })());
        var c = _this._r;
        if (_this._ae == null) {
            _this._ae = b.getDecoder();
            _this._s += a.read(_this._l, 4, 16384 - 4);
            _this._aj();
            var d = _this._af();
            if (d != null) {
                _this._ae = d;
            }
        }
        _this._x.seek(0, 0);
        _this._q = _this._v = 0;
        if (c > 0) {
            a.read(_this._l, 0, c);
        }
        _this._r = _this._s = 0;
        return _this;
    }
    Object.defineProperty(HtmlStream.prototype, "_ai", {
        get: function () {
            return this._ah;
        },
        enumerable: true,
        configurable: true
    });
    HtmlStream.prototype._w = function (a) {
        var b = 100000;
        var c = new Array(b);
        var d;
        var e = new MemoryStream(0);
        while ((d = a.read(c, 0, b)) > 0) {
            e.write(c, 0, d);
        }
        e.seek(0, 0);
        a.dispose();
        return e;
    };
    HtmlStream.prototype._aj = function () {
        if (this._q > 0) {
            if (this._q < this._v) {
                arrayCopy1(this._k, this._q, this._k, 0, this._v - this._q);
            }
            this._v -= this._q;
            this._q = 0;
        }
        var a = this._ae.a(this._l, this._r, this._s - this._r);
        var b = this._k.length - this._v;
        if (b < a) {
            var c = new Array(this._k.length + a);
            arrayCopy1(this._k, this._q, c, 0, this._v - this._q);
            this._k = c;
        }
        this._v = this._q + this._ae.c(this._l, this._r, this._s - this._r, this._k, this._q);
        this._r = this._s;
    };
    HtmlStream._ad = function (a, b, c) {
        if (4 <= (c - b)) {
            var d = u32BitwiseOr(u32BitwiseOr(u32BitwiseOr(u32LS(a[b + 0], 24), u32LS(a[b + 1], 16)), u32LS(a[b + 2], 8)), a[b + 3]);
            var t1 = d;
            L0: while (true) {
                switch (t1) {
                    case 4278189823:
                        b += 4;
                        return {
                            ret: new Ucs4DecoderBigEngian(),
                            p1: b
                        };
                    case 4294901758:
                        b += 4;
                        return {
                            ret: new Ucs4DecoderLittleEndian(),
                            p1: b
                        };
                    case 1006632960:
                        t1 = 4278189823;
                        continue L0;
                    case 60:
                        t1 = 4294901758;
                        continue L0;
                }
                break;
            }
            d >>>= 8;
            if (d == 15711167) {
                b += 3;
                return {
                    ret: Encoding.uTF8.getDecoder(),
                    p1: b
                };
            }
            d >>>= 8;
            {
                var t1_1 = d;
                L0: while (true) {
                    switch (t1_1) {
                        case 65279:
                            b += 2;
                            return {
                                ret: Encoding.bigEndianUnicode.getDecoder(),
                                p1: b
                            };
                        case 65534:
                            b += 2;
                            return {
                                ret: new UnicodeEncoding(1, false, false).getDecoder(),
                                p1: b
                            };
                        case 15360:
                            t1_1 = 65279;
                            continue L0;
                        case 60:
                            t1_1 = 65534;
                            continue L0;
                    }
                    break;
                }
            }
        }
        return {
            ret: null,
            p1: b
        };
    };
    HtmlStream.prototype._t = function () {
        if (this._q < this._v) {
            return this._k[this._q++].charCodeAt(0);
        }
        return -1;
    };
    HtmlStream.prototype._p = function () {
        var a = this._t();
        if (a != -1) {
            this._q--;
        }
        return a;
    };
    HtmlStream.prototype._m = function (a) {
        var b = this._p();
        if (b != a.charAt(0).charCodeAt(0)) {
            return false;
        }
        for (var c = 0, d = a.length; b != -1 && c < d; c++) {
            b = this._t();
            var e = a.charAt(c);
            if (b != e.charCodeAt(0)) {
                return false;
            }
        }
        return true;
    };
    HtmlStream.prototype._an = function () {
        var a = String.fromCharCode(this._p());
        while (a == ' ' || a == '\t' || a == '\r' || a == '\n') {
            var b = this._q;
            a = String.fromCharCode(this._t());
            if (a != ' ' && a != '\t' && a != '\r' && a != '\n') {
                this._q = b;
            }
        }
    };
    HtmlStream.prototype._ab = function () {
        var a = this._p();
        if (a == '\''.charCodeAt(0) || a == '\"'.charCodeAt(0)) {
            this._t();
            var b = this._q;
            var c = this._t();
            while (c != -1 && c != a) {
                c = this._t();
            }
            return (this._q > b) ? stringCreateFromCharArraySlice(this._k, b, this._q - b - 1) : "";
        }
        return null;
    };
    HtmlStream.prototype._z = function (a) {
        this._an();
        var b = this._ac();
        if (a == b) {
            this._an();
            if (this._m("=")) {
                this._an();
                return this._ab();
            }
        }
        return null;
    };
    HtmlStream.prototype._aa = function (a) {
        this._an();
        a = this._ac();
        if (a != null) {
            this._an();
            if (this._m("=")) {
                this._an();
                return {
                    ret: this._ab(),
                    p0: a
                };
            }
        }
        return {
            ret: null,
            p0: a
        };
    };
    HtmlStream.prototype._am = function (a) {
        var b = this._t();
        var c = 0;
        var d = a.length;
        while (c < d && b != -1) {
            if (a.charAt(c).charCodeAt(0) == b) {
                c++;
                if (c == d) {
                    break;
                }
            }
            else {
                c = 0;
            }
            b = this._t();
        }
    };
    HtmlStream.prototype._af = function () {
        var a = null;
        if (this._m("<?xml")) {
            var b = this._z("version");
            if (b != null) {
                var c = this._z("encoding");
                if (c != null) {
                    try {
                        var d = Encoding.getEncoding(c);
                        if (d != null) {
                            this._ah = d;
                            return d.getDecoder();
                        }
                    }
                    catch (e) {
                    }
                }
                this._am(">");
            }
        }
        if (a == null) {
            return this._ag();
        }
        return null;
    };
    HtmlStream.prototype._ag = function () {
        var _this = this;
        var a = this._t();
        var _loop_1 = function () {
            var b = String.fromCharCode(a);
            if (b == '<') {
                var c_1 = this_1._ac();
                if (c_1 != null && StringUtilitiesSgml.a(c_1, "meta")) {
                    var d = null;
                    var e = null;
                    while (true) {
                        var f = ((function () { var g = _this._aa(c_1); c_1 = g.p0; return g.ret; })());
                        if (c_1 == null) {
                            break;
                        }
                        if (StringUtilitiesSgml.a(c_1, "http-equiv")) {
                            d = f;
                        }
                        else if (StringUtilitiesSgml.a(c_1, "content")) {
                            e = f;
                        }
                    }
                    if (d != null && StringUtilitiesSgml.a(d, "content-type") && e != null) {
                        var g = e.indexOf("charset");
                        if (g >= 0) {
                            g = e.indexOf("=", g);
                            if (g >= 0) {
                                g++;
                                var h = e.indexOf(";", g);
                                if (h < 0) {
                                    h = e.length;
                                }
                                var i = e.substr(g, h - g).trim();
                                try {
                                    var j = Encoding.getEncoding(i);
                                    this_1._ah = j;
                                    return { value: j.getDecoder() };
                                }
                                catch (k) {
                                }
                            }
                        }
                    }
                }
            }
            a = this_1._t();
        };
        var this_1 = this;
        while (a != -1) {
            var state_1 = _loop_1();
            if (typeof state_1 === "object")
                return state_1.value;
        }
        return null;
    };
    HtmlStream.prototype._ac = function () {
        var a = this._p();
        if (a == -1) {
            return null;
        }
        var b = String.fromCharCode(a);
        var c = this._q;
        while (this._q < this._v - 1 && (isLetterOrDigit(b) || b == '-' || b == '_' || b == ':')) {
            b = this._k[++this._q];
        }
        if (c == this._q) {
            return null;
        }
        return stringCreateFromCharArraySlice(this._k, c, this._q - c);
    };
    HtmlStream.prototype._al = function () {
        var a = String.fromCharCode(this._p());
        while (this._q < this._v - 1 && (a == ' ' || a == '\r' || a == '\n')) {
            a = this._k[++this._q];
        }
    };
    HtmlStream.prototype._ak = function (a) {
        var b = String.fromCharCode(this._p());
        while (this._q < this._v - 1 && (b != a)) {
            b = this._k[++this._q];
        }
    };
    HtmlStream.prototype._y = function () {
        this._ak('=');
        if (this._q < this._v) {
            this._q++;
            this._al();
            if (this._q < this._v) {
                var a = this._k[this._q];
                this._q++;
                var b = this._q;
                this._ak(a);
                if (this._q < this._v) {
                    var c = stringCreateFromCharArraySlice(this._k, b, this._q - b);
                    this._q++;
                    return c;
                }
            }
        }
        return null;
    };
    HtmlStream.prototype.a = function () {
        var a = this.b();
        if (a != -1) {
            this._q--;
        }
        return a;
    };
    HtmlStream.prototype.b = function () {
        if (this._q == this._v) {
            this._s = this._x.read(this._l, 0, this._l.length);
            this._r = 0;
            if (this._s == 0) {
                return -1;
            }
            this._aj();
        }
        if (this._q < this._v) {
            return this._k[this._q++].charCodeAt(0);
        }
        return -1;
    };
    HtmlStream.prototype.c = function (a, b, c) {
        if (this._q == this._v) {
            this._s = this._x.read(this._l, 0, this._l.length);
            this._r = 0;
            if (this._s == 0) {
                return -1;
            }
            this._aj();
        }
        if (this._q < this._v) {
            c = Math.min(this._v - this._q, c);
            arrayCopy1(this._k, this._q, a, b, c);
            this._q += c;
            return c;
        }
        return 0;
    };
    HtmlStream.prototype.d = function (a, b, c) {
        return this.c(a, b, c);
    };
    HtmlStream.prototype._u = function (a, b, c) {
        var d = 0;
        var e = this._t();
        while (e != -1) {
            a[d + b] = String.fromCharCode(e);
            d++;
            if (d + b == c) {
                break;
            }
            if (e == '\r'.charCodeAt(0)) {
                if (this._p() == '\n'.charCodeAt(0)) {
                    e = this._t();
                    a[d + b] = String.fromCharCode(e);
                    d++;
                }
                break;
            }
            else if (e == '\n'.charCodeAt(0)) {
                break;
            }
            e = this._t();
        }
        return d;
    };
    HtmlStream.prototype.h = function () {
        var a = new Array(100000);
        var b = 0;
        var c = new StringBuilder(0);
        while ((b = this.c(a, 0, a.length)) > 0) {
            c.g(a, 0, b);
        }
        return c.toString();
    };
    HtmlStream.prototype.dispose1 = function (a) {
        if (a) {
            this._x.dispose();
        }
    };
    HtmlStream.$t = markType(HtmlStream, 'HtmlStream', TextReader.$);
    return HtmlStream;
}(TextReader));
export { HtmlStream };
var Ucs4Decoder = /** @class */ (function (_super) {
    tslib_1.__extends(Ucs4Decoder, _super);
    function Ucs4Decoder() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._g = new Array(4);
        _this._j = 0;
        return _this;
    }
    Ucs4Decoder.prototype.a = function (a, b, c) {
        return intDivide((c + this._j), 4);
    };
    Ucs4Decoder.prototype.c = function (a, b, c, d, e) {
        var f = this._j;
        if (this._j > 0) {
            for (; f < 4; f++) {
                this._g[f] = a[b];
                b++;
                c--;
            }
            f = 1;
            this._i(this._g, 0, 4, d, e);
            e++;
        }
        else {
            f = 0;
        }
        f = this._i(a, b, c, d, e) + f;
        var g = (this._j + c) % 4;
        c += b;
        b = c - g;
        this._j = 0;
        if (b >= 0) {
            for (; b < c; b++) {
                this._g[this._j] = a[b];
                this._j++;
            }
        }
        return f;
    };
    Ucs4Decoder.prototype._h = function (a) {
        var b, c;
        b = (55232 + (a >>> 10));
        c = (u32BitwiseOr(56320, a & 1023));
        return String.fromCharCode(((c << 8) | b));
    };
    Ucs4Decoder.$t = markType(Ucs4Decoder, 'Ucs4Decoder', Decoder.$);
    return Ucs4Decoder;
}(Decoder));
export { Ucs4Decoder };
var Ucs4DecoderBigEngian = /** @class */ (function (_super) {
    tslib_1.__extends(Ucs4DecoderBigEngian, _super);
    function Ucs4DecoderBigEngian() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Ucs4DecoderBigEngian.prototype._i = function (a, b, c, d, e) {
        var f;
        var g, h;
        c += b;
        for (g = b, h = e; g + 3 < c;) {
            f = ((((a[g + 3]) << 24) | (a[g + 2] << 16) | (a[g + 1] << 8) | (a[g])));
            if (f > 1114111) {
                throw new BaseError(1, "Invalid character 0x" + intToString1(f, "x") + " in encoding");
            }
            else if (f > 65535) {
                d[h] = this._h(f);
                h++;
            }
            else {
                if (f >= 55296 && f <= 57343) {
                    throw new BaseError(1, "Invalid character 0x" + intToString1(f, "x") + " in encoding");
                }
                else {
                    d[h] = String.fromCharCode(f);
                }
            }
            h++;
            g += 4;
        }
        return h - e;
    };
    Ucs4DecoderBigEngian.$t = markType(Ucs4DecoderBigEngian, 'Ucs4DecoderBigEngian', Ucs4Decoder.$);
    return Ucs4DecoderBigEngian;
}(Ucs4Decoder));
export { Ucs4DecoderBigEngian };
var Ucs4DecoderLittleEndian = /** @class */ (function (_super) {
    tslib_1.__extends(Ucs4DecoderLittleEndian, _super);
    function Ucs4DecoderLittleEndian() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Ucs4DecoderLittleEndian.prototype._i = function (a, b, c, d, e) {
        var f;
        var g, h;
        c += b;
        for (g = b, h = e; g + 3 < c;) {
            f = ((((a[g]) << 24) | (a[g + 1] << 16) | (a[g + 2] << 8) | (a[g + 3])));
            if (f > 1114111) {
                throw new BaseError(1, "Invalid character 0x" + intToString1(f, "x") + " in encoding");
            }
            else if (f > 65535) {
                d[h] = this._h(f);
                h++;
            }
            else {
                if (f >= 55296 && f <= 57343) {
                    throw new BaseError(1, "Invalid character 0x" + intToString1(f, "x") + " in encoding");
                }
                else {
                    d[h] = String.fromCharCode(f);
                }
            }
            h++;
            g += 4;
        }
        return h - e;
    };
    Ucs4DecoderLittleEndian.$t = markType(Ucs4DecoderLittleEndian, 'Ucs4DecoderLittleEndian', Ucs4Decoder.$);
    return Ucs4DecoderLittleEndian;
}(Ucs4Decoder));
export { Ucs4DecoderLittleEndian };
var ElementDecl = /** @class */ (function (_super) {
    tslib_1.__extends(ElementDecl, _super);
    function ElementDecl(a, b, c, d, e, f) {
        var _this = _super.call(this) || this;
        _this.i = null;
        _this.h = false;
        _this.g = false;
        _this.e = null;
        _this.b = null;
        _this.a = null;
        _this.d = null;
        _this.i = a;
        _this.h = b;
        _this.g = c;
        _this.e = d;
        _this.b = e;
        _this.a = f;
        return _this;
    }
    ElementDecl.prototype.c = function (a) {
        return this.d._item(a.toUpperCase());
    };
    ElementDecl.prototype.j = function (a) {
        if (this.d == null) {
            this.d = a;
        }
        else {
            try {
                for (var _0 = tslib_1.__values(fromEn(a)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                    var b = _1.value;
                    if (this.d._item(b.f) == null) {
                        this.d._c(b);
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
                }
                finally { if (e_1) throw e_1.error; }
            }
        }
        var e_1, _2;
    };
    ElementDecl.prototype.f = function (a, b) {
        if (this.a != null) {
            var e = this.a;
            for (var d = 0; d < e.length; d++) {
                var c = e[d];
                if (c == a) {
                    return false;
                }
            }
        }
        if (this.b != null) {
            var h = this.b;
            for (var g = 0; g < h.length; g++) {
                var f = h[g];
                if (f == a) {
                    return true;
                }
            }
        }
        return this.e.c(a, b);
    };
    ElementDecl.$t = markType(ElementDecl, 'ElementDecl');
    return ElementDecl;
}(Base));
export { ElementDecl };
var ContentModel = /** @class */ (function (_super) {
    tslib_1.__extends(ContentModel, _super);
    function ContentModel() {
        var _this = _super.call(this) || this;
        _this.a = 0;
        _this.d = 0;
        _this.b = null;
        _this.b = new Group(null);
        return _this;
    }
    ContentModel.prototype.i = function () {
        this.b = new Group(this.b);
        this.d++;
    };
    ContentModel.prototype.e = function () {
        if (this.d == 0) {
            return -1;
        }
        this.d--;
        this.b.a.i(this.b);
        this.b = this.b.a;
        return this.d;
    };
    ContentModel.prototype.h = function (a) {
        this.b.k(a);
    };
    ContentModel.prototype.f = function (a) {
        this.b.h(a);
    };
    ContentModel.prototype.g = function (a) {
        this.b.j(a);
    };
    ContentModel.prototype.j = function (a) {
        switch (a) {
            case "EMPTY":
                this.a = 3;
                break;
            case "RCDATA":
                this.a = 2;
                break;
            case "CDATA":
                this.a = 1;
                break;
            default: throw new BaseError(1, stringFormat("Declared content type '{0}' is not supported", a));
        }
    };
    ContentModel.prototype.c = function (a, b) {
        if (this.a != 0) {
            return false;
        }
        return this.b.d(a, b);
    };
    ContentModel.$t = markType(ContentModel, 'ContentModel');
    return ContentModel;
}(Base));
export { ContentModel };
var Group = /** @class */ (function (_super) {
    tslib_1.__extends(Group, _super);
    function Group(a) {
        var _this = _super.call(this) || this;
        _this.a = null;
        _this.g = null;
        _this.b = 0;
        _this.c = 0;
        _this.e = false;
        _this.a = a;
        _this.g = new List$1(Base.$, 0);
        _this.b = 0;
        _this.c = 0;
        return _this;
    }
    Object.defineProperty(Group.prototype, "f", {
        get: function () {
            return this.e && this.g.count == 0;
        },
        enumerable: true,
        configurable: true
    });
    Group.prototype.i = function (a) {
        this.g.add1(a);
    };
    Group.prototype.k = function (a) {
        if (a == "#PCDATA") {
            this.e = true;
        }
        else {
            this.g.add1(a);
        }
    };
    Group.prototype.h = function (a) {
        if (!this.e && this.g.count == 0) {
            throw new BaseError(1, stringFormat("Missing token before connector '{0}'.", a));
        }
        var b = 0;
        switch (a) {
            case ',':
                b = 3;
                break;
            case '|':
                b = 2;
                break;
            case '&':
                b = 1;
                break;
        }
        if (this.b != 0 && this.b != b) {
            throw new BaseError(1, stringFormat("Connector '{0}' is inconsistent with {1} group.", a, EnumUtil.getName(GroupType_$type, this.b)));
        }
        this.b = b;
    };
    Group.prototype.j = function (a) {
        var b = 0;
        switch (a) {
            case '?':
                b = 1;
                break;
            case '+':
                b = 3;
                break;
            case '*':
                b = 2;
                break;
        }
        this.c = b;
    };
    Group.prototype.d = function (a, b) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(this.g)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                if (typeof c === 'string') {
                    if (c == a) {
                        return true;
                    }
                }
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_2) throw e_2.error; }
        }
        try {
            for (var _3 = tslib_1.__values(fromEnum(this.g)), _4 = _3.next(); !_4.done; _4 = _3.next()) {
                var d = _4.value;
                if (typeof d === 'string') {
                    var e = d;
                    var f = b.d(e);
                    if (f != null) {
                        if (f.h) {
                            if (f.f(a, b)) {
                                return true;
                            }
                        }
                    }
                }
                else {
                    var g = d;
                    if (g.d(a, b)) {
                        return true;
                    }
                }
            }
        }
        catch (e_3_1) { e_3 = { error: e_3_1 }; }
        finally {
            try {
                if (_4 && !_4.done && (_5 = _3.return)) _5.call(_3);
            }
            finally { if (e_3) throw e_3.error; }
        }
        return false;
        var e_2, _2, e_3, _5;
    };
    Group.$t = markType(Group, 'Group');
    return Group;
}(Base));
export { Group };
var AttDef = /** @class */ (function (_super) {
    tslib_1.__extends(AttDef, _super);
    function AttDef(a) {
        var _this = _super.call(this) || this;
        _this.f = null;
        _this.c = 0;
        _this.a = null;
        _this.e = null;
        _this.b = 0;
        _this.f = a;
        return _this;
    }
    AttDef.prototype.g = function (a) {
        switch (a) {
            case "CDATA":
                this.c = 1;
                break;
            case "ENTITY":
                this.c = 2;
                break;
            case "ENTITIES":
                this.c = 3;
                break;
            case "ID":
                this.c = 4;
                break;
            case "IDREF":
                this.c = 5;
                break;
            case "IDREFS":
                this.c = 6;
                break;
            case "NAME":
                this.c = 7;
                break;
            case "NAMES":
                this.c = 8;
                break;
            case "NMTOKEN":
                this.c = 9;
                break;
            case "NMTOKENS":
                this.c = 10;
                break;
            case "NUMBER":
                this.c = 11;
                break;
            case "NUMBERS":
                this.c = 12;
                break;
            case "NUTOKEN":
                this.c = 13;
                break;
            case "NUTOKENS":
                this.c = 14;
                break;
            default: throw new BaseError(1, "Attribute type '" + a + "' is not supported");
        }
    };
    AttDef.prototype.d = function (a) {
        var b = true;
        if (a == "FIXED") {
            this.b = 1;
        }
        else if (a == "REQUIRED") {
            this.b = 2;
            b = false;
        }
        else if (a == "IMPLIED") {
            this.b = 3;
            b = false;
        }
        else {
            throw new BaseError(1, stringFormat("Attribute value '{0}' not supported", a));
        }
        return b;
    };
    AttDef.$t = markType(AttDef, 'AttDef');
    return AttDef;
}(Base));
export { AttDef };
var AttList = /** @class */ (function (_super) {
    tslib_1.__extends(AttList, _super);
    function AttList() {
        var _this = _super.call(this) || this;
        _this._b = null;
        _this._b = new Dictionary$2(String_$type, AttDef.$, 0);
        return _this;
    }
    AttList.prototype._c = function (a) {
        this._b.addItem(a.f, a);
    };
    AttList.prototype._item = function (a) {
        return this._b.item(a);
    };
    AttList.prototype.getEnumeratorObject = function () {
        return getEnumerator(this._b.values);
    };
    AttList.$t = markType(AttList, 'AttList', Base.$, [IEnumerable_$type]);
    return AttList;
}(Base));
export { AttList };
var SgmlDtd = /** @class */ (function (_super) {
    tslib_1.__extends(SgmlDtd, _super);
    function SgmlDtd(a, b) {
        var _this = _super.call(this) || this;
        _this.r = null;
        _this.m = null;
        _this.o = null;
        _this.n = null;
        _this.w = null;
        _this.e = null;
        _this.am = null;
        _this.am = b;
        _this.r = a;
        _this.m = new Dictionary$2(String_$type, ElementDecl.$, 0);
        _this.o = new Dictionary$2(String_$type, Entity.$, 0);
        _this.n = new Dictionary$2(String_$type, Entity.$, 0);
        _this.w = new StringBuilder(0);
        return _this;
    }
    Object.defineProperty(SgmlDtd.prototype, "an", {
        get: function () {
            return this.am;
        },
        enumerable: true,
        configurable: true
    });
    SgmlDtd.j = function (a, b, c, d, e, f, g) {
        var h = new SgmlDtd(b, g);
        if (d != null && d != "") {
            h.al(a, new Entity(0, h.r, c, d, f));
        }
        if (e != null && e != "") {
            h.al(a, new Entity(1, b, e));
        }
        try {
            h.x();
        }
        catch (i) {
            throw new BaseError(1, i.message + h.e.r());
        }
        return h;
    };
    SgmlDtd.i = function (a, b, c, d, e, f, g) {
        var h = new SgmlDtd(b, g);
        h.al(a, new Entity(2, h.r, a, d, f));
        if (e != null && e != "") {
            h.al(a, new Entity(1, b, e));
        }
        try {
            h.x();
        }
        catch (i) {
            throw new BaseError(1, i.message + h.e.r());
        }
        return h;
    };
    SgmlDtd.prototype.f = function (a) {
        return this.n.item(a);
    };
    SgmlDtd.prototype.d = function (a) {
        return this.m.item(a.toUpperCase());
    };
    SgmlDtd.prototype.al = function (a, b) {
        b.ak(this.e, a);
        this.e = b;
        this.e.k();
    };
    SgmlDtd.prototype.ak = function () {
        if (this.e != null) {
            this.e.af();
        }
        if (this.e.b != null) {
            this.e = this.e.b;
        }
        else {
            this.e = null;
        }
    };
    SgmlDtd.prototype.x = function () {
        var a = this.e.j;
        while (true) {
            switch (a) {
                case "\uffff":
                    this.ak();
                    if (this.e == null) {
                        return;
                    }
                    a = this.e.j;
                    break;
                case ' ':
                case '\n':
                case '\r':
                case '\t':
                    a = this.e.k();
                    break;
                case '<':
                    this.ah();
                    a = this.e.k();
                    break;
                case '%':
                    var b = this.h(SgmlDtd.v);
                    try {
                        this.al(this.e.ae, b);
                    }
                    catch (c) {
                    }
                    a = this.e.j;
                    break;
                default:
                    this.e.ah("Unexpected character '{0}'", a);
                    break;
            }
        }
    };
    SgmlDtd.prototype.ah = function () {
        var a = this.e.k();
        if (a != '!') {
            this.e.ag("Found '{0}', but expecing declaration starting with '<!'");
            return;
        }
        a = this.e.k();
        if (a == '-') {
            a = this.e.k();
            if (a != '-') {
                this.e.ah("Expecting comment '<!--' but found {0}", a);
            }
            this.e.y(this.w, "Comment", "-->");
        }
        else if (a == '[') {
            this.ag();
        }
        else {
            var b = this.e.z(this.w, SgmlDtd.v, true);
            switch (b) {
                case "ENTITY":
                    this.ad();
                    break;
                case "ELEMENT":
                    this.ac();
                    break;
                case "ATTLIST":
                    this.z();
                    break;
                default:
                    this.e.aj("Invalid declaration '<!{0}'.  Expecting 'ENTITY', 'ELEMENT' or 'ATTLIST'.", b);
                    break;
            }
        }
    };
    SgmlDtd.prototype.l = function () {
        var a = this.e.j;
        while (a == '-') {
            a = this.k(true);
        }
        return a;
    };
    SgmlDtd.prototype.k = function (a) {
        var b = this.e.n;
        var c = this.e.k();
        if (a && c != '-') {
            this.e.ah("Expecting comment delimiter '--' but found {0}", c);
        }
        this.e.y(this.w, "Markup Comment", "--");
        return this.e.l();
    };
    SgmlDtd.prototype.ag = function () {
        this.e.k();
        var a = this.u("[");
        if (a == "INCLUDE") {
            this.af();
        }
        else if (a == "IGNORE") {
            this.ae();
        }
        else {
            this.e.aj("Unsupported marked section type '{0}'", a);
        }
    };
    SgmlDtd.prototype.af = function () {
        throw new NotImplementedException(1, "Include Section");
    };
    SgmlDtd.prototype.ae = function () {
        var a = this.e.n;
        var b = this.e.l();
        if (b != '[') {
            this.e.ah("Expecting '[' but found {0}", b);
        }
        this.e.y(this.w, "Conditional Section", "]]>");
    };
    SgmlDtd.prototype.u = function (a) {
        var b = this.e.l();
        if (b == '%') {
            var c = this.h(a);
            b = this.e.j;
            if (!c.e) {
                throw new NotSupportedException(1, "External parameter entity resolution");
            }
            return c.t.trim();
        }
        else {
            return this.e.z(this.w, a, true);
        }
    };
    SgmlDtd.prototype.h = function (a) {
        var b = this.e.k();
        var c = this.e.z(this.w, ";" + a, false);
        c = this.am.b(c);
        if (this.e.j == ';') {
            this.e.k();
        }
        var d = this.g(c);
        return d;
    };
    SgmlDtd.prototype.g = function (a) {
        var b = this.o.item(a);
        if (b == null) {
            this.e.aj("Reference to undefined parameter entity '{0}'", a);
        }
        return b;
    };
    SgmlDtd.prototype.ad = function () {
        var a = this.e.l();
        var b = (a == '%');
        if (b) {
            this.e.k();
            a = this.e.l();
        }
        var c = this.e.z(this.w, SgmlDtd.v, true);
        c = this.am.b(c);
        a = this.e.l();
        var d = null;
        if (a == '\"' || a == '\'') {
            var e = this.e.x(this.w, a);
            d = new Entity(1, c, e);
        }
        else {
            var f = null;
            var g = null;
            var h = this.e.z(this.w, SgmlDtd.v, true);
            if (Entity.f(h)) {
                a = this.e.l();
                var i = this.e.x(this.w, a);
                d = new Entity(1, c, i);
                d.al(h);
            }
            else {
                g = h;
                if (g == "PUBLIC") {
                    a = this.e.l();
                    if (a == '\"' || a == '\'') {
                        f = this.e.x(this.w, a);
                    }
                    else {
                        this.e.ah("Expecting public identifier literal but found '{0}'", a);
                    }
                }
                else if (g != "SYSTEM") {
                    this.e.aj("Invalid external identifier '{0}'.  Expecing 'PUBLIC' or 'SYSTEM'.", g);
                }
                var j = null;
                a = this.e.l();
                if (a == '\"' || a == '\'') {
                    j = this.e.x(this.w, a);
                }
                else if (a != '>') {
                    this.e.ah("Expecting system identifier literal but found '{0}'", a);
                }
                d = new Entity(0, c, f, j, this.e.v);
            }
        }
        a = this.e.l();
        if (a == '-') {
            a = this.l();
        }
        if (a != '>') {
            this.e.ah("Expecting end of entity declaration '>' but found '{0}'", a);
        }
        if (b) {
            this.o.addItem(d.u, d);
        }
        else {
            this.n.addItem(d.u, d);
        }
    };
    SgmlDtd.prototype.ac = function () {
        var a = this.e.l();
        var b = this.a(a, true);
        a = this.e.l().toUpperCase();
        var c = false;
        var d = false;
        if (a == 'O' || a == '-') {
            c = (a == 'O');
            this.e.k();
            a = this.e.l().toUpperCase();
            if (a == 'O' || a == '-') {
                d = (a == 'O');
                a = this.e.k();
            }
        }
        a = this.e.l();
        var e = this.c(a);
        a = this.e.l();
        var f = null;
        var g = null;
        if (a == '-') {
            a = this.e.k();
            if (a == '(') {
                f = this.a(a, true);
                a = this.e.l();
            }
            else if (a == '-') {
                a = this.k(false);
            }
            else {
                this.e.ah("Invalid syntax at '{0}'", a);
            }
        }
        if (a == '-') {
            a = this.l();
        }
        if (a == '+') {
            a = this.e.k();
            if (a != '(') {
                this.e.ah("Expecting inclusions name group", a);
            }
            g = this.a(a, true);
            a = this.e.l();
        }
        if (a == '-') {
            a = this.l();
        }
        if (a != '>') {
            this.e.ah("Expecting end of ELEMENT declaration '>' but found '{0}'", a);
        }
        for (var i = 0; i < b.length; i++) {
            var h = b[i];
            var j = h.toUpperCase();
            j = this.am.b(h);
            this.m.addItem(j, new ElementDecl(j, c, d, e, g, f));
        }
    };
    SgmlDtd.prototype.a = function (a, b) {
        var c = new List$1(String_$type, 0);
        if (a == '(') {
            a = this.e.k();
            a = this.e.l();
            while (a != ')') {
                a = this.e.l();
                if (a == '%') {
                    var d = this.h(SgmlDtd.s);
                    this.al(this.e.ae, d);
                    this.aj(c, b);
                    this.ak();
                    a = this.e.j;
                }
                else {
                    var e = this.e.z(this.w, SgmlDtd.s, b);
                    e = e.toUpperCase();
                    var f = this.am.b(e);
                    c.add(f);
                }
                a = this.e.l();
                if (a == '|' || a == ',') {
                    a = this.e.k();
                }
            }
            this.e.k();
        }
        else {
            var g = this.e.z(this.w, SgmlDtd.v, b);
            g = g.toUpperCase();
            g = this.am.b(g);
            c.add(g);
        }
        return c.toArray();
    };
    SgmlDtd.prototype.aj = function (a, b) {
        var c = this.e.j;
        c = this.e.l();
        while (c != "\uffff") {
            var d = void 0;
            if (c == '%') {
                var e = this.h(SgmlDtd.s);
                this.al(this.e.ae, e);
                this.aj(a, b);
                this.ak();
                c = this.e.j;
            }
            else {
                d = this.e.z(this.w, SgmlDtd.s, true);
                d = d.toUpperCase();
                d = this.am.b(d);
                a.add(d);
            }
            c = this.e.l();
            if (c == '|') {
                c = this.e.k();
                c = this.e.l();
            }
        }
    };
    SgmlDtd.prototype.c = function (a) {
        var b = new ContentModel();
        if (a == '(') {
            this.e.k();
            this.ai(')', b);
            a = this.e.k();
            if (a == '?' || a == '+' || a == '*') {
                b.g(a);
                this.e.k();
            }
        }
        else if (a == '%') {
            var c = this.h(SgmlDtd.q);
            this.al(this.e.ae, c);
            b = this.c(this.e.j);
            this.ak();
        }
        else {
            var d = this.u(SgmlDtd.q);
            b.j(d);
        }
        return b;
    };
    SgmlDtd.prototype.ai = function (a, b) {
        var c = b.d;
        var d = this.e.j;
        d = this.e.l();
        while (d != a || b.d > c) {
            if (d == "\uffff") {
                this.e.ag("Content Model was not closed");
            }
            if (d == '%') {
                var e = this.h(SgmlDtd.p);
                this.al(this.e.ae, e);
                this.ai("\uffff", b);
                this.ak();
                d = this.e.l();
            }
            else if (d == '(') {
                b.i();
                this.e.k();
                d = this.e.l();
            }
            else if (d == ')') {
                d = this.e.k();
                if (d == '*' || d == '+' || d == '?') {
                    b.g(d);
                    d = this.e.k();
                }
                if (b.e() < c) {
                    this.e.ag("Parameter entity cannot close a paren outside it's own scope");
                }
                d = this.e.l();
            }
            else if (d == ',' || d == '|' || d == '&') {
                b.f(d);
                this.e.k();
                d = this.e.l();
            }
            else {
                var f = void 0;
                if (d == '#') {
                    d = this.e.k();
                    f = "#" + this.e.z(this.w, SgmlDtd.p, true);
                }
                else {
                    f = this.e.z(this.w, SgmlDtd.p, true);
                }
                f = f.toUpperCase();
                f = this.am.b(f);
                d = this.e.j;
                if (d == '?' || d == '+' || d == '*') {
                    b.i();
                    b.h(f);
                    b.g(d);
                    b.e();
                    this.e.k();
                    d = this.e.l();
                }
                else {
                    b.h(f);
                    d = this.e.l();
                }
            }
        }
    };
    SgmlDtd.prototype.z = function () {
        var a = this.e.l();
        var b = this.a(a, true);
        var c = new AttList();
        this.aa(c, '>');
        for (var e = 0; e < b.length; e++) {
            var d = b[e];
            var f = this.m.item(d);
            if (f == null) {
                this.e.aj("ATTLIST references undefined ELEMENT {0}", d);
            }
            f.j(c);
        }
    };
    SgmlDtd.prototype.aa = function (a, b) {
        var c = this.e.l();
        while (c != b) {
            if (c == '%') {
                var d = this.h(SgmlDtd.t);
                this.al(this.e.ae, d);
                this.aa(a, "\uffff");
                this.ak();
                c = this.e.l();
            }
            else if (c == '-') {
                c = this.l();
            }
            else {
                var e = this.b(c);
                a._c(e);
            }
            c = this.e.l();
        }
    };
    SgmlDtd.prototype.b = function (a) {
        a = this.e.l();
        var b = this.u(SgmlDtd.v);
        b = b.toUpperCase();
        b = this.am.b(b);
        var c = new AttDef(b);
        a = this.e.l();
        if (a == '-') {
            a = this.l();
        }
        this.ab(a, c);
        a = this.e.l();
        if (a == '-') {
            a = this.l();
        }
        this.y(a, c);
        a = this.e.l();
        if (a == '-') {
            a = this.l();
        }
        return c;
    };
    SgmlDtd.prototype.ab = function (a, b) {
        if (a == '%') {
            var c = this.h(SgmlDtd.v);
            this.al(this.e.ae, c);
            this.ab(this.e.j, b);
            this.ak();
            a = this.e.j;
            return;
        }
        if (a == '(') {
            b.a = this.a(a, false);
            b.c = 16;
        }
        else {
            var d = this.u(SgmlDtd.v);
            if (d == "NOTATION") {
                a = this.e.l();
                if (a != '(') {
                    this.e.ah("Expecting name group '(', but found '{0}'", a);
                }
                b.c = 15;
                b.a = this.a(a, true);
            }
            else {
                b.g(d);
            }
        }
    };
    SgmlDtd.prototype.y = function (a, b) {
        if (a == '%') {
            var c = this.h(SgmlDtd.v);
            this.al(this.e.ae, c);
            this.y(this.e.j, b);
            this.ak();
            a = this.e.j;
            return;
        }
        var d = true;
        if (a == '#') {
            this.e.k();
            var e = this.e.z(this.w, SgmlDtd.v, true);
            d = b.d(e);
            a = this.e.l();
        }
        if (d) {
            if (a == '\'' || a == '\"') {
                var f = this.e.x(this.w, a);
                b.e = f;
                a = this.e.l();
            }
            else {
                var g = this.e.z(this.w, SgmlDtd.v, false);
                g = g.toUpperCase();
                g = this.am.b(g);
                b.e = g;
                a = this.e.l();
            }
        }
    };
    SgmlDtd.$t = markType(SgmlDtd, 'SgmlDtd');
    SgmlDtd.v = " \r\n\t";
    SgmlDtd.s = " \r\n\t|,)";
    SgmlDtd.q = " \r\n\t>";
    SgmlDtd.p = " \r\n\t,&|()?+*";
    SgmlDtd.t = " \t\r\n>";
    return SgmlDtd;
}(Base));
export { SgmlDtd };
var StringUtilitiesSgml = /** @class */ (function (_super) {
    tslib_1.__extends(StringUtilitiesSgml, _super);
    function StringUtilitiesSgml() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StringUtilitiesSgml.a = function (a, b) {
        return stringCompare1(a, b, StringUtilities.g) == 0;
    };
    StringUtilitiesSgml.$t = markType(StringUtilitiesSgml, 'StringUtilitiesSgml');
    return StringUtilitiesSgml;
}(Base));
export { StringUtilitiesSgml };
var HWStack = /** @class */ (function (_super) {
    tslib_1.__extends(HWStack, _super);
    function HWStack(a) {
        var _this = _super.call(this) || this;
        _this.a = null;
        _this.e = 0;
        _this.b = 0;
        _this.d = 0;
        _this.d = a;
        return _this;
    }
    Object.defineProperty(HWStack.prototype, "c", {
        get: function () {
            return this.b;
        },
        set: function (a) {
            this.b = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(HWStack.prototype, "f", {
        get: function () {
            return this.e;
        },
        enumerable: true,
        configurable: true
    });
    HWStack.prototype.item = function (a, b) {
        if (arguments.length === 2) {
            this.a[a] = b;
            return b;
        }
        else {
            return (a >= 0 && a < this.e) ? this.a[a] : null;
        }
    };
    HWStack.prototype.h = function () {
        this.b--;
        if (this.b > 0) {
            return this.a[this.b - 1];
        }
        return null;
    };
    HWStack.prototype.i = function () {
        if (this.b == this.e) {
            var a = this.e + this.d;
            var b = new Array(a);
            if (this.a != null) {
                arrayCopy2(this.a, b, this.e);
            }
            this.e = a;
            this.a = b;
        }
        return this.a[this.b++];
    };
    HWStack.prototype.j = function (a) {
        this.a[a] = null;
        arrayCopy1(this.a, a + 1, this.a, a, this.b - a - 1);
        this.b--;
    };
    HWStack.$t = markType(HWStack, 'HWStack');
    return HWStack;
}(Base));
export { HWStack };
var Attribute = /** @class */ (function (_super) {
    tslib_1.__extends(Attribute, _super);
    function Attribute() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = null;
        _this.a = null;
        _this.c = '\0';
        _this.d = null;
        return _this;
    }
    Attribute.prototype.g = function (a, b, c) {
        this.e = a;
        this.d = b;
        this.c = c;
        this.a = null;
    };
    Object.defineProperty(Attribute.prototype, "f", {
        get: function () {
            if (this.d != null) {
                return this.d;
            }
            if (this.a != null) {
                return this.a.e;
            }
            return null;
        },
        set: function (a) {
            this.d = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Attribute.prototype, "b", {
        get: function () {
            return (this.d == null);
        },
        enumerable: true,
        configurable: true
    });
    Attribute.$t = markType(Attribute, 'Attribute');
    return Attribute;
}(Base));
export { Attribute };
var Node = /** @class */ (function (_super) {
    tslib_1.__extends(Node, _super);
    function Node() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.p = 0;
        _this.k = null;
        _this.q = 0;
        _this.l = null;
        _this.f = false;
        _this.j = null;
        _this.c = null;
        _this.e = 0;
        _this.g = false;
        _this.d = new HWStack(10);
        return _this;
    }
    Node.prototype.o = function (a, b, c) {
        this.k = c;
        this.j = a;
        this.p = b;
        this.q = 0;
        this.l = null;
        this.f = true;
        this.d.c = 0;
        this.c = null;
    };
    Node.prototype.a = function (a, b, c, d) {
        var e;
        for (var f = 0, g = this.d.c; f < g; f++) {
            e = this.d.item(f);
            if (d && stringCompare1(e.e, a, 1) == 0) {
                return null;
            }
            else if (e.e == a) {
                return null;
            }
        }
        e = this.d.i();
        if (e == null) {
            e = new Attribute();
            this.d.item(this.d.c - 1, e);
        }
        e.g(a, b, c);
        return e;
    };
    Node.prototype.n = function (a) {
        for (var b = 0, c = this.d.c; b < c; b++) {
            var d = this.d.item(b);
            if (d.e == a) {
                this.d.j(b);
                return;
            }
        }
    };
    Node.prototype.m = function (a) {
        for (var b = 0, c = a.d.c; b < c; b++) {
            var d = a.d.item(b);
            var e = this.a(d.e, d.f, d.c, false);
            e.a = d.a;
        }
    };
    Object.defineProperty(Node.prototype, "h", {
        get: function () {
            return this.d.c;
        },
        enumerable: true,
        configurable: true
    });
    Node.prototype.i = function (a) {
        for (var b = 0, c = this.d.c; b < c; b++) {
            var d = this.d.item(b);
            if (d.e == a) {
                return b;
            }
        }
        return -1;
    };
    Node.prototype.b = function (a) {
        if (a >= 0 && a < this.d.c) {
            var b = this.d.item(a);
            return b;
        }
        return null;
    };
    Node.$t = markType(Node, 'Node');
    return Node;
}(Base));
export { Node };
var SgmlReader = /** @class */ (function (_super) {
    tslib_1.__extends(SgmlReader, _super);
    function SgmlReader() {
        var _this = _super.call(this) || this;
        _this._bk = null;
        _this._bc = null;
        _this._bm = 0;
        _this._dh = null;
        _this._b2 = '\0';
        _this._ca = null;
        _this._be = null;
        _this._bg = null;
        _this._a9 = null;
        _this._b3 = 0;
        _this._c0 = null;
        _this._cz = null;
        _this._cy = null;
        _this._b9 = null;
        _this._bn = false;
        _this._bf = null;
        _this._b4 = 0;
        _this._b5 = 0;
        _this._bo = false;
        _this._cp = null;
        _this._ci = null;
        _this._bd = null;
        _this._cm = null;
        _this._b6 = null;
        _this._ct = null;
        _this._cn = null;
        _this._cs = null;
        _this._cf = null;
        _this._de = 0;
        _this._bb = 0;
        _this._b0 = true;
        _this._dg = null;
        _this.c2();
        _this._dh = new NameTable();
        _this._dg = new XmlNamespaceManager(_this._dh);
        return _this;
    }
    Object.defineProperty(SgmlReader.prototype, "_bl", {
        get: function () {
            this._c3(this._c0);
            return this._bk;
        },
        set: function (a) {
            this._bk = a;
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype._c3 = function (a) {
        if (this._bk == null) {
            if (this._bk != null && this._bk.r != null) {
                switch (this._ba) {
                    case 1:
                        this._cp = this._bk.r.toUpperCase();
                        break;
                    case 2:
                        this._cp = this._bk.r.toLowerCase();
                        break;
                    default:
                        this._cp = this._bk.r;
                        break;
                }
                this._bo = StringUtilitiesSgml.a(this._bk.r, "html");
            }
        }
    };
    Object.defineProperty(SgmlReader.prototype, "_cg", {
        get: function () {
            return this._cf;
        },
        set: function (a) {
            this._cf = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SgmlReader.prototype, "_co", {
        get: function () {
            return this._cn;
        },
        set: function (a) {
            this._cn = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SgmlReader.prototype, "_cu", {
        get: function () {
            return this._ct;
        },
        set: function (a) {
            this._ct = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SgmlReader.prototype, "_ck", {
        get: function () {
            return this._cs;
        },
        set: function (a) {
            this._cs = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SgmlReader.prototype, "_b7", {
        get: function () {
            return this._b6;
        },
        set: function (a) {
            this._b6 = a;
            this.c2();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SgmlReader.prototype, "_cw", {
        get: function () {
            return this._cm;
        },
        set: function (a) {
            this._cm = a;
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype._c9 = function (a) {
        this._c0 = new Uri(0, a);
    };
    Object.defineProperty(SgmlReader.prototype, "_cj", {
        get: function () {
            return this._ci;
        },
        set: function (a) {
            this._ci = a;
            this.c2();
            if (this._c0 == null) {
                if (this._ci.indexOf("://") > 0) {
                    this._c0 = new Uri(0, this._ci);
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SgmlReader.prototype, "_b1", {
        get: function () {
            return this._b0;
        },
        set: function (a) {
            this._b0 = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SgmlReader.prototype, "_ba", {
        get: function () {
            return this._bb;
        },
        set: function (a) {
            this._bb = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SgmlReader.prototype, "_b8", {
        get: function () {
            return this._b9;
        },
        set: function (a) {
            this._b9 = a;
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype._c4 = function (a) {
        var b = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            b[_0 - 1] = arguments[_0];
        }
        if (this._b8 != null) {
            var c = stringFormat1.apply(void 0, tslib_1.__spread([a], b));
            if (this._bd != this._bc) {
                c = c + "    " + this._bc.r();
                this._bd = this._bc;
                this._b8.an("### Error:" + c);
            }
            else {
                var d = "";
                if (this._bc.ae != null) {
                    d = this._bc.ae.absolutePath;
                }
                this._b8.an("### Error in " + d + "#" + this._bc.u + ", line " + this._bc.n + ", position " + this._bc.o + ": " + c);
            }
        }
    };
    SgmlReader.prototype._c5 = function (a, b) {
        this._c4(a, b.toString());
    };
    SgmlReader.prototype.c2 = function () {
        this._bm = 0;
        this._be = new HWStack(10);
        this._bg = this._bi(null, 9, null);
        this._bg.f = false;
        this._cz = new StringBuilder(0);
        this._cy = new StringBuilder(0);
        this._b4 = 0;
        this._bc = null;
        this._b2 = '\0';
        this._ca = null;
        this._a9 = null;
        this._b3 = 0;
        this._bf = null;
        this._b5 = 0;
        this._bn = false;
    };
    SgmlReader.prototype._bi = function (a, b, c) {
        var d = this._be.i();
        if (d == null) {
            d = new Node();
            this._be.item(this._be.c - 1, d);
        }
        d.o(a, b, c);
        this._bg = d;
        return d;
    };
    SgmlReader.prototype._da = function () {
        var a = this._be.c - 1;
        if (a > 0) {
            var b = this._be.item(a - 1);
            this._be.item(a - 1, this._be.item(a));
            this._be.item(a, b);
        }
    };
    SgmlReader.prototype._bh = function (a) {
        var b = this._bi(a.j, a.p, a.k);
        b.c = a.c;
        b.f = a.f;
        b.q = a.q;
        b.l = a.l;
        b.e = a.e;
        b.m(a);
        this._bg = b;
        return b;
    };
    SgmlReader.prototype._c8 = function () {
        if (this._be.c > 1) {
            this._bg = this._be.h();
        }
    };
    SgmlReader.prototype._bj = function () {
        var a = this._be.c - 1;
        if (a > 0) {
            return this._be.item(a);
        }
        return null;
    };
    SgmlReader.prototype.get_a7 = function () {
        if (this._bm == 3) {
            return 2;
        }
        else if (this._bm == 4) {
            return 3;
        }
        else if (this._bm == 2 || this._bm == 7) {
            return 15;
        }
        return this._bg.p;
    };
    Object.defineProperty(SgmlReader.prototype, "a7", {
        get: function () {
            return this.get_a7();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_ai = function () {
        var a = null;
        if (this._bm == 3) {
            a = this._a9.e;
        }
        else if (this._bm == 4) {
            a = null;
        }
        else {
            a = this._bg.j;
        }
        return a;
    };
    Object.defineProperty(SgmlReader.prototype, "ai", {
        get: function () {
            return this.get_ai();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_ag = function () {
        var a = this.ai;
        var b = this.ak;
        if (b.length != 0) {
            return a.substr(b.length + 1);
        }
        return a;
    };
    Object.defineProperty(SgmlReader.prototype, "ag", {
        get: function () {
            return this.get_ag();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_aj = function () {
        if (this._bm == 3 && StringUtilitiesSgml.a(this._a9.e, "xmlns")) {
            return "http://www.w3.org/2000/xmlns/";
        }
        var a = this.ak;
        switch (a) {
            case "xmlns": return "http://www.w3.org/2000/xmlns/";
            case "xml": return "http://www.w3.org/XML/1998/namespace";
            case "": return stringEmpty();
            default: return this.ah(a);
        }
    };
    Object.defineProperty(SgmlReader.prototype, "aj", {
        get: function () {
            return this.get_aj();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_ak = function () {
        var a = this.ai;
        if (a == null) {
            return stringEmpty();
        }
        var b = a.indexOf(':');
        if (b < 0) {
            return stringEmpty();
        }
        return a.substr(0, b);
    };
    Object.defineProperty(SgmlReader.prototype, "ak", {
        get: function () {
            return this.get_ak();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_f = function () {
        if (this._bm == 3 || this._bm == 4) {
            return true;
        }
        return (this._bg.k != null);
    };
    Object.defineProperty(SgmlReader.prototype, "f", {
        get: function () {
            return this.get_f();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_ar = function () {
        if (this._bm == 3 || this._bm == 4) {
            return this._a9.f;
        }
        return this._bg.k;
    };
    Object.defineProperty(SgmlReader.prototype, "ar", {
        get: function () {
            return this.get_ar();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_x = function () {
        if (this._bm == 3) {
            return this._be.c;
        }
        else if (this._bm == 4) {
            return this._be.c + 1;
        }
        return this._be.c - 1;
    };
    Object.defineProperty(SgmlReader.prototype, "x", {
        get: function () {
            return this.get_x();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_z = function () {
        return this._c0 == null ? "" : this._c0.absoluteUri;
    };
    Object.defineProperty(SgmlReader.prototype, "z", {
        get: function () {
            return this.get_z();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_i = function () {
        if (this._bm == 1 || this._bm == 3 || this._bm == 4) {
            return this._bg.f;
        }
        return false;
    };
    Object.defineProperty(SgmlReader.prototype, "i", {
        get: function () {
            return this.get_i();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_h = function () {
        if (this._bm == 3 || this._bm == 4) {
            return this._a9.b;
        }
        return false;
    };
    Object.defineProperty(SgmlReader.prototype, "h", {
        get: function () {
            return this.get_h();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_v = function () {
        if (this._a9 != null) {
            return this._a9.c;
        }
        return '\0';
    };
    Object.defineProperty(SgmlReader.prototype, "v", {
        get: function () {
            return this.get_v();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_a8 = function () {
        for (var a = this._be.c - 1; a > 1; a--) {
            var b = this._be.item(a);
            var c = b.q;
            if (c != 0) {
                return c;
            }
        }
        return 0;
    };
    Object.defineProperty(SgmlReader.prototype, "a8", {
        get: function () {
            return this.get_a8();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_as = function () {
        for (var a = this._be.c - 1; a > 1; a--) {
            var b = this._be.item(a);
            var c = b.l;
            if (c != null) {
                return c;
            }
        }
        return stringEmpty();
    };
    Object.defineProperty(SgmlReader.prototype, "as", {
        get: function () {
            return this.get_as();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SgmlReader.prototype, "_df", {
        get: function () {
            return this._de;
        },
        set: function (a) {
            this._de = a;
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.get_w = function () {
        if (this._bm == 3 || this._bm == 4) {
            return 0;
        }
        if (this._bg.p == 1 || this._bg.p == 10) {
            return this._bg.h;
        }
        return 0;
    };
    Object.defineProperty(SgmlReader.prototype, "w", {
        get: function () {
            return this.get_w();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.ab = function (a) {
        if (this._bm != 3 && this._bm != 4) {
            var b = this._bg.i(a);
            if (b >= 0) {
                return this.aa(b);
            }
        }
        return null;
    };
    SgmlReader.prototype.ac = function (a, b) {
        return this.ab(a);
    };
    SgmlReader.prototype.aa = function (a) {
        if (this._bm != 3 && this._bm != 4) {
            var b = this._bg.b(a);
            if (b != null) {
                return b.f;
            }
        }
        throw new IndexOutOfRangeException(0);
    };
    SgmlReader.prototype.item = function (a) {
        return this.aa(a);
    };
    SgmlReader.prototype.item1 = function (a) {
        return this.ab(a);
    };
    SgmlReader.prototype.item2 = function (a, b) {
        return this.ac(a, b);
    };
    SgmlReader.prototype.o = function (a) {
        var b = this._bg.i(a);
        if (b >= 0) {
            this.aw(b);
            return true;
        }
        return false;
    };
    SgmlReader.prototype.p = function (a, b) {
        return this.o(a);
    };
    SgmlReader.prototype.aw = function (a) {
        var b = this._bg.b(a);
        if (b != null) {
            this._b3 = a;
            this._a9 = b;
            if (this._bm != 3) {
                this._bg.e = this._bm;
            }
            this._bm = 3;
            return;
        }
        throw new IndexOutOfRangeException(0);
    };
    SgmlReader.prototype.r = function () {
        if (this._bg.h > 0) {
            this.aw(0);
            return true;
        }
        return false;
    };
    SgmlReader.prototype.s = function () {
        if (this._bm != 3 && this._bm != 4) {
            return this.r();
        }
        if (this._b3 < this._bg.h - 1) {
            this.aw(this._b3 + 1);
            return true;
        }
        return false;
    };
    SgmlReader.prototype.q = function () {
        if (this._bm == 3 || this._bm == 4) {
            this._bm = this._bg.e;
            this._a9 = null;
            return true;
        }
        return (this._bg.p == 1);
    };
    Object.defineProperty(SgmlReader.prototype, "_bp", {
        get: function () {
            return this._bo;
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype._cx = function () {
        if (this._bc == null) {
            this._c6();
        }
        return this._bc.ac();
    };
    SgmlReader.prototype._c6 = function () {
        this._c3(this._c0);
        if (this._cj != null) {
            this._bc = new Entity(0, "#document", null, this._ci, this._cm);
        }
        else if (this._b6 != null) {
            this._bc = new Entity(2, "#document", null, this._b6, this._cm);
        }
        else {
            throw new InvalidOperationException(1, "You must specify input either via Href or InputStream properties");
        }
        this._bc.d = this._bp;
        this._bc.ak(null, this._c0);
        if (this._bc.ae != null) {
            this._c0 = this._bc.ae;
        }
        if (this._bc.d && this._bk == null) {
            this._cf = "HTML";
            this._c3(this._c0);
        }
    };
    SgmlReader.prototype.t = function () {
        if (this._bc == null) {
            this._c6();
        }
        var a = this._bm;
        if (this._bg.g) {
            this._bg.g = false;
            this._bg = this._bj();
            this._bm = this._bg.e;
            return true;
        }
        var b = false;
        while (!b) {
            var t1 = this._bm;
            L0: while (true) {
                switch (t1) {
                    case 0:
                        this._bm = 1;
                        this._bc.k();
                        t1 = 1;
                        continue L0;
                    case 11:
                        if (this._bc.b != null) {
                            this._bc.af();
                            this._bc = this._bc.b;
                        }
                        else {
                            return false;
                        }
                        break;
                    case 2:
                        if (this._ca == this._bg.j) {
                            this._c8();
                            this._bm = 1;
                            t1 = 1;
                            continue L0;
                        }
                        this._c8();
                        b = true;
                        break;
                    case 1:
                        if (this._bg.f) {
                            this._c8();
                        }
                        var c = this._bg;
                        b = this._bv();
                        break;
                    case 6:
                        this._c8();
                        this._bm = 1;
                        b = this._by(this._b2);
                        break;
                    case 10:
                        b = this._bx('<');
                        break;
                    case 7:
                        this._c8();
                        if (this._be.c <= this._b4) {
                            this._bm = 1;
                            if (this._bf != null) {
                                this._bh(this._bf);
                                this._bf = null;
                                this._bm = 1;
                            }
                            else if (this._bg.p == 9) {
                                this._bm = 11;
                                t1 = 11;
                                continue L0;
                            }
                        }
                        b = true;
                        break;
                    case 8:
                        b = this._br();
                        break;
                    case 3:
                        t1 = 4;
                        continue L0;
                    case 4:
                        this._bm = 1;
                        t1 = 1;
                        continue L0;
                    case 5:
                        this._c8();
                        t1 = 1;
                        continue L0;
                    case 9:
                        if (this._bz(this._bc.j, false)) {
                            this._bg.p = 13;
                        }
                        b = true;
                        break;
                }
                break;
            }
            if (b && this._bg.p == 13 && this._de == 2) {
                b = false;
            }
            if (!b && this._bm == 11 && this._be.c > 1) {
                this._b4 = 1;
                this._bm = 7;
                this._bg = this._bj();
                return true;
            }
        }
        if (!this._bn && (this.a7 == 1 || this.a7 == 3 || this.a7 == 4)) {
            this._bn = true;
            if (this._bp && (this.a7 != 1 || stringCompare1(this.ag, "html", StringUtilities.g) != 0)) {
                this._bg.e = this._bm;
                var d = this._bi("html", 1, null);
                this._da();
                this._bg = d;
                d.g = true;
                d.f = false;
                this._bm = 1;
            }
            return true;
        }
        return true;
    };
    SgmlReader.prototype._bv = function () {
        var a = this._bc.j;
        if (a == '<') {
            a = this._bc.k();
            return this._by(a);
        }
        else if (a != "\uffff") {
            if (this._bg.c != null && this._bg.c.e.a == 1) {
                this._b2 = '\0';
                this._bm = 8;
                return false;
            }
            else if (this._bz(a, true)) {
                this._bg.p = 13;
            }
            return true;
        }
        this._bm = 11;
        return false;
    };
    SgmlReader.prototype._by = function (a) {
        if (a == '%') {
            return this._bq();
        }
        if (a == '!') {
            a = this._bc.k();
            if (a == '-') {
                return this._bs();
            }
            else if (a == '[') {
                return this._bt();
            }
            else if (a != '_' && !isLetter(a)) {
                var b = this._bc.y(this._cz, "Recovering", ">");
                this._c4("Ignoring invalid markup '<!" + b + ">");
                return false;
            }
            else {
                var c = this._bc.z(this._cz, SgmlReader._ce, false);
                if (c == "DOCTYPE") {
                    this._c7();
                    if (this.ab("SYSTEM") == null && this.ab("PUBLIC") != null) {
                        this._bg.a("SYSTEM", "", '\"', this._bb == 0);
                    }
                    if (this._b0) {
                        return false;
                    }
                    else {
                        this._bg.p = 10;
                        return true;
                    }
                }
                else {
                    this._c4("Invalid declaration '<!{0}...'.  Expecting '<!DOCTYPE' only.", c);
                    this._bc.y(null, "Recovering", ">");
                    return false;
                }
            }
        }
        else if (a == '?') {
            this._bc.k();
            return this._bw();
        }
        else if (a == '/') {
            return this._bu();
        }
        else {
            return this._bx(a);
        }
    };
    SgmlReader.prototype._cr = function (a) {
        var b = this._bc.z(this._cz, a, false);
        switch (this._bb) {
            case 1:
                b = b.toUpperCase();
                break;
            case 2:
                b = b.toLowerCase();
                break;
        }
        return this._dh.b(b);
    };
    SgmlReader.prototype._bx = function (a) {
        var b = null;
        if (this._bm != 10) {
            if (SgmlReader._cv.indexOf(a) >= 0) {
                this._cz.c = 0;
                this._cz.h('<');
                this._bm = 9;
                return false;
            }
            b = this._cr(SgmlReader._cv);
        }
        else {
            this._bm = 1;
        }
        var c = this._bi(b, 1, null);
        c.f = false;
        this._db(c);
        a = this._bc.l();
        this._dg.ac();
        while (a != "\uffff" && a != '>') {
            if (a == '/') {
                this._dg.h();
                c.f = true;
                a = this._bc.k();
                if (a != '>') {
                    this._c5("Expected empty start tag '/>' sequence instead of '{0}'", a);
                    this._bc.y(null, "Recovering", ">");
                    return false;
                }
                break;
            }
            else if (a == '<') {
                this._c4("Start tag '{0}' is missing '>'", b);
                break;
            }
            var d = this._cr(SgmlReader._cb);
            a = this._bc.l();
            if (d == "," || d == "=" || d == ":" || d == ";") {
                continue;
            }
            var e = null;
            var f = '\0';
            if (a == '=' || a == '\"' || a == '\'') {
                if (a == '=') {
                    this._bc.k();
                    a = this._bc.l();
                }
                if (a == '\'' || a == '\"') {
                    f = a;
                    e = this._cq(this._cz, a);
                }
                else if (a != '>') {
                    var g = SgmlReader._cc;
                    e = this._bc.z(this._cz, g, false);
                }
            }
            if (d.length > 0) {
                var h = c.a(d, e, f, this._bb == 0);
                if (h == null) {
                    this._c4("Duplicate attribute '{0}' ignored", d);
                }
                else {
                    this._dc(c, h);
                    if (startsWith1(h.e, "xmlns:", StringUtilities.g)) {
                        var i = h.e.substr(6);
                        this._dg.x(i, h.f);
                    }
                }
            }
            a = this._bc.l();
        }
        if (a == "\uffff") {
            this._bc.aj("Unexpected EOF parsing start tag '{0}'", b);
        }
        else if (a == '>') {
            this._bc.k();
        }
        if (this.x == 1) {
            if (this._b5 == 1) {
                this._bm = 11;
                return false;
            }
            this._b5++;
        }
        this._dd(c);
        return true;
    };
    SgmlReader.prototype._bu = function () {
        this._dg.h();
        this._bm = 2;
        this._bc.k();
        var a = this._cr(SgmlReader._cv);
        var b = this._bc.l();
        if (b != '>') {
            this._c5("Expected empty start tag '/>' sequence instead of '{0}'", b);
            this._bc.y(null, "Recovering", ">");
        }
        this._bc.k();
        this._ca = a;
        var c = (this._bb == 0);
        this._bg = this._be.item(this._be.c - 1);
        for (var d = this._be.c - 1; d > 0; d--) {
            var e = this._be.item(d);
            if (c && stringCompare1(e.j, a, 1) == 0) {
                this._ca = e.j;
                return true;
            }
            else if (e.j == a) {
                return true;
            }
        }
        this._c4("No matching start tag for '</{0}>'", a);
        this._bm = 1;
        return false;
    };
    SgmlReader.prototype._bq = function () {
        var a = "<%" + this._bc.y(this._cz, "AspNet", "%>") + "%>";
        this._bi(null, 4, a);
        return true;
    };
    SgmlReader.prototype._bs = function () {
        var a = this._bc.k();
        if (a != '-') {
            this._c5("Expecting comment '<!--' but found {0}", a);
            this._bc.y(null, "Comment", ">");
            return false;
        }
        var b = this._bc.y(this._cz, "Comment", "-->");
        var c = b.indexOf("--");
        while (c >= 0) {
            var d = c + 2;
            while (d < b.length && b.charAt(d) == '-') {
                d++;
            }
            if (c > 0) {
                b = b.substr(0, c - 1) + "-" + b.substr(d);
            }
            else {
                b = "-" + b.substr(d);
            }
            c = b.indexOf("--");
        }
        if (b.length > 0 && b.charAt(b.length - 1) == '-') {
            b += " ";
        }
        this._bi(null, 8, b);
        return true;
    };
    SgmlReader.prototype._bt = function () {
        var a = this._bc.k();
        a = this._bc.l();
        var b = this._bc.z(this._cz, SgmlReader._cd, false);
        if (b != "CDATA") {
            this._c4("Expecting CDATA but found '{0}'", b);
            this._bc.y(null, "CDATA", ">");
            return false;
        }
        a = this._bc.l();
        if (a != '[') {
            this._c5("Expecting '[' but found '{0}'", a);
            this._bc.y(null, "CDATA", ">");
            return false;
        }
        var c = this._bc.y(this._cz, "CDATA", "]]>");
        this._bi(null, 4, c);
        return true;
    };
    SgmlReader.prototype._c7 = function () {
        var a = this._bc.l();
        var b = this._cr(SgmlReader._ch);
        this._bi(b, 10, null);
        a = this._bc.l();
        if (a != '>') {
            var c = "";
            var d = "";
            var e = "";
            if (a != '[') {
                var f = this._bc.z(this._cz, SgmlReader._ch, false);
                if (f == "PUBLIC") {
                    a = this._bc.l();
                    if (a == '\"' || a == '\'') {
                        d = this._bc.x(this._cz, a);
                        this._bg.a(f, d, a, this._bb == 0);
                    }
                }
                else if (f != "SYSTEM") {
                    this._c4("Unexpected token in DOCTYPE '{0}'", f);
                    this._bc.y(null, "DOCTYPE", ">");
                }
                a = this._bc.l();
                if (a == '\"' || a == '\'') {
                    f = this._dh.b("SYSTEM");
                    e = this._bc.x(this._cz, a);
                    this._bg.a(f, e, a, this._bb == 0);
                }
                a = this._bc.l();
            }
            if (a == '[') {
                c = this._bc.y(this._cz, "Internal Subset", "]");
                this._bg.k = c;
            }
            a = this._bc.l();
            if (a != '>') {
                this._c5("Expecting end of DOCTYPE tag, but found '{0}'", a);
                this._bc.y(null, "DOCTYPE", ">");
            }
            if (this._bk == null) {
                this._cf = b;
                this._cn = d;
                this._ct = e;
                this._cs = c;
                this._c3(this._bc.ae);
            }
        }
        this._bc.k();
    };
    SgmlReader.prototype._bw = function () {
        var a = this._bc.z(this._cz, SgmlReader._cl, false);
        var b = null;
        if (this._bc.j != '?') {
            b = this._bc.y(this._cz, "Processing Instruction", ">");
        }
        else {
            b = this._bc.y(this._cz, "Processing Instruction", ">");
        }
        if (a != "xml") {
            this._bi(this._dh.b(a), 7, b);
            return true;
        }
        return false;
    };
    SgmlReader.prototype._bz = function (a, b) {
        var c = !b || this._bc.g;
        if (b) {
            this._cz.c = 0;
        }
        this._bm = 5;
        while (a != "\uffff") {
            if (a == '<') {
                a = this._bc.k();
                if (a == '/' || a == '!' || a == '?' || isLetter(a)) {
                    this._bm = 6;
                    this._b2 = a;
                    break;
                }
                else {
                    this._cz.h('<');
                    this._cz.h(a);
                    c = false;
                    a = this._bc.k();
                }
            }
            else if (a == '&') {
                this._c1(this._cz, '<');
                c = false;
                a = this._bc.j;
            }
            else {
                if (!this._bc.g) {
                    c = false;
                }
                this._cz.h(a);
                a = this._bc.k();
            }
        }
        var d = this._cz.toString();
        this._bi(null, 3, d);
        return c;
    };
    SgmlReader.prototype._cq = function (a, b) {
        a.c = 0;
        var c = this._bc.k();
        while (c != "\uffff" && c != b) {
            if (c == '&') {
                this._c1(this._cz, b);
                c = this._bc.j;
            }
            else {
                a.h(c);
                c = this._bc.k();
            }
        }
        this._bc.k();
        return a.toString();
    };
    SgmlReader.prototype._br = function () {
        var a = this._bc.g;
        this._cz.c = 0;
        var b = this._bc.j;
        if (this._b2 != '\0') {
            this._c8();
            switch (this._b2) {
                case '!':
                    this._b2 = ' ';
                    return this._bs();
                case '?':
                    this._b2 = ' ';
                    return this._bw();
                case '/':
                    this._bm = 2;
                    return true;
                case ' ': break;
            }
        }
        else {
            b = this._bc.k();
        }
        while (b != "\uffff") {
            if (b == '<') {
                b = this._bc.k();
                if (b == '!') {
                    b = this._bc.k();
                    if (b == '-') {
                        if (a) {
                            this._b2 = ' ';
                            return this._bs();
                        }
                        else {
                            this._b2 = '!';
                            break;
                        }
                    }
                    else {
                        this._cz.h('<');
                        this._cz.h('!');
                        this._cz.h(b);
                        a = false;
                    }
                }
                else if (b == '?') {
                    this._bc.k();
                    if (a) {
                        this._b2 = ' ';
                        return this._bw();
                    }
                    else {
                        this._b2 = '?';
                        break;
                    }
                }
                else if (b == '/') {
                    var c = this._cz.toString();
                    if (this._bu() && this._ca == this._bg.j) {
                        if (a || c == "") {
                            return true;
                        }
                        else {
                            this._b2 = '/';
                            this._cz.c = 0;
                            this._cz.l(c);
                            this._bm = 8;
                            break;
                        }
                    }
                    else {
                        this._cz.c = 0;
                        this._cz.l(c);
                        this._cz.l("</" + this._ca + ">");
                        a = false;
                    }
                }
                else {
                    this._cz.h('<');
                    this._cz.h(b);
                    a = false;
                }
            }
            else {
                if (!this._bc.g && a) {
                    a = false;
                }
                this._cz.h(b);
            }
            b = this._bc.k();
        }
        var d = this._cz.toString();
        this._bi(null, 4, d);
        if (this._b2 == '\0') {
            this._b2 = ' ';
        }
        return true;
    };
    SgmlReader.prototype._c1 = function (a, b) {
        var c = this._bc.k();
        if (c == '#') {
            var d = this._bc.s();
            a.l(d);
            c = this._bc.j;
        }
        else {
            this._cy.c = 0;
            while (c != "\uffff" && (isLetter(c) || c == '_' || c == '-')) {
                this._cy.h(c);
                c = this._bc.k();
            }
            var e = this._cy.toString();
            if (this._bk != null && e != "") {
                var f = this._bk.f(e);
                if (f != null) {
                    if (f.e) {
                        a.l(f.t);
                        if (c != b) {
                            c = this._bc.k();
                        }
                        return;
                    }
                    else {
                        var g = new Entity(0, e, f.w, f.aa, this._bc.v);
                        f.ak(this._bc, new Uri(0, f.aa));
                        this._bc = g;
                        this._bc.k();
                        return;
                    }
                }
                else {
                    this._c4("Undefined entity '{0}'", e);
                }
            }
            a.l("&");
            a.l(e);
            if (c != b) {
                a.h(c);
                c = this._bc.k();
            }
        }
    };
    SgmlReader.prototype.get_d = function () {
        return this._bm == 11;
    };
    Object.defineProperty(SgmlReader.prototype, "d", {
        get: function () {
            return this.get_d();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.au = function () {
        this.disposeCore(true);
    };
    SgmlReader.prototype.disposeCore = function (a) {
        if (a) {
            if (this._bc != null) {
                this._bc.af();
                this._bc = null;
            }
            if (this._b9 != null) {
                this._b9.i();
                this._b9 = null;
            }
        }
    };
    SgmlReader.prototype.get_a3 = function () {
        if (this._bm == 0) {
            return 0;
        }
        else if (this._bm == 11) {
            return 3;
        }
        return 1;
    };
    Object.defineProperty(SgmlReader.prototype, "a3", {
        get: function () {
            return this.get_a3();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.aq = function () {
        if (this._bg.p == 1) {
            this._cz.c = 0;
            while (this.t()) {
                switch (this.a7) {
                    case 4:
                    case 14:
                    case 13:
                    case 3:
                        this._cz.l(this._bg.k);
                        break;
                    default: return this._cz.toString();
                }
            }
            return this._cz.toString();
        }
        return this._bg.k;
    };
    SgmlReader.prototype.ao = function () {
        var a = new StringWriter(0);
        {
            var b = new XmlTextWriter(1, a);
            try {
                switch (this.a7) {
                    case 1:
                        this.t();
                        while (!this.d && this.a7 != 15) {
                            b.ac(this, true);
                        }
                        this.t();
                        break;
                    case 2:
                        a.v(this.ar);
                        break;
                    default: break;
                }
            }
            finally {
                if (b != null) {
                    b.dispose();
                }
            }
        }
        return a.toString();
    };
    SgmlReader.prototype.ap = function () {
        var a = new StringWriter(0);
        {
            var b = new XmlTextWriter(1, a);
            try {
                b.ac(this, true);
            }
            finally {
                if (b != null) {
                    b.dispose();
                }
            }
        }
        return a.toString();
    };
    SgmlReader.prototype.get_a5 = function () {
        return this._dh;
    };
    Object.defineProperty(SgmlReader.prototype, "a5", {
        get: function () {
            return this.get_a5();
        },
        enumerable: true,
        configurable: true
    });
    SgmlReader.prototype.ah = function (a) {
        return this._dg.lookupNamespace(a);
    };
    SgmlReader.prototype.a1 = function () {
        throw new InvalidOperationException(1, "Not on an entity reference.");
    };
    SgmlReader.prototype.u = function () {
        if (this._bm == 3) {
            this._bm = 4;
            return true;
        }
        else if (this._bm == 4) {
            return false;
        }
        throw new InvalidOperationException(1, "Not on an attribute.");
    };
    SgmlReader.prototype._db = function (a) {
        if (this._bk != null) {
            var b = this._bk.d(a.j);
            if (b != null) {
                a.c = b;
                if (b.e.a == 3) {
                    a.f = true;
                }
            }
        }
    };
    SgmlReader.prototype._dc = function (a, b) {
        var c = a.c;
        if (c != null) {
            var d = c.c(b.e);
            if (d != null) {
                b.a = d;
            }
        }
    };
    SgmlReader.prototype._dd = function (a) {
        if (this._bk != null) {
            var b = this._dh.b(a.j.toUpperCase());
            var c = 0;
            var d = this._be.c - 2;
            if (a.c != null) {
                for (c = d; c > 0; c--) {
                    var e = this._be.item(c);
                    if (e.f) {
                        continue;
                    }
                    var f = e.c;
                    if (f != null) {
                        if (f.i == this._bk.r) {
                            break;
                        }
                        if (f.f(b, this._bk)) {
                            break;
                        }
                        else if (!f.g) {
                            break;
                        }
                    }
                    else {
                        break;
                    }
                }
            }
            if (c == 0) {
            }
            else if (c < d) {
                var g = this._be.item(d);
                if (c == d - 1 && b == g.j) {
                }
                else {
                    var h = "";
                    for (var i = d; i >= c + 1; i--) {
                        if (h != "") {
                            h += ",";
                        }
                        var j = this._be.item(i);
                        h += "<" + j.j + ">";
                    }
                    this._c4("Element '{0}' not allowed inside '{1}', closing {2}.", b, g.j, h);
                }
                this._bm = 7;
                this._bf = a;
                this._c8();
                this._b4 = c + 1;
            }
        }
    };
    SgmlReader.$t = markType(SgmlReader, 'SgmlReader', XmlReader.$);
    SgmlReader._ce = " \t\r\n><";
    SgmlReader._cv = " \t\r\n=/><";
    SgmlReader._cb = " \t\r\n='\"/>";
    SgmlReader._cc = " \t\r\n>";
    SgmlReader._cd = "\t\r\n[<>";
    SgmlReader._ch = " \t\r\n>";
    SgmlReader._cl = " \t\r\n?";
    return SgmlReader;
}(XmlReader));
export { SgmlReader };
var OverrideContentTypePart = /** @class */ (function (_super) {
    tslib_1.__extends(OverrideContentTypePart, _super);
    function OverrideContentTypePart(a, b) {
        var _this = _super.call(this) || this;
        _this.b = null;
        _this.a = null;
        _this.a = a;
        _this.b = b != null ? b : a.contentType;
        return _this;
    }
    Object.defineProperty(OverrideContentTypePart.prototype, "$package", {
        get: function () {
            return this.a.$package;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OverrideContentTypePart.prototype, "uri", {
        get: function () {
            return this.a.uri;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OverrideContentTypePart.prototype, "contentType", {
        get: function () {
            return this.b;
        },
        enumerable: true,
        configurable: true
    });
    OverrideContentTypePart.prototype.getStream = function (a, b) {
        return this.a.getStream(a, b);
    };
    OverrideContentTypePart.prototype.createRelationship = function (a, b, c, d) {
        return this.a.createRelationship(a, b, c, d);
    };
    OverrideContentTypePart.prototype.getRelationships = function () {
        return this.a.getRelationships();
    };
    OverrideContentTypePart.prototype.getRelationship = function (a) {
        return this.a.getRelationship(a);
    };
    OverrideContentTypePart.$t = markType(OverrideContentTypePart, 'OverrideContentTypePart', Base.$, [IPackagePart_$type]);
    return OverrideContentTypePart;
}(Base));
export { OverrideContentTypePart };
var InvalidPackage = /** @class */ (function (_super) {
    tslib_1.__extends(InvalidPackage, _super);
    function InvalidPackage() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    InvalidPackage.prototype.createPart = function (a, b) {
        throw new InvalidOperationException(0);
    };
    InvalidPackage.prototype.createRelationship = function (a, b, c, d) {
        throw new InvalidOperationException(0);
    };
    InvalidPackage.prototype.dispose = function () {
        throw new InvalidOperationException(0);
    };
    InvalidPackage.prototype.getPart = function (a) {
        throw new InvalidOperationException(0);
    };
    InvalidPackage.prototype.getParts = function () {
        throw new InvalidOperationException(0);
    };
    InvalidPackage.prototype.getRelationship = function (a) {
        throw new InvalidOperationException(0);
    };
    InvalidPackage.prototype.getRelationships = function () {
        throw new InvalidOperationException(0);
    };
    InvalidPackage.prototype.partExists = function (a) {
        throw new InvalidOperationException(0);
    };
    InvalidPackage.$t = markType(InvalidPackage, 'InvalidPackage', Base.$, [IPackage_$type]);
    return InvalidPackage;
}(Base));
export { InvalidPackage };
var ZipFile = /** @class */ (function (_super) {
    tslib_1.__extends(ZipFile, _super);
    function ZipFile() {
        var _this = _super.call(this) || this;
        _this.c = new List$1(ZipEntry.$, 0);
        _this.e = null;
        _this.e = new JSZip();
        return _this;
    }
    ZipFile.prototype.a = function (a) {
        var _this = this;
        var b = null;
        var c = typeCast(MemoryStream.$, a);
        if (c != null) {
            b = c.getBuffer();
            if (b.length != a.length) {
                b = null;
            }
        }
        if (b == null) {
            b = new Array(a.length);
            a.read(b, 0, b.length);
        }
        var d = null;
        var e = null;
        var f = new ExternalEventWorkItem$1(ZipFile.$);
        var g = function (h) {
            var i = (Base.getArrayOfValues(_this.e.files));
            for (var j = 0; j < i.length; j++) {
                _this.c.add(new ZipEntry(0, i[j]));
            }
            f.ag(_this);
        };
        var h = function (i) { return f.ag(null, new BaseError(1, i != null ? i.toString() : "Load error")); };
        this.e.loadAsync(b).then(g, h);
        return f;
    };
    Object.defineProperty(ZipFile.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: true,
        configurable: true
    });
    ZipFile.prototype.b = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(this.c)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                var c = b.f;
                if (c.charAt(0) == '/') {
                    c = c.substr(1);
                }
                if (b.c) {
                    this.e.folder(c);
                }
                else {
                    var d = new Array(b.d.length);
                    b.d.position = 0;
                    b.d.read(d, 0, d.length);
                    this.e.file(c, d);
                }
            }
        }
        catch (e_4_1) { e_4 = { error: e_4_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_4) throw e_4.error; }
        }
        var e = (JSZip.support.uint8array) ? "uint8array" : "array";
        var f = null;
        var g = null;
        var h = new ExternalEventWorkItem();
        var i = function (j) {
            var k = j;
            a.write(k, 0, k.length);
            h.af();
        };
        var j = function (k) { return h.af(new BaseError(1, k != null ? k.toString() : "Load error")); };
        this.e.generateAsync({ type: e, compression: 'DEFLATE' }).then(i, j);
        return h;
        var e_4, _2;
    };
    ZipFile.$t = markType(ZipFile, 'ZipFile');
    return ZipFile;
}(Base));
export { ZipFile };
var ZipEntry = /** @class */ (function (_super) {
    tslib_1.__extends(ZipEntry, _super);
    function ZipEntry(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.e = null;
        _this.c = false;
        _this.f = null;
        _this.d = null;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0:
                {
                    var c = _rest[0];
                    _this.e = c;
                    _this.c = (_this.e.dir);
                    _this.f = (_this.e.name);
                }
                break;
            case 1:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    _this.f = c;
                    _this.d = d;
                }
                break;
        }
        return _this;
    }
    ZipEntry.a = function (a, b, c) {
        return new ZipEntry(1, stringReplace(IOPath.combine1(b, a), '\\', '/'), c);
    };
    ZipEntry.prototype.b = function () {
        if (this.e != null) {
            var a = (JSZip.support.uint8array);
            var b = null;
            var c = null;
            var d_1 = new ExternalEventWorkItem$1(Stream.$);
            var e = a ? "uint8array" : "binarystring";
            var f = function (g) { return d_1.ag(new MemoryStream(2, g)); };
            var g = function (h) { return d_1.ag(null, new BaseError(1, h != null ? h.toString() : "Open ZipObject Error")); };
            this.e.async(e).then(f, g);
            return d_1;
        }
        return WorkItem.g(Stream.$, this.d);
    };
    ZipEntry.$t = markType(ZipEntry, 'ZipEntry');
    return ZipEntry;
}(Base));
export { ZipEntry };
var PackagePartExposedStream = /** @class */ (function (_super) {
    tslib_1.__extends(PackagePartExposedStream, _super);
    function PackagePartExposedStream(a) {
        var _this = _super.call(this) || this;
        _this._o = null;
        _this._o = a;
        return _this;
    }
    PackagePartExposedStream.prototype.get_canRead = function () {
        return this._o.canRead;
    };
    Object.defineProperty(PackagePartExposedStream.prototype, "canRead", {
        get: function () {
            return this.get_canRead();
        },
        enumerable: true,
        configurable: true
    });
    PackagePartExposedStream.prototype.get_canSeek = function () {
        return this._o.canSeek;
    };
    Object.defineProperty(PackagePartExposedStream.prototype, "canSeek", {
        get: function () {
            return this.get_canSeek();
        },
        enumerable: true,
        configurable: true
    });
    PackagePartExposedStream.prototype.get_canWrite = function () {
        return this._o.canWrite;
    };
    Object.defineProperty(PackagePartExposedStream.prototype, "canWrite", {
        get: function () {
            return this.get_canWrite();
        },
        enumerable: true,
        configurable: true
    });
    PackagePartExposedStream.prototype.flush = function () {
        this._o.flush();
    };
    PackagePartExposedStream.prototype.get_length = function () {
        return this._o.length;
    };
    Object.defineProperty(PackagePartExposedStream.prototype, "length", {
        get: function () {
            return this.get_length();
        },
        enumerable: true,
        configurable: true
    });
    PackagePartExposedStream.prototype.get_position = function () {
        return this._o.position;
    };
    PackagePartExposedStream.prototype.set_position = function (a) {
        this._o.position = a;
    };
    Object.defineProperty(PackagePartExposedStream.prototype, "position", {
        get: function () {
            return this.get_position();
        },
        set: function (a) {
            this.set_position(a);
        },
        enumerable: true,
        configurable: true
    });
    PackagePartExposedStream.prototype.read = function (a, b, c) {
        return this._o.read(a, b, c);
    };
    PackagePartExposedStream.prototype.seek = function (a, b) {
        return this._o.seek(a, b);
    };
    PackagePartExposedStream.prototype.setLength = function (a) {
        this._o.setLength(a);
    };
    PackagePartExposedStream.prototype.write = function (a, b, c) {
        this._o.write(a, b, c);
    };
    PackagePartExposedStream.$t = markType(PackagePartExposedStream, 'PackagePartExposedStream', Stream.$);
    return PackagePartExposedStream;
}(Stream));
export { PackagePartExposedStream };
var PackageRelationship = /** @class */ (function (_super) {
    tslib_1.__extends(PackageRelationship, _super);
    function PackageRelationship(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this._sourceUri = null;
        _this._targetUri = null;
        _this._id = null;
        _this._relationshipType = null;
        _this._targetMode = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    var e = _rest[2];
                    var f = _rest[3];
                    var g = [new Uri(1, "/", 2), c, d, e, f];
                    {
                        var i = g[0];
                        var j = g[1];
                        var k = g[2];
                        var l = g[3];
                        var m = g[4];
                        _this.sourceUri = i;
                        _this.targetMode = k;
                        _this.targetUri = j;
                        _this.id = m;
                        _this.relationshipType = l;
                    }
                }
                break;
            case 1:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    var e = _rest[2];
                    var f = _rest[3];
                    var g = _rest[4];
                    _this.sourceUri = c;
                    _this.targetMode = e;
                    _this.targetUri = d;
                    _this.id = g;
                    _this.relationshipType = f;
                }
                break;
        }
        return _this;
    }
    Object.defineProperty(PackageRelationship.prototype, "sourceUri", {
        get: function () {
            return this._sourceUri;
        },
        set: function (a) {
            this._sourceUri = a;
        },
        enumerable: true,
        configurable: true
    });
    PackageRelationship.prototype.get_targetUri = function () {
        return this._targetUri;
    };
    PackageRelationship.prototype.set_targetUri = function (a) {
        this._targetUri = a;
    };
    Object.defineProperty(PackageRelationship.prototype, "targetUri", {
        get: function () {
            return this.get_targetUri();
        },
        set: function (a) {
            this.set_targetUri(a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PackageRelationship.prototype, "id", {
        get: function () {
            return this._id;
        },
        set: function (a) {
            this._id = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PackageRelationship.prototype, "relationshipType", {
        get: function () {
            return this._relationshipType;
        },
        set: function (a) {
            this._relationshipType = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PackageRelationship.prototype, "targetMode", {
        get: function () {
            return this._targetMode;
        },
        set: function (a) {
            this._targetMode = a;
        },
        enumerable: true,
        configurable: true
    });
    PackageRelationship.$t = markType(PackageRelationship, 'PackageRelationship', Base.$, [IPackageRelationship_$type]);
    return PackageRelationship;
}(Base));
export { PackageRelationship };
var InvalidTargetPackageRelationship = /** @class */ (function (_super) {
    tslib_1.__extends(InvalidTargetPackageRelationship, _super);
    function InvalidTargetPackageRelationship(a, b, c, d, e) {
        var _this = _super.call(this, 1, a, null, c, d, e) || this;
        _this._targetString = null;
        _this.targetString = b;
        return _this;
    }
    InvalidTargetPackageRelationship.prototype.get_targetUri = function () {
        if (this.targetString != null && _super.prototype.get_targetUri.call(this) == null) {
            this.targetUri = new Uri(1, this.targetString, 0);
        }
        return _super.prototype.get_targetUri.call(this);
    };
    InvalidTargetPackageRelationship.prototype.set_targetUri = function (a) {
        _super.prototype.set_targetUri.call(this, a);
    };
    Object.defineProperty(InvalidTargetPackageRelationship.prototype, "targetString", {
        get: function () {
            return this._targetString;
        },
        set: function (a) {
            this._targetString = a;
        },
        enumerable: true,
        configurable: true
    });
    InvalidTargetPackageRelationship.$t = markType(InvalidTargetPackageRelationship, 'InvalidTargetPackageRelationship', PackageRelationship.$, [IInvalidPackageRelationshipTarget_$type]);
    return InvalidTargetPackageRelationship;
}(PackageRelationship));
export { InvalidTargetPackageRelationship };
var PackagePart = /** @class */ (function (_super) {
    tslib_1.__extends(PackagePart, _super);
    function PackagePart(a, b, c) {
        var _this = _super.call(this) || this;
        _this.f = null;
        _this.d = null;
        _this._$package = null;
        _this._uri = null;
        _this._contentType = null;
        _this.b = null;
        _this.f = new MemoryStream(0);
        _this.$package = a;
        _this.uri = b;
        _this.contentType = c;
        var d = typeCast(Package.$, _this.$package);
        if (d == null) {
            throw new ArgumentException(2, "The expected type for package parameter is type of Package.", "package");
        }
        if (d._p == 2) {
            var e = IOPath.getFileName(b.toString());
            var f = IOPath.getDirectoryName(b.toString());
            f = stringReplace(f, '\\', '/');
            _this.b = ZipEntry.a(e, f, new MemoryStream(0));
            d._c.d.add(_this.b);
        }
        return _this;
    }
    Object.defineProperty(PackagePart.prototype, "$package", {
        get: function () {
            return this._$package;
        },
        set: function (a) {
            this._$package = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PackagePart.prototype, "uri", {
        get: function () {
            return this._uri;
        },
        set: function (a) {
            this._uri = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PackagePart.prototype, "contentType", {
        get: function () {
            return this._contentType;
        },
        set: function (a) {
            this._contentType = a;
        },
        enumerable: true,
        configurable: true
    });
    PackagePart.prototype.getStream = function (a, b) {
        return WorkItemExtensions.l(Stream.$, Stream.$, this.b.b(), function (c) { return WorkItem.g(Stream.$, new PackagePartExposedStream(WorkItemExtensions.m(Stream.$, c))); });
    };
    PackagePart.prototype.createRelationship = function (a, b, c, d) {
        var e = new PackageRelationship(1, this.uri, a, b, c, d);
        return this.a(e);
    };
    PackagePart.prototype.createExternalRelationship = function (a, b, c) {
        var d;
        if (((function () { var e = Uri.tryCreate(a, 0, d); d = e.p2; return e.ret; })())) {
            return this.createRelationship(d, 1, b, c);
        }
        var e = new InvalidTargetPackageRelationship(this.uri, a, 1, b, c);
        return this.a(e);
    };
    PackagePart.prototype.a = function (a) {
        if (this.d == null) {
            this.d = new Dictionary$2(String_$type, IPackageRelationship_$type, 1, 1);
        }
        if (this.d.count == 0) {
            var b = IOPath.getFileName(this.uri.toString()) + ".rels";
            var c = IOPath.getDirectoryName(this.uri.toString()) + "/_rels";
            if (c.charAt(0) == '\\') {
                c = c.substr(1);
            }
            var d = ZipEntry.a(b, c, this.f);
            this.$package._c.d.add(d);
        }
        this.d.addItem(a.id, a);
        return a;
    };
    PackagePart.prototype.getRelationships = function () {
        this.j();
        return this.d.values;
    };
    PackagePart.prototype.getRelationship = function (a) {
        this.j();
        var b = null;
        var c = this.d.tryGetValue(a, b);
        b = c.p1;
        return b;
    };
    Object.defineProperty(PackagePart.prototype, "e", {
        get: function () {
            return this.getRelationships();
        },
        enumerable: true,
        configurable: true
    });
    PackagePart.prototype.c = function () {
        var _this = this;
        this.d = new Dictionary$2(String_$type, IPackageRelationship_$type, 0);
        var a = stringReplace(IOPath.getDirectoryName(DocCoreExtensions.fixDirectoryPath(this.uri.toString())), "\\", "/");
        var b = IOPath.getFileName(this.uri.toString());
        var c = this.$package;
        var d = c._c;
        var e = a + "/_rels/" + b + ".rels";
        var f = Enumerable.u(ZipEntry.$, d.d, function (g) { return g.f == e; });
        if (Enumerable.aj(ZipEntry.$, f) != 1) {
            return null;
        }
        c._b = Enumerable.ad(ZipEntry.$, f);
        return Async.o(Stream.$, c._b.b(), function (g) {
            _this.f = g;
            {
                var h = new XmlTextReader(1, _this.f);
                try {
                    while (h.t()) {
                        if (h.l() && h.ai == "Relationship") {
                            if (h.e) {
                                var i = h.ab("TargetMode");
                                var j = h.ab("Target");
                                var k = h.ab("Id");
                                var l = h.ab("Type");
                                var m = 0;
                                if (stringIsNullOrEmpty(i) == false) {
                                    m = EnumUtil.getEnumValue(RelationshipTargetMode_$type, EnumUtil.parse(RelationshipTargetMode_$type, i, true));
                                }
                                var n = new PackageRelationship(1, _this.uri, new Uri(1, j, 0), m, l, k);
                                _this.d.addItem(k, n);
                            }
                        }
                    }
                }
                finally {
                    if (h != null) {
                        h.dispose();
                    }
                }
            }
            return null;
        });
    };
    PackagePart.prototype.j = function () {
        if (this.d == null) {
            this.d = new Dictionary$2(String_$type, IPackageRelationship_$type, 0);
        }
    };
    PackagePart.$t = markType(PackagePart, 'PackagePart', Base.$, [IPackagePart_$type, IPackagePartEx_$type]);
    return PackagePart;
}(Base));
export { PackagePart };
var Package = /** @class */ (function (_super) {
    tslib_1.__extends(Package, _super);
    function Package() {
        var _this = _super.call(this) || this;
        _this._h = false;
        _this._i = false;
        _this._r = null;
        _this._s = null;
        _this._q = null;
        _this._l = new Dictionary$2(String_$type, PackagePart.$, 0);
        _this._o = null;
        _this._j = new Dictionary$2(String_$type, String_$type, 2, StringComparer.g);
        _this._k = new Dictionary$2(String_$type, String_$type, 2, StringComparer.g);
        _this._p = 0;
        _this._c = null;
        _this._b = null;
        _this._a = null;
        _this._g = null;
        return _this;
    }
    Object.defineProperty(Package.prototype, "_n", {
        get: function () {
            return this._o;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Package.prototype, "_m", {
        get: function () {
            return this._l;
        },
        enumerable: true,
        configurable: true
    });
    Package._d = function (a, b) {
        var c = new Package();
        c._p = b;
        c._c = new ZipFile();
        if (b == 3) {
            a.position = 0;
            return WorkItemExtensions.g(IPackage_$type, WorkItemExtensions.c(WorkItemExtensions.c(c._c.a(a), runOn(c, c._e)), runOn(c, c._f)), function () { return c; });
        }
        else {
            c._r = a;
            return WorkItem.g(IPackage_$type, c);
        }
    };
    Package.prototype.createPart = function (a, b) {
        if (!this._h) {
            this._ag();
        }
        var c = new PackagePart(this, a, b);
        this._k.addItem(a.toString(), b);
        if (this.partExists(a)) {
            this._l.item(a.originalString, c);
        }
        else {
            this._l.addItem(a.originalString, c);
        }
        return c;
    };
    Package.prototype.createRelationship = function (a, b, c, d) {
        if (!this._i) {
            this._ah();
        }
        var e = new PackageRelationship(0, a, b, c, d);
        this._o.add(e);
        return e;
    };
    Package.prototype.getRelationships = function () {
        if (this._o == null) {
            this._ah();
        }
        return this._o;
    };
    Package.prototype.getPart = function (a) {
        var b = null;
        if (this.partExists(a)) {
            b = this._l.item(a.originalString);
        }
        return b;
    };
    Package.prototype.getParts = function () {
        return this._l.values;
    };
    Package.prototype.getRelationship = function (a) {
        if (this._o == null) {
            this._ah();
        }
        return Enumerable.af(IPackageRelationship_$type, Enumerable.u(IPackageRelationship_$type, this._o, function (b) { return b.id == a; }));
    };
    Package.prototype._z = function (a) {
        if (this._k.containsKey(a)) {
            return this._k.item(a);
        }
        var b = IOPath.getExtension(a).substr(1);
        if (this._j.containsKey(b)) {
            return this._j.item(b);
        }
        return null;
    };
    Package.prototype._e = function () {
        var _this = this;
        var a = Enumerable.ad(ZipEntry.$, Enumerable.u(ZipEntry.$, this._c.d, function (b) { return b.f == "[Content_Types].xml"; }));
        return WorkItemExtensions.c(Async.o(Stream.$, a.b(), function (b) {
            {
                var c = new XmlTextReader(1, b);
                try {
                    while (c.t()) {
                        if (c.l() && c.ai == "Types") {
                            while (c.t()) {
                                if (c.l()) {
                                    if (c.ai == "Override") {
                                        var d = c.ab("PartName");
                                        var e = c.ab("ContentType");
                                        if (!_this._k.containsKey(d)) {
                                            _this._k.addItem(d, e);
                                        }
                                    }
                                    else if (c.ai == "Default") {
                                        var f = c.ab("Extension");
                                        var g = c.ab("ContentType");
                                        if (!_this._j.containsKey(f)) {
                                            _this._j.addItem(f, g);
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
                finally {
                    if (c != null) {
                        c.dispose();
                    }
                }
            }
            return null;
        }), function () {
            return Async.d(ZipEntry.$, Enumerable.u(ZipEntry.$, _this._c.d, function (b) { return b.f != "[Content_Types].xml" && !b.c; }), function (b) {
                var c = "/" + b.f;
                var d = _this._z(c);
                var e = new PackagePart(_this, new Uri(1, c, 2), d);
                e.b = b;
                _this._l.addItem(e.uri.originalString, e);
                return e.c();
            });
        });
    };
    Package.prototype._f = function () {
        var _this = this;
        this._o = new List$1(IPackageRelationship_$type, 0);
        this._b = Enumerable.ad(ZipEntry.$, Enumerable.u(ZipEntry.$, this._c.d, function (a) { return a.f == "_rels/.rels"; }));
        return Async.o(Stream.$, this._b.b(), function (a) {
            _this._s = a;
            {
                var b = new XmlTextReader(1, a);
                try {
                    while (b.t()) {
                        if (b.l() && b.ai == "Relationship") {
                            if (b.e) {
                                var c = b.ab("TargetMode");
                                var d = b.ab("Id");
                                var e = b.ab("Type");
                                var f = b.ab("Target");
                                var g = 0;
                                if (stringIsNullOrEmpty(c) == false) {
                                    g = EnumUtil.getEnumValue(RelationshipTargetMode_$type, EnumUtil.parse(RelationshipTargetMode_$type, c, true));
                                }
                                var h = new PackageRelationship(1, new Uri(1, "/", 2), new Uri(1, f, 0), g, e, d);
                                _this._o.add(h);
                            }
                        }
                    }
                }
                finally {
                    if (b != null) {
                        b.dispose();
                    }
                }
            }
            return null;
        });
    };
    Package.prototype.partExists = function (a) {
        return this._l.containsKey(a.originalString);
    };
    Package.prototype.dispose = function () {
        var _this = this;
        if (this._p == 2) {
            if (this._s != null) {
                RelationshipsWriter.j(this._n, this._s);
            }
            try {
                for (var _0 = tslib_1.__values(fromEnum(this._l.values)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                    var a = _1.value;
                    if (a.f != null) {
                        RelationshipsWriter.j(a.e, a.f);
                    }
                }
            }
            catch (e_5_1) { e_5 = { error: e_5_1 }; }
            finally {
                try {
                    if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
                }
                finally { if (e_5) throw e_5.error; }
            }
            if (this._q != null) {
                ContentTypesWriter.j(this, this._q);
            }
            if (this._r != null) {
                this._g = WorkItem.d(function () { return _this._c.b(_this._r); });
            }
        }
        var e_5, _2;
    };
    Package.prototype._ag = function () {
        this._q = new MemoryStream(0);
        this._a = ZipEntry.a("[Content_Types].xml", "/", this._q);
        this._c.d.add(this._a);
        this._h = true;
    };
    Package.prototype._ah = function () {
        this._s = new MemoryStream(0);
        this._b = ZipEntry.a(".rels", "/_rels", this._s);
        this._c.d.add(this._b);
        if (this._o == null) {
            this._o = new List$1(IPackageRelationship_$type, 0);
        }
        this._i = true;
    };
    Package.$t = markType(Package, 'Package', Base.$, [IPackage_$type]);
    Package._u = "http://schemas.openxmlformats.org/package/2006/content-types";
    return Package;
}(Base));
export { Package };
var PackageFactory = /** @class */ (function (_super) {
    tslib_1.__extends(PackageFactory, _super);
    function PackageFactory() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PackageFactory.prototype.open = function (stream, packageMode) {
        arguments[0] = (typeof arguments[0] === 'string' ? b64toUint8Array(arguments[0]) : arguments[0]);
        arguments[0] = (typeCast(Stream.$, arguments[0]) ? arguments[0] : new MemoryStream(2, arguments[0]));
        return this._open$i.apply(this, arguments);
    };
    PackageFactory.prototype._open$i = function (a, b) {
        return Package._d(a, b);
    };
    PackageFactory.$t = markType(PackageFactory, 'PackageFactory', Base.$, [IPackageFactory_$type]);
    return PackageFactory;
}(Base));
export { PackageFactory };
var ContentTypesWriter = /** @class */ (function (_super) {
    tslib_1.__extends(ContentTypesWriter, _super);
    function ContentTypesWriter() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ContentTypesWriter.k = function (a, b, c) {
        a.an("Default", ContentTypesWriter.b);
        a.h("Extension", c);
        a.h("ContentType", b);
        a.v();
    };
    ContentTypesWriter.l = function (a, b, c) {
        a.an("Override", ContentTypesWriter.b);
        a.h("PartName", c);
        a.h("ContentType", b);
        a.v();
    };
    ContentTypesWriter.j = function (a, b) {
        {
            var c = new XmlTextWriter(0, b, Encoding.uTF8);
            try {
                c.ad("xml", "version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"");
                c.an("Types", ContentTypesWriter.b);
                ContentTypesWriter.k(c, ContentTypesWriter.d, "rels");
                ContentTypesWriter.k(c, "application/xml", "xml");
                try {
                    for (var _0 = tslib_1.__values(fromEnum(a._k)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                        var d = _1.value;
                        ContentTypesWriter.l(c, d.value, d.key);
                    }
                }
                catch (e_6_1) { e_6 = { error: e_6_1 }; }
                finally {
                    try {
                        if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
                    }
                    finally { if (e_6) throw e_6.error; }
                }
                c.v();
            }
            finally {
                if (c != null) {
                    c.dispose();
                }
            }
        }
        var e_6, _2;
    };
    ContentTypesWriter.$t = markType(ContentTypesWriter, 'ContentTypesWriter');
    ContentTypesWriter.d = "application/vnd.openxmlformats-package.relationships+xml";
    ContentTypesWriter.b = "http://schemas.openxmlformats.org/package/2006/content-types";
    return ContentTypesWriter;
}(Base));
export { ContentTypesWriter };
var RelationshipsWriter = /** @class */ (function (_super) {
    tslib_1.__extends(RelationshipsWriter, _super);
    function RelationshipsWriter() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RelationshipsWriter.j = function (a, b) {
        {
            var c = new XmlTextWriter(0, b, Encoding.uTF8);
            try {
                c.ad("xml", "version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"");
                c.an("Relationships", RelationshipsWriter.c);
                try {
                    for (var _0 = tslib_1.__values(fromEnum(a)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                        var d = _1.value;
                        c.an("Relationship", RelationshipsWriter.c);
                        c.h("Id", d.id);
                        c.h("Type", d.relationshipType);
                        if (d.targetMode == 1) {
                            c.h("Target", d.targetUri.originalString);
                            c.h("TargetMode", "External");
                        }
                        else {
                            c.h("Target", DocCoreExtensions.fixDirectoryPath(d.targetUri.toString()));
                        }
                        c.v();
                    }
                }
                catch (e_7_1) { e_7 = { error: e_7_1 }; }
                finally {
                    try {
                        if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
                    }
                    finally { if (e_7) throw e_7.error; }
                }
                c.v();
            }
            finally {
                if (c != null) {
                    c.dispose();
                }
            }
        }
        var e_7, _2;
    };
    RelationshipsWriter.$t = markType(RelationshipsWriter, 'RelationshipsWriter');
    RelationshipsWriter.c = "http://schemas.openxmlformats.org/package/2006/relationships";
    RelationshipsWriter.a = [RelationshipsWriter.c];
    return RelationshipsWriter;
}(Base));
export { RelationshipsWriter };
var DocCoreExtensions = /** @class */ (function (_super) {
    tslib_1.__extends(DocCoreExtensions, _super);
    function DocCoreExtensions() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DocCoreExtensions.fixDirectoryPath = function (a) {
        if (stringStartsWith(a, "\\")) {
            return a.substr(1);
        }
        if (stringStartsWith(a, "/")) {
            return a.substr(1);
        }
        return a;
    };
    DocCoreExtensions.$t = markType(DocCoreExtensions, 'DocCoreExtensions');
    return DocCoreExtensions;
}(Base));
export { DocCoreExtensions };
var PackageUtilities = /** @class */ (function (_super) {
    tslib_1.__extends(PackageUtilities, _super);
    function PackageUtilities() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PackageUtilities.j = function (a, b) {
        if (stringStartsWith(b, ".." + "/")) {
            return PackageUtilities.j(PackageUtilities.n(a), b.substr(3));
        }
        var c = a.length > 0 && a.charAt(a.length - 1) == "/";
        var d = b.length > 0 && b.charAt(0) == "/";
        if (d) {
            return b;
        }
        if (c != d) {
            return a + b;
        }
        if (c) {
            return a + b.substr(1);
        }
        return a + "/" + b;
    };
    PackageUtilities.ag = function (a, b) {
        var c = a.toString();
        var d = b.toString();
        return UriUtilities.b(PackageUtilities.j(c, d));
    };
    PackageUtilities.a = function (a, b) {
        return Package._d(a, b ? 3 : 2);
    };
    PackageUtilities.k = function (a) {
        var b = toUniversalTime(a);
        return dateToStringFormat(b, "s") + "Z";
    };
    PackageUtilities.m = function (a) {
        var b = PackageUtilities.n(a);
        var c = PackageUtilities.o(a);
        var d = PackageUtilities.j(b, "_rels");
        var e = c + ".rels";
        return PackageUtilities.j(d, e);
    };
    PackageUtilities.n = function (a) {
        var b = a.lastIndexOf("/");
        if (b < 0) {
            return a;
        }
        return a.substr(0, b);
    };
    PackageUtilities.ah = function (a) {
        return new Uri(1, PackageUtilities.n(a.toString()), 2);
    };
    PackageUtilities.o = function (a) {
        var b = a.lastIndexOf("/");
        if (b < 0) {
            return a;
        }
        return a.substr(b + 1);
    };
    PackageUtilities.e = function (a) {
        if (a == null || a.length != 3 || a.charAt(0) != '%') {
            PackageUtilities.al("The value passed to GetPercentEncodedValue was not expoected: " + a);
            return 0;
        }
        try {
            return Convert.toByte2(a.substr(1), 16);
        }
        catch (b) {
            PackageUtilities.al("The value passed to GetPercentEncodedValue was not expoected: " + a);
            return 0;
        }
    };
    PackageUtilities.ai = function (a, b) {
        return PackageUtilities.aj(a, b, "/");
    };
    PackageUtilities.aj = function (a, b, c) {
        var d = PackageUtilities.q(a.toString(), b.toString(), "/", false);
        return UriUtilities.b(d);
    };
    PackageUtilities.p = function (a, b) {
        return PackageUtilities.q(a, b, "/", false);
    };
    PackageUtilities.q = function (a, b, c, d) {
        var e = PackageUtilities.h(a, c);
        var f = PackageUtilities.h(b, c);
        for (var g = 0; g < e.count - 1 && g < f.count; g++) {
            if (e._inner[g] == f._inner[g]) {
                e.removeAt(g);
                f.removeAt(g);
                g--;
                continue;
            }
            else {
                if (d) {
                    var h = PackageUtilities.w.g(b, stringEmpty());
                    return stringReplace(h, c, "/");
                }
                else {
                    for (var i = 0; i < e.count - 1; i++) {
                        f.insert(0, "..");
                    }
                }
                break;
            }
        }
        var j = new StringBuilder(0);
        try {
            for (var _0 = tslib_1.__values(fromEnum(f)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var k = _1.value;
                if (c != "/") {
                    j.l(stringReplace(k, c, "/"));
                }
                else {
                    j.l(k);
                }
                j.h("/");
            }
        }
        catch (e_8_1) { e_8 = { error: e_8_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_8) throw e_8.error; }
        }
        j.y(j.c - 1, 1);
        return j.toString();
        var e_8, _2;
    };
    PackageUtilities.g = function (a) {
        return PackageUtilities.h(a, "/");
    };
    PackageUtilities.h = function (a, b) {
        if (stringIsNullOrEmpty(a)) {
            return new List$1(String_$type, 0);
        }
        return new List$1(String_$type, 1, a.split(b));
    };
    PackageUtilities.ak = function (a) {
        var b = PackageUtilities.ah(a.sourceUri);
        var c = PackageUtilities.ag(b, a.targetUri);
        return c;
    };
    PackageUtilities.b = function (a) {
        var b = PackageUtilities.g(a);
        if (b.count == 0) {
            return false;
        }
        if (b._inner[0].length != 0) {
            return false;
        }
        for (var c = 1; c < b.count; c++) {
            if (PackageUtilities.d(b._inner[c]) == false) {
                return false;
            }
        }
        return true;
    };
    PackageUtilities.c = function (a) {
        return PackageUtilities.b(a.toString());
    };
    PackageUtilities.d = function (a) {
        if (stringIsNullOrEmpty(a)) {
            return false;
        }
        if (a.charAt(a.length - 1) == '.') {
            return false;
        }
        var b = PackageUtilities.ae.i(a);
        if (b.i == false || b.d != a.length) {
            return false;
        }
        var c = PackageUtilities.aa.i(a);
        while (c.i) {
            var d = PackageUtilities.e(c.g);
            var e = Convert.toChar(d);
            switch (e) {
                case '\\':
                case '/': return false;
            }
            var f = e.toString();
            if (PackageUtilities.ac.i(f).i) {
                return false;
            }
            c = c.o();
        }
        return true;
    };
    PackageUtilities.i = function (a) {
        if (stringEndsWith(a, "Z") == false) {
            PackageUtilities.al("The date format was not correct.");
            return dateNow();
        }
        a = a.substr(0, a.length - 1);
        try {
            var b = dateParseExact(a, "s", null);
            return toLocalTime(b);
        }
        catch (c) {
            PackageUtilities.al("Error occurred while parsing the date in W3CDTF format: " + a);
            return dateNow();
        }
    };
    Object.defineProperty(PackageUtilities, "aa", {
        get: function () {
            if (PackageUtilities.z == null) {
                PackageUtilities.z = new Regex(1, "%[0-9A-F]{2}", 8 | 1);
            }
            return PackageUtilities.z;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PackageUtilities, "ac", {
        get: function () {
            if (PackageUtilities.ab == null) {
                PackageUtilities.ab = new Regex(1, "[\\-\\._~0-9A-Z]", 8 | 1);
            }
            return PackageUtilities.ab;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PackageUtilities, "ae", {
        get: function () {
            if (PackageUtilities.ad == null) {
                PackageUtilities.ad = new Regex(1, "([:@\\-\\._~!$&'()*+,;=0-9A-Z]|(%[0-9A-F]{2}))*", 8 | 1);
            }
            return PackageUtilities.ad;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PackageUtilities, "y", {
        get: function () {
            if (PackageUtilities.x == null) {
                PackageUtilities.x = new Regex(1, "[^.]", 8 | 1);
            }
            return PackageUtilities.x;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PackageUtilities, "w", {
        get: function () {
            if (PackageUtilities.v == null) {
                PackageUtilities.v = new Regex(1, "\\w:", 8);
            }
            return PackageUtilities.v;
        },
        enumerable: true,
        configurable: true
    });
    PackageUtilities.al = function (a) {
    };
    PackageUtilities.$t = markType(PackageUtilities, 'PackageUtilities');
    PackageUtilities.z = null;
    PackageUtilities.ab = null;
    PackageUtilities.ad = null;
    PackageUtilities.x = null;
    PackageUtilities.v = null;
    return PackageUtilities;
}(Base));
export { PackageUtilities };
var AlternateContentChoice = /** @class */ (function (_super) {
    tslib_1.__extends(AlternateContentChoice, _super);
    function AlternateContentChoice(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.a = null;
        _this.b = null;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    var e = [[c], d];
                    {
                        var g = e[0];
                        var h = e[1];
                        _this.a = h;
                        _this.b = g;
                    }
                }
                break;
            case 1:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    _this.a = d;
                    _this.b = c;
                }
                break;
        }
        return _this;
    }
    AlternateContentChoice.$t = markType(AlternateContentChoice, 'AlternateContentChoice');
    return AlternateContentChoice;
}(Base));
export { AlternateContentChoice };
var AttributeValue = /** @class */ (function (_super) {
    tslib_1.__extends(AttributeValue, _super);
    function AttributeValue(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.a = new QualifiedNameInfo();
        _this.d = null;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    var e = _rest[2];
                    var f = _rest[3];
                    _this.a = new QualifiedNameInfo(1, c, d, e);
                    _this.d = f;
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    _this.a = c;
                    _this.d = d;
                }
                break;
        }
        return _this;
    }
    AttributeValue.prototype.toString = function () {
        return this.a.toString() + "=\"" + this.d + "\"";
    };
    AttributeValue.prototype.e = function (a, b, c, d) {
        this.a.i(a, b, c);
        this.d = d;
    };
    Object.defineProperty(AttributeValue.prototype, "b", {
        get: function () {
            return this.a.c;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AttributeValue.prototype, "c", {
        get: function () {
            if (this.a.g == "http://www.w3.org/2000/xmlns/") {
                if (this.a.f == "xmlns" || this.a.h == "xmlns") {
                    return true;
                }
            }
            return false;
        },
        enumerable: true,
        configurable: true
    });
    AttributeValue.$t = markStruct(AttributeValue, 'AttributeValue');
    return AttributeValue;
}(ValueType));
export { AttributeValue };
var CT_GraphicalObject = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GraphicalObject, _super);
    function CT_GraphicalObject() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        return _this;
    }
    CT_GraphicalObject.$t = markType(CT_GraphicalObject, 'CT_GraphicalObject');
    return CT_GraphicalObject;
}(Base));
export { CT_GraphicalObject };
export var IGraphicalObjectContent_$type = new Type(null, 'IGraphicalObjectContent');
var AlternateGraphicalObjectContent = /** @class */ (function (_super) {
    tslib_1.__extends(AlternateGraphicalObjectContent, _super);
    function AlternateGraphicalObjectContent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = null;
        _this.a = null;
        return _this;
    }
    AlternateGraphicalObjectContent.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitAlternateGraphicalObjectContent$i(this, b);
    };
    AlternateGraphicalObjectContent.prototype.getStrictElementName = function (a) {
        return MarkupCompatibility2006.ap;
    };
    AlternateGraphicalObjectContent.$t = markType(AlternateGraphicalObjectContent, 'AlternateGraphicalObjectContent', Base.$, [IGraphicalObjectContent_$type]);
    return AlternateGraphicalObjectContent;
}(Base));
export { AlternateGraphicalObjectContent };
var CT_AdjustHandleList = /** @class */ (function (_super) {
    tslib_1.__extends(CT_AdjustHandleList, _super);
    function CT_AdjustHandleList() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new List$1(IAdjustHandle_$type, 0);
        return _this;
    }
    Object.defineProperty(CT_AdjustHandleList.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: true,
        configurable: true
    });
    CT_AdjustHandleList.$t = markType(CT_AdjustHandleList, 'CT_AdjustHandleList');
    return CT_AdjustHandleList;
}(Base));
export { CT_AdjustHandleList };
var CT_AdjPoint2D = /** @class */ (function (_super) {
    tslib_1.__extends(CT_AdjPoint2D, _super);
    function CT_AdjPoint2D() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new ST_AdjCoordinate();
        _this.b = new ST_AdjCoordinate();
        return _this;
    }
    CT_AdjPoint2D.prototype.c = function (a, b) {
        CT_AdjPoint2D.d(a, b, this);
    };
    CT_AdjPoint2D.d = function (a, b, c) {
        var d = a.ad;
        d.p(b, null);
        var e = null;
        var f = null;
        f = "x";
        e = ST_AdjCoordinate.f(c.a);
        a.ad.h(f, e);
        f = "y";
        e = ST_AdjCoordinate.f(c.b);
        a.ad.h(f, e);
        d.k();
    };
    CT_AdjPoint2D.$t = markType(CT_AdjPoint2D, 'CT_AdjPoint2D');
    return CT_AdjPoint2D;
}(Base));
export { CT_AdjPoint2D };
var CT_Angle = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Angle, _super);
    function CT_Angle() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new ST_Angle();
        return _this;
    }
    CT_Angle.$t = markType(CT_Angle, 'CT_Angle');
    return CT_Angle;
}(Base));
export { CT_Angle };
var CT_Blip = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Blip, _super);
    function CT_Blip() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = Nullable$1.toNullable(ST_BlipCompression_$type, null);
        _this.b = null;
        _this.c = null;
        return _this;
    }
    CT_Blip.$t = markType(CT_Blip, 'CT_Blip');
    return CT_Blip;
}(Base));
export { CT_Blip };
var CT_BlipFillPropertiesBase = /** @class */ (function (_super) {
    tslib_1.__extends(CT_BlipFillPropertiesBase, _super);
    function CT_BlipFillPropertiesBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = Nullable$1.toNullable(Number_$type, null);
        _this.c = Nullable$1.toNullable(Boolean_$type, null);
        _this.a = null;
        return _this;
    }
    CT_BlipFillPropertiesBase.$t = markType(CT_BlipFillPropertiesBase, 'CT_BlipFillPropertiesBase');
    return CT_BlipFillPropertiesBase;
}(Base));
export { CT_BlipFillPropertiesBase };
export var IEG_FillProperties_$type = new Type(null, 'IEG_FillProperties');
var CT_BlipFillProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_BlipFillProperties, _super);
    function CT_BlipFillProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = null;
        _this.e = null;
        return _this;
    }
    CT_BlipFillProperties.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_BlipFillProperties$i(this, b);
    };
    CT_BlipFillProperties.$t = markType(CT_BlipFillProperties, 'CT_BlipFillProperties', CT_BlipFillPropertiesBase.$, [IEG_FillProperties_$type]);
    return CT_BlipFillProperties;
}(CT_BlipFillPropertiesBase));
export { CT_BlipFillProperties };
var CT_Color = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Color, _super);
    function CT_Color() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        return _this;
    }
    CT_Color.$t = markType(CT_Color, 'CT_Color');
    return CT_Color;
}(Base));
export { CT_Color };
var CT_ComplementTransform = /** @class */ (function (_super) {
    tslib_1.__extends(CT_ComplementTransform, _super);
    function CT_ComplementTransform() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CT_ComplementTransform.$t = markType(CT_ComplementTransform, 'CT_ComplementTransform');
    return CT_ComplementTransform;
}(Base));
export { CT_ComplementTransform };
var CT_Connection = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Connection, _super);
    function CT_Connection() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = 0;
        _this.b = 0;
        return _this;
    }
    CT_Connection.$t = markType(CT_Connection, 'CT_Connection');
    return CT_Connection;
}(Base));
export { CT_Connection };
var CT_ConnectionSite = /** @class */ (function (_super) {
    tslib_1.__extends(CT_ConnectionSite, _super);
    function CT_ConnectionSite() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = new ST_AdjAngle();
        return _this;
    }
    CT_ConnectionSite.$t = markType(CT_ConnectionSite, 'CT_ConnectionSite');
    return CT_ConnectionSite;
}(Base));
export { CT_ConnectionSite };
var CT_ConnectionSiteList = /** @class */ (function (_super) {
    tslib_1.__extends(CT_ConnectionSiteList, _super);
    function CT_ConnectionSiteList() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new List$1(CT_ConnectionSite.$, 0);
        return _this;
    }
    Object.defineProperty(CT_ConnectionSiteList.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: true,
        configurable: true
    });
    CT_ConnectionSiteList.$t = markType(CT_ConnectionSiteList, 'CT_ConnectionSiteList');
    return CT_ConnectionSiteList;
}(Base));
export { CT_ConnectionSiteList };
export var ICT_ShapePropertiesOwner_$type = new Type(null, 'ICT_ShapePropertiesOwner');
export var ICT_ShapeStyleOwner_$type = new Type(null, 'ICT_ShapeStyleOwner');
var CT_Connector = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Connector, _super);
    function CT_Connector() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = false;
        _this.c = null;
        _this.a = null;
        _this._spPr = null;
        _this._style = null;
        return _this;
    }
    Object.defineProperty(CT_Connector.prototype, "spPr", {
        get: function () {
            return this._spPr;
        },
        set: function (a) {
            this._spPr = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CT_Connector.prototype, "style", {
        get: function () {
            return this._style;
        },
        set: function (a) {
            this._style = a;
        },
        enumerable: true,
        configurable: true
    });
    CT_Connector.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_Connector$i(this, b);
    };
    CT_Connector.prototype.getStrictElementName = function (a) {
        return a._t.av;
    };
    CT_Connector.$t = markType(CT_Connector, 'CT_Connector', Base.$, [IGraphicalObjectContent_$type, ICT_ShapePropertiesOwner_$type, ICT_ShapeStyleOwner_$type]);
    return CT_Connector;
}(Base));
export { CT_Connector };
var CT_ConnectorLocking = /** @class */ (function (_super) {
    tslib_1.__extends(CT_ConnectorLocking, _super);
    function CT_ConnectorLocking() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.f = false;
        _this.j = false;
        _this.i = false;
        _this.c = false;
        _this.g = false;
        _this.h = false;
        _this.e = false;
        _this.a = false;
        _this.b = false;
        _this.d = false;
        return _this;
    }
    CT_ConnectorLocking.$t = markType(CT_ConnectorLocking, 'CT_ConnectorLocking');
    return CT_ConnectorLocking;
}(Base));
export { CT_ConnectorLocking };
var CT_NonVisualBase = /** @class */ (function (_super) {
    tslib_1.__extends(CT_NonVisualBase, _super);
    function CT_NonVisualBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        return _this;
    }
    CT_NonVisualBase.$t = markType(CT_NonVisualBase, 'CT_NonVisualBase');
    return CT_NonVisualBase;
}(Base));
export { CT_NonVisualBase };
var CT_ConnectorNonVisual = /** @class */ (function (_super) {
    tslib_1.__extends(CT_ConnectorNonVisual, _super);
    function CT_ConnectorNonVisual() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = null;
        return _this;
    }
    CT_ConnectorNonVisual.$t = markType(CT_ConnectorNonVisual, 'CT_ConnectorNonVisual', CT_NonVisualBase.$);
    return CT_ConnectorNonVisual;
}(CT_NonVisualBase));
export { CT_ConnectorNonVisual };
export var IEG_Geometry_$type = new Type(null, 'IEG_Geometry');
var CT_CustomGeometry2D = /** @class */ (function (_super) {
    tslib_1.__extends(CT_CustomGeometry2D, _super);
    function CT_CustomGeometry2D() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = null;
        _this.d = null;
        _this.a = null;
        _this.b = null;
        _this.e = null;
        _this.f = null;
        _this.g = null;
        return _this;
    }
    CT_CustomGeometry2D.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_CustomGeometry2D$i(this, b);
    };
    CT_CustomGeometry2D.$t = markType(CT_CustomGeometry2D, 'CT_CustomGeometry2D', Base.$, [IEG_Geometry_$type]);
    return CT_CustomGeometry2D;
}(Base));
export { CT_CustomGeometry2D };
var CT_DashStop = /** @class */ (function (_super) {
    tslib_1.__extends(CT_DashStop, _super);
    function CT_DashStop() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new ST_PositivePercentage();
        _this.b = new ST_PositivePercentage();
        return _this;
    }
    CT_DashStop.$t = markType(CT_DashStop, 'CT_DashStop');
    return CT_DashStop;
}(Base));
export { CT_DashStop };
export var IEG_LineDashProperties_$type = new Type(null, 'IEG_LineDashProperties');
var CT_DashStopList = /** @class */ (function (_super) {
    tslib_1.__extends(CT_DashStopList, _super);
    function CT_DashStopList() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new List$1(CT_DashStop.$, 0);
        return _this;
    }
    Object.defineProperty(CT_DashStopList.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: true,
        configurable: true
    });
    CT_DashStopList.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_DashStopList$i(this, b);
    };
    CT_DashStopList.$t = markType(CT_DashStopList, 'CT_DashStopList', Base.$, [IEG_LineDashProperties_$type]);
    return CT_DashStopList;
}(Base));
export { CT_DashStopList };
var CT_EmbeddedWAVAudioFile = /** @class */ (function (_super) {
    tslib_1.__extends(CT_EmbeddedWAVAudioFile, _super);
    function CT_EmbeddedWAVAudioFile() {
        var _this = _super.call(this) || this;
        _this.c = null;
        _this.d = null;
        _this.b = Nullable$1.toNullable(Boolean_$type, null);
        _this.d = "";
        return _this;
    }
    CT_EmbeddedWAVAudioFile.$t = markType(CT_EmbeddedWAVAudioFile, 'CT_EmbeddedWAVAudioFile');
    CT_EmbeddedWAVAudioFile.a = false;
    return CT_EmbeddedWAVAudioFile;
}(Base));
export { CT_EmbeddedWAVAudioFile };
var CT_FixedPercentage = /** @class */ (function (_super) {
    tslib_1.__extends(CT_FixedPercentage, _super);
    function CT_FixedPercentage() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new ST_FixedPercentage();
        return _this;
    }
    CT_FixedPercentage.$t = markType(CT_FixedPercentage, 'CT_FixedPercentage');
    return CT_FixedPercentage;
}(Base));
export { CT_FixedPercentage };
var CT_FontReference = /** @class */ (function (_super) {
    tslib_1.__extends(CT_FontReference, _super);
    function CT_FontReference() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = 0;
        return _this;
    }
    CT_FontReference.$t = markType(CT_FontReference, 'CT_FontReference');
    return CT_FontReference;
}(Base));
export { CT_FontReference };
var CT_GeomGuide = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GeomGuide, _super);
    function CT_GeomGuide() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = null;
        return _this;
    }
    CT_GeomGuide.c = function (a, b, c) {
        b = null;
        c = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "name":
                        b = d.d;
                        break;
                    case "fmla":
                        c = d.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_9_1) { e_9 = { error: e_9_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_9) throw e_9.error; }
        }
        ;
        return {
            p1: b,
            p2: c
        };
        var e_9, _2;
    };
    CT_GeomGuide.$t = markType(CT_GeomGuide, 'CT_GeomGuide');
    return CT_GeomGuide;
}(Base));
export { CT_GeomGuide };
var CT_GeomGuideList = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GeomGuideList, _super);
    function CT_GeomGuideList() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new List$1(CT_GeomGuide.$, 0);
        return _this;
    }
    Object.defineProperty(CT_GeomGuideList.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: true,
        configurable: true
    });
    CT_GeomGuideList.$t = markType(CT_GeomGuideList, 'CT_GeomGuideList');
    return CT_GeomGuideList;
}(Base));
export { CT_GeomGuideList };
var CT_GeomRect = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GeomRect, _super);
    function CT_GeomRect() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new ST_AdjCoordinate();
        _this.d = new ST_AdjCoordinate();
        _this.c = new ST_AdjCoordinate();
        _this.a = new ST_AdjCoordinate();
        return _this;
    }
    CT_GeomRect.$t = markType(CT_GeomRect, 'CT_GeomRect');
    return CT_GeomRect;
}(Base));
export { CT_GeomRect };
export var IShapesOwner_$type = new Type(null, 'IShapesOwner');
var CT_GraphicalObjectData = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GraphicalObjectData, _super);
    function CT_GraphicalObjectData() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.c = null;
        return _this;
    }
    Object.defineProperty(CT_GraphicalObjectData.prototype, "b", {
        get: function () {
            if (this.a == null) {
                this.a = new List$1(Tuple$2.$.specialize(String_$type, Base.$), 0);
            }
            return this.a;
        },
        set: function (a) {
            this.a = a;
        },
        enumerable: true,
        configurable: true
    });
    CT_GraphicalObjectData.prototype.addShape = function (a, b) {
        this.b.add(Tuple.a(String_$type, Base.$, b.getStrictElementName(a), b));
    };
    CT_GraphicalObjectData.$t = markType(CT_GraphicalObjectData, 'CT_GraphicalObjectData', Base.$, [IShapesOwner_$type]);
    return CT_GraphicalObjectData;
}(Base));
export { CT_GraphicalObjectData };
var CT_GraphicalObjectFrame = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GraphicalObjectFrame, _super);
    function CT_GraphicalObjectFrame() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = false;
        _this.a = null;
        _this.e = null;
        _this.b = null;
        _this.c = null;
        return _this;
    }
    CT_GraphicalObjectFrame.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_GraphicalObjectFrame$i(this, b);
    };
    CT_GraphicalObjectFrame.prototype.getStrictElementName = function (a) {
        return a._t.a3;
    };
    CT_GraphicalObjectFrame.$t = markType(CT_GraphicalObjectFrame, 'CT_GraphicalObjectFrame', Base.$, [IGraphicalObjectContent_$type]);
    return CT_GraphicalObjectFrame;
}(Base));
export { CT_GraphicalObjectFrame };
var CT_GraphicalObjectFrameLocking = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GraphicalObjectFrameLocking, _super);
    function CT_GraphicalObjectFrameLocking() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = false;
        _this.b = false;
        _this.f = false;
        _this.a = false;
        _this.d = false;
        _this.e = false;
        return _this;
    }
    CT_GraphicalObjectFrameLocking.$t = markType(CT_GraphicalObjectFrameLocking, 'CT_GraphicalObjectFrameLocking');
    return CT_GraphicalObjectFrameLocking;
}(Base));
export { CT_GraphicalObjectFrameLocking };
var CT_GraphicalObjectFrameNonVisual = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GraphicalObjectFrameNonVisual, _super);
    function CT_GraphicalObjectFrameNonVisual() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = null;
        return _this;
    }
    CT_GraphicalObjectFrameNonVisual.$t = markType(CT_GraphicalObjectFrameNonVisual, 'CT_GraphicalObjectFrameNonVisual', CT_NonVisualBase.$);
    return CT_GraphicalObjectFrameNonVisual;
}(CT_NonVisualBase));
export { CT_GraphicalObjectFrameNonVisual };
var CT_GrayscaleTransform = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GrayscaleTransform, _super);
    function CT_GrayscaleTransform() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CT_GrayscaleTransform.$t = markType(CT_GrayscaleTransform, 'CT_GrayscaleTransform');
    return CT_GrayscaleTransform;
}(Base));
export { CT_GrayscaleTransform };
export var ISaveToXLSX_$type = new Type(null, 'ISaveToXLSX');
var CT_GroupFillProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GroupFillProperties, _super);
    function CT_GroupFillProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(CT_GroupFillProperties.prototype, "elementName", {
        get: function () {
            return DrawingMLMain.es;
        },
        enumerable: true,
        configurable: true
    });
    CT_GroupFillProperties.prototype.saveX = function (a, b, c, d) {
        b.p(c, null);
        b.k();
    };
    CT_GroupFillProperties.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_GroupFillProperties$i(this, b);
    };
    CT_GroupFillProperties.$t = markType(CT_GroupFillProperties, 'CT_GroupFillProperties', Base.$, [IEG_FillProperties_$type, ISaveToXLSX_$type]);
    return CT_GroupFillProperties;
}(Base));
export { CT_GroupFillProperties };
var CT_GroupLocking = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GroupLocking, _super);
    function CT_GroupLocking() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = false;
        _this.g = false;
        _this.f = false;
        _this.e = false;
        _this.a = false;
        _this.c = false;
        _this.d = false;
        return _this;
    }
    CT_GroupLocking.$t = markType(CT_GroupLocking, 'CT_GroupLocking');
    return CT_GroupLocking;
}(Base));
export { CT_GroupLocking };
var CT_GroupShape = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GroupShape, _super);
    function CT_GroupShape() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = null;
        _this.a = null;
        _this.c = new List$1(IGraphicalObjectContent_$type, 0);
        return _this;
    }
    Object.defineProperty(CT_GroupShape.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: true,
        configurable: true
    });
    CT_GroupShape.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_GroupShape$i(this, b);
    };
    CT_GroupShape.prototype.getStrictElementName = function (a) {
        return a._t.a4;
    };
    CT_GroupShape.prototype.addShape = function (a, b) {
        this.d.add(b);
    };
    CT_GroupShape.$t = markType(CT_GroupShape, 'CT_GroupShape', Base.$, [IGraphicalObjectContent_$type, IShapesOwner_$type]);
    return CT_GroupShape;
}(Base));
export { CT_GroupShape };
var CT_GroupShapeNonVisual = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GroupShapeNonVisual, _super);
    function CT_GroupShapeNonVisual() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = null;
        return _this;
    }
    CT_GroupShapeNonVisual.$t = markType(CT_GroupShapeNonVisual, 'CT_GroupShapeNonVisual', CT_NonVisualBase.$);
    return CT_GroupShapeNonVisual;
}(CT_NonVisualBase));
export { CT_GroupShapeNonVisual };
var CT_ShapePropertiesBase = /** @class */ (function (_super) {
    tslib_1.__extends(CT_ShapePropertiesBase, _super);
    function CT_ShapePropertiesBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = Nullable$1.toNullable(ST_BlackWhiteMode_$type, null);
        _this.a = null;
        return _this;
    }
    CT_ShapePropertiesBase.$t = markType(CT_ShapePropertiesBase, 'CT_ShapePropertiesBase');
    return CT_ShapePropertiesBase;
}(Base));
export { CT_ShapePropertiesBase };
var CT_GroupShapeProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_GroupShapeProperties, _super);
    function CT_GroupShapeProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = null;
        return _this;
    }
    CT_GroupShapeProperties.$t = markType(CT_GroupShapeProperties, 'CT_GroupShapeProperties', CT_ShapePropertiesBase.$);
    return CT_GroupShapeProperties;
}(CT_ShapePropertiesBase));
export { CT_GroupShapeProperties };
export var ISupportSetProperty_$type = new Type(null, 'ISupportSetProperty');
var CT_Hyperlink = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Hyperlink, _super);
    function CT_Hyperlink() {
        var _this = _super.call(this) || this;
        _this.f = null;
        _this.b = Nullable$1.toNullable(Boolean_$type, null);
        _this.c = Nullable$1.toNullable(Boolean_$type, null);
        _this.d = Nullable$1.toNullable(Boolean_$type, null);
        _this.g = null;
        _this.h = null;
        _this.a = null;
        _this.i = null;
        _this.j = null;
        _this.e = null;
        _this.h = "";
        _this.f = "";
        _this.i = "";
        _this.j = "";
        _this.d = Nullable$1.toNullable(Boolean_$type, true);
        return _this;
    }
    CT_Hyperlink.prototype.setProperty = function (a, b) {
        switch (a) {
            case 596:
                this.e = b;
                break;
            case 1543:
                this.a = typeCast(CT_EmbeddedWAVAudioFile.$, b);
                break;
        }
    };
    CT_Hyperlink.$t = markType(CT_Hyperlink, 'CT_Hyperlink', Base.$, [ISupportSetProperty_$type]);
    return CT_Hyperlink;
}(Base));
export { CT_Hyperlink };
var CT_InverseTransform = /** @class */ (function (_super) {
    tslib_1.__extends(CT_InverseTransform, _super);
    function CT_InverseTransform() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CT_InverseTransform.$t = markType(CT_InverseTransform, 'CT_InverseTransform');
    return CT_InverseTransform;
}(Base));
export { CT_InverseTransform };
var CT_LineEndProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_LineEndProperties, _super);
    function CT_LineEndProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = Nullable$1.toNullable(ST_LineEndLength_$type, null);
        _this.b = Nullable$1.toNullable(ST_LineEndType_$type, null);
        _this.c = Nullable$1.toNullable(ST_LineEndWidth_$type, null);
        return _this;
    }
    CT_LineEndProperties.$t = markType(CT_LineEndProperties, 'CT_LineEndProperties');
    return CT_LineEndProperties;
}(Base));
export { CT_LineEndProperties };
export var IEG_LineJoinProperties_$type = new Type(null, 'IEG_LineJoinProperties');
var CT_LineJoinBevel = /** @class */ (function (_super) {
    tslib_1.__extends(CT_LineJoinBevel, _super);
    function CT_LineJoinBevel() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CT_LineJoinBevel.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_LineJoinBevel$i(this, b);
    };
    CT_LineJoinBevel.$t = markType(CT_LineJoinBevel, 'CT_LineJoinBevel', Base.$, [IEG_LineJoinProperties_$type]);
    return CT_LineJoinBevel;
}(Base));
export { CT_LineJoinBevel };
var ST_PositivePercentage = /** @class */ (function (_super) {
    tslib_1.__extends(ST_PositivePercentage, _super);
    function ST_PositivePercentage(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.a = new ST_Percentage();
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    DocCoreUtils.au(ST_PositivePercentage.$, ST_Percentage.k(c), "value", 0, 1.7976931348623157E+308);
                    _this.a = c;
                }
                break;
        }
        return _this;
    }
    ST_PositivePercentage.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_PositivePercentage.$, typeCast(ST_PositivePercentage.$, a));
        if (ST_PositivePercentage.j(b, Nullable$1.toNullable(ST_PositivePercentage.$, null))) {
            return false;
        }
        return ST_PositivePercentage.g(this, b.getValueOrDefault());
    };
    ST_PositivePercentage.prototype.getHashCode = function () {
        return this.a.getHashCode();
    };
    ST_PositivePercentage.prototype.toString = function () {
        return this.s(1);
    };
    ST_PositivePercentage.prototype.s = function (a) {
        return this.a.p(a);
    };
    ST_PositivePercentage.f = function (a, b) {
        var c = ST_PositivePercentage.r(a, b);
        if (ST_PositivePercentage.j(c, Nullable$1.toNullable(ST_PositivePercentage.$, null))) {
            return c.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_PositivePercentage.$, a);
    };
    ST_PositivePercentage.r = function (a, b) {
        return ST_PositivePercentage.q(ST_Percentage.o(a, b));
    };
    ST_PositivePercentage.g = function (a, b) {
        return ST_Percentage.d(a.a, b.a);
    };
    ST_PositivePercentage.h = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_PositivePercentage.g(a.value, b.value);
    };
    ST_PositivePercentage.i = function (a, b) {
        return !(ST_PositivePercentage.g(a, b));
    };
    ST_PositivePercentage.j = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_PositivePercentage.i(a.value, b.value);
    };
    ST_PositivePercentage.d = function (a) {
        return new ST_PositivePercentage(1, a);
    };
    ST_PositivePercentage.q = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_PositivePercentage.$, null);
        }
        return Nullable$1.toNullable(ST_PositivePercentage.$, ST_PositivePercentage.d(a.value));
    };
    ST_PositivePercentage.b = function (a) {
        return a.a;
    };
    ST_PositivePercentage.p = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Percentage.$, null);
        }
        return Nullable$1.toNullable(ST_Percentage.$, ST_PositivePercentage.b(a.value));
    };
    ST_PositivePercentage.m = function (a) {
        return ST_Percentage.k(a.a);
    };
    ST_PositivePercentage.o = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_PositivePercentage.m(a.value));
    };
    ST_PositivePercentage.$t = markStruct(ST_PositivePercentage, 'ST_PositivePercentage');
    return ST_PositivePercentage;
}(ValueType));
export { ST_PositivePercentage };
var CT_LineJoinMiterProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_LineJoinMiterProperties, _super);
    function CT_LineJoinMiterProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = Nullable$1.toNullable(ST_PositivePercentage.$, null);
        return _this;
    }
    CT_LineJoinMiterProperties.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_LineJoinMiterProperties$i(this, b);
    };
    CT_LineJoinMiterProperties.$t = markType(CT_LineJoinMiterProperties, 'CT_LineJoinMiterProperties', Base.$, [IEG_LineJoinProperties_$type]);
    return CT_LineJoinMiterProperties;
}(Base));
export { CT_LineJoinMiterProperties };
var CT_LineJoinRound = /** @class */ (function (_super) {
    tslib_1.__extends(CT_LineJoinRound, _super);
    function CT_LineJoinRound() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CT_LineJoinRound.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_LineJoinRound$i(this, b);
    };
    CT_LineJoinRound.$t = markType(CT_LineJoinRound, 'CT_LineJoinRound', Base.$, [IEG_LineJoinProperties_$type]);
    return CT_LineJoinRound;
}(Base));
export { CT_LineJoinRound };
var ST_LineWidth = /** @class */ (function (_super) {
    tslib_1.__extends(ST_LineWidth, _super);
    function ST_LineWidth(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.a = new ST_Coordinate32Unqualified();
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    DocCoreUtils.au(ST_LineWidth.$, ST_Coordinate32Unqualified.e(c), "value", 0, 20116800);
                    _this.a = c;
                }
                break;
        }
        return _this;
    }
    ST_LineWidth.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_LineWidth.$, typeCast(ST_LineWidth.$, a));
        if (ST_LineWidth.j(b, Nullable$1.toNullable(ST_LineWidth.$, null))) {
            return false;
        }
        return ST_LineWidth.g(this, b.getValueOrDefault());
    };
    ST_LineWidth.prototype.getHashCode = function () {
        return Base.getHashCodeStatic(this.a);
    };
    ST_LineWidth.prototype.toString = function () {
        return this.a.toString();
    };
    ST_LineWidth.f = function (a) {
        var b = ST_LineWidth.t(a);
        if (ST_LineWidth.j(b, Nullable$1.toNullable(ST_LineWidth.$, null))) {
            return b.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_LineWidth.$, a);
    };
    ST_LineWidth.t = function (a) {
        return ST_LineWidth.s(ST_Coordinate32Unqualified.j(a));
    };
    ST_LineWidth.g = function (a, b) {
        return ST_Coordinate32Unqualified.e(a.a) == ST_Coordinate32Unqualified.e(b.a);
    };
    ST_LineWidth.h = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_LineWidth.g(a.value, b.value);
    };
    ST_LineWidth.i = function (a, b) {
        return !(ST_LineWidth.g(a, b));
    };
    ST_LineWidth.j = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_LineWidth.i(a.value, b.value);
    };
    ST_LineWidth.d = function (a) {
        return new ST_LineWidth(1, a);
    };
    ST_LineWidth.s = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_LineWidth.$, null);
        }
        return Nullable$1.toNullable(ST_LineWidth.$, ST_LineWidth.d(a.value));
    };
    ST_LineWidth.b = function (a) {
        return a.a;
    };
    ST_LineWidth.r = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Coordinate32Unqualified.$, null);
        }
        return Nullable$1.toNullable(ST_Coordinate32Unqualified.$, ST_LineWidth.b(a.value));
    };
    ST_LineWidth.m = function (a) {
        return ST_Coordinate32Unqualified.e(a.a);
    };
    ST_LineWidth.q = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_LineWidth.m(a.value));
    };
    ST_LineWidth.$t = markStruct(ST_LineWidth, 'ST_LineWidth');
    return ST_LineWidth;
}(ValueType));
export { ST_LineWidth };
var CT_LinePropertiesBase = /** @class */ (function (_super) {
    tslib_1.__extends(CT_LinePropertiesBase, _super);
    function CT_LinePropertiesBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = Nullable$1.toNullable(ST_PenAlignment_$type, null);
        _this.f = Nullable$1.toNullable(ST_LineCap_$type, null);
        _this.g = Nullable$1.toNullable(ST_CompoundLine_$type, null);
        _this.a = null;
        _this.c = null;
        _this.d = null;
        _this.b = null;
        _this.h = Nullable$1.toNullable(ST_LineWidth.$, null);
        return _this;
    }
    CT_LinePropertiesBase.$t = markType(CT_LinePropertiesBase, 'CT_LinePropertiesBase');
    return CT_LinePropertiesBase;
}(Base));
export { CT_LinePropertiesBase };
var CT_LineProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_LineProperties, _super);
    function CT_LineProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.i = null;
        return _this;
    }
    CT_LineProperties.$t = markType(CT_LineProperties, 'CT_LineProperties', CT_LinePropertiesBase.$);
    return CT_LineProperties;
}(CT_LinePropertiesBase));
export { CT_LineProperties };
export var IEG_LineFillProperties_$type = new Type(null, 'IEG_LineFillProperties');
var CT_NoFillProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_NoFillProperties, _super);
    function CT_NoFillProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CT_NoFillProperties.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_NoFillProperties$i(this, b);
    };
    CT_NoFillProperties.prototype._accept$21$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_NoFillProperties$i(this, b);
    };
    Object.defineProperty(CT_NoFillProperties.prototype, "elementName", {
        get: function () {
            return DrawingMLMain.gy;
        },
        enumerable: true,
        configurable: true
    });
    CT_NoFillProperties.prototype.saveX = function (a, b, c, d) {
        b.p(c, null);
        b.k();
    };
    CT_NoFillProperties.$t = markType(CT_NoFillProperties, 'CT_NoFillProperties', Base.$, [IEG_FillProperties_$type, IEG_LineFillProperties_$type, ISaveToXLSX_$type]);
    return CT_NoFillProperties;
}(Base));
export { CT_NoFillProperties };
var CT_NonVisualConnectorProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_NonVisualConnectorProperties, _super);
    function CT_NonVisualConnectorProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = null;
        _this.a = null;
        _this.b = null;
        return _this;
    }
    CT_NonVisualConnectorProperties.$t = markType(CT_NonVisualConnectorProperties, 'CT_NonVisualConnectorProperties');
    return CT_NonVisualConnectorProperties;
}(Base));
export { CT_NonVisualConnectorProperties };
var CT_NonVisualDrawingProps = /** @class */ (function (_super) {
    tslib_1.__extends(CT_NonVisualDrawingProps, _super);
    function CT_NonVisualDrawingProps() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = null;
        _this.d = false;
        _this.a = null;
        _this.b = null;
        _this.c = new ST_DrawingElementId();
        _this.f = null;
        _this.g = null;
        return _this;
    }
    CT_NonVisualDrawingProps.$t = markType(CT_NonVisualDrawingProps, 'CT_NonVisualDrawingProps');
    return CT_NonVisualDrawingProps;
}(Base));
export { CT_NonVisualDrawingProps };
var CT_NonVisualGraphicFrameProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_NonVisualGraphicFrameProperties, _super);
    function CT_NonVisualGraphicFrameProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        return _this;
    }
    CT_NonVisualGraphicFrameProperties.$t = markType(CT_NonVisualGraphicFrameProperties, 'CT_NonVisualGraphicFrameProperties');
    return CT_NonVisualGraphicFrameProperties;
}(Base));
export { CT_NonVisualGraphicFrameProperties };
var CT_NonVisualGroupDrawingShapeProps = /** @class */ (function (_super) {
    tslib_1.__extends(CT_NonVisualGroupDrawingShapeProps, _super);
    function CT_NonVisualGroupDrawingShapeProps() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        return _this;
    }
    CT_NonVisualGroupDrawingShapeProps.$t = markType(CT_NonVisualGroupDrawingShapeProps, 'CT_NonVisualGroupDrawingShapeProps');
    return CT_NonVisualGroupDrawingShapeProps;
}(Base));
export { CT_NonVisualGroupDrawingShapeProps };
var CT_NonVisualPictureProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_NonVisualPictureProperties, _super);
    function CT_NonVisualPictureProperties() {
        var _this = _super.call(this) || this;
        _this.a = null;
        _this.b = false;
        _this.b = true;
        return _this;
    }
    CT_NonVisualPictureProperties.$t = markType(CT_NonVisualPictureProperties, 'CT_NonVisualPictureProperties');
    return CT_NonVisualPictureProperties;
}(Base));
export { CT_NonVisualPictureProperties };
var CT_NonVisualDrawingShapeProps = /** @class */ (function (_super) {
    tslib_1.__extends(CT_NonVisualDrawingShapeProps, _super);
    function CT_NonVisualDrawingShapeProps() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = false;
        return _this;
    }
    CT_NonVisualDrawingShapeProps.$t = markType(CT_NonVisualDrawingShapeProps, 'CT_NonVisualDrawingShapeProps');
    return CT_NonVisualDrawingShapeProps;
}(Base));
export { CT_NonVisualDrawingShapeProps };
var CT_Path2D = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Path2D, _super);
    function CT_Path2D() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new List$1(IPath2DCommand_$type, 0);
        _this.g = Nullable$1.toNullable(ST_PositiveCoordinate.$, null);
        _this.e = Nullable$1.toNullable(ST_PositiveCoordinate.$, null);
        _this.d = Nullable$1.toNullable(ST_PathFillMode_$type, null);
        _this.f = Nullable$1.toNullable(Boolean_$type, null);
        _this.c = Nullable$1.toNullable(Boolean_$type, null);
        return _this;
    }
    Object.defineProperty(CT_Path2D.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: true,
        configurable: true
    });
    CT_Path2D.$t = markType(CT_Path2D, 'CT_Path2D');
    return CT_Path2D;
}(Base));
export { CT_Path2D };
export var IPath2DCommand_$type = new Type(null, 'IPath2DCommand');
var CT_Path2DArcTo = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Path2DArcTo, _super);
    function CT_Path2DArcTo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new ST_AdjCoordinate();
        _this.c = new ST_AdjCoordinate();
        _this.a = new ST_AdjAngle();
        _this.b = new ST_AdjAngle();
        return _this;
    }
    CT_Path2DArcTo.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        if (b === void 0) { b = Type.getDefaultValue($tArg); }
        return a._visitCT_Path2DArcTo$i(this, b);
    };
    Object.defineProperty(CT_Path2DArcTo.prototype, "elementName", {
        get: function () {
            return DrawingMLMain.bf;
        },
        enumerable: true,
        configurable: true
    });
    CT_Path2DArcTo.prototype.saveX = function (a, b, c, d) {
        CT_Path2DArcTo.e(a, c, this);
    };
    CT_Path2DArcTo.e = function (a, b, c) {
        var d = a.ad;
        d.p(b, null);
        var e = null;
        var f = null;
        f = "hR";
        e = ST_AdjCoordinate.f(c.c);
        a.ad.h(f, e);
        f = "stAng";
        e = ST_AdjAngle.f(c.a);
        a.ad.h(f, e);
        f = "swAng";
        e = ST_AdjAngle.f(c.b);
        a.ad.h(f, e);
        f = "wR";
        e = ST_AdjCoordinate.f(c.d);
        a.ad.h(f, e);
        d.k();
    };
    CT_Path2DArcTo.$t = markType(CT_Path2DArcTo, 'CT_Path2DArcTo', Base.$, [IPath2DCommand_$type, ISaveToXLSX_$type]);
    return CT_Path2DArcTo;
}(Base));
export { CT_Path2DArcTo };
var CT_Path2DClose = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Path2DClose, _super);
    function CT_Path2DClose() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CT_Path2DClose.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        if (b === void 0) { b = Type.getDefaultValue($tArg); }
        return a._visitCT_Path2DClose$i(this, b);
    };
    Object.defineProperty(CT_Path2DClose.prototype, "elementName", {
        get: function () {
            return DrawingMLMain.ci;
        },
        enumerable: true,
        configurable: true
    });
    CT_Path2DClose.prototype.saveX = function (a, b, c, d) {
        b.o(c);
        b.k();
    };
    CT_Path2DClose.$t = markType(CT_Path2DClose, 'CT_Path2DClose', Base.$, [IPath2DCommand_$type, ISaveToXLSX_$type]);
    return CT_Path2DClose;
}(Base));
export { CT_Path2DClose };
var CT_Path2DCubicBezierTo = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Path2DCubicBezierTo, _super);
    function CT_Path2DCubicBezierTo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = null;
        _this.c = null;
        return _this;
    }
    CT_Path2DCubicBezierTo.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        if (b === void 0) { b = Type.getDefaultValue($tArg); }
        return a._visitCT_Path2DCubicBezierTo$i(this, b);
    };
    Object.defineProperty(CT_Path2DCubicBezierTo.prototype, "elementName", {
        get: function () {
            return DrawingMLMain.cv;
        },
        enumerable: true,
        configurable: true
    });
    CT_Path2DCubicBezierTo.prototype.saveX = function (a, b, c, d) {
        b.o(c);
        if (this.a != null) {
            this.a.c(a, DrawingMLMain.hs);
        }
        if (this.b != null) {
            this.b.c(a, DrawingMLMain.hs);
        }
        if (this.c != null) {
            this.c.c(a, DrawingMLMain.hs);
        }
        b.k();
    };
    CT_Path2DCubicBezierTo.$t = markType(CT_Path2DCubicBezierTo, 'CT_Path2DCubicBezierTo', Base.$, [IPath2DCommand_$type, ISaveToXLSX_$type]);
    return CT_Path2DCubicBezierTo;
}(Base));
export { CT_Path2DCubicBezierTo };
var CT_Path2DLineTo = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Path2DLineTo, _super);
    function CT_Path2DLineTo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        return _this;
    }
    CT_Path2DLineTo.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        if (b === void 0) { b = Type.getDefaultValue($tArg); }
        return a._visitCT_Path2DLineTo$i(this, b);
    };
    Object.defineProperty(CT_Path2DLineTo.prototype, "elementName", {
        get: function () {
            return DrawingMLMain.f0;
        },
        enumerable: true,
        configurable: true
    });
    CT_Path2DLineTo.prototype.saveX = function (a, b, c, d) {
        b.o(c);
        if (this.a != null) {
            this.a.c(a, DrawingMLMain.hs);
        }
        b.k();
    };
    CT_Path2DLineTo.$t = markType(CT_Path2DLineTo, 'CT_Path2DLineTo', Base.$, [IPath2DCommand_$type, ISaveToXLSX_$type]);
    return CT_Path2DLineTo;
}(Base));
export { CT_Path2DLineTo };
var CT_Path2DList = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Path2DList, _super);
    function CT_Path2DList() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new List$1(CT_Path2D.$, 0);
        return _this;
    }
    Object.defineProperty(CT_Path2DList.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: true,
        configurable: true
    });
    CT_Path2DList.$t = markType(CT_Path2DList, 'CT_Path2DList');
    return CT_Path2DList;
}(Base));
export { CT_Path2DList };
var CT_Path2DMoveTo = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Path2DMoveTo, _super);
    function CT_Path2DMoveTo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        return _this;
    }
    CT_Path2DMoveTo.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        if (b === void 0) { b = Type.getDefaultValue($tArg); }
        return a._visitCT_Path2DMoveTo$i(this, b);
    };
    Object.defineProperty(CT_Path2DMoveTo.prototype, "elementName", {
        get: function () {
            return DrawingMLMain.gm;
        },
        enumerable: true,
        configurable: true
    });
    CT_Path2DMoveTo.prototype.saveX = function (a, b, c, d) {
        b.o(c);
        if (this.a != null) {
            this.a.c(a, DrawingMLMain.hs);
        }
        b.k();
    };
    CT_Path2DMoveTo.$t = markType(CT_Path2DMoveTo, 'CT_Path2DMoveTo', Base.$, [IPath2DCommand_$type, ISaveToXLSX_$type]);
    return CT_Path2DMoveTo;
}(Base));
export { CT_Path2DMoveTo };
var CT_Path2DQuadBezierTo = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Path2DQuadBezierTo, _super);
    function CT_Path2DQuadBezierTo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = null;
        return _this;
    }
    CT_Path2DQuadBezierTo.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        if (b === void 0) { b = Type.getDefaultValue($tArg); }
        return a._visitCT_Path2DQuadBezierTo$i(this, b);
    };
    Object.defineProperty(CT_Path2DQuadBezierTo.prototype, "elementName", {
        get: function () {
            return DrawingMLMain.ht;
        },
        enumerable: true,
        configurable: true
    });
    CT_Path2DQuadBezierTo.prototype.saveX = function (a, b, c, d) {
        b.o(c);
        if (this.a != null) {
            this.a.c(a, DrawingMLMain.hs);
        }
        if (this.b != null) {
            this.b.c(a, DrawingMLMain.hs);
        }
        b.k();
    };
    CT_Path2DQuadBezierTo.$t = markType(CT_Path2DQuadBezierTo, 'CT_Path2DQuadBezierTo', Base.$, [IPath2DCommand_$type, ISaveToXLSX_$type]);
    return CT_Path2DQuadBezierTo;
}(Base));
export { CT_Path2DQuadBezierTo };
var CT_Percentage = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Percentage, _super);
    function CT_Percentage() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new ST_Percentage();
        return _this;
    }
    CT_Percentage.$t = markType(CT_Percentage, 'CT_Percentage');
    return CT_Percentage;
}(Base));
export { CT_Percentage };
var CT_Picture = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Picture, _super);
    function CT_Picture() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.c = false;
        _this.d = null;
        _this.b = null;
        _this._spPr = null;
        return _this;
    }
    Object.defineProperty(CT_Picture.prototype, "spPr", {
        get: function () {
            return this._spPr;
        },
        set: function (a) {
            this._spPr = a;
        },
        enumerable: true,
        configurable: true
    });
    CT_Picture.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_Picture$i(this, b);
    };
    CT_Picture.prototype.getStrictElementName = function (a) {
        return a._t.bs;
    };
    CT_Picture.$t = markType(CT_Picture, 'CT_Picture', Base.$, [IGraphicalObjectContent_$type, ICT_ShapePropertiesOwner_$type]);
    return CT_Picture;
}(Base));
export { CT_Picture };
var CT_PictureLocking = /** @class */ (function (_super) {
    tslib_1.__extends(CT_PictureLocking, _super);
    function CT_PictureLocking() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = false;
        _this.b = false;
        _this.c = false;
        _this.d = false;
        _this.e = false;
        _this.f = false;
        _this.g = false;
        _this.h = false;
        _this.i = false;
        _this.j = false;
        _this.k = false;
        return _this;
    }
    CT_PictureLocking.$t = markType(CT_PictureLocking, 'CT_PictureLocking');
    return CT_PictureLocking;
}(Base));
export { CT_PictureLocking };
var CT_PictureNonVisual = /** @class */ (function (_super) {
    tslib_1.__extends(CT_PictureNonVisual, _super);
    function CT_PictureNonVisual() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = null;
        return _this;
    }
    CT_PictureNonVisual.$t = markType(CT_PictureNonVisual, 'CT_PictureNonVisual', CT_NonVisualBase.$);
    return CT_PictureNonVisual;
}(CT_NonVisualBase));
export { CT_PictureNonVisual };
var ST_GeomGuideName = /** @class */ (function (_super) {
    tslib_1.__extends(ST_GeomGuideName, _super);
    function ST_GeomGuideName(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.a = null;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.a = c;
                }
                break;
        }
        return _this;
    }
    ST_GeomGuideName.$t = markStruct(ST_GeomGuideName, 'ST_GeomGuideName');
    return ST_GeomGuideName;
}(ValueType));
export { ST_GeomGuideName };
var ST_AdjCoordinate = /** @class */ (function (_super) {
    tslib_1.__extends(ST_AdjCoordinate, _super);
    function ST_AdjCoordinate(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.b = Nullable$1.toNullable(ST_Coordinate.$, null);
        _this.c = Nullable$1.toNullable(ST_GeomGuideName.$, null);
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.b = Nullable$1.toNullable(ST_Coordinate.$, null);
                    _this.c = Nullable$1.toNullable(ST_GeomGuideName.$, new ST_GeomGuideName(1, c));
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    _this.b = Nullable$1.toNullable(ST_Coordinate.$, c);
                    _this.c = Nullable$1.toNullable(ST_GeomGuideName.$, null);
                }
                break;
        }
        return _this;
    }
    Object.defineProperty(ST_AdjCoordinate.prototype, "e", {
        get: function () {
            return this.c;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ST_AdjCoordinate.prototype, "d", {
        get: function () {
            return this.b;
        },
        enumerable: true,
        configurable: true
    });
    ST_AdjCoordinate.a = function (a) {
        var b = ST_Coordinate.s(a);
        if (nullableNotEquals(b, null)) {
            return new ST_AdjCoordinate(2, b.value);
        }
        return new ST_AdjCoordinate(1, a);
    };
    ST_AdjCoordinate.f = function (a) {
        if (a.d.hasValue) {
            return a.d.value.toString();
        }
        else if (a.e.hasValue) {
            return a.e.value.toString();
        }
        else {
            return stringEmpty();
        }
    };
    ST_AdjCoordinate.$t = markStruct(ST_AdjCoordinate, 'ST_AdjCoordinate');
    return ST_AdjCoordinate;
}(ValueType));
export { ST_AdjCoordinate };
var ST_AdjAngle = /** @class */ (function (_super) {
    tslib_1.__extends(ST_AdjAngle, _super);
    function ST_AdjAngle(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.b = Nullable$1.toNullable(ST_Angle.$, null);
        _this.c = Nullable$1.toNullable(ST_GeomGuideName.$, null);
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.b = Nullable$1.toNullable(ST_Angle.$, null);
                    _this.c = Nullable$1.toNullable(ST_GeomGuideName.$, new ST_GeomGuideName(1, c));
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    _this.b = Nullable$1.toNullable(ST_Angle.$, c);
                    _this.c = Nullable$1.toNullable(ST_GeomGuideName.$, null);
                }
                break;
        }
        return _this;
    }
    Object.defineProperty(ST_AdjAngle.prototype, "e", {
        get: function () {
            return this.c;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ST_AdjAngle.prototype, "d", {
        get: function () {
            return this.b;
        },
        enumerable: true,
        configurable: true
    });
    ST_AdjAngle.a = function (a) {
        var b = ST_Angle.m(a);
        if (b.hasValue) {
            return new ST_AdjAngle(2, b.value);
        }
        return new ST_AdjAngle(1, a);
    };
    ST_AdjAngle.f = function (a) {
        if (a.d.hasValue) {
            return a.d.value.toString();
        }
        else if (a.e.hasValue) {
            return a.e.value.toString();
        }
        else {
            return stringEmpty();
        }
    };
    ST_AdjAngle.$t = markStruct(ST_AdjAngle, 'ST_AdjAngle');
    return ST_AdjAngle;
}(ValueType));
export { ST_AdjAngle };
export var IAdjustHandle_$type = new Type(null, 'IAdjustHandle');
var CT_PolarAdjustHandle = /** @class */ (function (_super) {
    tslib_1.__extends(CT_PolarAdjustHandle, _super);
    function CT_PolarAdjustHandle() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.c = Nullable$1.toNullable(ST_GeomGuideName.$, null);
        _this.g = Nullable$1.toNullable(ST_AdjCoordinate.$, null);
        _this.e = Nullable$1.toNullable(ST_AdjCoordinate.$, null);
        _this.b = Nullable$1.toNullable(ST_GeomGuideName.$, null);
        _this.f = Nullable$1.toNullable(ST_AdjAngle.$, null);
        _this.d = Nullable$1.toNullable(ST_AdjAngle.$, null);
        return _this;
    }
    CT_PolarAdjustHandle.$t = markType(CT_PolarAdjustHandle, 'CT_PolarAdjustHandle', Base.$, [IAdjustHandle_$type]);
    return CT_PolarAdjustHandle;
}(Base));
export { CT_PolarAdjustHandle };
var CT_PositiveFixedAngle = /** @class */ (function (_super) {
    tslib_1.__extends(CT_PositiveFixedAngle, _super);
    function CT_PositiveFixedAngle() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new ST_PositiveFixedAngle();
        return _this;
    }
    CT_PositiveFixedAngle.$t = markType(CT_PositiveFixedAngle, 'CT_PositiveFixedAngle');
    return CT_PositiveFixedAngle;
}(Base));
export { CT_PositiveFixedAngle };
var CT_PositiveFixedPercentage = /** @class */ (function (_super) {
    tslib_1.__extends(CT_PositiveFixedPercentage, _super);
    function CT_PositiveFixedPercentage() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new ST_PositiveFixedPercentage();
        return _this;
    }
    CT_PositiveFixedPercentage.$t = markType(CT_PositiveFixedPercentage, 'CT_PositiveFixedPercentage');
    return CT_PositiveFixedPercentage;
}(Base));
export { CT_PositiveFixedPercentage };
var CT_PositivePercentage = /** @class */ (function (_super) {
    tslib_1.__extends(CT_PositivePercentage, _super);
    function CT_PositivePercentage() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new ST_PositivePercentage();
        return _this;
    }
    CT_PositivePercentage.$t = markType(CT_PositivePercentage, 'CT_PositivePercentage');
    return CT_PositivePercentage;
}(Base));
export { CT_PositivePercentage };
export var IEG_ColorChoice_$type = new Type(null, 'IEG_ColorChoice');
var EG_ColorChoice = /** @class */ (function (_super) {
    tslib_1.__extends(EG_ColorChoice, _super);
    function EG_ColorChoice() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new List$1(IEG_ColorTransform_$type, 0);
        return _this;
    }
    Object.defineProperty(EG_ColorChoice.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: true,
        configurable: true
    });
    EG_ColorChoice.$t = markType(EG_ColorChoice, 'EG_ColorChoice', Base.$, [IEG_ColorChoice_$type]);
    return EG_ColorChoice;
}(Base));
export { EG_ColorChoice };
var CT_PresetColor_Core = /** @class */ (function (_super) {
    tslib_1.__extends(CT_PresetColor_Core, _super);
    function CT_PresetColor_Core() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = 0;
        return _this;
    }
    CT_PresetColor_Core.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_PresetColor$i(this, b);
    };
    CT_PresetColor_Core.$t = markType(CT_PresetColor_Core, 'CT_PresetColor_Core', EG_ColorChoice.$, [IEG_ColorChoice_$type]);
    return CT_PresetColor_Core;
}(EG_ColorChoice));
export { CT_PresetColor_Core };
var CT_PresetGeometry2D = /** @class */ (function (_super) {
    tslib_1.__extends(CT_PresetGeometry2D, _super);
    function CT_PresetGeometry2D() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = 0;
        return _this;
    }
    CT_PresetGeometry2D.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_PresetGeometry2D$i(this, b);
    };
    CT_PresetGeometry2D.$t = markType(CT_PresetGeometry2D, 'CT_PresetGeometry2D', Base.$, [IEG_Geometry_$type]);
    return CT_PresetGeometry2D;
}(Base));
export { CT_PresetGeometry2D };
var CT_PresetLineDashProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_PresetLineDashProperties, _super);
    function CT_PresetLineDashProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = Nullable$1.toNullable(ST_PresetLineDashVal_$type, null);
        return _this;
    }
    CT_PresetLineDashProperties.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_PresetLineDashProperties$i(this, b);
    };
    CT_PresetLineDashProperties.$t = markType(CT_PresetLineDashProperties, 'CT_PresetLineDashProperties', Base.$, [IEG_LineDashProperties_$type]);
    return CT_PresetLineDashProperties;
}(Base));
export { CT_PresetLineDashProperties };
export var IEG_TextRun_$type = new Type(null, 'IEG_TextRun');
var CT_RegularTextRun = /** @class */ (function (_super) {
    tslib_1.__extends(CT_RegularTextRun, _super);
    function CT_RegularTextRun() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = null;
        return _this;
    }
    CT_RegularTextRun.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_RegularTextRun$i(this, b);
    };
    CT_RegularTextRun.$t = markType(CT_RegularTextRun, 'CT_RegularTextRun', Base.$, [IEG_TextRun_$type]);
    return CT_RegularTextRun;
}(Base));
export { CT_RegularTextRun };
var CT_RelId = /** @class */ (function (_super) {
    tslib_1.__extends(CT_RelId, _super);
    function CT_RelId() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        return _this;
    }
    CT_RelId.$t = markType(CT_RelId, 'CT_RelId');
    return CT_RelId;
}(Base));
export { CT_RelId };
var CT_RelativeRect = /** @class */ (function (_super) {
    tslib_1.__extends(CT_RelativeRect, _super);
    function CT_RelativeRect() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new ST_Percentage();
        _this.b = new ST_Percentage();
        _this.c = new ST_Percentage();
        _this.d = new ST_Percentage();
        return _this;
    }
    Object.defineProperty(CT_RelativeRect.prototype, "e", {
        get: function () {
            return ST_Percentage.d(this.a, ST_Percentage.a(0)) || ST_Percentage.d(this.b, ST_Percentage.a(0)) || ST_Percentage.d(this.c, ST_Percentage.a(0)) || ST_Percentage.d(this.d, ST_Percentage.a(0));
        },
        enumerable: true,
        configurable: true
    });
    CT_RelativeRect.$t = markType(CT_RelativeRect, 'CT_RelativeRect');
    return CT_RelativeRect;
}(Base));
export { CT_RelativeRect };
var CT_SchemeColor = /** @class */ (function (_super) {
    tslib_1.__extends(CT_SchemeColor, _super);
    function CT_SchemeColor() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = 0;
        return _this;
    }
    CT_SchemeColor.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_SchemeColor$i(this, b);
    };
    CT_SchemeColor.$t = markType(CT_SchemeColor, 'CT_SchemeColor', EG_ColorChoice.$, [IEG_ColorChoice_$type]);
    return CT_SchemeColor;
}(EG_ColorChoice));
export { CT_SchemeColor };
var CT_Shape = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Shape, _super);
    function CT_Shape() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = false;
        _this.d = false;
        _this.e = null;
        _this.f = null;
        _this.a = null;
        _this._spPr = null;
        _this._style = null;
        _this.b = null;
        return _this;
    }
    Object.defineProperty(CT_Shape.prototype, "spPr", {
        get: function () {
            return this._spPr;
        },
        set: function (a) {
            this._spPr = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CT_Shape.prototype, "style", {
        get: function () {
            return this._style;
        },
        set: function (a) {
            this._style = a;
        },
        enumerable: true,
        configurable: true
    });
    CT_Shape.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_Shape$i(this, b);
    };
    CT_Shape.prototype.getStrictElementName = function (a) {
        return a._t.bw;
    };
    CT_Shape.$t = markType(CT_Shape, 'CT_Shape', Base.$, [IGraphicalObjectContent_$type, ICT_ShapePropertiesOwner_$type, ICT_ShapeStyleOwner_$type]);
    return CT_Shape;
}(Base));
export { CT_Shape };
var CT_ShapeLocking = /** @class */ (function (_super) {
    tslib_1.__extends(CT_ShapeLocking, _super);
    function CT_ShapeLocking() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.f = false;
        _this.j = false;
        _this.i = false;
        _this.c = false;
        _this.g = false;
        _this.h = false;
        _this.e = false;
        _this.a = false;
        _this.b = false;
        _this.d = false;
        _this.k = false;
        return _this;
    }
    CT_ShapeLocking.$t = markType(CT_ShapeLocking, 'CT_ShapeLocking');
    return CT_ShapeLocking;
}(Base));
export { CT_ShapeLocking };
var CT_ShapeNonVisual = /** @class */ (function (_super) {
    tslib_1.__extends(CT_ShapeNonVisual, _super);
    function CT_ShapeNonVisual() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = null;
        return _this;
    }
    CT_ShapeNonVisual.$t = markType(CT_ShapeNonVisual, 'CT_ShapeNonVisual', CT_NonVisualBase.$);
    return CT_ShapeNonVisual;
}(CT_NonVisualBase));
export { CT_ShapeNonVisual };
var CT_ShapeProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_ShapeProperties, _super);
    function CT_ShapeProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = null;
        _this.c = null;
        _this.d = null;
        return _this;
    }
    CT_ShapeProperties.f = function (a, b) {
        b = Nullable$1.toNullable(ST_BlackWhiteMode_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "bwMode":
                        b = Nullable$1.toNullable(ST_BlackWhiteMode_$type, XmlNamespaceDefinitionBase.b(ST_BlackWhiteMode_$type, c.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_10_1) { e_10 = { error: e_10_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_10) throw e_10.error; }
        }
        return {
            p1: b
        };
        var e_10, _2;
    };
    CT_ShapeProperties.$t = markType(CT_ShapeProperties, 'CT_ShapeProperties', CT_ShapePropertiesBase.$);
    return CT_ShapeProperties;
}(CT_ShapePropertiesBase));
export { CT_ShapeProperties };
var CT_ShapeStyle = /** @class */ (function (_super) {
    tslib_1.__extends(CT_ShapeStyle, _super);
    function CT_ShapeStyle() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = null;
        _this.b = null;
        _this.d = null;
        _this.a = null;
        return _this;
    }
    CT_ShapeStyle.$t = markType(CT_ShapeStyle, 'CT_ShapeStyle');
    return CT_ShapeStyle;
}(Base));
export { CT_ShapeStyle };
var CT_Slicer = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Slicer, _super);
    function CT_Slicer() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        return _this;
    }
    CT_Slicer.$t = markType(CT_Slicer, 'CT_Slicer');
    return CT_Slicer;
}(Base));
export { CT_Slicer };
var CT_SolidFillProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_SolidFillProperties, _super);
    function CT_SolidFillProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        return _this;
    }
    CT_SolidFillProperties.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_SolidFillProperties$i(this, b);
    };
    CT_SolidFillProperties.prototype._accept$21$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_SolidFillProperties$i(this, b);
    };
    CT_SolidFillProperties.$t = markType(CT_SolidFillProperties, 'CT_SolidFillProperties', Base.$, [IEG_FillProperties_$type, IEG_LineFillProperties_$type]);
    return CT_SolidFillProperties;
}(Base));
export { CT_SolidFillProperties };
var CT_SRgbColor = /** @class */ (function (_super) {
    tslib_1.__extends(CT_SRgbColor, _super);
    function CT_SRgbColor() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new ST_HexColorRGB();
        return _this;
    }
    CT_SRgbColor.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        if (b === void 0) { b = Type.getDefaultValue($tArg); }
        return a._visitCT_SRgbColor$i(this, b);
    };
    CT_SRgbColor.d = function (a, b) {
        b = new ST_HexColorRGB(0);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = ST_HexColorRGB.d(c.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_11_1) { e_11 = { error: e_11_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_11) throw e_11.error; }
        }
        return {
            p1: b
        };
        var e_11, _2;
    };
    CT_SRgbColor.$t = markType(CT_SRgbColor, 'CT_SRgbColor', EG_ColorChoice.$, [IEG_ColorChoice_$type]);
    return CT_SRgbColor;
}(EG_ColorChoice));
export { CT_SRgbColor };
export var IEG_FillModeProperties_$type = new Type(null, 'IEG_FillModeProperties');
var CT_StretchInfoProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_StretchInfoProperties, _super);
    function CT_StretchInfoProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        return _this;
    }
    CT_StretchInfoProperties.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_StretchInfoProperties$i(this, b);
    };
    CT_StretchInfoProperties.$t = markType(CT_StretchInfoProperties, 'CT_StretchInfoProperties', Base.$, [IEG_FillModeProperties_$type]);
    return CT_StretchInfoProperties;
}(Base));
export { CT_StretchInfoProperties };
var CT_StyleMatrixReference = /** @class */ (function (_super) {
    tslib_1.__extends(CT_StyleMatrixReference, _super);
    function CT_StyleMatrixReference() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = 0;
        return _this;
    }
    CT_StyleMatrixReference.$t = markType(CT_StyleMatrixReference, 'CT_StyleMatrixReference');
    return CT_StyleMatrixReference;
}(Base));
export { CT_StyleMatrixReference };
var CT_SysColor = /** @class */ (function (_super) {
    tslib_1.__extends(CT_SysColor, _super);
    function CT_SysColor() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new ST_HexColorRGB();
        _this.d = 0;
        return _this;
    }
    CT_SysColor.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        if (b === void 0) { b = Type.getDefaultValue($tArg); }
        return a._visitCT_SysColor$i(this, b);
    };
    CT_SysColor.$t = markType(CT_SysColor, 'CT_SysColor', EG_ColorChoice.$, [IEG_ColorChoice_$type]);
    return CT_SysColor;
}(EG_ColorChoice));
export { CT_SysColor };
var CT_TextBody = /** @class */ (function (_super) {
    tslib_1.__extends(CT_TextBody, _super);
    function CT_TextBody() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = null;
        _this.c = new List$1(CT_TextParagraph.$, 0);
        return _this;
    }
    Object.defineProperty(CT_TextBody.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: true,
        configurable: true
    });
    CT_TextBody.$t = markType(CT_TextBody, 'CT_TextBody');
    return CT_TextBody;
}(Base));
export { CT_TextBody };
var ST_Coordinate32Unqualified = /** @class */ (function (_super) {
    tslib_1.__extends(ST_Coordinate32Unqualified, _super);
    function ST_Coordinate32Unqualified(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.d = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.d = c;
                }
                break;
        }
        return _this;
    }
    Object.defineProperty(ST_Coordinate32Unqualified.prototype, "g", {
        get: function () {
            return this.d;
        },
        enumerable: true,
        configurable: true
    });
    ST_Coordinate32Unqualified.c = function (a) {
        return ST_Coordinate32Unqualified.a(parseInt32_2(a, 7, CultureInfo.invariantCulture));
    };
    ST_Coordinate32Unqualified.j = function (a) {
        var b;
        if (((function () { var c = tryParseInt32_2(a, 7, CultureInfo.invariantCulture, b); b = c.p3; return c.ret; })())) {
            return Nullable$1.toNullable(ST_Coordinate32Unqualified.$, ST_Coordinate32Unqualified.a(b));
        }
        return Nullable$1.toNullable(ST_Coordinate32Unqualified.$, null);
    };
    ST_Coordinate32Unqualified.prototype.toString = function () {
        return this.d.toString();
    };
    ST_Coordinate32Unqualified.e = function (a) {
        return a.d;
    };
    ST_Coordinate32Unqualified.h = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_Coordinate32Unqualified.e(a.value));
    };
    ST_Coordinate32Unqualified.a = function (a) {
        return new ST_Coordinate32Unqualified(1, a);
    };
    ST_Coordinate32Unqualified.i = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Coordinate32Unqualified.$, null);
        }
        return Nullable$1.toNullable(ST_Coordinate32Unqualified.$, ST_Coordinate32Unqualified.a(a.value));
    };
    ST_Coordinate32Unqualified.$t = markStruct(ST_Coordinate32Unqualified, 'ST_Coordinate32Unqualified');
    return ST_Coordinate32Unqualified;
}(ValueType));
export { ST_Coordinate32Unqualified };
var ST_Coordinate32 = /** @class */ (function (_super) {
    tslib_1.__extends(ST_Coordinate32, _super);
    function ST_Coordinate32(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.k = Nullable$1.toNullable(ST_Coordinate32Unqualified.$, null);
        _this.l = Nullable$1.toNullable(ST_UniversalMeasure.$, null);
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.k = Nullable$1.toNullable(ST_Coordinate32Unqualified.$, c);
                    _this.l = Nullable$1.toNullable(ST_UniversalMeasure.$, null);
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    _this.k = Nullable$1.toNullable(ST_Coordinate32Unqualified.$, null);
                    _this.l = Nullable$1.toNullable(ST_UniversalMeasure.$, c);
                }
                break;
        }
        return _this;
    }
    ST_Coordinate32.prototype.j = function () {
        if (nullableNotEquals(this.k, null)) {
            return this.k.value.g;
        }
        if (ST_UniversalMeasure.f(this.l, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return this.l.value.m();
        }
        return 0;
    };
    ST_Coordinate32.g = function (a) {
        var b = ST_Coordinate32.q(a);
        if (nullableNotEquals(b, null)) {
            return b.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_Coordinate32.$, a);
    };
    ST_Coordinate32.q = function (a) {
        var b = ST_Coordinate32Unqualified.j(a);
        if (nullableNotEquals(b, null)) {
            return Nullable$1.toNullable(ST_Coordinate32.$, ST_Coordinate32.b(b.getValueOrDefault()));
        }
        var c = ST_UniversalMeasure.o(a);
        if (ST_UniversalMeasure.f(c, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return Nullable$1.toNullable(ST_Coordinate32.$, ST_Coordinate32.c(c.getValueOrDefault()));
        }
        return Nullable$1.toNullable(ST_Coordinate32.$, null);
    };
    ST_Coordinate32.prototype.toString = function () {
        if (nullableNotEquals(this.k, null)) {
            return this.k.getValueOrDefault().toString();
        }
        if (ST_UniversalMeasure.f(this.l, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return this.l.getValueOrDefault().toString();
        }
        return stringEmpty();
    };
    ST_Coordinate32.a = function (a) {
        return new ST_Coordinate32(1, ST_Coordinate32Unqualified.a(a));
    };
    ST_Coordinate32.n = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Coordinate32.$, null);
        }
        return Nullable$1.toNullable(ST_Coordinate32.$, ST_Coordinate32.a(a.value));
    };
    ST_Coordinate32.b = function (a) {
        return new ST_Coordinate32(1, a);
    };
    ST_Coordinate32.o = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Coordinate32.$, null);
        }
        return Nullable$1.toNullable(ST_Coordinate32.$, ST_Coordinate32.b(a.value));
    };
    ST_Coordinate32.h = function (a) {
        return a.k.value;
    };
    ST_Coordinate32.m = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Coordinate32Unqualified.$, null);
        }
        return Nullable$1.toNullable(ST_Coordinate32Unqualified.$, ST_Coordinate32.h(a.value));
    };
    ST_Coordinate32.c = function (a) {
        return new ST_Coordinate32(2, a);
    };
    ST_Coordinate32.p = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Coordinate32.$, null);
        }
        return Nullable$1.toNullable(ST_Coordinate32.$, ST_Coordinate32.c(a.value));
    };
    ST_Coordinate32.$t = markStruct(ST_Coordinate32, 'ST_Coordinate32');
    return ST_Coordinate32;
}(ValueType));
export { ST_Coordinate32 };
var CT_TextBodyProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_TextBodyProperties, _super);
    function CT_TextBodyProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = Nullable$1.toNullable(ST_TextAnchoringType_$type, null);
        _this.e = Nullable$1.toNullable(Boolean_$type, null);
        _this.f = Nullable$1.toNullable(ST_Coordinate32.$, null);
        _this.g = Nullable$1.toNullable(Boolean_$type, null);
        _this.h = Nullable$1.toNullable(Boolean_$type, null);
        _this.i = Nullable$1.toNullable(Boolean_$type, null);
        _this.j = Nullable$1.toNullable(ST_Coordinate32.$, null);
        _this.k = Nullable$1.toNullable(Number_$type, null);
        _this.l = Nullable$1.toNullable(Boolean_$type, null);
        _this.m = Nullable$1.toNullable(ST_Coordinate32.$, null);
        _this.n = Nullable$1.toNullable(Number_$type, null);
        _this.o = Nullable$1.toNullable(Number_$type, null);
        _this.p = Nullable$1.toNullable(ST_TextHorzOverflowType_$type, null);
        _this.c = false;
        _this.q = Nullable$1.toNullable(ST_TextVertOverflowType_$type, null);
        _this.r = Nullable$1.toNullable(ST_TextWrappingType_$type, null);
        _this.s = Nullable$1.toNullable(ST_Coordinate32.$, null);
        _this.t = Nullable$1.toNullable(ST_TextVerticalType_$type, null);
        return _this;
    }
    CT_TextBodyProperties.b = function (a) {
        var b = null;
        if (a != null) {
            b = typeCast(CT_TextBodyProperties.$, a);
            if (b == null) {
                b = new CT_TextBodyProperties();
                b.a = a.a;
            }
        }
        return b || new CT_TextBodyProperties();
    };
    CT_TextBodyProperties.$t = markType(CT_TextBodyProperties, 'CT_TextBodyProperties', CT_TextBodyPropertiesBase.$);
    return CT_TextBodyProperties;
}(CT_TextBodyPropertiesBase));
export { CT_TextBodyProperties };
var ST_TextPointUnqualified = /** @class */ (function (_super) {
    tslib_1.__extends(ST_TextPointUnqualified, _super);
    function ST_TextPointUnqualified(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.d = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    DocCoreUtils.au(ST_TextPointUnqualified.$, c, "value", -400000, 400000);
                    _this.d = c;
                }
                break;
        }
        return _this;
    }
    ST_TextPointUnqualified.c = function (a) {
        return ST_TextPointUnqualified.a(parseInt32_2(a, 7, CultureInfo.invariantCulture));
    };
    ST_TextPointUnqualified.i = function (a) {
        var b;
        if (((function () { var c = tryParseInt32_2(a, 7, CultureInfo.invariantCulture, b); b = c.p3; return c.ret; })())) {
            return Nullable$1.toNullable(ST_TextPointUnqualified.$, ST_TextPointUnqualified.a(b));
        }
        return Nullable$1.toNullable(ST_TextPointUnqualified.$, null);
    };
    ST_TextPointUnqualified.prototype.toString = function () {
        return this.d.toString();
    };
    ST_TextPointUnqualified.e = function (a) {
        return a.d;
    };
    ST_TextPointUnqualified.g = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_TextPointUnqualified.e(a.value));
    };
    ST_TextPointUnqualified.a = function (a) {
        return new ST_TextPointUnqualified(1, a);
    };
    ST_TextPointUnqualified.h = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_TextPointUnqualified.$, null);
        }
        return Nullable$1.toNullable(ST_TextPointUnqualified.$, ST_TextPointUnqualified.a(a.value));
    };
    ST_TextPointUnqualified.$t = markStruct(ST_TextPointUnqualified, 'ST_TextPointUnqualified');
    return ST_TextPointUnqualified;
}(ValueType));
export { ST_TextPointUnqualified };
var ST_TextPoint = /** @class */ (function (_super) {
    tslib_1.__extends(ST_TextPoint, _super);
    function ST_TextPoint(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.b = Nullable$1.toNullable(ST_TextPointUnqualified.$, null);
        _this.c = Nullable$1.toNullable(ST_UniversalMeasure.$, null);
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.b = Nullable$1.toNullable(ST_TextPointUnqualified.$, c);
                    _this.c = Nullable$1.toNullable(ST_UniversalMeasure.$, null);
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    _this.b = Nullable$1.toNullable(ST_TextPointUnqualified.$, null);
                    _this.c = Nullable$1.toNullable(ST_UniversalMeasure.$, c);
                }
                break;
        }
        return _this;
    }
    ST_TextPoint.prototype.toString = function () {
        if (nullableNotEquals(this.b, null)) {
            return this.b.toString();
        }
        if (ST_UniversalMeasure.f(this.c, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return this.c.toString();
        }
        return stringEmpty();
    };
    ST_TextPoint.a = function (a) {
        var b = ST_TextPointUnqualified.i(a);
        if (nullableNotEquals(b, null)) {
            return new ST_TextPoint(1, b.value);
        }
        var c = ST_UniversalMeasure.o(a);
        if (ST_UniversalMeasure.f(c, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return new ST_TextPoint(2, c.value);
        }
        throw DocCoreUtils.m(ST_TextPoint.$, a);
    };
    ST_TextPoint.$t = markStruct(ST_TextPoint, 'ST_TextPoint');
    return ST_TextPoint;
}(ValueType));
export { ST_TextPoint };
var ST_Percentage = /** @class */ (function (_super) {
    tslib_1.__extends(ST_Percentage, _super);
    function ST_Percentage(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.j = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.j = c;
                }
                break;
        }
        return _this;
    }
    ST_Percentage.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_Percentage.$, typeCast(ST_Percentage.$, a));
        if (ST_Percentage.g(b, Nullable$1.toNullable(ST_Percentage.$, null))) {
            return false;
        }
        return ST_Percentage.d(this, b.getValueOrDefault());
    };
    ST_Percentage.prototype.getHashCode = function () {
        return (this.j);
    };
    ST_Percentage.prototype.toString = function () {
        return this.p(1);
    };
    ST_Percentage.prototype.p = function (a) {
        var t1 = a;
        L0: while (true) {
            switch (t1) {
                case 0: return truncate(DocCoreUtils.i(this.j * 1000)).toString();
                case 1: return numberToString(this.j, CultureInfo.invariantCulture) + "%";
                default:
                    t1 = 0;
                    continue L0;
            }
            break;
        }
    };
    ST_Percentage.c = function (a, b) {
        var c = ST_Percentage.o(a, b);
        if (ST_Percentage.g(c, Nullable$1.toNullable(ST_Percentage.$, null))) {
            return c.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_Percentage.$, a);
    };
    ST_Percentage.o = function (a, b) {
        if (stringIsNullOrEmpty(a)) {
            return Nullable$1.toNullable(ST_Percentage.$, null);
        }
        var t1 = b;
        var _loop_2 = function () {
            switch (t1) {
                case 0:
                    {
                        if (a.charAt(a.length - 1) == '%') {
                            t1 = 1;
                            return "continue-L0";
                        }
                        var c_2;
                        if (((function () { var d = tryParseInt32_2(a, 7, CultureInfo.invariantCulture, c_2); c_2 = d.p3; return d.ret; })()) == false) {
                            return { value: Nullable$1.toNullable(ST_Percentage.$, null) };
                        }
                        return { value: Nullable$1.toNullable(ST_Percentage.$, new ST_Percentage(1, c_2 / 1000)) };
                    }
                case 1:
                    {
                        if (a.charAt(a.length - 1) != '%') {
                            t1 = 0;
                            return "continue-L0";
                        }
                        var d_2;
                        if (((function () { var e = tryParseNumber1(a.substr(0, a.length - 1), 167 | 64, CultureInfo.invariantCulture, d_2); d_2 = e.p3; return e.ret; })()) == false) {
                            return { value: Nullable$1.toNullable(ST_Percentage.$, null) };
                        }
                        return { value: Nullable$1.toNullable(ST_Percentage.$, ST_Percentage.a(d_2)) };
                    }
                default: return { value: Nullable$1.toNullable(ST_Percentage.$, null) };
            }
            return "break";
        };
        L0: while (true) {
            var state_2 = _loop_2();
            if (typeof state_2 === "object")
                return state_2.value;
            if (state_2 === "break")
                break;
            switch (state_2) {
                case "continue-L0": continue L0;
            }
        }
    };
    ST_Percentage.d = function (a, b) {
        return a.j == b.j;
    };
    ST_Percentage.e = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_Percentage.d(a.value, b.value);
    };
    ST_Percentage.f = function (a, b) {
        return !(ST_Percentage.d(a, b));
    };
    ST_Percentage.g = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_Percentage.f(a.value, b.value);
    };
    ST_Percentage.a = function (a) {
        return new ST_Percentage(1, a);
    };
    ST_Percentage.n = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Percentage.$, null);
        }
        return Nullable$1.toNullable(ST_Percentage.$, ST_Percentage.a(a.value));
    };
    ST_Percentage.k = function (a) {
        return a.j;
    };
    ST_Percentage.m = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_Percentage.k(a.value));
    };
    ST_Percentage.$t = markStruct(ST_Percentage, 'ST_Percentage');
    return ST_Percentage;
}(ValueType));
export { ST_Percentage };
var CT_TextCharacterPropertiesBase = /** @class */ (function (_super) {
    tslib_1.__extends(CT_TextCharacterPropertiesBase, _super);
    function CT_TextCharacterPropertiesBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = null;
        _this.b = null;
        _this.a = null;
        _this.k = Nullable$1.toNullable(Boolean_$type, null);
        _this.v = null;
        _this.t = null;
        _this.r = Nullable$1.toNullable(Number_$type, null);
        _this.d = Nullable$1.toNullable(Boolean_$type, null);
        _this.i = Nullable$1.toNullable(Boolean_$type, null);
        _this.s = Nullable$1.toNullable(ST_TextUnderlineType_$type, null);
        _this.q = Nullable$1.toNullable(ST_TextStrikeType_$type, null);
        _this.j = Nullable$1.toNullable(Number_$type, null);
        _this.f = Nullable$1.toNullable(ST_TextCapsType_$type, null);
        _this.p = Nullable$1.toNullable(ST_TextPoint.$, null);
        _this.m = Nullable$1.toNullable(Boolean_$type, null);
        _this.e = Nullable$1.toNullable(ST_Percentage.$, null);
        _this.l = Nullable$1.toNullable(Boolean_$type, null);
        _this.g = Nullable$1.toNullable(Boolean_$type, null);
        _this.h = Nullable$1.toNullable(Boolean_$type, null);
        _this.n = Nullable$1.toNullable(Boolean_$type, null);
        _this.o = Nullable$1.toNullable(Number_$type, null);
        _this.u = null;
        return _this;
    }
    CT_TextCharacterPropertiesBase.$t = markType(CT_TextCharacterPropertiesBase, 'CT_TextCharacterPropertiesBase');
    return CT_TextCharacterPropertiesBase;
}(Base));
export { CT_TextCharacterPropertiesBase };
var CT_TextCharacterProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_TextCharacterProperties, _super);
    function CT_TextCharacterProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.y = null;
        _this.w = null;
        return _this;
    }
    CT_TextCharacterProperties.prototype.cloneShallow = function () {
        return this.memberwiseClone();
    };
    CT_TextCharacterProperties.$t = markType(CT_TextCharacterProperties, 'CT_TextCharacterProperties', CT_TextCharacterPropertiesBase.$, [IShallowCloneable_$type]);
    return CT_TextCharacterProperties;
}(CT_TextCharacterPropertiesBase));
export { CT_TextCharacterProperties };
var CT_TextFont = /** @class */ (function (_super) {
    tslib_1.__extends(CT_TextFont, _super);
    function CT_TextFont() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = null;
        _this.a = null;
        _this.c = Nullable$1.toNullable(Number_$type, null);
        _this.b = Nullable$1.toNullable(Number_$type, null);
        return _this;
    }
    CT_TextFont.$t = markType(CT_TextFont, 'CT_TextFont');
    return CT_TextFont;
}(Base));
export { CT_TextFont };
var CT_TextListStyle = /** @class */ (function (_super) {
    tslib_1.__extends(CT_TextListStyle, _super);
    function CT_TextListStyle() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = null;
        _this.c = null;
        _this.d = null;
        _this.e = null;
        _this.f = null;
        _this.g = null;
        _this.h = null;
        _this.i = null;
        _this.j = null;
        _this.k = null;
        return _this;
    }
    CT_TextListStyle.prototype.setProperty = function (a, b) {
        switch (a) {
            case 449:
                this.a = typeCast(CT_TextParagraphProperties.$, b);
                break;
            case 940:
                this.b = typeCast(CT_TextParagraphProperties.$, b);
                break;
            case 941:
                this.c = typeCast(CT_TextParagraphProperties.$, b);
                break;
            case 942:
                this.d = typeCast(CT_TextParagraphProperties.$, b);
                break;
            case 943:
                this.e = typeCast(CT_TextParagraphProperties.$, b);
                break;
            case 944:
                this.f = typeCast(CT_TextParagraphProperties.$, b);
                break;
            case 945:
                this.g = typeCast(CT_TextParagraphProperties.$, b);
                break;
            case 946:
                this.h = typeCast(CT_TextParagraphProperties.$, b);
                break;
            case 947:
                this.i = typeCast(CT_TextParagraphProperties.$, b);
                break;
            case 948:
                this.j = typeCast(CT_TextParagraphProperties.$, b);
                break;
            case 596:
                this.k = b;
                break;
        }
    };
    CT_TextListStyle.$t = markType(CT_TextListStyle, 'CT_TextListStyle', Base.$, [ISupportSetProperty_$type]);
    return CT_TextListStyle;
}(Base));
export { CT_TextListStyle };
var CT_TextParagraph = /** @class */ (function (_super) {
    tslib_1.__extends(CT_TextParagraph, _super);
    function CT_TextParagraph() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = new List$1(IEG_TextRun_$type, 0);
        return _this;
    }
    Object.defineProperty(CT_TextParagraph.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: true,
        configurable: true
    });
    CT_TextParagraph.$t = markType(CT_TextParagraph, 'CT_TextParagraph');
    return CT_TextParagraph;
}(Base));
export { CT_TextParagraph };
var ST_TextMargin = /** @class */ (function (_super) {
    tslib_1.__extends(ST_TextMargin, _super);
    function ST_TextMargin(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.d = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    DocCoreUtils.au(ST_TextMargin.$, c, "value", 0, 51206400);
                    _this.d = c;
                }
                break;
        }
        return _this;
    }
    ST_TextMargin.c = function (a) {
        return ST_TextMargin.a(parseInt32_2(a, 7, CultureInfo.invariantCulture));
    };
    ST_TextMargin.i = function (a) {
        var b;
        if (((function () { var c = tryParseInt32_2(a, 7, CultureInfo.invariantCulture, b); b = c.p3; return c.ret; })())) {
            return Nullable$1.toNullable(ST_TextMargin.$, ST_TextMargin.a(b));
        }
        return Nullable$1.toNullable(ST_TextMargin.$, null);
    };
    ST_TextMargin.prototype.toString = function () {
        return this.d.toString();
    };
    ST_TextMargin.e = function (a) {
        return a.d;
    };
    ST_TextMargin.g = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_TextMargin.e(a.value));
    };
    ST_TextMargin.a = function (a) {
        return new ST_TextMargin(1, a);
    };
    ST_TextMargin.h = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_TextMargin.$, null);
        }
        return Nullable$1.toNullable(ST_TextMargin.$, ST_TextMargin.a(a.value));
    };
    ST_TextMargin.$t = markStruct(ST_TextMargin, 'ST_TextMargin');
    return ST_TextMargin;
}(ValueType));
export { ST_TextMargin };
var ST_TextIndentLevelType = /** @class */ (function (_super) {
    tslib_1.__extends(ST_TextIndentLevelType, _super);
    function ST_TextIndentLevelType(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.d = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    DocCoreUtils.au(ST_TextIndentLevelType.$, c, "value", 0, 8);
                    _this.d = c;
                }
                break;
        }
        return _this;
    }
    ST_TextIndentLevelType.c = function (a) {
        return ST_TextIndentLevelType.a(parseInt32_2(a, 7, CultureInfo.invariantCulture));
    };
    ST_TextIndentLevelType.i = function (a) {
        var b;
        if (((function () { var c = tryParseInt32_2(a, 7, CultureInfo.invariantCulture, b); b = c.p3; return c.ret; })())) {
            return Nullable$1.toNullable(ST_TextIndentLevelType.$, ST_TextIndentLevelType.a(b));
        }
        return Nullable$1.toNullable(ST_TextIndentLevelType.$, null);
    };
    ST_TextIndentLevelType.prototype.toString = function () {
        return this.d.toString();
    };
    ST_TextIndentLevelType.e = function (a) {
        return a.d;
    };
    ST_TextIndentLevelType.g = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_TextIndentLevelType.e(a.value));
    };
    ST_TextIndentLevelType.a = function (a) {
        return new ST_TextIndentLevelType(1, a);
    };
    ST_TextIndentLevelType.h = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_TextIndentLevelType.$, null);
        }
        return Nullable$1.toNullable(ST_TextIndentLevelType.$, ST_TextIndentLevelType.a(a.value));
    };
    ST_TextIndentLevelType.$t = markStruct(ST_TextIndentLevelType, 'ST_TextIndentLevelType');
    return ST_TextIndentLevelType;
}(ValueType));
export { ST_TextIndentLevelType };
var ST_TextIndent = /** @class */ (function (_super) {
    tslib_1.__extends(ST_TextIndent, _super);
    function ST_TextIndent(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.d = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    DocCoreUtils.au(ST_TextIndent.$, c, "value", -51206400, 51206400);
                    _this.d = c;
                }
                break;
        }
        return _this;
    }
    ST_TextIndent.c = function (a) {
        return ST_TextIndent.a(parseInt32_2(a, 7, CultureInfo.invariantCulture));
    };
    ST_TextIndent.i = function (a) {
        var b;
        if (((function () { var c = tryParseInt32_2(a, 7, CultureInfo.invariantCulture, b); b = c.p3; return c.ret; })())) {
            return Nullable$1.toNullable(ST_TextIndent.$, ST_TextIndent.a(b));
        }
        return Nullable$1.toNullable(ST_TextIndent.$, null);
    };
    ST_TextIndent.prototype.toString = function () {
        return this.d.toString();
    };
    ST_TextIndent.e = function (a) {
        return a.d;
    };
    ST_TextIndent.g = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_TextIndent.e(a.value));
    };
    ST_TextIndent.a = function (a) {
        return new ST_TextIndent(1, a);
    };
    ST_TextIndent.h = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_TextIndent.$, null);
        }
        return Nullable$1.toNullable(ST_TextIndent.$, ST_TextIndent.a(a.value));
    };
    ST_TextIndent.$t = markStruct(ST_TextIndent, 'ST_TextIndent');
    return ST_TextIndent;
}(ValueType));
export { ST_TextIndent };
var CT_TextParagraphProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_TextParagraphProperties, _super);
    function CT_TextParagraphProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.i = Nullable$1.toNullable(ST_TextMargin.$, null);
        _this.j = Nullable$1.toNullable(ST_TextMargin.$, null);
        _this.h = Nullable$1.toNullable(ST_TextIndentLevelType.$, null);
        _this.f = Nullable$1.toNullable(ST_TextIndent.$, null);
        _this.a = Nullable$1.toNullable(ST_TextAlignType_$type, null);
        _this.b = Nullable$1.toNullable(ST_Coordinate32.$, null);
        _this.k = Nullable$1.toNullable(Boolean_$type, null);
        _this.c = Nullable$1.toNullable(Boolean_$type, null);
        _this.d = Nullable$1.toNullable(ST_TextFontAlignType_$type, null);
        _this.g = Nullable$1.toNullable(Boolean_$type, null);
        _this.e = Nullable$1.toNullable(Boolean_$type, null);
        return _this;
    }
    CT_TextParagraphProperties.$t = markType(CT_TextParagraphProperties, 'CT_TextParagraphProperties');
    return CT_TextParagraphProperties;
}(Base));
export { CT_TextParagraphProperties };
var CT_TileInfoProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CT_TileInfoProperties, _super);
    function CT_TileInfoProperties() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = Nullable$1.toNullable(ST_RectAlignment_$type, null);
        _this.b = Nullable$1.toNullable(ST_TileFlipMode_$type, null);
        _this.c = Nullable$1.toNullable(ST_Percentage.$, null);
        _this.d = Nullable$1.toNullable(ST_Percentage.$, null);
        _this.e = Nullable$1.toNullable(ST_Coordinate.$, null);
        _this.f = Nullable$1.toNullable(ST_Coordinate.$, null);
        return _this;
    }
    CT_TileInfoProperties.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitCT_TileInfoProperties$i(this, b);
    };
    CT_TileInfoProperties.$t = markType(CT_TileInfoProperties, 'CT_TileInfoProperties', Base.$, [IEG_FillModeProperties_$type]);
    return CT_TileInfoProperties;
}(Base));
export { CT_TileInfoProperties };
var CT_XYAdjustHandle = /** @class */ (function (_super) {
    tslib_1.__extends(CT_XYAdjustHandle, _super);
    function CT_XYAdjustHandle() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.b = Nullable$1.toNullable(ST_GeomGuideName.$, null);
        _this.f = Nullable$1.toNullable(ST_AdjCoordinate.$, null);
        _this.d = Nullable$1.toNullable(ST_AdjCoordinate.$, null);
        _this.c = Nullable$1.toNullable(ST_GeomGuideName.$, null);
        _this.g = Nullable$1.toNullable(ST_AdjCoordinate.$, null);
        _this.e = Nullable$1.toNullable(ST_AdjCoordinate.$, null);
        return _this;
    }
    CT_XYAdjustHandle.$t = markType(CT_XYAdjustHandle, 'CT_XYAdjustHandle', Base.$, [IAdjustHandle_$type]);
    return CT_XYAdjustHandle;
}(Base));
export { CT_XYAdjustHandle };
export var IEG_ColorChoiceVisitor$2_$type = new Type(null, 'IEG_ColorChoiceVisitor$2');
export var IEG_ColorTransform_$type = new Type(null, 'IEG_ColorTransform');
export var IEG_ColorTransformVisitor$2_$type = new Type(null, 'IEG_ColorTransformVisitor$2');
export var IEG_FillModePropertiesVisitor$2_$type = new Type(null, 'IEG_FillModePropertiesVisitor$2');
export var IEG_FillPropertiesVisitor$2_$type = new Type(null, 'IEG_FillPropertiesVisitor$2');
export var IEG_GeometryVisitor$2_$type = new Type(null, 'IEG_GeometryVisitor$2');
export var IEG_LineDashPropertiesVisitor$2_$type = new Type(null, 'IEG_LineDashPropertiesVisitor$2');
export var IEG_LineFillPropertiesVisitor$2_$type = new Type(null, 'IEG_LineFillPropertiesVisitor$2');
export var IEG_LineJoinPropertiesVisitor$2_$type = new Type(null, 'IEG_LineJoinPropertiesVisitor$2');
export var IEG_TextRunVisitor$2_$type = new Type(null, 'IEG_TextRunVisitor$2');
export var IGraphicalObjectContentVisitor$2_$type = new Type(null, 'IGraphicalObjectContentVisitor$2');
export var IPath2DCommandVisitor$2_$type = new Type(null, 'IPath2DCommandVisitor$2');
var ColorTransform_Alpha = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_Alpha, _super);
    function ColorTransform_Alpha() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_Alpha.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_Alpha$i(this, b);
    };
    ColorTransform_Alpha.$t = markType(ColorTransform_Alpha, 'ColorTransform_Alpha', CT_PositiveFixedPercentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_Alpha;
}(CT_PositiveFixedPercentage));
export { ColorTransform_Alpha };
var ColorTransform_AlphaOff = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_AlphaOff, _super);
    function ColorTransform_AlphaOff() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_AlphaOff.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_AlphaOff$i(this, b);
    };
    ColorTransform_AlphaOff.$t = markType(ColorTransform_AlphaOff, 'ColorTransform_AlphaOff', CT_FixedPercentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_AlphaOff;
}(CT_FixedPercentage));
export { ColorTransform_AlphaOff };
var ColorTransform_AlphaMod = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_AlphaMod, _super);
    function ColorTransform_AlphaMod() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_AlphaMod.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_AlphaMod$i(this, b);
    };
    ColorTransform_AlphaMod.$t = markType(ColorTransform_AlphaMod, 'ColorTransform_AlphaMod', CT_PositivePercentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_AlphaMod;
}(CT_PositivePercentage));
export { ColorTransform_AlphaMod };
var ColorTransform_Blue = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_Blue, _super);
    function ColorTransform_Blue() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_Blue.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_Blue$i(this, b);
    };
    ColorTransform_Blue.$t = markType(ColorTransform_Blue, 'ColorTransform_Blue', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_Blue;
}(CT_Percentage));
export { ColorTransform_Blue };
var ColorTransform_BlueOff = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_BlueOff, _super);
    function ColorTransform_BlueOff() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_BlueOff.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_BlueOff$i(this, b);
    };
    ColorTransform_BlueOff.$t = markType(ColorTransform_BlueOff, 'ColorTransform_BlueOff', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_BlueOff;
}(CT_Percentage));
export { ColorTransform_BlueOff };
var ColorTransform_BlueMod = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_BlueMod, _super);
    function ColorTransform_BlueMod() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_BlueMod.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_BlueMod$i(this, b);
    };
    ColorTransform_BlueMod.$t = markType(ColorTransform_BlueMod, 'ColorTransform_BlueMod', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_BlueMod;
}(CT_Percentage));
export { ColorTransform_BlueMod };
var ColorTransform_Comp = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_Comp, _super);
    function ColorTransform_Comp() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_Comp.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_Comp$i(this, b);
    };
    ColorTransform_Comp.$t = markType(ColorTransform_Comp, 'ColorTransform_Comp', CT_ComplementTransform.$, [IEG_ColorTransform_$type]);
    return ColorTransform_Comp;
}(CT_ComplementTransform));
export { ColorTransform_Comp };
var ColorTransform_Gray = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_Gray, _super);
    function ColorTransform_Gray() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_Gray.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_Gray$i(this, b);
    };
    ColorTransform_Gray.$t = markType(ColorTransform_Gray, 'ColorTransform_Gray', CT_GrayscaleTransform.$, [IEG_ColorTransform_$type]);
    return ColorTransform_Gray;
}(CT_GrayscaleTransform));
export { ColorTransform_Gray };
var ColorTransform_Green = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_Green, _super);
    function ColorTransform_Green() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_Green.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_Green$i(this, b);
    };
    ColorTransform_Green.$t = markType(ColorTransform_Green, 'ColorTransform_Green', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_Green;
}(CT_Percentage));
export { ColorTransform_Green };
var ColorTransform_GreenOff = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_GreenOff, _super);
    function ColorTransform_GreenOff() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_GreenOff.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_GreenOff$i(this, b);
    };
    ColorTransform_GreenOff.$t = markType(ColorTransform_GreenOff, 'ColorTransform_GreenOff', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_GreenOff;
}(CT_Percentage));
export { ColorTransform_GreenOff };
var ColorTransform_GreenMod = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_GreenMod, _super);
    function ColorTransform_GreenMod() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_GreenMod.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_GreenMod$i(this, b);
    };
    ColorTransform_GreenMod.$t = markType(ColorTransform_GreenMod, 'ColorTransform_GreenMod', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_GreenMod;
}(CT_Percentage));
export { ColorTransform_GreenMod };
var ColorTransform_Hue = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_Hue, _super);
    function ColorTransform_Hue() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_Hue.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_Hue$i(this, b);
    };
    ColorTransform_Hue.$t = markType(ColorTransform_Hue, 'ColorTransform_Hue', CT_PositiveFixedAngle.$, [IEG_ColorTransform_$type]);
    return ColorTransform_Hue;
}(CT_PositiveFixedAngle));
export { ColorTransform_Hue };
var ColorTransform_HueOff = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_HueOff, _super);
    function ColorTransform_HueOff() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_HueOff.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_HueOff$i(this, b);
    };
    ColorTransform_HueOff.$t = markType(ColorTransform_HueOff, 'ColorTransform_HueOff', CT_Angle.$, [IEG_ColorTransform_$type]);
    return ColorTransform_HueOff;
}(CT_Angle));
export { ColorTransform_HueOff };
var ColorTransform_HueMod = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_HueMod, _super);
    function ColorTransform_HueMod() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_HueMod.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_HueMod$i(this, b);
    };
    ColorTransform_HueMod.$t = markType(ColorTransform_HueMod, 'ColorTransform_HueMod', CT_PositivePercentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_HueMod;
}(CT_PositivePercentage));
export { ColorTransform_HueMod };
var ColorTransform_Inv = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_Inv, _super);
    function ColorTransform_Inv() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_Inv.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_Inv$i(this, b);
    };
    ColorTransform_Inv.$t = markType(ColorTransform_Inv, 'ColorTransform_Inv', CT_InverseTransform.$, [IEG_ColorTransform_$type]);
    return ColorTransform_Inv;
}(CT_InverseTransform));
export { ColorTransform_Inv };
var ColorTransform_Lum = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_Lum, _super);
    function ColorTransform_Lum() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_Lum.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_Lum$i(this, b);
    };
    ColorTransform_Lum.$t = markType(ColorTransform_Lum, 'ColorTransform_Lum', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_Lum;
}(CT_Percentage));
export { ColorTransform_Lum };
var ColorTransform_LumOff = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_LumOff, _super);
    function ColorTransform_LumOff() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_LumOff.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_LumOff$i(this, b);
    };
    ColorTransform_LumOff.$t = markType(ColorTransform_LumOff, 'ColorTransform_LumOff', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_LumOff;
}(CT_Percentage));
export { ColorTransform_LumOff };
var ColorTransform_LumMod = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_LumMod, _super);
    function ColorTransform_LumMod() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_LumMod.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_LumMod$i(this, b);
    };
    ColorTransform_LumMod.$t = markType(ColorTransform_LumMod, 'ColorTransform_LumMod', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_LumMod;
}(CT_Percentage));
export { ColorTransform_LumMod };
var ColorTransform_Red = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_Red, _super);
    function ColorTransform_Red() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_Red.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_Red$i(this, b);
    };
    ColorTransform_Red.$t = markType(ColorTransform_Red, 'ColorTransform_Red', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_Red;
}(CT_Percentage));
export { ColorTransform_Red };
var ColorTransform_RedOff = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_RedOff, _super);
    function ColorTransform_RedOff() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_RedOff.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_RedOff$i(this, b);
    };
    ColorTransform_RedOff.$t = markType(ColorTransform_RedOff, 'ColorTransform_RedOff', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_RedOff;
}(CT_Percentage));
export { ColorTransform_RedOff };
var ColorTransform_RedMod = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_RedMod, _super);
    function ColorTransform_RedMod() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_RedMod.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_RedMod$i(this, b);
    };
    ColorTransform_RedMod.$t = markType(ColorTransform_RedMod, 'ColorTransform_RedMod', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_RedMod;
}(CT_Percentage));
export { ColorTransform_RedMod };
var ColorTransform_Sat = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_Sat, _super);
    function ColorTransform_Sat() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_Sat.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_Sat$i(this, b);
    };
    ColorTransform_Sat.$t = markType(ColorTransform_Sat, 'ColorTransform_Sat', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_Sat;
}(CT_Percentage));
export { ColorTransform_Sat };
var ColorTransform_SatOff = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_SatOff, _super);
    function ColorTransform_SatOff() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_SatOff.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_SatOff$i(this, b);
    };
    ColorTransform_SatOff.$t = markType(ColorTransform_SatOff, 'ColorTransform_SatOff', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_SatOff;
}(CT_Percentage));
export { ColorTransform_SatOff };
var ColorTransform_SatMod = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_SatMod, _super);
    function ColorTransform_SatMod() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_SatMod.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_SatMod$i(this, b);
    };
    ColorTransform_SatMod.$t = markType(ColorTransform_SatMod, 'ColorTransform_SatMod', CT_Percentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_SatMod;
}(CT_Percentage));
export { ColorTransform_SatMod };
var ColorTransform_Shade = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_Shade, _super);
    function ColorTransform_Shade() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_Shade.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_Shade$i(this, b);
    };
    ColorTransform_Shade.$t = markType(ColorTransform_Shade, 'ColorTransform_Shade', CT_PositiveFixedPercentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_Shade;
}(CT_PositiveFixedPercentage));
export { ColorTransform_Shade };
var ColorTransform_Tint = /** @class */ (function (_super) {
    tslib_1.__extends(ColorTransform_Tint, _super);
    function ColorTransform_Tint() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColorTransform_Tint.prototype._accept$2$i = function ($tArg, $tResult, a, b) {
        return a._visitColorTransform_Tint$i(this, b);
    };
    ColorTransform_Tint.$t = markType(ColorTransform_Tint, 'ColorTransform_Tint', CT_PositiveFixedPercentage.$, [IEG_ColorTransform_$type]);
    return ColorTransform_Tint;
}(CT_PositiveFixedPercentage));
export { ColorTransform_Tint };
var ElementLoadCallbacks = /** @class */ (function (_super) {
    tslib_1.__extends(ElementLoadCallbacks, _super);
    function ElementLoadCallbacks(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.b = null;
        _this.a = null;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    _this.b = c;
                    _this.a = d;
                }
                break;
        }
        return _this;
    }
    Object.defineProperty(ElementLoadCallbacks.prototype, "c", {
        get: function () {
            return this.b == null && this.a == null;
        },
        enumerable: true,
        configurable: true
    });
    ElementLoadCallbacks.$t = markStruct(ElementLoadCallbacks, 'ElementLoadCallbacks');
    return ElementLoadCallbacks;
}(ValueType));
export { ElementLoadCallbacks };
var OfficeDocumentManager = /** @class */ (function (_super) {
    tslib_1.__extends(OfficeDocumentManager, _super);
    function OfficeDocumentManager(a, b, c, d) {
        var _this = _super.call(this) || this;
        _this._c = null;
        _this._ap = Nullable$1.toNullable(ST_ConformanceClass_$type, null);
        _this._ab = false;
        _this._aj = null;
        _this._al = null;
        _this._ag = null;
        _this._am = null;
        _this._aq = null;
        _this._ah = null;
        _this._ai = null;
        _this._y = null;
        _this._a = null;
        _this._ao = null;
        _this._h = null;
        _this._i = null;
        _this._m = null;
        _this._ax = null;
        _this._av = null;
        _this._aw = null;
        _this._af = false;
        _this._aj = new HashSet$1(String_$type, 0);
        _this._al = new Stack$1(IPackagePart_$type);
        _this._ag = new Dictionary$2(String_$type, Base.$, 0);
        _this._am = new Stack$1(OfficeDocumentManager_PartRelationshipCounter.$);
        _this._am.h(new OfficeDocumentManager_PartRelationshipCounter());
        _this._aq = {};
        _this._ah = new Dictionary$2(String_$type, PartManagerBase.$, 0);
        _this._ai = new Dictionary$2(String_$type, PartManagerBase.$, 0);
        _this._ap = d;
        _this._ab = c;
        _this._ao = b;
        if (a != null && _this._ao != null) {
            _this._a = new InvalidPackage();
            var e = WorkItemExtensions.f(IPackage_$type, a._open$i(_this._ao, _this._ab ? 3 : 2), function (f) {
                _this._a = WorkItemExtensions.m(IPackage_$type, f);
                return null;
            });
            _this._m = e;
        }
        else {
            _this._m = WorkItem.g(Base.$, null);
        }
        return _this;
    }
    OfficeDocumentManager.prototype.dispose = function () {
        this.disposeCore(true);
    };
    OfficeDocumentManager.prototype._a0 = function (a, b) {
        return this._a1(a, b.o(this._z));
    };
    OfficeDocumentManager.prototype._a1 = function (a, b) {
        return this._a2(a, b, 0);
    };
    OfficeDocumentManager.prototype._az = function (a, b) {
        return this._a2(a, b, 1);
    };
    OfficeDocumentManager.prototype._ay = function (a, b) {
        var c;
        if (((function () { var d = UriUtilities.a(a, c); c = d.p1; return d.ret; })())) {
            return this._az(c, b);
        }
        return this._a2(null, b, 1, a);
    };
    OfficeDocumentManager.prototype._j = function (a, b, c) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = null; }
        var d = a.n(this._v);
        if (a.g) {
            d = this._a6(d, a.h == false);
        }
        return this._k(a, d, b, c);
    };
    OfficeDocumentManager.prototype._k = function (a, b, c, d) {
        var _this = this;
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        var e = UriUtilities.b(b);
        var f;
        if (d != null && this._ae(d)) {
            f = d;
            this._be(e, a.o(this._z), 0, f, null);
        }
        else {
            f = this._a2(e, a.o(this._z), 0);
        }
        var g = this._c;
        return WorkItemExtensions.g(Tuple$2.$.specialize(Uri.$, String_$type), Async.h(function () {
            if (g != null) {
                _this._al.h(g);
            }
            var h = _this._a.createPart(e, a.m);
            _this._c = h;
            _this._am.h(new OfficeDocumentManager_PartRelationshipCounter());
            return WorkItemExtensions.a(Async.o(Stream.$, h.getStream(2, 2), function (i) {
                var j = a.e(_this, i);
                return j.b(c);
            }), function () {
                _this._am.e();
                _this._ag.addItem(b, c);
            });
        }, function () {
            if (g != null) {
                _this._al.e();
            }
            _this._c = g;
        }), function () { return Tuple.a(Uri.$, String_$type, e, f); });
    };
    OfficeDocumentManager.prototype._l = function (a, b, c, d) {
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        if (b == null) {
            return null;
        }
        var e = this._w(a);
        if (e == null) {
            return null;
        }
        return this._k(e, b, c, d);
    };
    OfficeDocumentManager.prototype._a5 = function () {
        if (this._ao == null) {
            return null;
        }
        return DocCoreUtils.x(this._ao);
    };
    OfficeDocumentManager.prototype._u = function (a) {
        return (this._aq[a] || null);
    };
    OfficeDocumentManager.prototype._e = function (a) {
        return this._b.getPart(a);
    };
    OfficeDocumentManager.prototype._ar = function (a) {
        return this._at(a.uri.toString());
    };
    OfficeDocumentManager.prototype._as = function (a) {
        var b = PackageUtilities.ak(a).originalString;
        return this._at(b);
    };
    OfficeDocumentManager.prototype._bd = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(this._ag)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                if (Base.equalsStatic(b.value, a)) {
                    return UriUtilities.b(b.key);
                }
            }
        }
        catch (e_12_1) { e_12 = { error: e_12_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_12) throw e_12.error; }
        }
        return null;
        var e_12, _2;
    };
    OfficeDocumentManager.prototype._au = function (a) {
        var b = this._g(a);
        if (b == null) {
            return null;
        }
        if (b.targetMode == 1) {
            if (typeCast(IInvalidPackageRelationshipTarget_$type, b) !== null) {
                return b.targetString;
            }
            return b.targetUri;
        }
        return this._as(b);
    };
    OfficeDocumentManager.prototype._bc = function ($tData, a) {
        var b = a.o(this._z);
        try {
            for (var _0 = tslib_1.__values(fromEnum(this._ak())), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                if (c.relationshipType == b) {
                    var d = this._au(c.id);
                    if (d != null) {
                        return Tuple.a(String_$type, $tData, c.id, typeCastObjTo$t($tData, d));
                    }
                    break;
                }
            }
        }
        catch (e_13_1) { e_13 = { error: e_13_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_13) throw e_13.error; }
        }
        return null;
        var e_13, _2;
    };
    OfficeDocumentManager.prototype._g = function (a) {
        return this._c != null ? this._c.getRelationship(a) : this._a.getRelationship(a);
    };
    OfficeDocumentManager.prototype._f = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(this._ak())), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                if (this._as(b) == a) {
                    return b;
                }
            }
        }
        catch (e_14_1) { e_14 = { error: e_14_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_14) throw e_14.error; }
        }
        return null;
        var e_14, _2;
    };
    OfficeDocumentManager.prototype._a7 = function (a, b) {
        var c = a;
        var d = c == 0 ? 1 : 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(this._ai)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                var f = e.value.o(d);
                var g = e.value.o(c);
                if (f == b || b == g) {
                    return g;
                }
            }
        }
        catch (e_15_1) { e_15 = { error: e_15_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_15) throw e_15.error; }
        }
        return null;
        var e_15, _2;
    };
    OfficeDocumentManager.prototype._bh = function () {
        this._bk(XmlNamespace.an);
        this._bk(VmlNamespace.an);
        this._bk(CoreProperties.an);
        this._bk(DcDcmiType.an);
        this._bk(DcElements.an);
        this._bk(DcTerms.an);
        this._bk(Drawing2010Main.an);
        this._bk(Drawing2010Slicer.an);
        this._bk(DrawingMLChart.an);
        this._bk(DrawingMLMain.an);
        this._bk(EmptyNamespace.an);
        this._bk(MarkupCompatibility2006.an);
        this._bk(OfficeDocumentDocPropsVTypes.an);
        this._bk(OfficeDocumentExtendedProperties.an);
        this._bk(OfficeDocumentRelationships.an);
        this._bk(OfficeNamespace.an);
        this._bk(XmlSchemaInstance.an);
        this._bk(IGOfficeExtensions.an);
        var a = this._t;
        if (a != null) {
            this._bk(a);
        }
        if (nullableEquals(this._ap, null)) {
            this._ap = Nullable$1.toNullable(ST_ConformanceClass_$type, this._aa());
        }
    };
    OfficeDocumentManager.prototype._ad = function (a) {
        return (this._aq[a] != null);
    };
    OfficeDocumentManager.prototype._n = function () {
        var _this = this;
        return WorkItemExtensions.c(this._m, function () {
            _this._bh();
            return _this._o();
        });
    };
    OfficeDocumentManager.prototype._bj = function () {
    };
    OfficeDocumentManager.prototype._bb = function (a) {
        if (a == null || a.length == 0) {
            if (this._aw != null) {
                return this._aw;
            }
        }
        else if (Base.equalsStatic(a, this._ax)) {
            return this._av;
        }
        else {
            this._ax = a;
        }
        var b = this._u(a);
        if (b != null) {
            a = b.i(1);
        }
        if (a == null || a.length == 0) {
            this._aw = a;
        }
        else {
            this._av = a;
        }
        return a;
    };
    OfficeDocumentManager.prototype._r = function () {
        var _this = this;
        this._bh();
        return WorkItemExtensions.c(WorkItemExtensions.c(WorkItemExtensions.c(this._m, function () { return _this._s(); }), function () { return Async.g(_this._h != null, function () { return _this._j(Office2007ExtensibilityPartManager.a4); }); }), function () { return Async.g(_this._i != null, function () { return _this._j(Office2010ExtensibilityPartManager.a4); }); });
    };
    OfficeDocumentManager.prototype._bn = function (a) {
        this._ap = Nullable$1.toNullable(ST_ConformanceClass_$type, a);
    };
    OfficeDocumentManager.prototype.disposeCore = function (a) {
        if (this._a != null) {
            this._a.dispose();
            this._a = null;
        }
    };
    OfficeDocumentManager.prototype._o = function () {
        var _this = this;
        return WorkItemExtensions.f(Boolean_$type, this._q(null, null, this._a.getRelationships(), false), function (a) {
            var b = WorkItemExtensions.m(Boolean_$type, a);
            return Async.g((_this._y != null && _this._af == false), function () {
                var c = _this._a6(_this._y.n(_this._v), void 0, true);
                var d = null;
                return Async.g((_this._aj.contains(c) == false && ((function () { var e = Uri.tryCreate(c, 2, d); d = e.p2; return e.ret; })()) && _this._a.partExists(d)), function () { return _this._p(_this._a.getPart(d)); });
            });
        });
    };
    OfficeDocumentManager.prototype._bi = function (a) {
        this._bj();
    };
    OfficeDocumentManager.prototype._bk = function (a) {
        this._aq[a.i(1)] = a;
        this._aq[a.i(0)] = a;
    };
    OfficeDocumentManager.prototype._bl = function (a, b) {
        if (b === void 0) { b = true; }
        if (b) {
            this._ah.item(a.m, a);
        }
        this._ai.item(a.o(this._z), a);
        var c = typeCast(ThemePartManager.$, a);
        if (c != null) {
            this._y = c;
        }
    };
    OfficeDocumentManager.prototype._a2 = function (a, b, c, d) {
        if (d === void 0) { d = null; }
        var e;
        var f = this._am.d();
        e = OfficeDocumentManager._a3(f.b);
        this._be(a, b, c, e, d);
        return e;
    };
    OfficeDocumentManager.prototype._be = function (a, b, c, d, e) {
        this._am.d().c();
        var f;
        if (c == 0) {
            if (this._c == null) {
                var g = new Uri(1, "/".toString(), 0);
                f = PackageUtilities.ai(g, a);
            }
            else {
                f = PackageUtilities.ai(this._c.uri, a);
            }
        }
        else {
            if (a == null && e != null) {
                var h = typeCast(IPackagePartEx_$type, this._c);
                if (h != null) {
                    h.createExternalRelationship(e, b, d);
                    return;
                }
            }
            f = a;
        }
        if (this._c == null) {
            this._a.createRelationship(f, c, b, d);
        }
        else {
            this._c.createRelationship(f, c, b, d);
        }
    };
    OfficeDocumentManager._a3 = function (a) {
        return "rId" + (a + 1).toString();
    };
    OfficeDocumentManager.prototype._ak = function () {
        if (this._c != null) {
            return this._c.getRelationships();
        }
        return this._a.getRelationships();
    };
    OfficeDocumentManager.prototype._a4 = function () {
        switch (this._z) {
            case 0: return OfficeDocumentManager._a9;
            case 1: return OfficeDocumentManager._a8;
            default: return OfficeDocumentManager._a9;
        }
    };
    OfficeDocumentManager.prototype._a6 = function (a, b, c) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        var d = new HashSet$1(String_$type, 2, StringUtilities.e);
        if (c == false && b) {
            try {
                for (var _0 = tslib_1.__values(fromEnum(this._a.getParts())), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                    var e = _1.value;
                    var f = e.uri.toString();
                    var g = IOPath.getExtension(f);
                    var h = f.substr(0, f.length - g.length);
                    d.add_1(h);
                }
            }
            catch (e_16_1) { e_16 = { error: e_16_1 }; }
            finally {
                try {
                    if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
                }
                finally { if (e_16) throw e_16.error; }
            }
        }
        var i = IOPath.getExtension(a);
        var j = a.substr(0, a.length - i.length);
        var k = 1;
        while (true) {
            if (b) {
                var l = j + k;
                if (c || d.contains(l) == false) {
                    l += i;
                    return l;
                }
            }
            else {
                var m = j + k + i;
                if (c || this._a.partExists(UriUtilities.b(m)) == false) {
                    return m;
                }
            }
            k++;
        }
        var e_16, _2;
    };
    OfficeDocumentManager.prototype._at = function (a) {
        var b;
        var c = this._ag.tryGetValue(a, b);
        b = c.p1;
        return b;
    };
    OfficeDocumentManager.prototype._w = function (a) {
        var b;
        var c = this._ah.tryGetValue(a, b);
        b = c.p1;
        return b;
    };
    OfficeDocumentManager.prototype._x = function (a) {
        var _this = this;
        var b;
        if (((function () { var c = _this._ai.tryGetValue(a, b); b = c.p1; return c.ret; })()) == false) {
            var c = "http://purl.oclc.org/ooxml/officeDocument/relationships/worksheet";
            var d = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/worksheet";
            var e = "http://purl.oclc.org/ooxml/officeDocument/relationships/drawing";
            var f = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing";
            switch (a) {
                case c:
                    var g = this._ai.tryGetValue(d, b);
                    b = g.p1;
                    break;
                case e:
                    var h = this._ai.tryGetValue(f, b);
                    b = h.p1;
                    break;
            }
        }
        return b;
    };
    OfficeDocumentManager.prototype._ae = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(this._ak())), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                if (b.id == a) {
                    return false;
                }
            }
        }
        catch (e_17_1) { e_17 = { error: e_17_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_17) throw e_17.error; }
        }
        return true;
        var e_17, _2;
    };
    OfficeDocumentManager.prototype._p = function (a, b) {
        var _this = this;
        if (b === void 0) { b = null; }
        if (b == null) {
            b = this._w(a.contentType);
        }
        var c = a.getRelationships();
        var d = a.uri.toString();
        if (this._aj.add_1(d) == false) {
            return null;
        }
        var e = null;
        var f = null;
        return WorkItemExtensions.f(Boolean_$type, this._q(a, b, c, false), function (g) {
            var h = WorkItemExtensions.m(Boolean_$type, g);
            return WorkItemExtensions.a(WorkItemExtensions.c(Async.g((b != null), function () {
                var i = _this._c;
                return Async.h(function () {
                    _this._c = a;
                    return Async.o(Stream.$, a.getStream(3, 1), function (j) {
                        f = b.e(_this, j);
                        return WorkItemExtensions.e(Base.$, f.a(), function (k) { return e = WorkItemExtensions.m(Base.$, k); });
                    });
                }, function () { return _this._c = i; });
            }, function () {
                _this._bi(a);
                return null;
            }), function () {
                if (e != null) {
                    _this._ag.item(d, e);
                }
                return Async.g(h, function () { return _this._q(a, b, c, true); });
            }), function () {
                if (f != null) {
                    f.q();
                }
            });
        });
    };
    OfficeDocumentManager.prototype._q = function (a, b, c, d) {
        var _this = this;
        var e = false;
        return WorkItemExtensions.g(Boolean_$type, Async.h(function () {
            if (a != null) {
                _this._al.h(a);
            }
            var f = _this._bm(b, c);
            c = f.p1;
            return Async.d(IPackageRelationship_$type, c, function (g) {
                if (g.relationshipType == _this._a4()) {
                    return null;
                }
                switch (g.targetMode) {
                    case 0:
                        {
                            if (b != null) {
                                var h = _this._x(g.relationshipType);
                                var i = h != null && b.i(h);
                                if (d != i) {
                                    e = true;
                                    return null;
                                }
                            }
                            if (g.targetUri != null && g.targetUri.originalString == "NULL") {
                                return null;
                            }
                            var j = PackageUtilities.ak(g);
                            var k = _this._a.getPart(j);
                            var l = null;
                            if (b != null) {
                                l = b.f(k, g);
                            }
                            if (l == null && k != null && k.contentType == "application/xml") {
                                var m = _this._x(g.relationshipType);
                                if (m != null && m.m != k.contentType) {
                                    k = new OverrideContentTypePart(k, m.m);
                                }
                                l = m;
                            }
                            return _this._p(k, l);
                        }
                    case 1: break;
                    default: break;
                }
                return null;
            });
        }, function () {
            if (a != null) {
                _this._al.e();
            }
        }), function () { return e; });
    };
    OfficeDocumentManager.prototype._bm = function (a, b) {
        if (a == null) {
            return {
                p1: b
            };
        }
        var c = a.j();
        if (c == null) {
            return {
                p1: b
            };
        }
        var d = new Dictionary$2(String_$type, Number_$type, 0);
        try {
            for (var _0 = tslib_1.__values(fromEnum(c)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                d.addItem(e.key.o(this._z), e.value);
            }
        }
        catch (e_18_1) { e_18 = { error: e_18_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_18) throw e_18.error; }
        }
        var f = new List$1(IPackageRelationship_$type, 1, b);
        f.aa(function (g, h) {
            var i;
            var j = ((function () { var k = d.tryGetValue(g.relationshipType, i); i = k.p1; return k.ret; })());
            var k;
            var l = ((function () { var m = d.tryGetValue(h.relationshipType, k); k = m.p1; return m.ret; })());
            if (j == false && l == false) {
                return 0;
            }
            else if (j && l == false) {
                return -1;
            }
            else if (j == false && l) {
                return 1;
            }
            return Base.compareSimple(i, k);
        });
        b = f;
        return {
            p1: b
        };
        var e_18, _2;
    };
    Object.defineProperty(OfficeDocumentManager.prototype, "_d", {
        get: function () {
            return this._c;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OfficeDocumentManager.prototype, "_z", {
        get: function () {
            return this._ap.getValueOrDefault1(0);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OfficeDocumentManager.prototype, "_ac", {
        get: function () {
            return this._ab;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OfficeDocumentManager.prototype, "_an", {
        get: function () {
            return this._al;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OfficeDocumentManager.prototype, "_b", {
        get: function () {
            return this._a;
        },
        enumerable: true,
        configurable: true
    });
    OfficeDocumentManager.$t = markType(OfficeDocumentManager, 'OfficeDocumentManager', Base.$, [IDisposable_$type]);
    OfficeDocumentManager._a9 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/hyperlink";
    OfficeDocumentManager._a8 = "http://purl.oclc.org/ooxml/officeDocument/relationships/hyperlink";
    return OfficeDocumentManager;
}(Base));
export { OfficeDocumentManager };
var OfficeDocumentManager_PartRelationshipCounter = /** @class */ (function (_super) {
    tslib_1.__extends(OfficeDocumentManager_PartRelationshipCounter, _super);
    function OfficeDocumentManager_PartRelationshipCounter() {
        var _this = _super.call(this) || this;
        _this.a = 0;
        return _this;
    }
    OfficeDocumentManager_PartRelationshipCounter.prototype.c = function () {
        this.a++;
    };
    Object.defineProperty(OfficeDocumentManager_PartRelationshipCounter.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: true,
        configurable: true
    });
    OfficeDocumentManager_PartRelationshipCounter.$t = markType(OfficeDocumentManager_PartRelationshipCounter, 'OfficeDocumentManager_PartRelationshipCounter');
    return OfficeDocumentManager_PartRelationshipCounter;
}(Base));
export { OfficeDocumentManager_PartRelationshipCounter };
var QualifiedNameInfo = /** @class */ (function (_super) {
    tslib_1.__extends(QualifiedNameInfo, _super);
    function QualifiedNameInfo(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.h = null;
        _this.g = null;
        _this.f = null;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    var e = _rest[2];
                    if (c == stringEmpty()) {
                        c = null;
                    }
                    _this.h = c;
                    _this.g = d;
                    _this.f = e;
                }
                break;
        }
        return _this;
    }
    QualifiedNameInfo.prototype.toString = function () {
        if (this.h != null) {
            return this.h + ":" + this.f;
        }
        return this.f;
    };
    QualifiedNameInfo.d = function (a, b) {
        if (stringIsNullOrEmpty(a)) {
            return b;
        }
        var c;
        if (a.charAt(a.length - 1) != "/") {
            a += "/";
        }
        c = a + b;
        return c;
    };
    QualifiedNameInfo.prototype.e = function (a) {
        if (this.g == null) {
            return this.f;
        }
        if (a == null) {
            return QualifiedNameInfo.d(this.g, this.f);
        }
        return QualifiedNameInfo.d(a._bb(this.g), this.f);
    };
    QualifiedNameInfo.prototype.i = function (a, b, c) {
        if (a == stringEmpty()) {
            a = null;
        }
        this.h = a;
        this.g = b;
        this.f = c;
    };
    QualifiedNameInfo.prototype.b = function (a) {
        if (this.g == null) {
            return this;
        }
        if (a == null) {
            return this;
        }
        return new QualifiedNameInfo(1, this.h, a._bb(this.g), this.f);
    };
    Object.defineProperty(QualifiedNameInfo.prototype, "c", {
        get: function () {
            return this.f == null;
        },
        enumerable: true,
        configurable: true
    });
    QualifiedNameInfo.$t = markStruct(QualifiedNameInfo, 'QualifiedNameInfo');
    QualifiedNameInfo.a = new QualifiedNameInfo(0);
    return QualifiedNameInfo;
}(ValueType));
export { QualifiedNameInfo };
var UnknownElementCache = /** @class */ (function (_super) {
    tslib_1.__extends(UnknownElementCache, _super);
    function UnknownElementCache(a, b) {
        var _this = _super.call(this) || this;
        _this.h = null;
        _this.i = null;
        _this.a = new QualifiedNameInfo();
        _this.m = null;
        _this.o = null;
        _this.a = a;
        _this.o = b;
        return _this;
    }
    UnknownElementCache.prototype.l = function (a, b) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(this.j)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                if (c.a.e(b) == a) {
                    return Nullable$1.toNullable(AttributeValue.$, c);
                }
            }
        }
        catch (e_19_1) { e_19 = { error: e_19_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_19) throw e_19.error; }
        }
        return Nullable$1.toNullable(AttributeValue.$, null);
        var e_19, _2;
    };
    UnknownElementCache.prototype.c = function (a, b) {
        return Enumerable.ag(UnknownElementCache.$, this.k, function (c) { return c.b.e(b) == a; });
    };
    UnknownElementCache.prototype.f = function (a, b) {
        return Enumerable.u(UnknownElementCache.$, this.k, function (c) { return c.b.e(b) == a; });
    };
    UnknownElementCache.prototype._g = function (a, b) {
        var _0, _1, c, _2, _3, d, e_20_1, e_21_1, e_21, _4, e_20, _5;
        return tslib_1.__generator(this, function (_6) {
            switch (_6.label) {
                case 0:
                    _6.trys.push([0, 12, 13, 14]);
                    _0 = tslib_1.__values(fromEnum(this.k)), _1 = _0.next();
                    _6.label = 1;
                case 1:
                    if (!!_1.done) return [3 /*break*/, 11];
                    c = _1.value;
                    if (!(c.b.e(b) == a)) return [3 /*break*/, 3];
                    return [4 /*yield*/, c];
                case 2:
                    _6.sent();
                    _6.label = 3;
                case 3:
                    _6.trys.push([3, 8, 9, 10]);
                    _2 = tslib_1.__values(fromEnum(c.g(a, b))), _3 = _2.next();
                    _6.label = 4;
                case 4:
                    if (!!_3.done) return [3 /*break*/, 7];
                    d = _3.value;
                    return [4 /*yield*/, d];
                case 5:
                    _6.sent();
                    _6.label = 6;
                case 6:
                    _3 = _2.next();
                    return [3 /*break*/, 4];
                case 7: return [3 /*break*/, 10];
                case 8:
                    e_20_1 = _6.sent();
                    e_20 = { error: e_20_1 };
                    return [3 /*break*/, 10];
                case 9:
                    try {
                        if (_3 && !_3.done && (_5 = _2.return)) _5.call(_2);
                    }
                    finally { if (e_20) throw e_20.error; }
                    return [7 /*endfinally*/];
                case 10:
                    _1 = _0.next();
                    return [3 /*break*/, 1];
                case 11: return [3 /*break*/, 14];
                case 12:
                    e_21_1 = _6.sent();
                    e_21 = { error: e_21_1 };
                    return [3 /*break*/, 14];
                case 13:
                    try {
                        if (_1 && !_1.done && (_4 = _0.return)) _4.call(_0);
                    }
                    finally { if (e_21) throw e_21.error; }
                    return [7 /*endfinally*/];
                case 14: return [2 /*return*/];
            }
        });
    };
    UnknownElementCache.prototype.g = function (a, b) {
        var _this = this;
        return toEnum(function () { return _this._g(a, b); });
    };
    Object.defineProperty(UnknownElementCache.prototype, "j", {
        get: function () {
            if (this.h == null) {
                this.h = new List$1(AttributeValue.$, 0);
            }
            return this.h;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UnknownElementCache.prototype, "d", {
        get: function () {
            return this.h != null && this.h.count != 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UnknownElementCache.prototype, "k", {
        get: function () {
            if (this.i == null) {
                this.i = new List$1(UnknownElementCache.$, 0);
            }
            return this.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UnknownElementCache.prototype, "e", {
        get: function () {
            return this.i != null && this.i.count != 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UnknownElementCache.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UnknownElementCache.prototype, "n", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UnknownElementCache.prototype, "p", {
        get: function () {
            return this.o;
        },
        set: function (a) {
            this.o = a;
        },
        enumerable: true,
        configurable: true
    });
    UnknownElementCache.$t = markType(UnknownElementCache, 'UnknownElementCache');
    return UnknownElementCache;
}(Base));
export { UnknownElementCache };
var UnknownStructure = /** @class */ (function (_super) {
    tslib_1.__extends(UnknownStructure, _super);
    function UnknownStructure(a) {
        var _this = _super.call(this) || this;
        _this.a = null;
        _this.a = a;
        return _this;
    }
    Object.defineProperty(UnknownStructure.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: true,
        configurable: true
    });
    UnknownStructure.$t = markType(UnknownStructure, 'UnknownStructure');
    return UnknownStructure;
}(Base));
export { UnknownStructure };
var XmlReadManager = /** @class */ (function (_super) {
    tslib_1.__extends(XmlReadManager, _super);
    function XmlReadManager(a, b) {
        var _this = _super.call(this) || this;
        _this.u = null;
        _this.ab = 0;
        _this.k = new QualifiedNameInfo();
        _this.ad = null;
        _this.v = null;
        _this.z = 0;
        _this.m = null;
        _this.b = null;
        _this.i = null;
        _this.j = null;
        _this.ao = null;
        _this.aa = 0;
        _this.w = new Stack$1(XmlReadManager_LoadChildContext.$);
        _this.x = new Stack$1(XmlReadManager_LoadFastContext.$);
        _this.a = ([]);
        _this.y = 0;
        _this.v = new Stack$1(XmlReadManager_AlternateContentChoiceContext.$);
        _this.u = new List$1(AttributeValue.$, 0);
        _this.z = -1;
        _this.b = new Array(16);
        _this.i = a.d;
        _this.j = a;
        _this.ao = b;
        return _this;
    }
    XmlReadManager.prototype.q = function (a) {
        for (var b = 0; b <= this.z; b++) {
            if (this.b[b].a(a)) {
                return true;
            }
        }
        return false;
    };
    XmlReadManager.prototype.r = function (a) {
        if (this.w.f > 0) {
            var b = this.w.d();
            if (a == b.b.e(this.i)) {
                return true;
            }
        }
        return false;
    };
    XmlReadManager.prototype.d = function () {
        this.aa = 0;
        return this.f(this.w.f);
    };
    XmlReadManager.prototype.f = function (a, b, c, d, e) {
        var _this = this;
        if (b === void 0) { b = 0; }
        if (c === void 0) { c = 0; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = false; }
        var f = new XmlReadManager_LoadChildContext();
        if (d) {
            f = this.w.e();
        }
        else {
            f = new XmlReadManager_LoadChildContext();
            f.h = b;
            f.c = c;
        }
        var g = null;
        while (true) {
            if (e == true) {
                e = false;
            }
            else {
                if (this.ao.a7 == 15) {
                    if (this.w.f == a) {
                        break;
                    }
                    f = this.w.e();
                    e = true;
                    continue;
                }
                f.b = this.l();
                if (f.b.c) {
                    if (this.w.f == a) {
                        break;
                    }
                    f = this.w.e();
                    e = true;
                    continue;
                }
                this.al();
                f.f = true;
                f.g = true;
                f.e = false;
                g = f.b.e(this.i);
                var h = null;
                switch (g) {
                    case MarkupCompatibility2006.ap: return WorkItemExtensions.c(this.c(f.b, f.h), function () {
                        if (f.g && _this.ao.t() == false) {
                            if (_this.w.f == a) {
                                return null;
                            }
                            f = _this.w.e();
                            e = true;
                        }
                        else {
                            if (f.f) {
                                f.h++;
                            }
                            _this.ak();
                        }
                        _this.w.h(f);
                        return WorkItem.d(function () { return _this.f(a, f.h, f.c, true, e); }, 2);
                    });
                    case MarkupCompatibility2006.aq:
                        h = this.g(f.b, f.h, f.c);
                        break;
                    case MarkupCompatibility2006.ar:
                        h = this.h(f.b, f.h, f.c);
                        break;
                    default:
                        f.e = true;
                        break;
                }
                if (h != null) {
                    return WorkItemExtensions.f(Boolean_$type, h, function (i) {
                        if (WorkItemExtensions.m(Boolean_$type, i) == false) {
                            f.f = false;
                            f.g = false;
                        }
                        else {
                            f.c = 2;
                        }
                        if (f.g && _this.ao.t() == false) {
                            if (_this.w.f == a) {
                                return null;
                            }
                            f = _this.w.e();
                            e = true;
                        }
                        else {
                            if (f.f) {
                                f.h++;
                            }
                            _this.ak();
                        }
                        _this.w.h(f);
                        return WorkItem.d(function () { return _this.f(a, f.h, f.c, true, e); }, 2);
                    });
                }
                if (f.e) {
                    var i = false;
                    f.a = this.j.x(g);
                    if (f.a.c) {
                        if (this.t(f.b, f.h)) {
                            f.g = false;
                            i = true;
                        }
                    }
                    if (!i) {
                        var j = this.ao.i;
                        this.am(f.b, false);
                        f.d = j;
                        if (f.a.b != null) {
                            this.k = f.b;
                            this.ab = f.h;
                            f.a.b(this.j);
                        }
                        if (f.d == false) {
                            if (this.j.ai(f.b.e(this.i))) {
                                if (this.b[this.z].b) {
                                    return WorkItemExtensions.c(WorkItemExtensions.a(this.e(this.x.f), function () {
                                    }), function () {
                                        _this.w.h(f);
                                        return WorkItem.d(function () { return _this.f(a, f.h, f.c, true, true); }, 2);
                                    });
                                }
                                else {
                                    this.w.h(f);
                                    f = new XmlReadManager_LoadChildContext();
                                    f.h = 0;
                                    f.c = 0;
                                    continue;
                                }
                            }
                            else {
                                while (this.ao.a7 != 15) {
                                    this.ao.a2();
                                }
                            }
                        }
                    }
                }
            }
            if (f.e) {
                if (f.a.a != null) {
                    this.k = f.b;
                    this.ab = f.h;
                    f.a.a(this.j);
                }
            }
            if (f.g && this.ao.t() == false) {
                if (this.w.f == a) {
                    break;
                }
                f = this.w.e();
                e = true;
                continue;
            }
            if (f.f) {
                f.h++;
            }
            this.ak();
            this.aa++;
            if (1000 < this.aa) {
                this.aa = 0;
                this.w.h(f);
                return WorkItem.d(function () { return _this.f(a, f.h, f.c, true, e); }, 2);
            }
        }
        return null;
    };
    XmlReadManager.prototype.e = function (a, b, c) {
        var _this = this;
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        var d = b ? this.x.e() : new XmlReadManager_LoadFastContext();
        var e = null;
        while (true) {
            if (c == false) {
                if (this.ao.a7 == 15) {
                    if (this.x.f == a) {
                        break;
                    }
                    d = this.x.e();
                    c = true;
                    continue;
                }
                d.b = this.l();
                if (d.b.c) {
                    if (this.x.f == a) {
                        break;
                    }
                    d = this.x.e();
                    c = true;
                    continue;
                }
                this.al();
                e = d.b.e(this.i);
            }
            if (c == false && e == MarkupCompatibility2006.ap) {
                return WorkItemExtensions.c(this.c(d.b, 0), function () {
                    if (_this.ao.t() == false) {
                        if (_this.x.f == a) {
                            return null;
                        }
                        d = _this.x.e();
                        c = true;
                    }
                    else {
                        d.c++;
                        _this.ak();
                    }
                    _this.x.h(d);
                    return WorkItem.d(function () { return _this.e(a, true, c); }, 2);
                });
            }
            else {
                if (c) {
                    c = false;
                }
                else {
                    d.a = this.j.x(e);
                    var f = this.ao.i;
                    this.am(d.b, false);
                    if (d.a.b != null) {
                        this.k = d.b;
                        this.ab = d.c;
                        d.a.b(this.j);
                    }
                    if (f == false) {
                        this.x.h(d);
                        d = new XmlReadManager_LoadFastContext();
                        continue;
                    }
                }
                if (d.a.a != null) {
                    this.k = d.b;
                    this.ab = d.c;
                    d.a.a(this.j);
                }
            }
            if (this.ao.t() == false) {
                if (this.x.f == a) {
                    break;
                }
                d = this.x.e();
                c = true;
                continue;
            }
            d.c++;
            this.ak();
            if (1000 < ++this.aa) {
                this.aa = 0;
                this.x.h(d);
                return WorkItem.d(function () { return _this.e(a, true, c); }, 2);
            }
        }
        return null;
    };
    XmlReadManager.prototype.ae = function (a) {
        return this.ao.ah(a);
    };
    XmlReadManager.prototype.aj = function () {
        if (this.v.f == 0) {
            return;
        }
        this.v.d().a = true;
    };
    XmlReadManager.prototype.an = function () {
        this.b[this.z].b = true;
    };
    XmlReadManager.prototype.ah = function (a) {
        var b = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            b[_0 - 1] = arguments[_0];
        }
        for (var c = 0; c < b.length; c++) {
            var d = this.ae(b[c]);
            if (d != null) {
                a.add_1(d);
            }
        }
    };
    XmlReadManager.prototype.c = function (a, b) {
        var c = this.ao.i;
        this.am(a, false);
        this.k = a;
        this.ab = b;
        if (c == false) {
            return this.f(this.w.f, b, 1);
        }
        return null;
    };
    XmlReadManager.prototype.o = function (a, b) {
        b = this.ao.i;
        this.am(a, true, true);
        var c = new UnknownElementCache(a, this.ad);
        if (this.u.count != 0) {
            c.j.o(this.u);
        }
        return {
            ret: c,
            p1: b
        };
    };
    XmlReadManager.prototype.p = function (a, b) {
        var _this = this;
        this.al();
        var c;
        var d = ((function () { var e = _this.o(a, c); c = e.p1; return e.ret; })());
        var e = this.j.w(a);
        if (e.b != null) {
            this.k = a;
            this.ab = b;
            this.m = d;
            e.b(this.j);
            this.m = null;
        }
        if (c == false) {
            if (this.j.ai(a.e(this.i))) {
                this.ai(d);
            }
            else {
                while (this.ao.a7 != 15) {
                    this.ao.a2();
                }
            }
        }
        if (e.a != null) {
            this.k = a;
            this.ab = b;
            this.m = d;
            e.a(this.j);
            this.m = null;
        }
        this.j.au(d);
        this.ak();
        return d;
    };
    XmlReadManager.prototype.ai = function (a) {
        var b = 0;
        while (this.ao.a7 != 15) {
            var c = this.l();
            if (c.c) {
                break;
            }
            a.k.add(this.p(c, b));
            if (this.ao.t() == false) {
                break;
            }
            b++;
        }
    };
    XmlReadManager.prototype.t = function (a, b) {
        var c = a.e(this.i);
        var d = this.j.z(c);
        var t1 = d;
        L0: while (true) {
            switch (t1) {
                case 0:
                    this.ao.a2();
                    return true;
                case 1:
                    {
                        var e = this.ao.ap();
                        this.j.aw(c, e);
                        return true;
                    }
                case 2:
                    {
                        var f = this.p(a, b);
                        var g = new UnknownStructure(f);
                        this.j.av(g);
                        this.ao.t();
                        return true;
                    }
                case 3: return false;
                default:
                    t1 = 0;
                    continue L0;
            }
            break;
        }
    };
    XmlReadManager.prototype.l = function () {
        switch (this.ao.a7) {
            case 1: return new QualifiedNameInfo(1, this.ao.ak, this.ao.aj, this.ao.ag);
            case 2: break;
            case 15:
            case 14:
            case 3:
            case 0: break;
            case 17:
            case 13:
            case 8:
                {
                    do {
                        this.ao.t();
                    } while (this.ao.a7 == 13 || this.ao.a7 == 17 || this.ao.a7 == 8);
                    return this.l();
                }
            default: break;
        }
        return QualifiedNameInfo.a;
    };
    XmlReadManager.prototype.ak = function () {
        this.j.s.j(this.b[this.z].e, this.b[this.z].f);
        this.b[this.z] = (null);
        this.z--;
    };
    XmlReadManager.prototype.al = function () {
        this.z++;
        while (this.b.length <= this.z) {
            var a = new Array(this.b.length * 2);
            arrayCopy2(this.b, a, this.b.length);
            this.b = a;
        }
        this.b[this.z] = new XmlReadManager_ElementContext(1, this);
    };
    XmlReadManager.prototype.am = function (a, b, c) {
        if (c === void 0) { c = false; }
        this.y = 0;
        this.u.clear();
        this.ad = null;
        var d = this.ao.i;
        if (this.ao.r()) {
            do {
                var e = this.ao.aj;
                if (b == false && e == "http://www.w3.org/2000/xmlns/") {
                    if (this.ao.ag == "xmlns" || this.ao.ak == "xmlns") {
                        continue;
                    }
                }
                var f = new AttributeValue();
                if (c) {
                    f = new AttributeValue(1, this.ao.ak, e, this.ao.ag, this.ao.ar);
                }
                else if (this.y < this.a.length) {
                    f = (this.a[this.y++]);
                    f.e(this.ao.ak, e, this.ao.ag, this.ao.ar);
                }
                else {
                    f = new AttributeValue(1, this.ao.ak, e, this.ao.ag, this.ao.ar);
                    this.a.push(f);
                    this.y++;
                }
                if (f.a.f == "Ignorable" && f.a.e(this.i) == MarkupCompatibility2006.as) {
                    this.ah.apply(this, tslib_1.__spread([this.b[this.z].d], stringSplit(f.d, [' '], 1)));
                    continue;
                }
                this.u.add(f);
            } while (this.ao.s());
            this.ao.q();
        }
        if (d == false && this.ao.t()) {
            if (this.ao.a7 == 13 && a.f == "t" && a.e(this.i) == DrawingMLMain.ja) {
                this.ad = this.ao.ar;
            }
            else {
                while (this.ao.a7 == 13) {
                    this.ao.t();
                }
                if (this.ao.a7 == 14 || this.ao.a7 == 3) {
                    this.ad = this.ao.ar;
                    this.ao.t();
                }
            }
        }
    };
    XmlReadManager.prototype.ag = function (a) {
        var b = a.indexOf(':');
        if (b < 0) {
            return a;
        }
        var c = a.substr(0, b);
        var d = a.substr(b + 1);
        var e = this.ae(c);
        var f = new QualifiedNameInfo(1, c, e, d);
        return f.e(this.i);
    };
    XmlReadManager.prototype.g = function (a, b, c) {
        var _this = this;
        if (c != 1) {
            this.ao.a2();
            return WorkItem.g(Boolean_$type, false);
        }
        var d = this.ao.i;
        this.am(a, false);
        this.k = a;
        this.ab = b;
        var e;
        var f = MarkupCompatibility2006.aw(this.j, e);
        e = f.p1;
        if (this.j.ah(e) == false) {
            while (this.ao.a7 == 1) {
                this.ao.a2();
                if (this.ao.a7 == 13) {
                    this.ao.a2();
                }
            }
            if (this.ao.t() == false) {
            }
            return WorkItem.g(Boolean_$type, false);
        }
        var g = true;
        return WorkItemExtensions.g(Boolean_$type, Async.g(d == false, function () {
            _this.v.h(new XmlReadManager_AlternateContentChoiceContext());
            var h = _this.f(_this.w.f);
            var i = _this.v.e();
            if (i.a) {
                if (_this.ao.t() == false) {
                }
                g = false;
            }
            return h;
        }), function () { return g; });
    };
    XmlReadManager.prototype.h = function (a, b, c) {
        var _this = this;
        if (c != 1) {
            this.ao.a2();
            return WorkItem.g(Boolean_$type, false);
        }
        var d = this.ao.i;
        this.am(a, false);
        this.k = a;
        this.ab = b;
        return WorkItemExtensions.g(Boolean_$type, Async.g(d == false, function () { return _this.f(_this.w.f); }), function () { return true; });
    };
    Object.defineProperty(XmlReadManager.prototype, "n", {
        get: function () {
            return this.m;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(XmlReadManager.prototype, "s", {
        get: function () {
            return this.v.f != 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(XmlReadManager.prototype, "af", {
        get: function () {
            return this.ao.aj;
        },
        enumerable: true,
        configurable: true
    });
    XmlReadManager.$t = markType(XmlReadManager, 'XmlReadManager');
    return XmlReadManager;
}(Base));
export { XmlReadManager };
var XmlReadManager_AlternateContentChoiceContext = /** @class */ (function (_super) {
    tslib_1.__extends(XmlReadManager_AlternateContentChoiceContext, _super);
    function XmlReadManager_AlternateContentChoiceContext() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = false;
        return _this;
    }
    XmlReadManager_AlternateContentChoiceContext.$t = markType(XmlReadManager_AlternateContentChoiceContext, 'XmlReadManager_AlternateContentChoiceContext');
    return XmlReadManager_AlternateContentChoiceContext;
}(Base));
export { XmlReadManager_AlternateContentChoiceContext };
var XmlReadManager_ElementContext = /** @class */ (function (_super) {
    tslib_1.__extends(XmlReadManager_ElementContext, _super);
    function XmlReadManager_ElementContext(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.e = 0;
        _this.f = null;
        _this.c = null;
        _this.b = false;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.e = c.j.s.e;
                    _this.f = c.j.s.f;
                    _this.b = false;
                    _this.c = null;
                }
                break;
        }
        return _this;
    }
    XmlReadManager_ElementContext.prototype.a = function (a) {
        return this.c != null && this.c.contains(a);
    };
    Object.defineProperty(XmlReadManager_ElementContext.prototype, "d", {
        get: function () {
            if (this.c == null) {
                this.c = new HashSet$1(String_$type, 0);
            }
            return this.c;
        },
        enumerable: true,
        configurable: true
    });
    XmlReadManager_ElementContext.$t = markStruct(XmlReadManager_ElementContext, 'XmlReadManager_ElementContext');
    return XmlReadManager_ElementContext;
}(ValueType));
export { XmlReadManager_ElementContext };
var XmlReadManager_LoadChildContext = /** @class */ (function (_super) {
    tslib_1.__extends(XmlReadManager_LoadChildContext, _super);
    function XmlReadManager_LoadChildContext() {
        var _this = _super.call(this) || this;
        _this.h = 0;
        _this.c = 0;
        _this.b = new QualifiedNameInfo();
        _this.a = new ElementLoadCallbacks();
        _this.g = false;
        _this.f = false;
        _this.e = false;
        _this.d = false;
        return _this;
    }
    XmlReadManager_LoadChildContext.$t = markStruct(XmlReadManager_LoadChildContext, 'XmlReadManager_LoadChildContext');
    return XmlReadManager_LoadChildContext;
}(ValueType));
export { XmlReadManager_LoadChildContext };
var XmlReadManager_LoadFastContext = /** @class */ (function (_super) {
    tslib_1.__extends(XmlReadManager_LoadFastContext, _super);
    function XmlReadManager_LoadFastContext() {
        var _this = _super.call(this) || this;
        _this.c = 0;
        _this.b = new QualifiedNameInfo();
        _this.a = new ElementLoadCallbacks();
        return _this;
    }
    XmlReadManager_LoadFastContext.$t = markStruct(XmlReadManager_LoadFastContext, 'XmlReadManager_LoadFastContext');
    return XmlReadManager_LoadFastContext;
}(ValueType));
export { XmlReadManager_LoadFastContext };
var ST_DecimalNumber = /** @class */ (function (_super) {
    tslib_1.__extends(ST_DecimalNumber, _super);
    function ST_DecimalNumber(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.e = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.e = c;
                }
                break;
        }
        return _this;
    }
    ST_DecimalNumber.d = function (a) {
        return ST_DecimalNumber.b(parseInt32_1(a, CultureInfo.invariantCulture));
    };
    ST_DecimalNumber.j = function (a) {
        var b;
        if (((function () { var c = tryParseInt32_2(a, 7 | 4, CultureInfo.invariantCulture, b); b = c.p3; return c.ret; })())) {
            return Nullable$1.toNullable(ST_DecimalNumber.$, ST_DecimalNumber.b(b));
        }
        return Nullable$1.toNullable(ST_DecimalNumber.$, null);
    };
    ST_DecimalNumber.prototype.toString = function () {
        return this.e.toString();
    };
    ST_DecimalNumber.f = function (a) {
        return a.e;
    };
    ST_DecimalNumber.h = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_DecimalNumber.f(a.value));
    };
    ST_DecimalNumber.b = function (a) {
        return new ST_DecimalNumber(1, a);
    };
    ST_DecimalNumber.i = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_DecimalNumber.$, null);
        }
        return Nullable$1.toNullable(ST_DecimalNumber.$, ST_DecimalNumber.b(a.value));
    };
    ST_DecimalNumber.$t = markStruct(ST_DecimalNumber, 'ST_DecimalNumber');
    ST_DecimalNumber.a = new ST_DecimalNumber(0);
    return ST_DecimalNumber;
}(ValueType));
export { ST_DecimalNumber };
var ST_DecimalNumberOrPercent = /** @class */ (function (_super) {
    tslib_1.__extends(ST_DecimalNumberOrPercent, _super);
    function ST_DecimalNumberOrPercent(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.b = false;
        _this.a = new ST_Percentage();
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    _this.b = d;
                    _this.a = c;
                }
                break;
        }
        return _this;
    }
    ST_DecimalNumberOrPercent.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_DecimalNumberOrPercent.$, typeCast(ST_DecimalNumberOrPercent.$, a));
        if (ST_DecimalNumberOrPercent.f(b, Nullable$1.toNullable(ST_DecimalNumberOrPercent.$, null))) {
            return false;
        }
        return ST_DecimalNumberOrPercent.c(this, b.getValueOrDefault());
    };
    ST_DecimalNumberOrPercent.prototype.getHashCode = function () {
        return this.a.getHashCode();
    };
    ST_DecimalNumberOrPercent.prototype.toString = function () {
        return this.k(0);
    };
    ST_DecimalNumberOrPercent.prototype.k = function (a) {
        if (this.b) {
            return (ST_Percentage.k(this.a)).toString();
        }
        return this.a.p(a);
    };
    ST_DecimalNumberOrPercent.prototype.i = function (a) {
        a = this.b;
        return {
            ret: ST_Percentage.k(this.a),
            p0: a
        };
    };
    ST_DecimalNumberOrPercent.j = function (a, b) {
        var c = ST_DecimalNumber.j(a);
        if (nullableNotEquals(c, null)) {
            return Nullable$1.toNullable(ST_DecimalNumberOrPercent.$, new ST_DecimalNumberOrPercent(1, new ST_Percentage(1, ST_DecimalNumber.f(c.getValueOrDefault())), true));
        }
        var d = ST_Percentage.o(a, b);
        if (ST_Percentage.g(d, Nullable$1.toNullable(ST_Percentage.$, null))) {
            return Nullable$1.toNullable(ST_DecimalNumberOrPercent.$, new ST_DecimalNumberOrPercent(1, d.getValueOrDefault(), false));
        }
        return Nullable$1.toNullable(ST_DecimalNumberOrPercent.$, null);
    };
    ST_DecimalNumberOrPercent.c = function (a, b) {
        return ST_Percentage.d(a.a, b.a);
    };
    ST_DecimalNumberOrPercent.d = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_DecimalNumberOrPercent.c(a.value, b.value);
    };
    ST_DecimalNumberOrPercent.e = function (a, b) {
        return !(ST_DecimalNumberOrPercent.c(a, b));
    };
    ST_DecimalNumberOrPercent.f = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_DecimalNumberOrPercent.e(a.value, b.value);
    };
    ST_DecimalNumberOrPercent.$t = markStruct(ST_DecimalNumberOrPercent, 'ST_DecimalNumberOrPercent');
    return ST_DecimalNumberOrPercent;
}(ValueType));
export { ST_DecimalNumberOrPercent };
var ST_DrawingElementId = /** @class */ (function (_super) {
    tslib_1.__extends(ST_DrawingElementId, _super);
    function ST_DrawingElementId(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.g = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.g = c;
                }
                break;
        }
        return _this;
    }
    ST_DrawingElementId.c = function (a) {
        return ST_DrawingElementId.a(parseUInt32_2(a, 7, CultureInfo.invariantCulture));
    };
    ST_DrawingElementId.f = function (a) {
        var b;
        if (((function () { var c = tryParseUInt32_2(a, 7, CultureInfo.invariantCulture, b); b = c.p3; return c.ret; })())) {
            return Nullable$1.toNullable(ST_DrawingElementId.$, ST_DrawingElementId.a(b));
        }
        return Nullable$1.toNullable(ST_DrawingElementId.$, null);
    };
    ST_DrawingElementId.prototype.toString = function () {
        return this.g.toString();
    };
    ST_DrawingElementId.h = function (a) {
        return a.g;
    };
    ST_DrawingElementId.e = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_DrawingElementId.h(a.value));
    };
    ST_DrawingElementId.a = function (a) {
        return new ST_DrawingElementId(1, a);
    };
    ST_DrawingElementId.d = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_DrawingElementId.$, null);
        }
        return Nullable$1.toNullable(ST_DrawingElementId.$, ST_DrawingElementId.a(a.value));
    };
    ST_DrawingElementId.$t = markStruct(ST_DrawingElementId, 'ST_DrawingElementId');
    return ST_DrawingElementId;
}(ValueType));
export { ST_DrawingElementId };
var ST_EighthPointMeasure = /** @class */ (function (_super) {
    tslib_1.__extends(ST_EighthPointMeasure, _super);
    function ST_EighthPointMeasure(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.d = new ST_UnsignedDecimalNumber();
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.d = c;
                }
                break;
        }
        return _this;
    }
    ST_EighthPointMeasure.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_EighthPointMeasure.$, typeCast(ST_EighthPointMeasure.$, a));
        if (ST_EighthPointMeasure.j(b, Nullable$1.toNullable(ST_EighthPointMeasure.$, null))) {
            return false;
        }
        return ST_EighthPointMeasure.g(this, b.getValueOrDefault());
    };
    ST_EighthPointMeasure.prototype.getHashCode = function () {
        return Base.getHashCodeStatic(this.d);
    };
    ST_EighthPointMeasure.prototype.toString = function () {
        return this.d.toString();
    };
    ST_EighthPointMeasure.c = function (a) {
        var b = ST_EighthPointMeasure.p(a);
        if (ST_EighthPointMeasure.j(b, Nullable$1.toNullable(ST_EighthPointMeasure.$, null))) {
            return b.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_EighthPointMeasure.$, a);
    };
    ST_EighthPointMeasure.p = function (a) {
        var b = ST_UnsignedDecimalNumber.f(a);
        if (nullableNotEquals(b, null)) {
            return Nullable$1.toNullable(ST_EighthPointMeasure.$, ST_EighthPointMeasure.a(b.getValueOrDefault()));
        }
        return Nullable$1.toNullable(ST_EighthPointMeasure.$, null);
    };
    ST_EighthPointMeasure.g = function (a, b) {
        return ST_UnsignedDecimalNumber.h(a.d) == ST_UnsignedDecimalNumber.h(b.d);
    };
    ST_EighthPointMeasure.h = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_EighthPointMeasure.g(a.value, b.value);
    };
    ST_EighthPointMeasure.i = function (a, b) {
        return !(ST_EighthPointMeasure.g(a, b));
    };
    ST_EighthPointMeasure.j = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_EighthPointMeasure.i(a.value, b.value);
    };
    ST_EighthPointMeasure.a = function (a) {
        return new ST_EighthPointMeasure(1, a);
    };
    ST_EighthPointMeasure.m = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_EighthPointMeasure.$, null);
        }
        return Nullable$1.toNullable(ST_EighthPointMeasure.$, ST_EighthPointMeasure.a(a.value));
    };
    ST_EighthPointMeasure.e = function (a) {
        return a.d;
    };
    ST_EighthPointMeasure.n = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, null);
        }
        return Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, ST_EighthPointMeasure.e(a.value));
    };
    ST_EighthPointMeasure.q = function (a) {
        return ST_UnsignedDecimalNumber.h(a.d);
    };
    ST_EighthPointMeasure.o = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_EighthPointMeasure.q(a.value));
    };
    ST_EighthPointMeasure.$t = markStruct(ST_EighthPointMeasure, 'ST_EighthPointMeasure');
    return ST_EighthPointMeasure;
}(ValueType));
export { ST_EighthPointMeasure };
var ST_FixedAngle = /** @class */ (function (_super) {
    tslib_1.__extends(ST_FixedAngle, _super);
    function ST_FixedAngle(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.a = new ST_Angle();
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    DocCoreUtils.au(ST_FixedAngle.$, c.n(), "value", -5400000, 5400000);
                    _this.a = c;
                }
                break;
        }
        return _this;
    }
    ST_FixedAngle.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_FixedAngle.$, typeCast(ST_FixedAngle.$, a));
        if (ST_FixedAngle.k(b, Nullable$1.toNullable(ST_FixedAngle.$, null))) {
            return false;
        }
        return ST_FixedAngle.h(this, b.getValueOrDefault());
    };
    ST_FixedAngle.prototype.getHashCode = function () {
        return this.a.getHashCode();
    };
    ST_FixedAngle.prototype.toString = function () {
        return this.a.toString();
    };
    ST_FixedAngle.d = function (a) {
        return ST_FixedAngle.e(ST_Angle.a(a));
    };
    ST_FixedAngle.g = function (a) {
        var b = ST_FixedAngle.r(a);
        if (ST_FixedAngle.k(b, Nullable$1.toNullable(ST_FixedAngle.$, null))) {
            return b.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_FixedAngle.$, a);
    };
    ST_FixedAngle.prototype.s = function () {
        return this.a.n();
    };
    ST_FixedAngle.r = function (a) {
        return ST_FixedAngle.q(ST_Angle.m(a));
    };
    ST_FixedAngle.h = function (a, b) {
        return ST_Angle.c(a.a, b.a);
    };
    ST_FixedAngle.i = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_FixedAngle.h(a.value, b.value);
    };
    ST_FixedAngle.j = function (a, b) {
        return !(ST_FixedAngle.h(a, b));
    };
    ST_FixedAngle.k = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_FixedAngle.j(a.value, b.value);
    };
    ST_FixedAngle.e = function (a) {
        return new ST_FixedAngle(1, a);
    };
    ST_FixedAngle.q = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_FixedAngle.$, null);
        }
        return Nullable$1.toNullable(ST_FixedAngle.$, ST_FixedAngle.e(a.value));
    };
    ST_FixedAngle.b = function (a) {
        return a.a;
    };
    ST_FixedAngle.p = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Angle.$, null);
        }
        return Nullable$1.toNullable(ST_Angle.$, ST_FixedAngle.b(a.value));
    };
    ST_FixedAngle.$t = markStruct(ST_FixedAngle, 'ST_FixedAngle');
    return ST_FixedAngle;
}(ValueType));
export { ST_FixedAngle };
var ST_FixedPercentage = /** @class */ (function (_super) {
    tslib_1.__extends(ST_FixedPercentage, _super);
    function ST_FixedPercentage(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.d = new ST_Percentage();
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    DocCoreUtils.au(ST_FixedPercentage.$, ST_Percentage.k(c), "value", -100, 100);
                    _this.d = c;
                }
                break;
        }
        return _this;
    }
    ST_FixedPercentage.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_FixedPercentage.$, typeCast(ST_FixedPercentage.$, a));
        if (ST_FixedPercentage.j(b, Nullable$1.toNullable(ST_FixedPercentage.$, null))) {
            return false;
        }
        return ST_FixedPercentage.g(this, b.getValueOrDefault());
    };
    ST_FixedPercentage.prototype.getHashCode = function () {
        return this.d.getHashCode();
    };
    ST_FixedPercentage.prototype.toString = function () {
        return this.s(1);
    };
    ST_FixedPercentage.prototype.s = function (a) {
        return this.d.p(a);
    };
    ST_FixedPercentage.c = function (a, b) {
        var c = ST_FixedPercentage.r(a, b);
        if (ST_FixedPercentage.j(c, Nullable$1.toNullable(ST_FixedPercentage.$, null))) {
            return c.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_FixedPercentage.$, a);
    };
    ST_FixedPercentage.r = function (a, b) {
        return ST_FixedPercentage.p(ST_Percentage.o(a, b));
    };
    ST_FixedPercentage.g = function (a, b) {
        return ST_Percentage.d(a.d, b.d);
    };
    ST_FixedPercentage.h = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_FixedPercentage.g(a.value, b.value);
    };
    ST_FixedPercentage.i = function (a, b) {
        return !(ST_FixedPercentage.g(a, b));
    };
    ST_FixedPercentage.j = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_FixedPercentage.i(a.value, b.value);
    };
    ST_FixedPercentage.a = function (a) {
        return new ST_FixedPercentage(1, a);
    };
    ST_FixedPercentage.p = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_FixedPercentage.$, null);
        }
        return Nullable$1.toNullable(ST_FixedPercentage.$, ST_FixedPercentage.a(a.value));
    };
    ST_FixedPercentage.e = function (a) {
        return a.d;
    };
    ST_FixedPercentage.q = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Percentage.$, null);
        }
        return Nullable$1.toNullable(ST_Percentage.$, ST_FixedPercentage.e(a.value));
    };
    ST_FixedPercentage.m = function (a) {
        return ST_Percentage.k(a.d);
    };
    ST_FixedPercentage.o = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_FixedPercentage.m(a.value));
    };
    ST_FixedPercentage.$t = markStruct(ST_FixedPercentage, 'ST_FixedPercentage');
    return ST_FixedPercentage;
}(ValueType));
export { ST_FixedPercentage };
var ST_HexColorRGB = /** @class */ (function (_super) {
    tslib_1.__extends(ST_HexColorRGB, _super);
    function ST_HexColorRGB(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.m = 0;
        _this.l = 0;
        _this.k = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    var d = [c.o, c.n, c.m];
                    {
                        var f = d[0];
                        var g = d[1];
                        var h = d[2];
                        _this.m = f;
                        _this.l = g;
                        _this.k = h;
                    }
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    var e = _rest[2];
                    _this.m = c;
                    _this.l = d;
                    _this.k = e;
                }
                break;
        }
        return _this;
    }
    ST_HexColorRGB.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_HexColorRGB.$, typeCast(ST_HexColorRGB.$, a));
        if (ST_HexColorRGB.h(b, Nullable$1.toNullable(ST_HexColorRGB.$, null))) {
            return false;
        }
        return ST_HexColorRGB.e(this, b.getValueOrDefault());
    };
    ST_HexColorRGB.prototype.getHashCode = function () {
        return (this.m << 16) | (this.l << 8) | this.k;
    };
    ST_HexColorRGB.d = function (a) {
        var b = ST_HexColorRGB.p(a);
        if (ST_HexColorRGB.h(b, Nullable$1.toNullable(ST_HexColorRGB.$, null))) {
            return b.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_HexColorRGB.$, a);
    };
    ST_HexColorRGB.p = function (a) {
        var b;
        if (((function () { var c = tryParseInt32_2(a, 515, CultureInfo.invariantCulture, b); b = c.p3; return c.ret; })()) == false) {
            return Nullable$1.toNullable(ST_HexColorRGB.$, null);
        }
        var c = ((b & 16711680) >> 16);
        var d = ((b & 65280) >> 8);
        var e = ((b & 255) >> 0);
        return Nullable$1.toNullable(ST_HexColorRGB.$, new ST_HexColorRGB(2, c, d, e));
    };
    ST_HexColorRGB.prototype.toString = function () {
        return intToString1(this.m, "X2", CultureInfo.invariantCulture) + intToString1(this.l, "X2", CultureInfo.invariantCulture) + intToString1(this.k, "X2", CultureInfo.invariantCulture);
    };
    Object.defineProperty(ST_HexColorRGB.prototype, "r", {
        get: function () {
            return Color.u(255, this.m, this.l, this.k);
        },
        enumerable: true,
        configurable: true
    });
    ST_HexColorRGB.prototype.q = function () {
        return this.toString();
    };
    ST_HexColorRGB.e = function (a, b) {
        return a.k == b.k && a.l == b.l && a.m == b.m;
    };
    ST_HexColorRGB.f = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_HexColorRGB.e(a.value, b.value);
    };
    ST_HexColorRGB.g = function (a, b) {
        return !(ST_HexColorRGB.e(a, b));
    };
    ST_HexColorRGB.h = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_HexColorRGB.g(a.value, b.value);
    };
    ST_HexColorRGB.s = function (a) {
        return a.r;
    };
    ST_HexColorRGB.n = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Color.$, null);
        }
        return Nullable$1.toNullable(Color.$, ST_HexColorRGB.s(a.value));
    };
    ST_HexColorRGB.b = function (a) {
        return new ST_HexColorRGB(2, a.o, a.n, a.m);
    };
    ST_HexColorRGB.o = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_HexColorRGB.$, null);
        }
        return Nullable$1.toNullable(ST_HexColorRGB.$, ST_HexColorRGB.b(a.value));
    };
    ST_HexColorRGB.$t = markStruct(ST_HexColorRGB, 'ST_HexColorRGB');
    ST_HexColorRGB.a = new ST_HexColorRGB(0);
    return ST_HexColorRGB;
}(ValueType));
export { ST_HexColorRGB };
var ST_HexColorAuto = /** @class */ (function (_super) {
    tslib_1.__extends(ST_HexColorAuto, _super);
    function ST_HexColorAuto() {
        return _super.call(this) || this;
    }
    ST_HexColorAuto.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_HexColorAuto.$, typeCast(ST_HexColorAuto.$, a));
        if (ST_HexColorAuto.f(b, Nullable$1.toNullable(ST_HexColorAuto.$, null))) {
            return false;
        }
        return ST_HexColorAuto.c(this, b.getValueOrDefault());
    };
    ST_HexColorAuto.prototype.getHashCode = function () {
        return 0;
    };
    ST_HexColorAuto.b = function (a) {
        var b = ST_HexColorAuto.i(a);
        if (ST_HexColorAuto.f(b, Nullable$1.toNullable(ST_HexColorAuto.$, null))) {
            return b.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_HexColorAuto.$, a);
    };
    ST_HexColorAuto.i = function (a) {
        if (a == "auto") {
            return Nullable$1.toNullable(ST_HexColorAuto.$, ST_HexColorAuto.a);
        }
        return Nullable$1.toNullable(ST_HexColorAuto.$, null);
    };
    ST_HexColorAuto.prototype.toString = function () {
        return "auto";
    };
    ST_HexColorAuto.c = function (a, b) {
        return true;
    };
    ST_HexColorAuto.d = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_HexColorAuto.c(a.value, b.value);
    };
    ST_HexColorAuto.e = function (a, b) {
        return false;
    };
    ST_HexColorAuto.f = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_HexColorAuto.e(a.value, b.value);
    };
    ST_HexColorAuto.$t = markStruct(ST_HexColorAuto, 'ST_HexColorAuto');
    ST_HexColorAuto.a = new ST_HexColorAuto();
    return ST_HexColorAuto;
}(ValueType));
export { ST_HexColorAuto };
var ST_HexColor = /** @class */ (function (_super) {
    tslib_1.__extends(ST_HexColor, _super);
    function ST_HexColor(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.p = Nullable$1.toNullable(ST_HexColorRGB.$, null);
        _this.q = Nullable$1.toNullable(ST_HexColorAuto.$, null);
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.p = Nullable$1.toNullable(ST_HexColorRGB.$, c);
                    _this.q = Nullable$1.toNullable(ST_HexColorAuto.$, null);
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    _this.p = Nullable$1.toNullable(ST_HexColorRGB.$, null);
                    _this.q = Nullable$1.toNullable(ST_HexColorAuto.$, c);
                }
                break;
        }
        return _this;
    }
    ST_HexColor.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_HexColor.$, typeCast(ST_HexColor.$, a));
        if (ST_HexColor.m(b, Nullable$1.toNullable(ST_HexColor.$, null))) {
            return false;
        }
        return ST_HexColor.j(this, b.getValueOrDefault());
    };
    ST_HexColor.prototype.getHashCode = function () {
        if (ST_HexColorRGB.h(this.p, Nullable$1.toNullable(ST_HexColorRGB.$, null))) {
            return this.p.value.getHashCode();
        }
        if (ST_HexColorAuto.f(this.q, Nullable$1.toNullable(ST_HexColorAuto.$, null))) {
            return this.q.value.getHashCode();
        }
        return 0;
    };
    ST_HexColor.e = function (a) {
        var b = ST_HexColor.u(a);
        if (ST_HexColor.m(b, Nullable$1.toNullable(ST_HexColor.$, null))) {
            return b.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_HexColor.$, a);
    };
    ST_HexColor.u = function (a) {
        var b = ST_HexColorAuto.i(a);
        if (ST_HexColorAuto.f(b, Nullable$1.toNullable(ST_HexColorAuto.$, null))) {
            return Nullable$1.toNullable(ST_HexColor.$, ST_HexColor.a(b.getValueOrDefault()));
        }
        var c = ST_HexColorRGB.p(a);
        if (ST_HexColorRGB.h(c, Nullable$1.toNullable(ST_HexColorRGB.$, null))) {
            return Nullable$1.toNullable(ST_HexColor.$, ST_HexColor.b(c.getValueOrDefault()));
        }
        return Nullable$1.toNullable(ST_HexColor.$, null);
    };
    ST_HexColor.prototype.toString = function () {
        if (ST_HexColorRGB.h(this.p, Nullable$1.toNullable(ST_HexColorRGB.$, null))) {
            return this.p.getValueOrDefault().toString();
        }
        if (ST_HexColorAuto.f(this.q, Nullable$1.toNullable(ST_HexColorAuto.$, null))) {
            return this.q.getValueOrDefault().toString();
        }
        return stringEmpty();
    };
    Object.defineProperty(ST_HexColor.prototype, "h", {
        get: function () {
            return ST_HexColorAuto.f(this.q, Nullable$1.toNullable(ST_HexColorAuto.$, null));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ST_HexColor.prototype, "i", {
        get: function () {
            return ST_HexColorRGB.h(this.p, Nullable$1.toNullable(ST_HexColorRGB.$, null));
        },
        enumerable: true,
        configurable: true
    });
    ST_HexColor.j = function (a, b) {
        return ST_HexColorRGB.f(a.p, b.p) && ST_HexColorAuto.d(a.q, b.q);
    };
    ST_HexColor.k = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_HexColor.j(a.value, b.value);
    };
    ST_HexColor.l = function (a, b) {
        return !(ST_HexColor.j(a, b));
    };
    ST_HexColor.m = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_HexColor.l(a.value, b.value);
    };
    ST_HexColor.b = function (a) {
        return new ST_HexColor(1, a);
    };
    ST_HexColor.t = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_HexColor.$, null);
        }
        return Nullable$1.toNullable(ST_HexColor.$, ST_HexColor.b(a.value));
    };
    ST_HexColor.f = function (a) {
        return a.p.value;
    };
    ST_HexColor.r = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_HexColorRGB.$, null);
        }
        return Nullable$1.toNullable(ST_HexColorRGB.$, ST_HexColor.f(a.value));
    };
    ST_HexColor.a = function (a) {
        return new ST_HexColor(2, a);
    };
    ST_HexColor.s = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_HexColor.$, null);
        }
        return Nullable$1.toNullable(ST_HexColor.$, ST_HexColor.a(a.value));
    };
    ST_HexColor.$t = markStruct(ST_HexColor, 'ST_HexColor');
    return ST_HexColor;
}(ValueType));
export { ST_HexColor };
var ST_PositiveUniversalMeasure = /** @class */ (function (_super) {
    tslib_1.__extends(ST_PositiveUniversalMeasure, _super);
    function ST_PositiveUniversalMeasure(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.b = 0;
        _this.c = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    _this.c = c;
                    _this.b = d;
                }
                break;
        }
        return _this;
    }
    ST_PositiveUniversalMeasure.prototype.toString = function () {
        return ST_UniversalMeasure.p(this.c, this.b);
    };
    ST_PositiveUniversalMeasure.prototype.d = function () {
        return ST_UniversalMeasure.l(this.c, this.b);
    };
    ST_PositiveUniversalMeasure.a = function (a) {
        var b = ST_PositiveUniversalMeasure.e(a);
        if (nullableNotEquals(b, null)) {
            return b.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_PositiveUniversalMeasure.$, a);
    };
    ST_PositiveUniversalMeasure.e = function (a) {
        var b;
        var c;
        if (((function () { var d = ST_UniversalMeasure.i(a, b, c); b = d.p1; c = d.p2; return d.ret; })()) == false) {
            return Nullable$1.toNullable(ST_PositiveUniversalMeasure.$, null);
        }
        return Nullable$1.toNullable(ST_PositiveUniversalMeasure.$, new ST_PositiveUniversalMeasure(1, b, c));
    };
    ST_PositiveUniversalMeasure.$t = markStruct(ST_PositiveUniversalMeasure, 'ST_PositiveUniversalMeasure');
    return ST_PositiveUniversalMeasure;
}(ValueType));
export { ST_PositiveUniversalMeasure };
var ST_UnsignedDecimalNumber = /** @class */ (function (_super) {
    tslib_1.__extends(ST_UnsignedDecimalNumber, _super);
    function ST_UnsignedDecimalNumber(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.g = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.g = c;
                }
                break;
        }
        return _this;
    }
    ST_UnsignedDecimalNumber.f = function (a) {
        var b;
        if (((function () { var c = tryParseUInt64_2(a, 7 | 4, CultureInfo.invariantCulture, b); b = c.p3; return c.ret; })())) {
            return Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, ST_UnsignedDecimalNumber.b(b));
        }
        return Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, null);
    };
    ST_UnsignedDecimalNumber.prototype.toString = function () {
        return this.g.toString();
    };
    ST_UnsignedDecimalNumber.h = function (a) {
        return a.g;
    };
    ST_UnsignedDecimalNumber.e = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_UnsignedDecimalNumber.h(a.value));
    };
    ST_UnsignedDecimalNumber.b = function (a) {
        return new ST_UnsignedDecimalNumber(1, a);
    };
    ST_UnsignedDecimalNumber.d = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, null);
        }
        return Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, ST_UnsignedDecimalNumber.b(a.value));
    };
    ST_UnsignedDecimalNumber.$t = markStruct(ST_UnsignedDecimalNumber, 'ST_UnsignedDecimalNumber');
    ST_UnsignedDecimalNumber.a = new ST_UnsignedDecimalNumber(0);
    return ST_UnsignedDecimalNumber;
}(ValueType));
export { ST_UnsignedDecimalNumber };
var ST_HpsMeasure = /** @class */ (function (_super) {
    tslib_1.__extends(ST_HpsMeasure, _super);
    function ST_HpsMeasure(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.g = Nullable$1.toNullable(ST_PositiveUniversalMeasure.$, null);
        _this.h = Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, null);
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    var d = [new ST_PositiveUniversalMeasure(1, c, 3)];
                    {
                        var f = d[0];
                        _this.g = Nullable$1.toNullable(ST_PositiveUniversalMeasure.$, f);
                        _this.h = Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, null);
                    }
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    _this.g = Nullable$1.toNullable(ST_PositiveUniversalMeasure.$, c);
                    _this.h = Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, null);
                }
                break;
            case 3:
                {
                    var c = _rest[0];
                    _this.g = Nullable$1.toNullable(ST_PositiveUniversalMeasure.$, null);
                    _this.h = Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, c);
                }
                break;
        }
        return _this;
    }
    ST_HpsMeasure.prototype.toString = function () {
        if (nullableNotEquals(this.g, null)) {
            return this.g.getValueOrDefault().toString();
        }
        if (nullableNotEquals(this.h, null)) {
            return this.h.getValueOrDefault().toString();
        }
        return stringEmpty();
    };
    ST_HpsMeasure.prototype.f = function () {
        if (nullableNotEquals(this.g, null)) {
            return this.g.getValueOrDefault().d();
        }
        if (nullableNotEquals(this.h, null)) {
            return (ST_UnsignedDecimalNumber.h(this.h.getValueOrDefault()) * 10);
        }
        return 0;
    };
    ST_HpsMeasure.e = function (a) {
        var b = ST_HpsMeasure.k(a);
        if (nullableNotEquals(b, null)) {
            return b.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_HpsMeasure.$, a);
    };
    ST_HpsMeasure.k = function (a) {
        var b = ST_PositiveUniversalMeasure.e(a);
        if (nullableNotEquals(b, null)) {
            return Nullable$1.toNullable(ST_HpsMeasure.$, ST_HpsMeasure.a(b.getValueOrDefault()));
        }
        var c = ST_UnsignedDecimalNumber.f(a);
        if (nullableNotEquals(c, null)) {
            return Nullable$1.toNullable(ST_HpsMeasure.$, ST_HpsMeasure.b(c.getValueOrDefault()));
        }
        return Nullable$1.toNullable(ST_HpsMeasure.$, null);
    };
    ST_HpsMeasure.a = function (a) {
        return new ST_HpsMeasure(2, a);
    };
    ST_HpsMeasure.i = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_HpsMeasure.$, null);
        }
        return Nullable$1.toNullable(ST_HpsMeasure.$, ST_HpsMeasure.a(a.value));
    };
    ST_HpsMeasure.b = function (a) {
        return new ST_HpsMeasure(3, a);
    };
    ST_HpsMeasure.j = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_HpsMeasure.$, null);
        }
        return Nullable$1.toNullable(ST_HpsMeasure.$, ST_HpsMeasure.b(a.value));
    };
    ST_HpsMeasure.$t = markStruct(ST_HpsMeasure, 'ST_HpsMeasure');
    return ST_HpsMeasure;
}(ValueType));
export { ST_HpsMeasure };
var ST_LongHexNumber = /** @class */ (function (_super) {
    tslib_1.__extends(ST_LongHexNumber, _super);
    function ST_LongHexNumber(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.e = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.e = c;
                }
                break;
        }
        return _this;
    }
    ST_LongHexNumber.d = function (a) {
        return ST_LongHexNumber.b(parseInt32_2(a, 515, CultureInfo.invariantCulture));
    };
    ST_LongHexNumber.prototype.toString = function () {
        return intToString1(this.e, "X8", CultureInfo.invariantCulture);
    };
    ST_LongHexNumber.b = function (a) {
        return new ST_LongHexNumber(1, a);
    };
    ST_LongHexNumber.f = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_LongHexNumber.$, null);
        }
        return Nullable$1.toNullable(ST_LongHexNumber.$, ST_LongHexNumber.b(a.value));
    };
    ST_LongHexNumber.$t = markStruct(ST_LongHexNumber, 'ST_LongHexNumber');
    ST_LongHexNumber.a = new ST_LongHexNumber(0);
    return ST_LongHexNumber;
}(ValueType));
export { ST_LongHexNumber };
var ST_MeasurementOrPercent = /** @class */ (function (_super) {
    tslib_1.__extends(ST_MeasurementOrPercent, _super);
    function ST_MeasurementOrPercent(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.m = Nullable$1.toNullable(ST_DecimalNumberOrPercent.$, null);
        _this.n = Nullable$1.toNullable(ST_UniversalMeasure.$, null);
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.m = Nullable$1.toNullable(ST_DecimalNumberOrPercent.$, c);
                    _this.n = Nullable$1.toNullable(ST_UniversalMeasure.$, null);
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    _this.m = Nullable$1.toNullable(ST_DecimalNumberOrPercent.$, null);
                    _this.n = Nullable$1.toNullable(ST_UniversalMeasure.$, c);
                }
                break;
        }
        return _this;
    }
    ST_MeasurementOrPercent.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_MeasurementOrPercent.$, typeCast(ST_MeasurementOrPercent.$, a));
        if (ST_MeasurementOrPercent.j(b, Nullable$1.toNullable(ST_MeasurementOrPercent.$, null))) {
            return false;
        }
        return ST_MeasurementOrPercent.g(this, b.getValueOrDefault());
    };
    ST_MeasurementOrPercent.prototype.getHashCode = function () {
        if (ST_DecimalNumberOrPercent.f(this.m, Nullable$1.toNullable(ST_DecimalNumberOrPercent.$, null))) {
            return this.m.getValueOrDefault().getHashCode();
        }
        if (ST_UniversalMeasure.f(this.n, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return this.n.getValueOrDefault().getHashCode() << 1;
        }
        return 0;
    };
    ST_MeasurementOrPercent.prototype.toString = function () {
        return this.r(1);
    };
    ST_MeasurementOrPercent.prototype.r = function (a) {
        if (ST_DecimalNumberOrPercent.f(this.m, Nullable$1.toNullable(ST_DecimalNumberOrPercent.$, null))) {
            return this.m.getValueOrDefault().k(a);
        }
        if (ST_UniversalMeasure.f(this.n, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return this.n.getValueOrDefault().toString();
        }
        return stringEmpty();
    };
    ST_MeasurementOrPercent.prototype.o = function (a) {
        var _this = this;
        if (ST_DecimalNumberOrPercent.f(this.m, Nullable$1.toNullable(ST_DecimalNumberOrPercent.$, null))) {
            return {
                ret: Nullable$1.toNullable(Number_$type, ((function () { var b = _this.m.getValueOrDefault().i(a); a = b.p0; return b.ret; })())),
                p0: a
            };
        }
        a = true;
        if (ST_UniversalMeasure.f(this.n, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return {
                ret: this.n.getValueOrDefault().n(),
                p0: a
            };
        }
        return {
            ret: Nullable$1.toNullable(Number_$type, null),
            p0: a
        };
    };
    ST_MeasurementOrPercent.e = function (a, b) {
        var c = ST_DecimalNumberOrPercent.j(a, b);
        if (ST_DecimalNumberOrPercent.f(c, Nullable$1.toNullable(ST_DecimalNumberOrPercent.$, null))) {
            return ST_MeasurementOrPercent.a(c.getValueOrDefault());
        }
        var d = ST_UniversalMeasure.o(a);
        if (ST_UniversalMeasure.f(d, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return ST_MeasurementOrPercent.b(d.getValueOrDefault());
        }
        throw DocCoreUtils.m(ST_MeasurementOrPercent.$, a);
    };
    Object.defineProperty(ST_MeasurementOrPercent.prototype, "f", {
        get: function () {
            return ST_UniversalMeasure.f(this.n, Nullable$1.toNullable(ST_UniversalMeasure.$, null));
        },
        enumerable: true,
        configurable: true
    });
    ST_MeasurementOrPercent.g = function (a, b) {
        if (ST_DecimalNumberOrPercent.f(a.m, b.m)) {
            return false;
        }
        if (!a.n.hasValue) {
            return !b.n.hasValue;
        }
        if (!b.n.hasValue) {
            return false;
        }
        return ST_UniversalMeasure.b(a.n.value, b.n.value);
    };
    ST_MeasurementOrPercent.h = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_MeasurementOrPercent.g(a.value, b.value);
    };
    ST_MeasurementOrPercent.i = function (a, b) {
        return !(ST_MeasurementOrPercent.g(a, b));
    };
    ST_MeasurementOrPercent.j = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_MeasurementOrPercent.i(a.value, b.value);
    };
    ST_MeasurementOrPercent.a = function (a) {
        return new ST_MeasurementOrPercent(1, a);
    };
    ST_MeasurementOrPercent.p = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_MeasurementOrPercent.$, null);
        }
        return Nullable$1.toNullable(ST_MeasurementOrPercent.$, ST_MeasurementOrPercent.a(a.value));
    };
    ST_MeasurementOrPercent.b = function (a) {
        return new ST_MeasurementOrPercent(2, a);
    };
    ST_MeasurementOrPercent.q = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_MeasurementOrPercent.$, null);
        }
        return Nullable$1.toNullable(ST_MeasurementOrPercent.$, ST_MeasurementOrPercent.b(a.value));
    };
    ST_MeasurementOrPercent.$t = markStruct(ST_MeasurementOrPercent, 'ST_MeasurementOrPercent');
    return ST_MeasurementOrPercent;
}(ValueType));
export { ST_MeasurementOrPercent };
var ST_OnOff = /** @class */ (function (_super) {
    tslib_1.__extends(ST_OnOff, _super);
    function ST_OnOff(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.d = false;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.d = c;
                }
                break;
        }
        return _this;
    }
    ST_OnOff.e = function (a) {
        switch (a) {
            case "1": return true;
            case "0": return false;
        }
        return parseBool(a);
    };
    ST_OnOff.prototype.toString = function () {
        return this.d ? "1" : "0";
    };
    ST_OnOff.g = function (a) {
        return a ? "1" : "0";
    };
    ST_OnOff.b = function (a) {
        return a ? ST_OnOff.c : ST_OnOff.a;
    };
    ST_OnOff.prototype.f = function () {
        return this.d;
    };
    ST_OnOff.$t = markStruct(ST_OnOff, 'ST_OnOff');
    ST_OnOff.a = new ST_OnOff(1, false);
    ST_OnOff.c = new ST_OnOff(1, true);
    return ST_OnOff;
}(ValueType));
export { ST_OnOff };
var ST_Panose = /** @class */ (function (_super) {
    tslib_1.__extends(ST_Panose, _super);
    function ST_Panose(a) {
        var _this = _super.call(this) || this;
        _this.a = null;
        _this.a = a;
        return _this;
    }
    ST_Panose.prototype.toString = function () {
        return stringConcat.apply(void 0, tslib_1.__spread(Enumerable.a(String_$type, Enumerable.o(Number_$type, String_$type, this.a, function (a) { return intToString1(a, "X2", CultureInfo.invariantCulture); }))));
    };
    ST_Panose.b = function (a) {
        var b = new Array(intDivide(a.length, 2));
        for (var c = 0; c < b.length; c++) {
            var d = a.charAt(c * 2);
            var e = a.charAt(c * 2 + 1);
            b[c] = (DocCoreUtils.q(d) << 4 | DocCoreUtils.q(e));
        }
        return new ST_Panose(b);
    };
    ST_Panose.$t = markType(ST_Panose, 'ST_Panose');
    return ST_Panose;
}(Base));
export { ST_Panose };
var ST_PointMeasure = /** @class */ (function (_super) {
    tslib_1.__extends(ST_PointMeasure, _super);
    function ST_PointMeasure(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.d = new ST_UnsignedDecimalNumber();
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.d = c;
                }
                break;
        }
        return _this;
    }
    ST_PointMeasure.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_PointMeasure.$, typeCast(ST_PointMeasure.$, a));
        if (ST_PointMeasure.j(b, Nullable$1.toNullable(ST_PointMeasure.$, null))) {
            return false;
        }
        return ST_PointMeasure.g(this, b.getValueOrDefault());
    };
    ST_PointMeasure.prototype.getHashCode = function () {
        return Base.getHashCodeStatic(this.d);
    };
    ST_PointMeasure.prototype.toString = function () {
        return this.d.toString();
    };
    ST_PointMeasure.c = function (a) {
        var b = ST_PointMeasure.p(a);
        if (ST_PointMeasure.j(b, Nullable$1.toNullable(ST_PointMeasure.$, null))) {
            return b.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_PointMeasure.$, a);
    };
    ST_PointMeasure.p = function (a) {
        var b = ST_UnsignedDecimalNumber.f(a);
        if (nullableNotEquals(b, null)) {
            return Nullable$1.toNullable(ST_PointMeasure.$, ST_PointMeasure.a(b.getValueOrDefault()));
        }
        return Nullable$1.toNullable(ST_PointMeasure.$, null);
    };
    ST_PointMeasure.g = function (a, b) {
        return ST_UnsignedDecimalNumber.h(a.d) == ST_UnsignedDecimalNumber.h(b.d);
    };
    ST_PointMeasure.h = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_PointMeasure.g(a.value, b.value);
    };
    ST_PointMeasure.i = function (a, b) {
        return !(ST_PointMeasure.g(a, b));
    };
    ST_PointMeasure.j = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_PointMeasure.i(a.value, b.value);
    };
    ST_PointMeasure.a = function (a) {
        return new ST_PointMeasure(1, a);
    };
    ST_PointMeasure.m = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_PointMeasure.$, null);
        }
        return Nullable$1.toNullable(ST_PointMeasure.$, ST_PointMeasure.a(a.value));
    };
    ST_PointMeasure.e = function (a) {
        return a.d;
    };
    ST_PointMeasure.n = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, null);
        }
        return Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, ST_PointMeasure.e(a.value));
    };
    ST_PointMeasure.q = function (a) {
        return ST_UnsignedDecimalNumber.h(a.d);
    };
    ST_PointMeasure.o = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_PointMeasure.q(a.value));
    };
    ST_PointMeasure.$t = markStruct(ST_PointMeasure, 'ST_PointMeasure');
    return ST_PointMeasure;
}(ValueType));
export { ST_PointMeasure };
var ST_PositiveFixedAngle = /** @class */ (function (_super) {
    tslib_1.__extends(ST_PositiveFixedAngle, _super);
    function ST_PositiveFixedAngle(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.a = new ST_Angle();
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    DocCoreUtils.au(ST_PositiveFixedAngle.$, c.n(), "value", 0, 21600000);
                    _this.a = c;
                }
                break;
        }
        return _this;
    }
    ST_PositiveFixedAngle.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_PositiveFixedAngle.$, typeCast(ST_PositiveFixedAngle.$, a));
        if (ST_PositiveFixedAngle.k(b, Nullable$1.toNullable(ST_PositiveFixedAngle.$, null))) {
            return false;
        }
        return ST_PositiveFixedAngle.h(this, b.getValueOrDefault());
    };
    ST_PositiveFixedAngle.prototype.getHashCode = function () {
        return this.a.getHashCode();
    };
    ST_PositiveFixedAngle.prototype.toString = function () {
        return this.a.toString();
    };
    ST_PositiveFixedAngle.d = function (a) {
        return ST_PositiveFixedAngle.e(ST_Angle.a(a));
    };
    ST_PositiveFixedAngle.prototype.q = function () {
        return this.a.n();
    };
    ST_PositiveFixedAngle.g = function (a) {
        var b = ST_PositiveFixedAngle.p(a);
        if (ST_PositiveFixedAngle.k(b, Nullable$1.toNullable(ST_PositiveFixedAngle.$, null))) {
            return b.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_PositiveFixedAngle.$, a);
    };
    ST_PositiveFixedAngle.p = function (a) {
        return ST_PositiveFixedAngle.o(ST_Angle.m(a));
    };
    ST_PositiveFixedAngle.h = function (a, b) {
        return ST_Angle.c(a.a, b.a);
    };
    ST_PositiveFixedAngle.i = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_PositiveFixedAngle.h(a.value, b.value);
    };
    ST_PositiveFixedAngle.j = function (a, b) {
        return !(ST_PositiveFixedAngle.h(a, b));
    };
    ST_PositiveFixedAngle.k = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_PositiveFixedAngle.j(a.value, b.value);
    };
    ST_PositiveFixedAngle.e = function (a) {
        return new ST_PositiveFixedAngle(1, a);
    };
    ST_PositiveFixedAngle.o = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_PositiveFixedAngle.$, null);
        }
        return Nullable$1.toNullable(ST_PositiveFixedAngle.$, ST_PositiveFixedAngle.e(a.value));
    };
    ST_PositiveFixedAngle.b = function (a) {
        return a.a;
    };
    ST_PositiveFixedAngle.n = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Angle.$, null);
        }
        return Nullable$1.toNullable(ST_Angle.$, ST_PositiveFixedAngle.b(a.value));
    };
    ST_PositiveFixedAngle.$t = markStruct(ST_PositiveFixedAngle, 'ST_PositiveFixedAngle');
    return ST_PositiveFixedAngle;
}(ValueType));
export { ST_PositiveFixedAngle };
var ST_PositiveFixedPercentage = /** @class */ (function (_super) {
    tslib_1.__extends(ST_PositiveFixedPercentage, _super);
    function ST_PositiveFixedPercentage(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.a = new ST_Percentage();
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    DocCoreUtils.au(ST_PositiveFixedPercentage.$, ST_Percentage.k(c), "value", 0, 100);
                    _this.a = c;
                }
                break;
        }
        return _this;
    }
    ST_PositiveFixedPercentage.prototype.equals = function (a) {
        var b = Nullable$1.toNullable(ST_PositiveFixedPercentage.$, typeCast(ST_PositiveFixedPercentage.$, a));
        if (ST_PositiveFixedPercentage.j(b, Nullable$1.toNullable(ST_PositiveFixedPercentage.$, null))) {
            return false;
        }
        return ST_PositiveFixedPercentage.g(this, b.getValueOrDefault());
    };
    ST_PositiveFixedPercentage.prototype.getHashCode = function () {
        return this.a.getHashCode();
    };
    ST_PositiveFixedPercentage.prototype.toString = function () {
        return this.u(1);
    };
    ST_PositiveFixedPercentage.prototype.u = function (a) {
        return this.a.p(a);
    };
    ST_PositiveFixedPercentage.f = function (a, b) {
        var c = ST_PositiveFixedPercentage.t(a, b);
        if (ST_PositiveFixedPercentage.j(c, Nullable$1.toNullable(ST_PositiveFixedPercentage.$, null))) {
            return c.getValueOrDefault();
        }
        throw DocCoreUtils.m(ST_PositiveFixedPercentage.$, a);
    };
    ST_PositiveFixedPercentage.t = function (a, b) {
        return ST_PositiveFixedPercentage.s(ST_Percentage.o(a, b));
    };
    ST_PositiveFixedPercentage.o = function (a) {
        if (a < 0 || a > 1) {
            throw new ArgumentOutOfRangeException(1, "value");
        }
        return (a * 100);
    };
    ST_PositiveFixedPercentage.p = function (a) {
        return truncate((a * 1000));
    };
    ST_PositiveFixedPercentage.g = function (a, b) {
        return ST_Percentage.d(a.a, b.a);
    };
    ST_PositiveFixedPercentage.h = function (a, b) {
        if (!a.hasValue) {
            return !b.hasValue;
        }
        else if (!b.hasValue) {
            return false;
        }
        return ST_PositiveFixedPercentage.g(a.value, b.value);
    };
    ST_PositiveFixedPercentage.i = function (a, b) {
        return !(ST_PositiveFixedPercentage.g(a, b));
    };
    ST_PositiveFixedPercentage.j = function (a, b) {
        if (!a.hasValue) {
            return b.hasValue;
        }
        else if (!b.hasValue) {
            return true;
        }
        return ST_PositiveFixedPercentage.i(a.value, b.value);
    };
    ST_PositiveFixedPercentage.d = function (a) {
        return new ST_PositiveFixedPercentage(1, a);
    };
    ST_PositiveFixedPercentage.s = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_PositiveFixedPercentage.$, null);
        }
        return Nullable$1.toNullable(ST_PositiveFixedPercentage.$, ST_PositiveFixedPercentage.d(a.value));
    };
    ST_PositiveFixedPercentage.b = function (a) {
        return a.a;
    };
    ST_PositiveFixedPercentage.r = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Percentage.$, null);
        }
        return Nullable$1.toNullable(ST_Percentage.$, ST_PositiveFixedPercentage.b(a.value));
    };
    ST_PositiveFixedPercentage.m = function (a) {
        return ST_Percentage.k(a.a);
    };
    ST_PositiveFixedPercentage.q = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_PositiveFixedPercentage.m(a.value));
    };
    ST_PositiveFixedPercentage.$t = markStruct(ST_PositiveFixedPercentage, 'ST_PositiveFixedPercentage');
    return ST_PositiveFixedPercentage;
}(ValueType));
export { ST_PositiveFixedPercentage };
var ST_SignedHpsMeasure = /** @class */ (function (_super) {
    tslib_1.__extends(ST_SignedHpsMeasure, _super);
    function ST_SignedHpsMeasure(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.c = Nullable$1.toNullable(Number_$type, null);
        _this.d = Nullable$1.toNullable(ST_UniversalMeasure.$, null);
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.c = Nullable$1.toNullable(Number_$type, truncate((c * 2)));
                    _this.d = Nullable$1.toNullable(ST_UniversalMeasure.$, null);
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    _this.c = Nullable$1.toNullable(Number_$type, null);
                    _this.d = Nullable$1.toNullable(ST_UniversalMeasure.$, c);
                }
                break;
        }
        return _this;
    }
    ST_SignedHpsMeasure.prototype.toString = function () {
        if (nullableNotEquals(this.c, null)) {
            return this.c.value.toString();
        }
        if (ST_UniversalMeasure.f(this.d, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return this.d.toString();
        }
        return stringEmpty();
    };
    ST_SignedHpsMeasure.prototype.b = function () {
        if (nullableNotEquals(this.c, null)) {
            return this.c.value * 10;
        }
        if (ST_UniversalMeasure.f(this.d, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return this.d.value.k();
        }
        return 0;
    };
    ST_SignedHpsMeasure.a = function (a) {
        var b;
        if (((function () { var c = tryParseInt32_2(a, 7, CultureInfo.invariantCulture, b); b = c.p3; return c.ret; })())) {
            return new ST_SignedHpsMeasure(1, intDivide(b, 2));
        }
        var c = ST_UniversalMeasure.o(a);
        if (ST_UniversalMeasure.f(c, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return new ST_SignedHpsMeasure(2, c.value);
        }
        throw DocCoreUtils.m(ST_SignedHpsMeasure.$, a);
    };
    ST_SignedHpsMeasure.$t = markStruct(ST_SignedHpsMeasure, 'ST_SignedHpsMeasure');
    return ST_SignedHpsMeasure;
}(ValueType));
export { ST_SignedHpsMeasure };
var ST_SignedTwipsMeasure = /** @class */ (function (_super) {
    tslib_1.__extends(ST_SignedTwipsMeasure, _super);
    function ST_SignedTwipsMeasure(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.c = Nullable$1.toNullable(Number_$type, null);
        _this.d = Nullable$1.toNullable(ST_UniversalMeasure.$, null);
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    var d = [truncate(c)];
                    {
                        var f = d[0];
                        _this.c = Nullable$1.toNullable(Number_$type, f);
                        _this.d = Nullable$1.toNullable(ST_UniversalMeasure.$, null);
                    }
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    _this.c = Nullable$1.toNullable(Number_$type, c);
                    _this.d = Nullable$1.toNullable(ST_UniversalMeasure.$, null);
                }
                break;
            case 3:
                {
                    var c = _rest[0];
                    _this.c = Nullable$1.toNullable(Number_$type, null);
                    _this.d = Nullable$1.toNullable(ST_UniversalMeasure.$, c);
                }
                break;
        }
        return _this;
    }
    ST_SignedTwipsMeasure.prototype.toString = function () {
        if (nullableNotEquals(this.c, null)) {
            return this.c.value.toString();
        }
        if (ST_UniversalMeasure.f(this.d, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return this.d.toString();
        }
        return stringEmpty();
    };
    ST_SignedTwipsMeasure.prototype.b = function () {
        if (nullableNotEquals(this.c, null)) {
            return this.c.value;
        }
        if (ST_UniversalMeasure.f(this.d, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return this.d.value.k();
        }
        return 0;
    };
    ST_SignedTwipsMeasure.a = function (a) {
        var b;
        if (((function () { var c = tryParseInt32_2(a, 7, CultureInfo.invariantCulture, b); b = c.p3; return c.ret; })())) {
            return new ST_SignedTwipsMeasure(2, b);
        }
        var c = ST_UniversalMeasure.o(a);
        if (ST_UniversalMeasure.f(c, Nullable$1.toNullable(ST_UniversalMeasure.$, null))) {
            return new ST_SignedTwipsMeasure(3, c.value);
        }
        throw DocCoreUtils.m(ST_SignedTwipsMeasure.$, a);
    };
    ST_SignedTwipsMeasure.$t = markStruct(ST_SignedTwipsMeasure, 'ST_SignedTwipsMeasure');
    return ST_SignedTwipsMeasure;
}(ValueType));
export { ST_SignedTwipsMeasure };
var ST_TextFontSize = /** @class */ (function (_super) {
    tslib_1.__extends(ST_TextFontSize, _super);
    function ST_TextFontSize(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.d = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    DocCoreUtils.au(ST_TextFontSize.$, c, "value", 100, 400000);
                    _this.d = c;
                }
                break;
        }
        return _this;
    }
    ST_TextFontSize.c = function (a) {
        return ST_TextFontSize.a(parseInt32_2(a, 7, CultureInfo.invariantCulture));
    };
    ST_TextFontSize.i = function (a) {
        var b;
        if (((function () { var c = tryParseInt32_2(a, 7, CultureInfo.invariantCulture, b); b = c.p3; return c.ret; })())) {
            return Nullable$1.toNullable(ST_TextFontSize.$, ST_TextFontSize.a(b));
        }
        return Nullable$1.toNullable(ST_TextFontSize.$, null);
    };
    ST_TextFontSize.prototype.toString = function () {
        return this.d.toString();
    };
    ST_TextFontSize.e = function (a) {
        return a.d;
    };
    ST_TextFontSize.g = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_TextFontSize.e(a.value));
    };
    ST_TextFontSize.a = function (a) {
        return new ST_TextFontSize(1, a);
    };
    ST_TextFontSize.h = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_TextFontSize.$, null);
        }
        return Nullable$1.toNullable(ST_TextFontSize.$, ST_TextFontSize.a(a.value));
    };
    ST_TextFontSize.$t = markStruct(ST_TextFontSize, 'ST_TextFontSize');
    return ST_TextFontSize;
}(ValueType));
export { ST_TextFontSize };
var ST_TrueFalse = /** @class */ (function (_super) {
    tslib_1.__extends(ST_TrueFalse, _super);
    function ST_TrueFalse(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.f = false;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.f = c;
                }
                break;
        }
        return _this;
    }
    ST_TrueFalse.d = function (a) {
        switch (a) {
            case "t": return ST_TrueFalse.b(true);
            case "f": return ST_TrueFalse.b(false);
        }
        return ST_TrueFalse.b(parseBool(a));
    };
    ST_TrueFalse.prototype.toString = function () {
        return this.f ? "t" : "f";
    };
    ST_TrueFalse.k = function (a) {
        return a.toString();
    };
    ST_TrueFalse.g = function (a) {
        return a.f;
    };
    ST_TrueFalse.i = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Boolean_$type, null);
        }
        return Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(a.value));
    };
    ST_TrueFalse.b = function (a) {
        return new ST_TrueFalse(1, a);
    };
    ST_TrueFalse.j = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_TrueFalse.$, null);
        }
        return Nullable$1.toNullable(ST_TrueFalse.$, ST_TrueFalse.b(a.value));
    };
    ST_TrueFalse.$t = markStruct(ST_TrueFalse, 'ST_TrueFalse');
    ST_TrueFalse.a = new ST_TrueFalse(1, false);
    ST_TrueFalse.e = new ST_TrueFalse(1, true);
    return ST_TrueFalse;
}(ValueType));
export { ST_TrueFalse };
var ST_TrueFalseBlank = /** @class */ (function (_super) {
    tslib_1.__extends(ST_TrueFalseBlank, _super);
    function ST_TrueFalseBlank(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.c = false;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.c = c;
                }
                break;
        }
        return _this;
    }
    ST_TrueFalseBlank.d = function (a) {
        if (stringIsNullOrEmpty(a)) {
            return true;
        }
        switch (a) {
            case "t":
            case "True": return true;
            case "f":
            case "False": return false;
        }
        throw DocCoreUtils.m(ST_TrueFalseBlank.$, a);
    };
    ST_TrueFalseBlank.prototype.toString = function () {
        if (this.c) {
            return stringEmpty();
        }
        return "False";
    };
    ST_TrueFalseBlank.e = function (a) {
        return a.toString();
    };
    ST_TrueFalseBlank.f = function (a) {
        return (a ? ST_TrueFalseBlank.b : ST_TrueFalseBlank.a).toString();
    };
    ST_TrueFalseBlank.$t = markStruct(ST_TrueFalseBlank, 'ST_TrueFalseBlank');
    ST_TrueFalseBlank.a = new ST_TrueFalseBlank(1, false);
    ST_TrueFalseBlank.b = new ST_TrueFalseBlank(1, true);
    return ST_TrueFalseBlank;
}(ValueType));
export { ST_TrueFalseBlank };
var ST_TwipsMeasure = /** @class */ (function (_super) {
    tslib_1.__extends(ST_TwipsMeasure, _super);
    function ST_TwipsMeasure(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.c = Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, null);
        _this.d = Nullable$1.toNullable(ST_PositiveUniversalMeasure.$, null);
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    var d = [ST_UnsignedDecimalNumber.b(truncate(DocCoreUtils.i(c)))];
                    {
                        var f = d[0];
                        _this.c = Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, f);
                        _this.d = Nullable$1.toNullable(ST_PositiveUniversalMeasure.$, null);
                    }
                }
                break;
            case 2:
                {
                    var c = _rest[0];
                    _this.c = Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, c);
                    _this.d = Nullable$1.toNullable(ST_PositiveUniversalMeasure.$, null);
                }
                break;
            case 3:
                {
                    var c = _rest[0];
                    _this.c = Nullable$1.toNullable(ST_UnsignedDecimalNumber.$, null);
                    _this.d = Nullable$1.toNullable(ST_PositiveUniversalMeasure.$, c);
                }
                break;
        }
        return _this;
    }
    ST_TwipsMeasure.prototype.toString = function () {
        if (nullableNotEquals(this.c, null)) {
            return this.c.value.toString();
        }
        if (nullableNotEquals(this.d, null)) {
            return this.d.value.toString();
        }
        return stringEmpty();
    };
    ST_TwipsMeasure.prototype.b = function () {
        if (nullableNotEquals(this.c, null)) {
            return ST_UnsignedDecimalNumber.h(this.c.value);
        }
        if (nullableNotEquals(this.d, null)) {
            return this.d.value.d();
        }
        return 0;
    };
    ST_TwipsMeasure.a = function (a) {
        var b = ST_UnsignedDecimalNumber.f(a);
        if (nullableNotEquals(b, null)) {
            return new ST_TwipsMeasure(2, b.value);
        }
        var c = ST_PositiveUniversalMeasure.e(a);
        if (nullableNotEquals(c, null)) {
            return new ST_TwipsMeasure(3, c.value);
        }
        throw DocCoreUtils.m(ST_TwipsMeasure.$, a);
    };
    ST_TwipsMeasure.$t = markStruct(ST_TwipsMeasure, 'ST_TwipsMeasure');
    return ST_TwipsMeasure;
}(ValueType));
export { ST_TwipsMeasure };
var ST_UcharHexNumber = /** @class */ (function (_super) {
    tslib_1.__extends(ST_UcharHexNumber, _super);
    function ST_UcharHexNumber(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.e = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.e = c;
                }
                break;
        }
        return _this;
    }
    ST_UcharHexNumber.d = function (a) {
        return ST_UcharHexNumber.b(parseUInt8_2(a, 515, CultureInfo.invariantCulture));
    };
    ST_UcharHexNumber.prototype.toString = function () {
        return intToString1(this.e, "X2", CultureInfo.invariantCulture);
    };
    ST_UcharHexNumber.b = function (a) {
        return new ST_UcharHexNumber(1, a);
    };
    ST_UcharHexNumber.i = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_UcharHexNumber.$, null);
        }
        return Nullable$1.toNullable(ST_UcharHexNumber.$, ST_UcharHexNumber.b(a.value));
    };
    ST_UcharHexNumber.f = function (a) {
        return a.e;
    };
    ST_UcharHexNumber.h = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_UcharHexNumber.f(a.value));
    };
    ST_UcharHexNumber.$t = markStruct(ST_UcharHexNumber, 'ST_UcharHexNumber');
    ST_UcharHexNumber.a = new ST_UcharHexNumber(0);
    return ST_UcharHexNumber;
}(ValueType));
export { ST_UcharHexNumber };
var ST_UnsignedIntHex = /** @class */ (function (_super) {
    tslib_1.__extends(ST_UnsignedIntHex, _super);
    function ST_UnsignedIntHex(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.g = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.g = c;
                }
                break;
        }
        return _this;
    }
    ST_UnsignedIntHex.d = function (a) {
        return ST_UnsignedIntHex.b(parseUInt32_2(a, 515, CultureInfo.invariantCulture));
    };
    ST_UnsignedIntHex.prototype.toString = function () {
        return intToString1(this.g, "X8", CultureInfo.invariantCulture);
    };
    ST_UnsignedIntHex.b = function (a) {
        return new ST_UnsignedIntHex(1, a);
    };
    ST_UnsignedIntHex.e = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_UnsignedIntHex.$, null);
        }
        return Nullable$1.toNullable(ST_UnsignedIntHex.$, ST_UnsignedIntHex.b(a.value));
    };
    ST_UnsignedIntHex.h = function (a) {
        return a.g;
    };
    ST_UnsignedIntHex.f = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Number_$type, null);
        }
        return Nullable$1.toNullable(Number_$type, ST_UnsignedIntHex.h(a.value));
    };
    ST_UnsignedIntHex.$t = markStruct(ST_UnsignedIntHex, 'ST_UnsignedIntHex');
    ST_UnsignedIntHex.a = new ST_UnsignedIntHex(0);
    return ST_UnsignedIntHex;
}(ValueType));
export { ST_UnsignedIntHex };
var ST_UnsignedShortHex = /** @class */ (function (_super) {
    tslib_1.__extends(ST_UnsignedShortHex, _super);
    function ST_UnsignedShortHex(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.c = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.c = c;
                }
                break;
        }
        return _this;
    }
    ST_UnsignedShortHex.d = function (a) {
        return parseUInt16_2(a, 515, CultureInfo.invariantCulture);
    };
    ST_UnsignedShortHex.b = function (a) {
        return new ST_UnsignedShortHex(1, ST_UnsignedShortHex.d(a));
    };
    ST_UnsignedShortHex.prototype.toString = function () {
        return intToString1(this.c, "X4", CultureInfo.invariantCulture);
    };
    ST_UnsignedShortHex.prototype.e = function () {
        return this.c;
    };
    ST_UnsignedShortHex.$t = markStruct(ST_UnsignedShortHex, 'ST_UnsignedShortHex');
    ST_UnsignedShortHex.a = new ST_UnsignedShortHex(0);
    return ST_UnsignedShortHex;
}(ValueType));
export { ST_UnsignedShortHex };
var XmlWriteManager = /** @class */ (function (_super) {
    tslib_1.__extends(XmlWriteManager, _super);
    function XmlWriteManager(a, b) {
        var _this = _super.call(this) || this;
        _this.a = null;
        _this.c = null;
        _this.b = null;
        _this.w = null;
        _this.c = new List$1(String_$type, 0);
        _this.a = a.d;
        _this.b = a;
        _this.w = b;
        return _this;
    }
    XmlWriteManager.prototype.d = function (a) {
        return this.w.a(a.i(this.a._z));
    };
    XmlWriteManager.prototype.e = function (a, b, c, d) {
        var e = a.lastIndexOf("/");
        if (e < 0) {
            c = a;
            d = "";
            b = stringEmpty();
            return {
                p1: b,
                p2: c,
                p3: d
            };
        }
        c = a.substr(e + 1);
        d = a.substr(0, e);
        if (this.a._z != 1) {
            var f = this.a._u(d);
            if (f != null) {
                d = f.i(this.a._z);
            }
        }
        b = this.w.a(d);
        if (stringIsNullOrEmpty(b)) {
            var g = d + "/";
            b = this.w.a(g);
            if (stringIsNullOrEmpty(b) == false) {
                d = g;
            }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
    };
    XmlWriteManager.prototype.f = function () {
        if (this.c.count == 0) {
            return;
        }
        this.l(MarkupCompatibility2006.an);
        this.h(MarkupCompatibility2006.as, stringJoin1(String_$type, " ", this.c));
        this.c.clear();
    };
    XmlWriteManager.prototype.g = function (a, b) {
        var _this = this;
        if (b === void 0) { b = null; }
        var c = new HashSet$1(XmlNamespaceDefinitionBase.$, 0);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                try {
                    for (var _2 = tslib_1.__values(fromEnum(Enumerable.u(XmlNamespaceDefinitionBase.$, d.b, function (f) { return _this.d(f) == null; }))), _3 = _2.next(); !_3.done; _3 = _2.next()) {
                        var e = _3.value;
                        c.add_1(e);
                    }
                }
                catch (e_22_1) { e_22 = { error: e_22_1 }; }
                finally {
                    try {
                        if (_3 && !_3.done && (_4 = _2.return)) _4.call(_2);
                    }
                    finally { if (e_22) throw e_22.error; }
                }
            }
        }
        catch (e_23_1) { e_23 = { error: e_23_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_5 = _0.return)) _5.call(_0);
            }
            finally { if (e_23) throw e_23.error; }
        }
        MarkupCompatibility2006.ay(this.b);
        try {
            for (var _6 = tslib_1.__values(fromEnum(c)), _7 = _6.next(); !_7.done; _7 = _6.next()) {
                var f = _7.value;
                this.l(f);
            }
        }
        catch (e_24_1) { e_24 = { error: e_24_1 }; }
        finally {
            try {
                if (_7 && !_7.done && (_8 = _6.return)) _8.call(_6);
            }
            finally { if (e_24) throw e_24.error; }
        }
        try {
            for (var _9 = tslib_1.__values(fromEnum(a)), _10 = _9.next(); !_10.done; _10 = _9.next()) {
                var g = _10.value;
                MarkupCompatibility2006.az(this.b, g.b);
                g.a();
                this.k();
            }
        }
        catch (e_25_1) { e_25 = { error: e_25_1 }; }
        finally {
            try {
                if (_10 && !_10.done && (_11 = _9.return)) _11.call(_9);
            }
            finally { if (e_25) throw e_25.error; }
        }
        if (b != null) {
            MarkupCompatibility2006.a1(this.b);
            b();
            this.k();
        }
        this.k();
        var e_23, _5, e_22, _4, e_24, _8, e_25, _11;
    };
    XmlWriteManager.prototype.h = function (a, b) {
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f = this.e(a, c, d, e);
        c = f.p1;
        d = f.p2;
        e = f.p3;
        this.i(c, d, e, b);
    };
    XmlWriteManager.prototype.i = function (a, b, c, d) {
        this.w.j(a, b, c, d);
    };
    XmlWriteManager.prototype.j = function (a, b) {
        this.w.h(a, b);
    };
    XmlWriteManager.prototype.k = function () {
        this.f();
        this.w.v();
    };
    XmlWriteManager.prototype.o = function (a) {
        this.p(a, null);
    };
    XmlWriteManager.prototype.p = function (a, b) {
        var c;
        var d;
        var e;
        var f = this.e(a, c, d, e);
        c = f.p1;
        d = f.p2;
        e = f.p3;
        this.q(c != null ? c : b, d, e);
    };
    XmlWriteManager.prototype.q = function (a, b, c) {
        this.f();
        this.w.ao(a, b, c);
    };
    XmlWriteManager.prototype.r = function (a) {
        this.w.am(a);
    };
    XmlWriteManager.prototype.l = function (a, b) {
        if (b === void 0) { b = false; }
        this.m(a.j, a.i(this.a._z), b);
    };
    XmlWriteManager.prototype.m = function (a, b, c) {
        if (c === void 0) { c = false; }
        var d = b;
        if (this.a._z != 1) {
            var e = this.a._u(b);
            if (e != null) {
                d = e.i(this.a._z);
            }
        }
        this.w.j("xmlns", a, "http://www.w3.org/2000/xmlns/", d);
        if (c) {
            this.c.add(a);
        }
    };
    XmlWriteManager.prototype.n = function (a) {
        this.f();
        this.w.ah(a);
    };
    XmlWriteManager.prototype.t = function (a) {
        this.f();
        var b = new Stack$1(UnknownElementCache.$);
        this.s(a.b, b);
    };
    XmlWriteManager.prototype.s = function (a, b) {
        var c = this.b.y(a, b);
        var t1 = c;
        L0: while (true) {
            switch (t1) {
                case 0:
                    {
                        var d = a.b.b(this.a);
                        this.q(d.h, d.f, d.g);
                        if (a.d) {
                            try {
                                for (var _0 = tslib_1.__values(fromEnum(a.j)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                                    var e = _1.value;
                                    var f = e.a.b(this.a);
                                    this.i(f.h, f.f, f.g, e.d);
                                }
                            }
                            catch (e_26_1) { e_26 = { error: e_26_1 }; }
                            finally {
                                try {
                                    if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
                                }
                                finally { if (e_26) throw e_26.error; }
                            }
                        }
                        if (a.p != null) {
                            this.u(a.p);
                        }
                    }
                    t1 = 1;
                    continue L0;
                case 1:
                    {
                        if (a.e) {
                            b.h(a);
                            try {
                                for (var _3 = tslib_1.__values(fromEnum(a.k)), _4 = _3.next(); !_4.done; _4 = _3.next()) {
                                    var g = _4.value;
                                    this.s(g, b);
                                }
                            }
                            catch (e_27_1) { e_27 = { error: e_27_1 }; }
                            finally {
                                try {
                                    if (_4 && !_4.done && (_5 = _3.return)) _5.call(_3);
                                }
                                finally { if (e_27) throw e_27.error; }
                            }
                            b.e();
                        }
                        this.k();
                    }
                    break;
                case 2: break;
                default:
                    t1 = 0;
                    continue L0;
            }
            break;
        }
        var e_26, _2, e_27, _5;
    };
    XmlWriteManager.prototype.u = function (a) {
        this.f();
        this.w.ap(a);
    };
    XmlWriteManager.prototype.v = function (a, b, c) {
        this.f();
        var d = new StringBuilder(2, "version=\"" + a + "\"");
        if (b.length > 0) {
            d.l(" encoding=\"");
            d.l(b);
            d.l("\"");
        }
        if (c.length > 0) {
            d.l(" standalone=\"");
            d.l(c);
            d.l("\"");
        }
        var e = d.toString();
        this.w.ad("xml", e);
    };
    XmlWriteManager.$t = markType(XmlWriteManager, 'XmlWriteManager');
    return XmlWriteManager;
}(Base));
export { XmlWriteManager };
var PartManagerBase = /** @class */ (function (_super) {
    tslib_1.__extends(PartManagerBase, _super);
    function PartManagerBase() {
        var _this = _super.call(this) || this;
        _this.c = null;
        _this.k = null;
        return _this;
    }
    PartManagerBase.prototype.e = function (a, b) {
        var c = this.memberwiseClone();
        c.k = b;
        c.c = a;
        c.p();
        return c;
    };
    PartManagerBase.prototype.j = function () {
        return null;
    };
    PartManagerBase.prototype.f = function (a, b) {
        return null;
    };
    PartManagerBase.prototype.p = function () {
    };
    PartManagerBase.prototype.q = function () {
    };
    PartManagerBase.prototype.i = function (a) {
        return false;
    };
    Object.defineProperty(PartManagerBase.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: true,
        configurable: true
    });
    PartManagerBase.prototype.get_h = function () {
        return true;
    };
    Object.defineProperty(PartManagerBase.prototype, "h", {
        get: function () {
            return this.get_h();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PartManagerBase.prototype, "l", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
        },
        enumerable: true,
        configurable: true
    });
    PartManagerBase.$t = markType(PartManagerBase, 'PartManagerBase');
    return PartManagerBase;
}(Base));
export { PartManagerBase };
var ActiveXBinaryPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(ActiveXBinaryPartManager, _super);
    function ActiveXBinaryPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ActiveXBinaryPartManager.prototype.get_m = function () {
        return "application/vnd.ms-office.activeX";
    };
    Object.defineProperty(ActiveXBinaryPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    ActiveXBinaryPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/activeX.bin";
            default: return null;
        }
    };
    ActiveXBinaryPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return ActiveXBinaryPartManager.u;
            case 1: return ActiveXBinaryPartManager.t;
            default: return ActiveXBinaryPartManager.u;
        }
    };
    ActiveXBinaryPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(ActiveXBinaryPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ActiveXBinaryPartManager.$t = markType(ActiveXBinaryPartManager, 'ActiveXBinaryPartManager', PartManagerBase.$);
    ActiveXBinaryPartManager.u = "http://schemas.microsoft.com/office/2006/relationships/activeXControlBinary";
    ActiveXBinaryPartManager.t = "http://schemas.microsoft.com/office/2006/relationships/activeXControlBinary";
    return ActiveXBinaryPartManager;
}(PartManagerBase));
export { ActiveXBinaryPartManager };
var ActiveXPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(ActiveXPartManager, _super);
    function ActiveXPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ActiveXPartManager.prototype.get_m = function () {
        return "application/vnd.ms-office.activeX+xml";
    };
    Object.defineProperty(ActiveXPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    ActiveXPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/activeX.xml";
            default: return null;
        }
    };
    ActiveXPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return ActiveXPartManager.u;
            case 1: return ActiveXPartManager.t;
            default: return ActiveXPartManager.u;
        }
    };
    ActiveXPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(ActiveXPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ActiveXPartManager.$t = markType(ActiveXPartManager, 'ActiveXPartManager', PartManagerBase.$);
    ActiveXPartManager.u = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/control";
    ActiveXPartManager.t = "http://purl.oclc.org/ooxml/officeDocument/relationships/control";
    return ActiveXPartManager;
}(PartManagerBase));
export { ActiveXPartManager };
var ImagePartManagerBase = /** @class */ (function (_super) {
    tslib_1.__extends(ImagePartManagerBase, _super);
    function ImagePartManagerBase() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImagePartManagerBase.prototype.n = function (a) {
        switch (a) {
            case 0: return this.s;
            case 1: return this.u;
            case 2: return this.t;
            default: return null;
        }
    };
    ImagePartManagerBase.prototype.o = function (a) {
        return ImagePartManagerBase.v(a);
    };
    ImagePartManagerBase.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(ImagePartManagerBase.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ImagePartManagerBase.prototype.a = function () {
        return WorkItem.g(Base.$, new ImageData(1, this.r(this.d._d.uri.toString()), this.l));
    };
    ImagePartManagerBase.prototype.get_h = function () {
        return false;
    };
    ImagePartManagerBase.prototype.b = function (a) {
        var b = typeCast(ImageData.$, a);
        if (b != null) {
            b.f(this.l);
        }
        return null;
    };
    ImagePartManagerBase.v = function (a) {
        switch (a) {
            case 0: return ImagePartManagerBase.x;
            case 1: return ImagePartManagerBase.w;
            default: return ImagePartManagerBase.x;
        }
    };
    ImagePartManagerBase.$t = markType(ImagePartManagerBase, 'ImagePartManagerBase', PartManagerBase.$);
    ImagePartManagerBase.x = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/image";
    ImagePartManagerBase.w = "http://purl.oclc.org/ooxml/officeDocument/relationships/image";
    return ImagePartManagerBase;
}(PartManagerBase));
export { ImagePartManagerBase };
var BmpPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(BmpPartManager, _super);
    function BmpPartManager(a) {
        var _this = _super.call(this) || this;
        _this.aa = false;
        _this.aa = a;
        return _this;
    }
    BmpPartManager.prototype.get_s = function () {
        return this.aa ? "/xl/media/image.dib" : "/xl/media/image.bmp";
    };
    Object.defineProperty(BmpPartManager.prototype, "s", {
        get: function () {
            return this.get_s();
        },
        enumerable: true,
        configurable: true
    });
    BmpPartManager.prototype.get_t = function () {
        return this.aa ? "/ppt/media/image.dib" : "/ppt/media/image.bmp";
    };
    Object.defineProperty(BmpPartManager.prototype, "t", {
        get: function () {
            return this.get_t();
        },
        enumerable: true,
        configurable: true
    });
    BmpPartManager.prototype.get_u = function () {
        return this.aa ? "/word/media/image.dib" : "/word/media/image.bmp";
    };
    Object.defineProperty(BmpPartManager.prototype, "u", {
        get: function () {
            return this.get_u();
        },
        enumerable: true,
        configurable: true
    });
    BmpPartManager.prototype.get_m = function () {
        return "image/bmp";
    };
    Object.defineProperty(BmpPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    BmpPartManager.prototype.r = function (a) {
        var b = IOPath.getExtension(a);
        if (b.toLowerCase() == ".dib") {
            return ImageFormat.b;
        }
        return ImageFormat.a;
    };
    BmpPartManager.$t = markType(BmpPartManager, 'BmpPartManager', ImagePartManagerBase.$);
    BmpPartManager.y = new BmpPartManager(false);
    BmpPartManager.z = new BmpPartManager(true);
    return BmpPartManager;
}(ImagePartManagerBase));
export { BmpPartManager };
var XmlPartManagerBase = /** @class */ (function (_super) {
    tslib_1.__extends(XmlPartManagerBase, _super);
    function XmlPartManagerBase() {
        var _this = _super.call(this) || this;
        _this.r = null;
        _this.am = null;
        _this.al = 0;
        _this.aa = null;
        _this.ac = null;
        _this.v = new ElementLoadCallbacks(0);
        _this.an = null;
        _this.ae = false;
        _this.am = {};
        return _this;
    }
    XmlPartManagerBase.prototype.p = function () {
        _super.prototype.p.call(this);
        var a = this.am;
        this.am = {};
        for (var p in a) {
            if (a.hasOwnProperty(p)) {
                this.am[p] = a[p];
            }
        }
        ;
    };
    XmlPartManagerBase.prototype.a = function () {
        var _this = this;
        return Async.i(Base.$, function () {
            _this.r = new ContextStack();
            return _this.t();
        }, function () {
            _this.r = null;
            _this.aa = null;
        });
    };
    XmlPartManagerBase.prototype.b = function (a) {
        var _this = this;
        this.r = new ContextStack();
        if (a != null) {
            this.r.k(a);
        }
        return Async.n(XmlWriter.$, this.a1(), function (b) {
            _this.ac = new XmlWriteManager(_this, b);
            if (_this.aj) {
                _this.ac.v("1.0", "UTF-8", "yes");
            }
            return _this.u(a);
        });
    };
    XmlPartManagerBase.prototype.as = function () {
        this.al++;
    };
    XmlPartManagerBase.prototype.at = function () {
        this.al--;
        if (this.al == 0) {
            this.ae = false;
        }
    };
    XmlPartManagerBase.prototype.ar = function (a) {
    };
    XmlPartManagerBase.prototype.w = function (a) {
        return this.x(a.e(this.d));
    };
    XmlPartManagerBase.prototype.x = function (a) {
        return (this.am[a] || this.v);
    };
    XmlPartManagerBase.prototype.z = function (a) {
        this.d._bj();
        return 0;
    };
    XmlPartManagerBase.prototype.au = function (a) {
    };
    XmlPartManagerBase.prototype.av = function (a) {
    };
    XmlPartManagerBase.prototype.aw = function (a, b) {
    };
    XmlPartManagerBase.prototype.ax = function (a, b, c) {
        if (c === void 0) { c = true; }
        switch (a) {
            case MarkupCompatibility2006.ap:
            case MarkupCompatibility2006.aq:
            case MarkupCompatibility2006.ar: return;
        }
        var d = (this.am[a]);
        var e = (d != null);
        var f = e ? new ElementLoadCallbacks(1, d.b, b) : new ElementLoadCallbacks(1, null, b);
        this.am[a] = f;
    };
    XmlPartManagerBase.ag = function (a, b) {
        if (a == null || b == null) {
            return false;
        }
        return a == b;
    };
    XmlPartManagerBase.prototype.ay = function (a, b, c) {
        if (c === void 0) { c = true; }
        switch (a) {
            case MarkupCompatibility2006.ap:
            case MarkupCompatibility2006.aq:
            case MarkupCompatibility2006.ar: return;
        }
        var d = (this.am[a]);
        var e = (d != null);
        var f = e ? new ElementLoadCallbacks(1, b, d.a) : new ElementLoadCallbacks(1, b, null);
        this.am[a] = f;
    };
    XmlPartManagerBase.prototype.ah = function (a) {
        if (stringIsNullOrEmpty(a)) {
            return true;
        }
        var b = a.split(' ');
        for (var d = 0; d < b.length; d++) {
            var c = b[d];
            var e = this.aa.ae(c);
            if (stringIsNullOrEmpty(e)) {
                continue;
            }
            if (this.d._ad(e) == false) {
                return false;
            }
        }
        return true;
    };
    XmlPartManagerBase.prototype.ai = function (a) {
        return this.s.c == false;
    };
    XmlPartManagerBase.prototype.y = function (a, b) {
        return 0;
    };
    XmlPartManagerBase.prototype.az = function (a) {
        var b = this.aa.k.e(this.d);
    };
    XmlPartManagerBase.prototype.a0 = function () {
        return new XmlTextReader(1, this.l);
    };
    XmlPartManagerBase.prototype.a1 = function () {
        return new XmlTextWriter(0, this.l, Encoding.uTF8);
    };
    XmlPartManagerBase.prototype.t = function () {
        var _this = this;
        return WorkItemExtensions.g(Base.$, Async.n(XmlReader.$, this.a0(), function (a) {
            return Async.g(a.t(), function () {
                _this.aa = new XmlReadManager(_this, a);
                return _this.aa.d();
            });
        }), function () { return _this.an; });
    };
    Object.defineProperty(XmlPartManagerBase.prototype, "s", {
        get: function () {
            return this.r;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(XmlPartManagerBase.prototype, "af", {
        get: function () {
            return this.al != 0;
        },
        enumerable: true,
        configurable: true
    });
    XmlPartManagerBase.prototype.get_aj = function () {
        return true;
    };
    Object.defineProperty(XmlPartManagerBase.prototype, "aj", {
        get: function () {
            return this.get_aj();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(XmlPartManagerBase.prototype, "ab", {
        get: function () {
            return this.aa;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(XmlPartManagerBase.prototype, "ad", {
        get: function () {
            return this.ac;
        },
        enumerable: true,
        configurable: true
    });
    XmlPartManagerBase.$t = markType(XmlPartManagerBase, 'XmlPartManagerBase', PartManagerBase.$);
    return XmlPartManagerBase;
}(PartManagerBase));
export { XmlPartManagerBase };
var CorePropertiesPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(CorePropertiesPartManager, _super);
    function CorePropertiesPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CorePropertiesPartManager.prototype.get_m = function () {
        return CorePropertiesPartManager.a2;
    };
    Object.defineProperty(CorePropertiesPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    CorePropertiesPartManager.prototype.n = function (a) {
        return "/docProps/core.xml";
    };
    CorePropertiesPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return CorePropertiesPartManager.a5;
            case 1: return CorePropertiesPartManager.a4;
            default: return CorePropertiesPartManager.a5;
        }
    };
    CorePropertiesPartManager.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(CorePropertiesPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    CorePropertiesPartManager.$t = markType(CorePropertiesPartManager, 'CorePropertiesPartManager', XmlPartManagerBase.$);
    CorePropertiesPartManager.a2 = "application/vnd.openxmlformats-package.core-properties+xml";
    CorePropertiesPartManager.a5 = "http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties";
    CorePropertiesPartManager.a4 = "http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties";
    return CorePropertiesPartManager;
}(XmlPartManagerBase));
export { CorePropertiesPartManager };
var CustomXmlItemPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(CustomXmlItemPartManager, _super);
    function CustomXmlItemPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomXmlItemPartManager.prototype.get_m = function () {
        return "application/xml";
    };
    Object.defineProperty(CustomXmlItemPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    CustomXmlItemPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/customXml/item.xml";
            default: return null;
        }
    };
    CustomXmlItemPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return CustomXmlItemPartManager.u;
            case 1: return CustomXmlItemPartManager.t;
            default: return CustomXmlItemPartManager.u;
        }
    };
    CustomXmlItemPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(CustomXmlItemPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    CustomXmlItemPartManager.$t = markType(CustomXmlItemPartManager, 'CustomXmlItemPartManager', PartManagerBase.$);
    CustomXmlItemPartManager.u = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/customXml";
    CustomXmlItemPartManager.t = "http://purl.oclc.org/ooxml/officeDocument/relationships/customXml";
    return CustomXmlItemPartManager;
}(PartManagerBase));
export { CustomXmlItemPartManager };
var CustomXmlItemPropsPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(CustomXmlItemPropsPartManager, _super);
    function CustomXmlItemPropsPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomXmlItemPropsPartManager.prototype.get_m = function () {
        return CustomXmlItemPropsPartManager.s;
    };
    Object.defineProperty(CustomXmlItemPropsPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    CustomXmlItemPropsPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/customXml/itemProps.xml";
            default: return null;
        }
    };
    CustomXmlItemPropsPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return CustomXmlItemPropsPartManager.u;
            case 1: return CustomXmlItemPropsPartManager.t;
            default: return CustomXmlItemPropsPartManager.u;
        }
    };
    CustomXmlItemPropsPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(CustomXmlItemPropsPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    CustomXmlItemPropsPartManager.$t = markType(CustomXmlItemPropsPartManager, 'CustomXmlItemPropsPartManager', PartManagerBase.$);
    CustomXmlItemPropsPartManager.s = "application/vnd.openxmlformats-officedocument.customXmlProperties+xml";
    CustomXmlItemPropsPartManager.u = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/customXmlProps";
    CustomXmlItemPropsPartManager.t = "http://purl.oclc.org/ooxml/officeDocument/relationships/customXmlProps";
    return CustomXmlItemPropsPartManager;
}(PartManagerBase));
export { CustomXmlItemPropsPartManager };
var DownRevPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(DownRevPartManager, _super);
    function DownRevPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DownRevPartManager.prototype.get_m = function () {
        return DownRevPartManager.a2;
    };
    Object.defineProperty(DownRevPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    DownRevPartManager.prototype.n = function (a) {
        return "/drs/downrev.xml";
    };
    DownRevPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return DownRevPartManager.a4;
            case 1: return DownRevPartManager.a4;
            default: return DownRevPartManager.a4;
        }
    };
    DownRevPartManager.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(DownRevPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    DownRevPartManager.$t = markType(DownRevPartManager, 'DownRevPartManager', XmlPartManagerBase.$);
    DownRevPartManager.a2 = "application/vnd.ms-office.DrsDownRev+xml";
    DownRevPartManager.a4 = "http://schemas.microsoft.com/office/2006/relationships/downRev";
    return DownRevPartManager;
}(XmlPartManagerBase));
export { DownRevPartManager };
var DrawingPartManagerHelpers = /** @class */ (function (_super) {
    tslib_1.__extends(DrawingPartManagerHelpers, _super);
    function DrawingPartManagerHelpers() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DrawingPartManagerHelpers.a = function (a, b) {
        var c = a.s.a(CT_Color.$);
        if (c != null) {
            c.a = b;
            return;
        }
        var d = a.s.a(CT_SolidFillProperties.$);
        if (d != null) {
            d.a = b;
            return;
        }
        var e = a.s.a(CT_StyleMatrixReference.$);
        if (e != null) {
            e.a = b;
            return;
        }
        var f = a.s.a(CT_FontReference.$);
        if (f != null) {
            f.a = b;
            return;
        }
    };
    DrawingPartManagerHelpers.b = function ($t, a, b) {
        var c = typeCast(CT_LineProperties.$, a.s.f);
        if (c != null) {
            c.i = b;
            return;
        }
        var d = typeCast(CT_ShapePropertiesBase.$, a.s.f);
        if (d != null) {
            d.a = b;
            return;
        }
        var e = typeCast(CT_TextCharacterProperties.$, a.s.f);
        if (e != null) {
            e.y = b;
            return;
        }
    };
    DrawingPartManagerHelpers.c = function ($t, a, b) {
        var c = typeCast(CT_ShapePropertiesBase.$, a.s.f);
        if (c != null) {
            c.a = b;
            return;
        }
    };
    DrawingPartManagerHelpers.g = function (a) {
        var b = a.s.a(CT_PresetGeometry2D.$);
        if (b == null) {
            return;
        }
        var c = new CT_GeomGuideList();
        b.a = c;
        a.s.k(c);
    };
    DrawingPartManagerHelpers.d = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_PositiveFixedPercentage();
        var d = DrawingMLMain.kg(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_Alpha();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.e = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_PositivePercentage();
        var d = DrawingMLMain.kh(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_AlphaMod();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.f = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_FixedPercentage();
        var d = DrawingMLMain.ki(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_AlphaOff();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.h = function (a) {
        var b = a.s.a(CT_BlipFillProperties.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f = DrawingMLMain.kk(a, c, d, e);
        c = f.p1;
        d = f.p2;
        e = f.p3;
        var g = ((function () {
            var $ret = new CT_Blip();
            $ret.b = c;
            $ret.c = d;
            $ret.a = Nullable$1.toNullable(ST_BlipCompression_$type, e.value);
            return $ret;
        })());
        b.d = g;
        a.s.k(g);
    };
    DrawingPartManagerHelpers.i = function (a) {
        var b = a.s.a(CT_Picture.$);
        if (b != null) {
            var c_3;
            var d_3;
            var e = a.d._t.b4(a, c_3, d_3);
            c_3 = e.p1;
            d_3 = e.p2;
            var f = ((function () {
                var $ret = new CT_BlipFillProperties();
                $ret.b = c_3;
                $ret.c = d_3;
                return $ret;
            })());
            b.a = f;
            a.s.k(f);
            return;
        }
        else {
            var g_1;
            var h_1;
            var i = DrawingMLMain.kl(a, g_1, h_1);
            g_1 = i.p1;
            h_1 = i.p2;
            var j = ((function () {
                var $ret = new CT_BlipFillProperties();
                $ret.b = g_1;
                $ret.c = h_1;
                return $ret;
            })());
            DrawingPartManagerHelpers.c(CT_BlipFillProperties.$, a, j);
            a.s.k(j);
        }
    };
    DrawingPartManagerHelpers.j = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.km(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_Blue();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.k = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.kn(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_BlueMod();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.l = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.ko(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_BlueOff();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.m = function (a) {
        var b = a.s.a(CT_TextBody.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f;
        var g;
        var h;
        var i;
        var j;
        var k;
        var l;
        var m;
        var n;
        var o;
        var p;
        var q;
        var r;
        var s;
        var t;
        var u;
        var v = DrawingMLMain.kp(a, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u);
        c = v.p1;
        d = v.p2;
        e = v.p3;
        f = v.p4;
        g = v.p5;
        h = v.p6;
        i = v.p7;
        j = v.p8;
        k = v.p9;
        l = v.p10;
        m = v.p11;
        n = v.p12;
        o = v.p13;
        p = v.p14;
        q = v.p15;
        r = v.p16;
        s = v.p17;
        t = v.p18;
        u = v.p19;
        b.a = ((function () {
            var $ret = new CT_TextBodyProperties();
            $ret.n = c;
            $ret.l = d;
            $ret.q = e;
            $ret.p = f;
            $ret.t = g;
            $ret.r = h;
            $ret.j = i;
            $ret.s = j;
            $ret.m = k;
            $ret.f = l;
            $ret.k = m;
            $ret.o = n;
            $ret.a = o;
            $ret.i = p;
            $ret.d = q;
            $ret.e = r;
            $ret.h = s;
            $ret.c = t;
            $ret.g = u;
            return $ret;
        })());
        a.s.k(b.a);
    };
    DrawingPartManagerHelpers.n = function (a) {
        var b = a.s.a(CT_GraphicalObjectData.$);
        if (b == null) {
            return;
        }
        var c;
        var d = DrawingMLChart.gx(a, c);
        c = d.p1;
        b.b.add(Tuple.a(String_$type, Base.$, DrawingMLChart.be, ((function () {
            var $ret = new CT_RelId();
            $ret.a = c;
            return $ret;
        })())));
    };
    DrawingPartManagerHelpers.o = function (a) {
        var b = a.s.a(CT_GroupTransform2D.$);
        if (b == null) {
            return;
        }
        var c = new ST_PositiveCoordinate();
        var d = new ST_PositiveCoordinate();
        var e = DrawingMLMain.kq(a, c, d);
        c = e.p1;
        d = e.p2;
        var f = ((function () {
            var $ret = new CT_PositiveSize2D();
            $ret.a = c;
            $ret.b = d;
            return $ret;
        })());
        b.m = f;
        a.s.k(f);
    };
    DrawingPartManagerHelpers.p = function (a) {
        var b = a.s.a(CT_GroupTransform2D.$);
        if (b == null) {
            return;
        }
        var c = new ST_Coordinate();
        var d = new ST_Coordinate();
        var e = DrawingMLMain.kr(a, c, d);
        c = e.p1;
        d = e.p2;
        var f = ((function () {
            var $ret = new CT_Point2D();
            $ret.a = c;
            $ret.b = d;
            return $ret;
        })());
        b.l = f;
        a.s.k(f);
    };
    DrawingPartManagerHelpers.q = function (a) {
        var b = a.s.a(CT_ConnectorNonVisual.$);
        if (b == null) {
            return;
        }
        var c = new CT_NonVisualConnectorProperties();
        b.b = c;
        a.s.k(c);
    };
    DrawingPartManagerHelpers.r = function (a) {
        var b = a.s.a(CT_GraphicalObjectFrameNonVisual.$);
        if (b == null) {
            return;
        }
        var c = new CT_NonVisualGraphicFrameProperties();
        b.b = c;
        a.s.k(c);
    };
    DrawingPartManagerHelpers.s = function (a) {
        var b = a.s.a(CT_GroupShapeNonVisual.$);
        if (b == null) {
            return;
        }
        var c = new CT_NonVisualGroupDrawingShapeProps();
        b.b = c;
        a.s.k(c);
    };
    DrawingPartManagerHelpers.t = function (a) {
        var b = a.s.a(CT_PictureNonVisual.$);
        if (b == null) {
            return;
        }
        var c;
        var d = a.d._t.b8(a, c);
        c = d.p1;
        var e = ((function () {
            var $ret = new CT_NonVisualPictureProperties();
            $ret.b = c;
            return $ret;
        })());
        b.b = e;
        a.s.k(e);
    };
    DrawingPartManagerHelpers.u = function (a) {
        var b = a.s.a(CT_NonVisualBase.$);
        if (b == null) {
            return;
        }
        var c = new ST_DrawingElementId();
        var d;
        var e;
        var f;
        var g;
        var h = a.d._t.b9(a, c, d, e, f, g);
        c = h.p1;
        d = h.p2;
        e = h.p3;
        f = h.p4;
        g = h.p5;
        var i = ((function () {
            var $ret = new CT_NonVisualDrawingProps();
            $ret.c = c;
            $ret.f = d;
            $ret.e = e;
            $ret.d = f;
            $ret.g = g;
            return $ret;
        })());
        b.a = i;
        a.s.k(i);
    };
    DrawingPartManagerHelpers.v = function (a) {
        var b = a.s.a(CT_ShapeNonVisual.$);
        if (b == null) {
            return;
        }
        var c;
        var d = a.d._t.ca(a, c);
        c = d.p1;
        var e = ((function () {
            var $ret = new CT_NonVisualDrawingShapeProps();
            $ret.b = c;
            return $ret;
        })());
        b.b = e;
        a.s.k(e);
    };
    DrawingPartManagerHelpers.y = function (a) {
        var b = a.s.a(IShapesOwner_$type);
        var c;
        var d;
        var e = a.d._t.cc(a, c, d);
        c = e.p1;
        d = e.p2;
        var f = ((function () {
            var $ret = new CT_Connector();
            $ret.c = c;
            $ret.b = d;
            return $ret;
        })());
        if (b != null) {
            b.addShape(a.d, f);
        }
        a.s.k(f);
    };
    DrawingPartManagerHelpers.w = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        b.b.add(new ColorTransform_Comp());
    };
    DrawingPartManagerHelpers.x = function (a) {
        var b = a.s.a(CT_TextCharacterProperties.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f;
        var g = DrawingMLMain.ku(a, c, d, e, f);
        c = g.p1;
        d = g.p2;
        e = g.p3;
        f = g.p4;
        var h = ((function () {
            var $ret = new CT_TextFont();
            $ret.d = c;
            $ret.a = d;
            $ret.c = e;
            $ret.b = f;
            return $ret;
        })());
        b.a = h;
        a.s.k(h);
    };
    DrawingPartManagerHelpers.z = function (a) {
        var b = a.s.a(CT_NonVisualConnectorProperties.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f;
        var g;
        var h;
        var i;
        var j;
        var k;
        var l;
        var m = a.d._t.cd(a, c, d, e, f, g, h, i, j, k, l);
        c = m.p1;
        d = m.p2;
        e = m.p3;
        f = m.p4;
        g = m.p5;
        h = m.p6;
        i = m.p7;
        j = m.p8;
        k = m.p9;
        l = m.p10;
        var n = ((function () {
            var $ret = new CT_ConnectorLocking();
            $ret.f = c;
            $ret.j = d;
            $ret.i = e;
            $ret.c = f;
            $ret.g = g;
            $ret.h = h;
            $ret.e = i;
            $ret.a = j;
            $ret.b = k;
            $ret.d = l;
            return $ret;
        })());
        b.c = n;
        a.s.k(n);
    };
    DrawingPartManagerHelpers.aa = function (a) {
        var b = a.s.a(CT_TextCharacterProperties.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f;
        var g = DrawingMLMain.ld(a, c, d, e, f);
        c = g.p1;
        d = g.p2;
        e = g.p3;
        f = g.p4;
        var h = ((function () {
            var $ret = new CT_TextFont();
            $ret.d = c;
            $ret.a = d;
            $ret.c = e;
            $ret.b = Nullable$1.toNullable(Number_$type, f);
            return $ret;
        })());
        b.b = h;
        a.s.k(h);
    };
    DrawingPartManagerHelpers.ab = function (a) {
        var b = a.s.a(CT_ShapeStyle.$);
        if (b == null) {
            return;
        }
        var c;
        var d = DrawingMLMain.le(a, c);
        c = d.p1;
        var e = ((function () {
            var $ret = new CT_StyleMatrixReference();
            $ret.b = c;
            return $ret;
        })());
        b.b = e;
        a.s.k(e);
    };
    DrawingPartManagerHelpers.ac = function (a) {
        var b = a.s.a(CT_NonVisualConnectorProperties.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e = a.d._t.ce(a, c, d);
        c = e.p1;
        d = e.p2;
        var f = ((function () {
            var $ret = new CT_Connection();
            $ret.a = c;
            $ret.b = d;
            return $ret;
        })());
        b.a = f;
        a.s.k(f);
    };
    DrawingPartManagerHelpers.ad = function (a) {
        var b = a.s.a(CT_Transform2D.$);
        if (b == null) {
            return;
        }
        var c = new ST_PositiveCoordinate();
        var d = new ST_PositiveCoordinate();
        var e = DrawingMLMain.lf(a, c, d);
        c = e.p1;
        d = e.p2;
        var f = ((function () {
            var $ret = new CT_PositiveSize2D();
            $ret.a = c;
            $ret.b = d;
            return $ret;
        })());
        b.b = f;
        a.s.k(f);
    };
    DrawingPartManagerHelpers.ae = function (a) {
        a.s.k(IgnoreChildrenMarker.a);
    };
    DrawingPartManagerHelpers.af = function (a) {
        var b = a.s.a(CT_StretchInfoProperties.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = new ST_Percentage();
        var e = new ST_Percentage();
        var f = new ST_Percentage();
        var g = DrawingMLMain.lj(a, c, d, e, f);
        c = g.p1;
        d = g.p2;
        e = g.p3;
        f = g.p4;
        var h = ((function () {
            var $ret = new CT_RelativeRect();
            $ret.b = c;
            $ret.d = d;
            $ret.c = e;
            $ret.a = f;
            return $ret;
        })());
        b.a = h;
        a.s.k(h);
    };
    DrawingPartManagerHelpers.ag = function (a) {
        var b = a.s.a(CT_ShapeStyle.$);
        if (b == null) {
            return;
        }
        var c;
        var d = DrawingMLMain.lk(a, c);
        c = d.p1;
        var e = ((function () {
            var $ret = new CT_StyleMatrixReference();
            $ret.b = c;
            return $ret;
        })());
        b.c = e;
        a.s.k(e);
    };
    DrawingPartManagerHelpers.ah = function (a) {
        var b = a.s.a(CT_ShapeStyle.$);
        if (b == null) {
            return;
        }
        var c;
        var d = DrawingMLMain.ln(a, c);
        c = d.p1;
        var e = ((function () {
            var $ret = new CT_FontReference();
            $ret.b = c;
            return $ret;
        })());
        b.a = e;
        a.s.k(e);
    };
    DrawingPartManagerHelpers.ai = function (a) {
        var b = a.s.a(CT_GeomGuideList.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e = DrawingMLMain.lp(a, c, d);
        c = e.p1;
        d = e.p2;
        var f = ((function () {
            var $ret = new CT_GeomGuide();
            $ret.b = c;
            $ret.a = d;
            return $ret;
        })());
        b.b.add(f);
        a.s.k(f);
    };
    DrawingPartManagerHelpers.ak = function (a) {
        var b = a.s.a(CT_GraphicalObjectFrame.$);
        var c = new CT_GraphicalObject();
        if (b != null) {
            b.a = c;
        }
        a.s.k(c);
    };
    DrawingPartManagerHelpers.aj = function (a) {
        var b = a.s.a(CT_GraphicalObject.$);
        if (b == null) {
            return;
        }
        var c;
        var d = DrawingMLMain.lq(a, c);
        c = d.p1;
        var e = ((function () {
            var $ret = new CT_GraphicalObjectData();
            $ret.c = c;
            return $ret;
        })());
        b.a = e;
        a.s.k(e);
    };
    DrawingPartManagerHelpers.al = function (a) {
        var b = a.s.a(IShapesOwner_$type);
        var c;
        var d;
        var e = a.d._t.cf(a, c, d);
        c = e.p1;
        d = e.p2;
        var f = ((function () {
            var $ret = new CT_GraphicalObjectFrame();
            $ret.e = c;
            $ret.d = d;
            return $ret;
        })());
        if (b != null) {
            b.addShape(a.d, f);
        }
        a.s.k(f);
    };
    DrawingPartManagerHelpers.am = function (a) {
        var b = Enumerable.ag(AttributeValue.$, a.ab.u, function (c) { return c.a.e(a.d) == IGOfficeExtensions.ap; });
        if (b.d == null || ST_OnOff.e(b.d) == false) {
            a.d._bj();
        }
    };
    DrawingPartManagerHelpers.an = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        b.b.add(new ColorTransform_Gray());
    };
    DrawingPartManagerHelpers.ao = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.lu(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_Green();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.ap = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.lv(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_GreenMod();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.aq = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.lw(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_GreenOff();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.ar = function (a) {
        var b = new CT_GroupFillProperties();
        DrawingPartManagerHelpers.c(CT_GroupFillProperties.$, a, b);
        a.s.k(b);
    };
    DrawingPartManagerHelpers.as = function (a) {
        var b = a.s.a(IShapesOwner_$type);
        var c = new CT_GroupShape();
        if (b != null) {
            b.addShape(a.d, c);
        }
        a.s.k(c);
    };
    DrawingPartManagerHelpers.at = function (a) {
        var b = a.s.a(CT_NonVisualGroupDrawingShapeProps.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f;
        var g;
        var h;
        var i;
        var j = a.d._t.ch(a, c, d, e, f, g, h, i);
        c = j.p1;
        d = j.p2;
        e = j.p3;
        f = j.p4;
        g = j.p5;
        h = j.p6;
        i = j.p7;
        var k = ((function () {
            var $ret = new CT_GroupLocking();
            $ret.b = c;
            $ret.g = d;
            $ret.f = e;
            $ret.e = f;
            $ret.a = g;
            $ret.c = h;
            $ret.d = i;
            return $ret;
        })());
        b.a = k;
        a.s.k(k);
    };
    DrawingPartManagerHelpers.au = function (a) {
        var b = a.s.a(CT_GroupShape.$);
        if (b == null) {
            return;
        }
        var c;
        var d = a.d._t.ci(a, c);
        c = d.p1;
        var e = ((function () {
            var $ret = new CT_GroupShapeProperties();
            $ret.b = c;
            return $ret;
        })());
        b.b = e;
        a.s.k(e);
    };
    DrawingPartManagerHelpers.av = function (a) {
        var b = a.s.a(CT_LineProperties.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f = DrawingMLMain.ly(a, c, d, e);
        c = f.p1;
        d = f.p2;
        e = f.p3;
        var g = ((function () {
            var $ret = new CT_LineEndProperties();
            $ret.b = c;
            $ret.c = d;
            $ret.a = e;
            return $ret;
        })());
        b.a = g;
        a.s.k(g);
    };
    DrawingPartManagerHelpers.aw = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_PositiveFixedAngle();
        var d = DrawingMLMain.l1(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_Hue();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.ax = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_PositivePercentage();
        var d = DrawingMLMain.l2(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_HueMod();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.ay = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Angle();
        var d = DrawingMLMain.l3(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_HueOff();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.az = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        b.b.add(new ColorTransform_Inv());
    };
    DrawingPartManagerHelpers.a0 = function (a) {
        var b = a.s.a(CT_TextCharacterProperties.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f;
        var g = DrawingMLMain.l5(a, c, d, e, f);
        c = g.p1;
        d = g.p2;
        e = g.p3;
        f = g.p4;
        var h = ((function () {
            var $ret = new CT_TextFont();
            $ret.d = c;
            $ret.a = d;
            $ret.c = e;
            $ret.b = Nullable$1.toNullable(Number_$type, f);
            return $ret;
        })());
        b.c = h;
        a.s.k(h);
    };
    DrawingPartManagerHelpers.a1 = function (a) {
        var b = a.s.a(CT_ShapeProperties.$);
        var c = b == null ? a.s.a(CT_TextCharacterProperties.$) : null;
        if (b == null && c == null) {
            return;
        }
        var d;
        var e;
        var f;
        var g;
        var h = DrawingMLMain.l6(a, d, e, f, g);
        d = h.p1;
        e = h.p2;
        f = h.p3;
        g = h.p4;
        var i = ((function () {
            var $ret = new CT_LineProperties();
            $ret.h = d;
            $ret.f = e;
            $ret.g = f;
            $ret.e = g;
            return $ret;
        })());
        if (b != null) {
            b.c = i;
        }
        else {
            c.w = i;
        }
        a.s.k(i);
    };
    DrawingPartManagerHelpers.a2 = function (a) {
        var b = a.s.a(CT_ShapeStyle.$);
        if (b == null) {
            return;
        }
        var c;
        var d = DrawingMLMain.l7(a, c);
        c = d.p1;
        var e = ((function () {
            var $ret = new CT_StyleMatrixReference();
            $ret.b = c;
            return $ret;
        })());
        b.d = e;
        a.s.k(e);
    };
    DrawingPartManagerHelpers.a3 = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.mb(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_Lum();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.a4 = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.mc(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_LumMod();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.a5 = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.md(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_LumOff();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.a6 = function (a) {
        var b = new CT_NoFillProperties();
        DrawingPartManagerHelpers.b(CT_NoFillProperties.$, a, b);
        a.s.k(b);
    };
    DrawingPartManagerHelpers.a7 = function (a) {
        var b = a.s.a(CT_Connector.$);
        if (b == null) {
            return;
        }
        var c = new CT_ConnectorNonVisual();
        b.a = c;
        a.s.k(c);
    };
    DrawingPartManagerHelpers.a8 = function (a) {
        var b = a.s.a(CT_GraphicalObjectFrame.$);
        if (b == null) {
            return;
        }
        var c = new CT_GraphicalObjectFrameNonVisual();
        b.b = c;
        a.s.k(c);
    };
    DrawingPartManagerHelpers.a9 = function (a) {
        var b = a.s.a(CT_GroupShape.$);
        if (b == null) {
            return;
        }
        var c = new CT_GroupShapeNonVisual();
        b.a = c;
        a.s.k(c);
    };
    DrawingPartManagerHelpers.ba = function (a) {
        var b = a.s.a(CT_Picture.$);
        if (b == null) {
            return;
        }
        var c = new CT_PictureNonVisual();
        b.b = c;
        a.s.k(c);
    };
    DrawingPartManagerHelpers.bb = function (a) {
        var b = a.s.a(CT_Shape.$);
        if (b == null) {
            return;
        }
        var c = new CT_ShapeNonVisual();
        b.a = c;
        a.s.k(c);
    };
    DrawingPartManagerHelpers.bc = function (a) {
        var b = a.s.a(CT_Transform2D.$);
        if (b == null) {
            return;
        }
        var c = new ST_Coordinate();
        var d = new ST_Coordinate();
        var e = DrawingMLMain.mi(a, c, d);
        c = e.p1;
        d = e.p2;
        var f = ((function () {
            var $ret = new CT_Point2D();
            $ret.a = c;
            $ret.b = d;
            return $ret;
        })());
        b.a = f;
        a.s.k(f);
    };
    DrawingPartManagerHelpers.bd = function (a) {
        var b = a.s.a(CT_TextBody.$);
        if (b == null) {
            return;
        }
        var c = new CT_TextParagraph();
        b.d.add(c);
        a.s.k(c);
    };
    DrawingPartManagerHelpers.be = function (a) {
        var b = a.s.a(IShapesOwner_$type);
        var c;
        var d;
        var e = a.d._t.co(a, c, d);
        c = e.p1;
        d = e.p2;
        var f = ((function () {
            var $ret = new CT_Picture();
            $ret.d = c;
            $ret.c = d;
            return $ret;
        })());
        if (b != null) {
            b.addShape(a.d, f);
        }
        a.s.k(f);
    };
    DrawingPartManagerHelpers.bf = function (a) {
        var b = a.s.a(CT_NonVisualPictureProperties.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f;
        var g;
        var h;
        var i;
        var j;
        var k;
        var l;
        var m;
        var n = DrawingMLMain.mk(a, c, d, e, f, g, h, i, j, k, l, m);
        c = n.p1;
        d = n.p2;
        e = n.p3;
        f = n.p4;
        g = n.p5;
        h = n.p6;
        i = n.p7;
        j = n.p8;
        k = n.p9;
        l = n.p10;
        m = n.p11;
        var o = ((function () {
            var $ret = new CT_PictureLocking();
            $ret.g = c;
            $ret.k = d;
            $ret.j = e;
            $ret.c = f;
            $ret.h = g;
            $ret.i = h;
            $ret.f = i;
            $ret.a = j;
            $ret.b = k;
            $ret.d = l;
            $ret.e = m;
            return $ret;
        })());
        b.a = o;
        a.s.k(o);
    };
    DrawingPartManagerHelpers.bg = function (a) {
        var b = a.s.a(CT_TextParagraph.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f;
        var g;
        var h;
        var i;
        var j;
        var k;
        var l;
        var m;
        var n = DrawingMLMain.ml(a, c, d, e, f, g, h, i, j, k, l, m);
        c = n.p1;
        d = n.p2;
        e = n.p3;
        f = n.p4;
        g = n.p5;
        h = n.p6;
        i = n.p7;
        j = n.p8;
        k = n.p9;
        l = n.p10;
        m = n.p11;
        var o = ((function () {
            var $ret = new CT_TextParagraphProperties();
            $ret.i = c;
            $ret.j = d;
            $ret.h = e;
            $ret.f = f;
            $ret.a = g;
            $ret.b = h;
            $ret.k = i;
            $ret.c = j;
            $ret.d = k;
            $ret.g = l;
            $ret.e = m;
            return $ret;
        })());
        b.a = o;
        a.s.k(o);
    };
    DrawingPartManagerHelpers.bh = function (a) {
        var b;
        var c = DrawingMLMain.mm(a, b);
        b = c.p1;
        var d = ((function () {
            var $ret = new CT_PresetColor_Core();
            $ret.c = b;
            return $ret;
        })());
        a.s.k(d);
        DrawingPartManagerHelpers.a(a, d);
    };
    DrawingPartManagerHelpers.bi = function (a) {
        var b = a.s.a(CT_ShapeProperties.$);
        if (b == null) {
            return;
        }
        var c;
        var d = DrawingMLMain.mn(a, c);
        c = d.p1;
        var e = ((function () {
            var $ret = new CT_PresetGeometry2D();
            $ret.b = c;
            return $ret;
        })());
        b.e = e;
        a.s.k(e);
    };
    DrawingPartManagerHelpers.bj = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.mo(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_Red();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.bk = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.mp(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_RedMod();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.bl = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.mq(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_RedOff();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.bm = function (a) {
        var b = a.s.a(CT_TextParagraph.$);
        if (b == null) {
            return;
        }
        var c = new CT_RegularTextRun();
        b.c.add(c);
        a.s.k(c);
    };
    DrawingPartManagerHelpers.bn = function (a) {
        var b = a.s.a(CT_RegularTextRun.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f;
        var g;
        var h;
        var i;
        var j;
        var k;
        var l;
        var m;
        var n;
        var o;
        var p;
        var q;
        var r;
        var s;
        var t;
        var u;
        var v = DrawingMLMain.ms(a, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u);
        c = v.p1;
        d = v.p2;
        e = v.p3;
        f = v.p4;
        g = v.p5;
        h = v.p6;
        i = v.p7;
        j = v.p8;
        k = v.p9;
        l = v.p10;
        m = v.p11;
        n = v.p12;
        o = v.p13;
        p = v.p14;
        q = v.p15;
        r = v.p16;
        s = v.p17;
        t = v.p18;
        u = v.p19;
        var w = ((function () {
            var $ret = new CT_TextCharacterProperties();
            $ret.k = c;
            $ret.v = d;
            $ret.t = e;
            $ret.r = ST_TextFontSize.g(f);
            $ret.d = g;
            $ret.i = h;
            $ret.s = i;
            $ret.q = j;
            $ret.j = k;
            $ret.f = l;
            $ret.p = m;
            $ret.m = n;
            $ret.e = o;
            $ret.l = p;
            $ret.g = q;
            $ret.h = r;
            $ret.n = s;
            $ret.o = t;
            $ret.u = u;
            return $ret;
        })());
        b.a = w;
        a.s.k(w);
    };
    DrawingPartManagerHelpers.bo = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.mt(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_Sat();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.bp = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.mu(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_SatMod();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.bq = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = DrawingMLMain.mv(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_SatOff();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.br = function (a) {
        var b;
        var c = DrawingMLMain.mw(a, b);
        b = c.p1;
        var d = ((function () {
            var $ret = new CT_SchemeColor();
            $ret.c = b;
            return $ret;
        })());
        a.s.k(d);
        DrawingPartManagerHelpers.a(a, d);
    };
    DrawingPartManagerHelpers.bs = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_PositiveFixedPercentage();
        var d = DrawingMLMain.mx(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_Shade();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.bt = function (a) {
        var b = a.s.a(CT_GraphicalObjectData.$);
        if (b == null) {
            return;
        }
        var c;
        var d = Drawing2010Slicer.at(a, c);
        c = d.p1;
        b.b.add(Tuple.a(String_$type, Base.$, Drawing2010Slicer.as, ((function () {
            var $ret = new CT_Slicer();
            $ret.a = c;
            return $ret;
        })())));
    };
    DrawingPartManagerHelpers.bu = function (a) {
        var b = new CT_SolidFillProperties();
        DrawingPartManagerHelpers.b(CT_SolidFillProperties.$, a, b);
        a.s.k(b);
    };
    DrawingPartManagerHelpers.bv = function (a) {
        var b = a.s.a(IShapesOwner_$type);
        var c;
        var d;
        var e;
        var f;
        var g = a.d._t.cp(a, c, d, e, f);
        c = g.p1;
        d = g.p2;
        e = g.p3;
        f = g.p4;
        var h = ((function () {
            var $ret = new CT_Shape();
            $ret.e = c;
            $ret.f = d;
            $ret.c = e;
            $ret.d = f;
            return $ret;
        })());
        if (b != null) {
            b.addShape(a.d, h);
        }
        a.s.k(h);
    };
    DrawingPartManagerHelpers.bw = function (a) {
        var b = a.s.a(CT_NonVisualDrawingShapeProps.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f;
        var g;
        var h;
        var i;
        var j;
        var k;
        var l;
        var m;
        var n = DrawingMLMain.mz(a, c, d, e, f, g, h, i, j, k, l, m);
        c = n.p1;
        d = n.p2;
        e = n.p3;
        f = n.p4;
        g = n.p5;
        h = n.p6;
        i = n.p7;
        j = n.p8;
        k = n.p9;
        l = n.p10;
        m = n.p11;
        var o = ((function () {
            var $ret = new CT_ShapeLocking();
            $ret.f = c;
            $ret.j = d;
            $ret.i = e;
            $ret.c = f;
            $ret.g = g;
            $ret.h = h;
            $ret.e = i;
            $ret.a = j;
            $ret.b = k;
            $ret.d = l;
            $ret.k = m;
            return $ret;
        })());
        b.a = o;
        a.s.k(o);
    };
    DrawingPartManagerHelpers.bx = function (a) {
        var b = a.s.a(ICT_ShapePropertiesOwner_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = a.d._t.cq(a, c);
        c = d.p1;
        var e = ((function () {
            var $ret = new CT_ShapeProperties();
            $ret.b = c;
            return $ret;
        })());
        b.spPr = e;
        a.s.k(e);
    };
    DrawingPartManagerHelpers.by = function (a) {
        var b = a.s.a(CT_BlipFillProperties.$);
        if (b == null) {
            return;
        }
        var c = new ST_Percentage();
        var d = new ST_Percentage();
        var e = new ST_Percentage();
        var f = new ST_Percentage();
        var g = DrawingMLMain.m0(a, c, d, e, f);
        c = g.p1;
        d = g.p2;
        e = g.p3;
        f = g.p4;
        var h = ((function () {
            var $ret = new CT_RelativeRect();
            $ret.b = c;
            $ret.d = d;
            $ret.c = e;
            $ret.a = f;
            return $ret;
        })());
        b.a = h;
        a.s.k(h);
    };
    DrawingPartManagerHelpers.bz = function (a) {
        var b = new ST_HexColorRGB();
        var c = DrawingMLMain.m1(a, b);
        b = c.p1;
        var d = ((function () {
            var $ret = new CT_SRgbColor();
            $ret.c = b;
            return $ret;
        })());
        a.s.k(d);
        DrawingPartManagerHelpers.a(a, d);
    };
    DrawingPartManagerHelpers.b0 = function (a) {
        var b = a.s.a(CT_NonVisualConnectorProperties.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e = a.d._t.cr(a, c, d);
        c = e.p1;
        d = e.p2;
        var f = ((function () {
            var $ret = new CT_Connection();
            $ret.a = c;
            $ret.b = d;
            return $ret;
        })());
        b.b = f;
        a.s.k(f);
    };
    DrawingPartManagerHelpers.b1 = function (a) {
        var b = a.s.a(CT_BlipFillProperties.$);
        if (b == null) {
            return;
        }
        var c = new CT_StretchInfoProperties();
        b.e = c;
        a.s.k(c);
    };
    DrawingPartManagerHelpers.b2 = function (a) {
        var b = a.s.a(ICT_ShapeStyleOwner_$type);
        if (b == null) {
            return;
        }
        var c = new CT_ShapeStyle();
        b.style = c;
        a.s.k(c);
    };
    DrawingPartManagerHelpers.b3 = function (a) {
        var b;
        var c = new ST_HexColorRGB();
        var d = DrawingMLMain.m3(a, b, c);
        b = d.p1;
        c = d.p2;
        var e = ((function () {
            var $ret = new CT_SysColor();
            $ret.d = b;
            $ret.c = c;
            return $ret;
        })());
        a.s.k(e);
        DrawingPartManagerHelpers.a(a, e);
    };
    DrawingPartManagerHelpers.b4 = function (a) {
        var b = a.s.a(CT_LineProperties.$);
        if (b == null) {
            return;
        }
        var c;
        var d;
        var e;
        var f = DrawingMLMain.m4(a, c, d, e);
        c = f.p1;
        d = f.p2;
        e = f.p3;
        var g = ((function () {
            var $ret = new CT_LineEndProperties();
            $ret.b = c;
            $ret.c = d;
            $ret.a = e;
            return $ret;
        })());
        b.b = g;
        a.s.k(g);
    };
    DrawingPartManagerHelpers.b5 = function (a) {
        var b = a.s.a(CT_RegularTextRun.$);
        if (b == null) {
            return;
        }
        var c;
        var d = DrawingMLMain.m5(a, c);
        c = d.p1;
        b.b = c != null ? c : stringEmpty();
    };
    DrawingPartManagerHelpers.b6 = function (a) {
        var b = a.s.a(EG_ColorChoice.$);
        if (b == null) {
            return;
        }
        var c = new ST_PositiveFixedPercentage();
        var d = DrawingMLMain.m9(a, c);
        c = d.p1;
        b.b.add(((function () {
            var $ret = new ColorTransform_Tint();
            $ret.a = c;
            return $ret;
        })()));
    };
    DrawingPartManagerHelpers.b7 = function (a) {
        var b = a.s.a(CT_Shape.$);
        if (b == null) {
            return;
        }
        var c = new CT_TextBody();
        b.b = c;
        a.s.k(c);
    };
    DrawingPartManagerHelpers.b8 = function (a) {
        var b = new ST_Angle();
        var c;
        var d;
        var e = a.s.a(CT_GraphicalObjectFrame.$);
        if (e != null) {
            var f = a.d._t.cu(a, b, c, d);
            b = f.p1;
            c = f.p2;
            d = f.p3;
            var g = ((function () {
                var $ret = new CT_Transform2D();
                $ret.j = Nullable$1.toNullable(ST_Angle.$, b);
                $ret.i = Nullable$1.toNullable(Boolean_$type, c);
                $ret.k = Nullable$1.toNullable(Boolean_$type, d);
                return $ret;
            })());
            e.c = g;
            a.s.k(g);
            return;
        }
        var h = DrawingMLMain.na(a, b, c, d);
        b = h.p1;
        c = h.p2;
        d = h.p3;
        var i = a.s.a(CT_ShapeProperties.$);
        if (i != null) {
            var j = ((function () {
                var $ret = new CT_Transform2D();
                $ret.j = Nullable$1.toNullable(ST_Angle.$, b);
                $ret.i = Nullable$1.toNullable(Boolean_$type, c);
                $ret.k = Nullable$1.toNullable(Boolean_$type, d);
                return $ret;
            })());
            i.d = j;
            a.s.k(j);
            return;
        }
        var k = a.s.a(CT_GroupShapeProperties.$);
        if (k != null) {
            var l = ((function () {
                var $ret = new CT_GroupTransform2D();
                $ret.j = Nullable$1.toNullable(ST_Angle.$, b);
                $ret.i = Nullable$1.toNullable(Boolean_$type, c);
                $ret.k = Nullable$1.toNullable(Boolean_$type, d);
                return $ret;
            })());
            k.c = l;
            a.s.k(l);
            return;
        }
    };
    DrawingPartManagerHelpers.b9 = function (a) {
        a.ay(DrawingMLMain.a1, DrawingPartManagerHelpers.d);
        a.ay(DrawingMLMain.a6, DrawingPartManagerHelpers.e);
        a.ay(DrawingMLMain.a8, DrawingPartManagerHelpers.f);
        a.ay(DrawingMLMain.bg, DrawingPartManagerHelpers.g);
        a.ay(DrawingMLMain.bs, DrawingPartManagerHelpers.h);
        a.ay(DrawingMLMain.bt, DrawingPartManagerHelpers.i);
        a.ay(DrawingMLMain.bu, DrawingPartManagerHelpers.j);
        a.ay(DrawingMLMain.bv, DrawingPartManagerHelpers.k);
        a.ay(DrawingMLMain.bw, DrawingPartManagerHelpers.l);
        a.ay(DrawingMLMain.bz, DrawingPartManagerHelpers.m);
        a.ay(DrawingMLMain.cg, DrawingPartManagerHelpers.o);
        a.ay(DrawingMLMain.ch, DrawingPartManagerHelpers.p);
        a.ay(DrawingMLMain.cp, DrawingPartManagerHelpers.w);
        a.ay(DrawingMLMain.ct, DrawingPartManagerHelpers.x);
        a.ay(DrawingMLMain.de, DrawingPartManagerHelpers.aa);
        a.ay(DrawingMLMain.dj, DrawingPartManagerHelpers.ab);
        a.ay(DrawingMLMain.dq, DrawingPartManagerHelpers.ad);
        a.ay(DrawingMLMain.dr, DrawingPartManagerHelpers.ae);
        a.ay(DrawingMLMain.dy, DrawingPartManagerHelpers.af);
        a.ay(DrawingMLMain.dz, DrawingPartManagerHelpers.ag);
        a.ay(DrawingMLMain.eb, DrawingPartManagerHelpers.ah);
        a.ay(DrawingMLMain.eg, DrawingPartManagerHelpers.ai);
        a.ay(DrawingMLMain.ek, DrawingPartManagerHelpers.ak);
        a.ay(DrawingMLMain.el, DrawingPartManagerHelpers.aj);
        a.ay(DrawingMLMain.em, DrawingPartManagerHelpers.am);
        a.ay(DrawingMLMain.en, DrawingPartManagerHelpers.an);
        a.ay(DrawingMLMain.ep, DrawingPartManagerHelpers.ao);
        a.ay(DrawingMLMain.eq, DrawingPartManagerHelpers.ap);
        a.ay(DrawingMLMain.er, DrawingPartManagerHelpers.aq);
        a.ay(DrawingMLMain.es, DrawingPartManagerHelpers.ar);
        a.ay(DrawingMLMain.ew, DrawingPartManagerHelpers.av);
        a.ay(DrawingMLMain.e8, DrawingPartManagerHelpers.aw);
        a.ay(DrawingMLMain.e9, DrawingPartManagerHelpers.ax);
        a.ay(DrawingMLMain.fa, DrawingPartManagerHelpers.ay);
        a.ay(DrawingMLMain.fg, DrawingPartManagerHelpers.az);
        a.ay(DrawingMLMain.fq, DrawingPartManagerHelpers.a0);
        a.ay(DrawingMLMain.fw, DrawingPartManagerHelpers.a1);
        a.ay(DrawingMLMain.fx, DrawingPartManagerHelpers.a2);
        a.ay(DrawingMLMain.f4, DrawingPartManagerHelpers.a3);
        a.ay(DrawingMLMain.f5, DrawingPartManagerHelpers.a4);
        a.ay(DrawingMLMain.f6, DrawingPartManagerHelpers.a5);
        a.ay(DrawingMLMain.gy, DrawingPartManagerHelpers.a6);
        a.ay(DrawingMLMain.hb, DrawingPartManagerHelpers.bc);
        a.ay(DrawingMLMain.hd, DrawingPartManagerHelpers.bd);
        a.ay(DrawingMLMain.hi, DrawingPartManagerHelpers.bf);
        a.ay(DrawingMLMain.hl, DrawingPartManagerHelpers.bg);
        a.ay(DrawingMLMain.hn, DrawingPartManagerHelpers.bh);
        a.ay(DrawingMLMain.hp, DrawingPartManagerHelpers.bi);
        a.ay(DrawingMLMain.hu, DrawingPartManagerHelpers.bm);
        a.ay(DrawingMLMain.hx, DrawingPartManagerHelpers.bj);
        a.ay(DrawingMLMain.hy, DrawingPartManagerHelpers.bk);
        a.ay(DrawingMLMain.hz, DrawingPartManagerHelpers.bl);
        a.ay(DrawingMLMain.h7, DrawingPartManagerHelpers.bn);
        a.ay(DrawingMLMain.ia, DrawingPartManagerHelpers.bo);
        a.ay(DrawingMLMain.ib, DrawingPartManagerHelpers.bp);
        a.ay(DrawingMLMain.ic, DrawingPartManagerHelpers.bq);
        a.ay(DrawingMLMain.ie, DrawingPartManagerHelpers.br);
        a.ay(DrawingMLMain.ii, DrawingPartManagerHelpers.bs);
        a.ay(DrawingMLMain.io, DrawingPartManagerHelpers.bu);
        a.ay(DrawingMLMain.iy, DrawingPartManagerHelpers.bw);
        a.ay(DrawingMLMain.iz, DrawingPartManagerHelpers.by);
        a.ay(DrawingMLMain.i0, DrawingPartManagerHelpers.bz);
        a.ay(DrawingMLMain.i2, DrawingPartManagerHelpers.b1);
        a.ay(DrawingMLMain.i8, DrawingPartManagerHelpers.b3);
        a.ay(DrawingMLMain.ja, DrawingPartManagerHelpers.b5);
        a.ay(DrawingMLMain.je, DrawingPartManagerHelpers.b4);
        a.ay(DrawingMLMain.jm, DrawingPartManagerHelpers.b6);
        a.ay(DrawingMLMain.j8, DrawingPartManagerHelpers.b8);
        a.ay(DrawingMLChart.be, DrawingPartManagerHelpers.n);
        a.ay(Drawing2010Slicer.as, DrawingPartManagerHelpers.bt);
        var b = a.d._t;
        if (b != null) {
            a.ay(b.an, DrawingPartManagerHelpers.i);
            a.ay(b.ap, DrawingPartManagerHelpers.q);
            a.ay(b.aq, DrawingPartManagerHelpers.r);
            a.ay(b.ar, DrawingPartManagerHelpers.s);
            a.ay(b.as, DrawingPartManagerHelpers.t);
            a.ay(b.at, DrawingPartManagerHelpers.u);
            a.ay(b.au, DrawingPartManagerHelpers.v);
            a.ay(b.av, DrawingPartManagerHelpers.y);
            a.ay(b.aw, DrawingPartManagerHelpers.z);
            a.ay(b.ay, DrawingPartManagerHelpers.ac);
            a.ay(b.a3, DrawingPartManagerHelpers.al);
            a.ay(b.a4, DrawingPartManagerHelpers.as);
            a.ay(b.a5, DrawingPartManagerHelpers.at);
            a.ay(b.a6, DrawingPartManagerHelpers.au);
            a.ay(b.bn, DrawingPartManagerHelpers.a7);
            a.ay(b.bo, DrawingPartManagerHelpers.a8);
            a.ay(b.bp, DrawingPartManagerHelpers.a9);
            a.ay(b.bq, DrawingPartManagerHelpers.ba);
            a.ay(b.br, DrawingPartManagerHelpers.bb);
            a.ay(b.bs, DrawingPartManagerHelpers.be);
            a.ay(b.bw, DrawingPartManagerHelpers.bv);
            a.ay(b.bx, DrawingPartManagerHelpers.bx);
            a.ay(b.by, DrawingPartManagerHelpers.b0);
            a.ay(b.bz, DrawingPartManagerHelpers.b2);
            a.ay(b.b1, DrawingPartManagerHelpers.b7);
            a.ay(b.b3, DrawingPartManagerHelpers.b8);
        }
    };
    DrawingPartManagerHelpers.ca = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.nh(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cb = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.ni(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cc = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.nj(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cd = function (a, b) {
        if (b == null) {
            return;
        }
        a.ad.g(Enumerable.o(Tuple$2.$.specialize(Array_$type, IGraphicalObjectContent_$type), AlternateContentChoice.$, b.b, function (c) { return new AlternateContentChoice(1, c.c, function () { return c.d._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a); }); }), b.a == null ? null : function () { return b.a._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a); });
    };
    DrawingPartManagerHelpers.ce = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.nk(a);
        b.b.q(function (c) { return DrawingPartManagerHelpers.c7(a, c); });
        a.ad.k();
    };
    DrawingPartManagerHelpers.cf = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.nl(a, b.b, b.c, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cg = function (a, b, c) {
        if (c === void 0) { c = false; }
        if (b == null) {
            return;
        }
        if (c) {
            a.d._t.cv(a, nullableEquals(b.b, 0) ? Nullable$1.toNullable(Number_$type, null) : b.b, nullableEquals(b.c, false) ? Nullable$1.toNullable(Boolean_$type, null) : b.c);
        }
        else {
            DrawingMLMain.nm(a, nullableEquals(b.b, 0) ? Nullable$1.toNullable(Number_$type, null) : b.b, nullableEquals(b.c, false) ? Nullable$1.toNullable(Boolean_$type, null) : b.c);
        }
        DrawingPartManagerHelpers.cf(a, b.d);
        DrawingPartManagerHelpers.eo(a, b.a);
        if (b.e != null) {
            b.e._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        a.ad.k();
    };
    DrawingPartManagerHelpers.ch = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.nn(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.ci = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.no(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cj = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.np(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.ck = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.nq(a, b.n, b.l, b.q, b.p, b.t, b.r, b.j, b.s, b.m, b.f, b.k, b.o, b.a, b.i, b.d, b.e, b.h, b.c, b.g);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cl = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.nr(a, b.a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cm = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.ns(a, b.a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cn = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.cw(a);
        DrawingPartManagerHelpers.cz(a, b.c);
        DrawingPartManagerHelpers.eq(a, b.b);
        DrawingPartManagerHelpers.c2(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.co = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.cx(a);
        DrawingPartManagerHelpers.dd(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cp = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.cy(a);
        DrawingPartManagerHelpers.dj(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cq = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.cz(a, b.b);
        DrawingPartManagerHelpers.d6(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cr = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.c0(a, b.c, b.f, b.e, b.d, b.g);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cs = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.c1(a, b.b);
        DrawingPartManagerHelpers.em(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.ct = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.nu(a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cu = function (a, b) {
        if (b == null) {
            return;
        }
        var c = b.b.hasValue ? b.b.value : 1;
        DrawingMLMain.nv(a, b.d, b.a, b.c, c);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cv = function (a, b, c) {
        if (b == null) {
            return;
        }
        c(a, b.b, b.c, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cw = function (a, b, c) {
        if (b == null) {
            return;
        }
        c(a, b.b, b.d, b.c, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cx = function (a, b) {
        if (b == null) {
            return;
        }
        a.ad.n(b.g);
    };
    DrawingPartManagerHelpers.cy = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.c3(a);
        DrawingPartManagerHelpers.dy(a, b.a);
        DrawingPartManagerHelpers.en(a, b.spPr);
        DrawingPartManagerHelpers.es(a, b.style);
        a.ad.k();
    };
    DrawingPartManagerHelpers.cz = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.c4(a, b.f, b.j, b.i, b.c, b.g, b.h, b.e, b.a, b.b, b.d);
        a.ad.k();
    };
    DrawingPartManagerHelpers.c0 = function (a, b) {
        if (b == null) {
            return;
        }
        var c = b.b.hasValue ? b.b.value : 1;
        DrawingMLMain.oe(a, b.d, b.a, b.c, c);
        a.ad.k();
    };
    DrawingPartManagerHelpers.c1 = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.of(a, b.b);
        if (b.a != null) {
            b.a._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        a.ad.k();
    };
    DrawingPartManagerHelpers.c2 = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.c5(a, b.a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.c3 = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.og(a, b.a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.c4 = function (a, b) {
        DrawingPartManagerHelpers.cw(a, b, DrawingMLMain.ok);
    };
    DrawingPartManagerHelpers.c5 = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.ol(a, b.b);
        if (b.a != null) {
            b.a._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        a.ad.k();
    };
    DrawingPartManagerHelpers.c6 = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.oo(a, b.b);
        if (b.a != null) {
            b.a._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        a.ad.k();
    };
    DrawingPartManagerHelpers.c7 = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.oq(a, b.b, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.c9 = function (a, b) {
        var c = typeCast(IGraphicalObjectContent_$type, b.d);
        if (c != null) {
            c._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
            return;
        }
        var d = typeCast(CT_RelId.$, b.d);
        if (d != null) {
            switch (b.c) {
                case DrawingMLChart.be:
                    DrawingMLChart.gy(a, d.a);
                    a.ad.k();
                    break;
                default: break;
            }
            return;
        }
        var e = typeCast(CT_Slicer.$, b.d);
        if (e != null) {
            switch (b.c) {
                case Drawing2010Slicer.as:
                    Drawing2010Slicer.au(a, e.a);
                    a.ad.k();
                    break;
                default: break;
            }
            return;
        }
    };
    DrawingPartManagerHelpers.da = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.or(a, b.c);
        b.b.q(function (c) { return DrawingPartManagerHelpers.c9(a, c); });
        a.ad.k();
    };
    DrawingPartManagerHelpers.db = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.os(a);
        DrawingPartManagerHelpers.da(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dc = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.c6(a, b.e, b.d);
        DrawingPartManagerHelpers.dz(a, b.b);
        DrawingPartManagerHelpers.ey(a, b.c, runOn(a.d._t, a.d._t.dm));
        DrawingPartManagerHelpers.db(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dd = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.ot(a, b.c, b.b, b.f, b.a, b.d, b.e);
        a.ad.k();
    };
    DrawingPartManagerHelpers.de = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.ou(a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.df = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.ov(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dg = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.ow(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dh = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.ox(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.di = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.c7(a);
        DrawingPartManagerHelpers.d0(a, b.a);
        DrawingPartManagerHelpers.dk(a, b.b);
        b.d.q(function (c) { return c._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a); });
        a.ad.k();
    };
    DrawingPartManagerHelpers.dj = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.c8(a, b.b, b.g, b.f, b.e, b.a, b.c, b.d);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dk = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.c9(a, b.b);
        DrawingPartManagerHelpers.ex(a, b.c);
        if (b.a != null) {
            b.a._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        a.ad.k();
    };
    DrawingPartManagerHelpers.dl = function (a, b) {
        DrawingPartManagerHelpers.cv(a, b, DrawingMLMain.oz);
    };
    DrawingPartManagerHelpers.dm = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.o2(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dn = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.o3(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dp = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.o4(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dq = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.o5(a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dr = function (a, b) {
        if (b == null) {
            return;
        }
        var c = b.b.hasValue ? b.b.value : 1;
        DrawingMLMain.o6(a, b.d, b.a, b.c, c);
        a.ad.k();
    };
    DrawingPartManagerHelpers.ds = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.o7(a, b.h, b.f, b.g, b.e);
        if (b.i != null) {
            b.i._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        if (b.c != null) {
            b.c._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        if (b.d != null) {
            b.d._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        DrawingPartManagerHelpers.dl(a, b.a);
        DrawingPartManagerHelpers.eu(a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dt = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.o8(a, b.b);
        if (b.a != null) {
            b.a._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        a.ad.k();
    };
    DrawingPartManagerHelpers.du = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pc(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dv = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pd(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dw = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pe(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dx = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.ph(a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dy = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.db(a);
        DrawingPartManagerHelpers.cr(a, b.a);
        DrawingPartManagerHelpers.cn(a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.dz = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.dc(a);
        DrawingPartManagerHelpers.cr(a, b.a);
        DrawingPartManagerHelpers.co(a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.d0 = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.dd(a);
        DrawingPartManagerHelpers.cr(a, b.a);
        DrawingPartManagerHelpers.cp(a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.d1 = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.de(a);
        DrawingPartManagerHelpers.cr(a, b.a);
        DrawingPartManagerHelpers.cq(a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.d2 = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.df(a);
        DrawingPartManagerHelpers.cr(a, b.a);
        DrawingPartManagerHelpers.cs(a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.d3 = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pj(a, b.a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.d4 = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pk(a);
        DrawingPartManagerHelpers.d7(a, b.a);
        b.c.q(function (c) { return c._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a); });
        a.ad.k();
    };
    DrawingPartManagerHelpers.d5 = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.dg(a);
        DrawingPartManagerHelpers.d1(a, b.b);
        DrawingPartManagerHelpers.cg(a, b.a, true);
        DrawingPartManagerHelpers.en(a, b.spPr);
        a.ad.k();
    };
    DrawingPartManagerHelpers.d6 = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pl(a, b.g, b.k, b.j, b.c, b.h, b.i, b.f, b.a, b.b, b.d, b.e);
        a.ad.k();
    };
    DrawingPartManagerHelpers.d7 = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pm(a, b.i, b.j, b.h, b.f, b.a, b.b, b.k, b.c, b.d, b.g, b.e);
        a.ad.k();
    };
    DrawingPartManagerHelpers.d8 = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pn(a, b.c);
        b.b.q(function (c) { return c._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a); });
        a.ad.k();
    };
    DrawingPartManagerHelpers.d9 = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.po(a, b.b);
        DrawingPartManagerHelpers.ce(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.ea = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pp(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.eb = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pq(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.ec = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pr(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.ed = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.ps(a);
        DrawingPartManagerHelpers.ee(a, b.a);
        DrawingMLMain.p6(a, b.b);
        a.ad.k();
        a.ad.k();
    };
    DrawingPartManagerHelpers.ee = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pt(a, b.k, b.v, b.t, ST_TextFontSize.h(b.r), b.d, b.i, b.s, b.q, b.j, b.f, b.p, b.m, b.e, b.l, b.g, b.h, b.n, b.o, b.u);
        DrawingPartManagerHelpers.ds(a, b.w);
        if (b.y != null) {
            b.y._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        DrawingPartManagerHelpers.dr(a, b.c);
        DrawingPartManagerHelpers.c0(a, b.b);
        DrawingPartManagerHelpers.cu(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.ef = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pu(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.eg = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pv(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.eh = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pw(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.ei = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.px(a, b.c);
        b.b.q(function (c) { return c._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a); });
        a.ad.k();
    };
    DrawingPartManagerHelpers.c8 = function (a, b) {
        if (b == null) {
            return;
        }
        b._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
    };
    DrawingPartManagerHelpers.ek = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.pz(a);
        if (b.a != null) {
            b.a._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        a.ad.k();
    };
    DrawingPartManagerHelpers.el = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.dh(a);
        DrawingPartManagerHelpers.d2(a, b.a);
        DrawingPartManagerHelpers.en(a, b.spPr);
        DrawingPartManagerHelpers.es(a, b.style);
        DrawingPartManagerHelpers.ew(a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.em = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.p0(a, b.f, b.j, b.i, b.c, b.g, b.h, b.e, b.a, b.b, b.d, b.k);
        a.ad.k();
    };
    DrawingPartManagerHelpers.en = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.di(a, b.b);
        DrawingPartManagerHelpers.ey(a, b.d, DrawingMLMain.qb);
        if (b.e != null) {
            b.e._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        if (b.a != null) {
            b.a._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a);
        }
        DrawingPartManagerHelpers.ds(a, b.c);
        a.ad.k();
    };
    DrawingPartManagerHelpers.eo = function (a, b) {
        DrawingPartManagerHelpers.cw(a, b, DrawingMLMain.p1);
    };
    DrawingPartManagerHelpers.ej = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.py(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.ep = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.p2(a, b.c);
        b.b.q(function (c) { return c._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a); });
        a.ad.k();
    };
    DrawingPartManagerHelpers.eq = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.dj(a, b.a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.er = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.p3(a);
        DrawingPartManagerHelpers.c4(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.es = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.dk(a);
        DrawingPartManagerHelpers.dt(a, b.d);
        DrawingPartManagerHelpers.c5(a, b.c);
        DrawingPartManagerHelpers.c1(a, b.b);
        DrawingPartManagerHelpers.c6(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.et = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.p4(a, b.d, b.c);
        b.b.q(function (c) { return c._accept$2$i(XmlPartManagerBase.$, Boolean_$type, DrawingPartManagerHelpers_DrawingSerializationHelper.a, a); });
        a.ad.k();
    };
    DrawingPartManagerHelpers.eu = function (a, b) {
        DrawingPartManagerHelpers.cv(a, b, DrawingMLMain.p5);
    };
    DrawingPartManagerHelpers.ev = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.qa(a, b.a);
        a.ad.k();
    };
    DrawingPartManagerHelpers.ew = function (a, b) {
        if (b == null) {
            return;
        }
        a.d._t.dl(a);
        DrawingPartManagerHelpers.ck(a, b.a);
        b.d.q(function (c) { return DrawingPartManagerHelpers.d4(a, c); });
        a.ad.k();
    };
    DrawingPartManagerHelpers.ey = function (a, b, c) {
        if (b == null) {
            return;
        }
        c(a, b.d(), b.g(), b.h());
        DrawingPartManagerHelpers.d3(a, b.a);
        DrawingPartManagerHelpers.c3(a, b.b);
        a.ad.k();
    };
    DrawingPartManagerHelpers.ex = function (a, b) {
        if (b == null) {
            return;
        }
        DrawingMLMain.qb(a, b.d(), b.g(), b.h());
        DrawingPartManagerHelpers.d3(a, b.a);
        DrawingPartManagerHelpers.c3(a, b.b);
        DrawingPartManagerHelpers.cm(a, b.l);
        DrawingPartManagerHelpers.cl(a, b.m);
        a.ad.k();
    };
    DrawingPartManagerHelpers.$t = markType(DrawingPartManagerHelpers, 'DrawingPartManagerHelpers');
    return DrawingPartManagerHelpers;
}(Base));
export { DrawingPartManagerHelpers };
var DrawingPartManagerHelpers_DrawingSerializationHelper = /** @class */ (function (_super) {
    tslib_1.__extends(DrawingPartManagerHelpers_DrawingSerializationHelper, _super);
    function DrawingPartManagerHelpers_DrawingSerializationHelper() {
        return _super.call(this) || this;
    }
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_SchemeColor$i = function (a, b) {
        DrawingPartManagerHelpers.ei(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_SRgbColor$i = function (a, b) {
        DrawingPartManagerHelpers.ep(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_SysColor$i = function (a, b) {
        DrawingPartManagerHelpers.et(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_PresetColor$i = function (a, b) {
        DrawingPartManagerHelpers.d8(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_Alpha$i = function (a, b) {
        DrawingPartManagerHelpers.ca(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_AlphaMod$i = function (a, b) {
        DrawingPartManagerHelpers.cb(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_AlphaOff$i = function (a, b) {
        DrawingPartManagerHelpers.cc(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_Blue$i = function (a, b) {
        DrawingPartManagerHelpers.ch(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_BlueMod$i = function (a, b) {
        DrawingPartManagerHelpers.ci(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_BlueOff$i = function (a, b) {
        DrawingPartManagerHelpers.cj(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_Comp$i = function (a, b) {
        DrawingPartManagerHelpers.ct(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_Gray$i = function (a, b) {
        DrawingPartManagerHelpers.de(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_Green$i = function (a, b) {
        DrawingPartManagerHelpers.df(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_GreenMod$i = function (a, b) {
        DrawingPartManagerHelpers.dg(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_GreenOff$i = function (a, b) {
        DrawingPartManagerHelpers.dh(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_Hue$i = function (a, b) {
        DrawingPartManagerHelpers.dm(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_HueMod$i = function (a, b) {
        DrawingPartManagerHelpers.dn(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_HueOff$i = function (a, b) {
        DrawingPartManagerHelpers.dp(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_Inv$i = function (a, b) {
        DrawingPartManagerHelpers.dq(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_Lum$i = function (a, b) {
        DrawingPartManagerHelpers.du(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_LumMod$i = function (a, b) {
        DrawingPartManagerHelpers.dv(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_LumOff$i = function (a, b) {
        DrawingPartManagerHelpers.dw(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_Red$i = function (a, b) {
        DrawingPartManagerHelpers.ea(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_RedMod$i = function (a, b) {
        DrawingPartManagerHelpers.eb(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_RedOff$i = function (a, b) {
        DrawingPartManagerHelpers.ec(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_Sat$i = function (a, b) {
        DrawingPartManagerHelpers.ef(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_SatMod$i = function (a, b) {
        DrawingPartManagerHelpers.eg(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_SatOff$i = function (a, b) {
        DrawingPartManagerHelpers.eh(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_Shade$i = function (a, b) {
        DrawingPartManagerHelpers.ej(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitColorTransform_Tint$i = function (a, b) {
        DrawingPartManagerHelpers.ev(b, a);
        return false;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_StretchInfoProperties$i = function (a, b) {
        DrawingPartManagerHelpers.er(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_TileInfoProperties$i = function (a, b) {
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_BlipFillProperties$i = function (a, b) {
        DrawingPartManagerHelpers.cg(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_GroupFillProperties$i = function (a, b) {
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_NoFillProperties$i = function (a, b) {
        DrawingPartManagerHelpers.dx(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_SolidFillProperties$i = function (a, b) {
        DrawingPartManagerHelpers.ek(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_PresetGeometry2D$i = function (a, b) {
        DrawingPartManagerHelpers.d9(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_CustomGeometry2D$i = function (a, b) {
        DrawingPartManagerHelpers.cx(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_DashStopList$i = function (a, b) {
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_PresetLineDashProperties$i = function (a, b) {
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_NoFillProperties1$i = function (a, b) {
        DrawingPartManagerHelpers.dx(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_SolidFillProperties1$i = function (a, b) {
        DrawingPartManagerHelpers.ek(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_LineJoinBevel$i = function (a, b) {
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_LineJoinMiterProperties$i = function (a, b) {
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_LineJoinRound$i = function (a, b) {
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_RegularTextRun$i = function (a, b) {
        DrawingPartManagerHelpers.ed(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitAlternateGraphicalObjectContent$i = function (a, b) {
        DrawingPartManagerHelpers.cd(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_Connector$i = function (a, b) {
        DrawingPartManagerHelpers.cy(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_GraphicalObjectFrame$i = function (a, b) {
        DrawingPartManagerHelpers.dc(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_GroupShape$i = function (a, b) {
        DrawingPartManagerHelpers.di(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_Picture$i = function (a, b) {
        DrawingPartManagerHelpers.d5(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.prototype._visitCT_Shape$i = function (a, b) {
        DrawingPartManagerHelpers.el(b, a);
        return true;
    };
    DrawingPartManagerHelpers_DrawingSerializationHelper.$t = markType(DrawingPartManagerHelpers_DrawingSerializationHelper, 'DrawingPartManagerHelpers_DrawingSerializationHelper', Base.$, [IEG_ColorChoiceVisitor$2_$type.specialize(XmlPartManagerBase.$, Boolean_$type), IEG_ColorTransformVisitor$2_$type.specialize(XmlPartManagerBase.$, Boolean_$type), IEG_FillModePropertiesVisitor$2_$type.specialize(XmlPartManagerBase.$, Boolean_$type), IEG_FillPropertiesVisitor$2_$type.specialize(XmlPartManagerBase.$, Boolean_$type), IEG_GeometryVisitor$2_$type.specialize(XmlPartManagerBase.$, Boolean_$type), IEG_LineDashPropertiesVisitor$2_$type.specialize(XmlPartManagerBase.$, Boolean_$type), IEG_LineFillPropertiesVisitor$2_$type.specialize(XmlPartManagerBase.$, Boolean_$type), IEG_LineJoinPropertiesVisitor$2_$type.specialize(XmlPartManagerBase.$, Boolean_$type), IEG_TextRunVisitor$2_$type.specialize(XmlPartManagerBase.$, Boolean_$type), IGraphicalObjectContentVisitor$2_$type.specialize(XmlPartManagerBase.$, Boolean_$type)]);
    DrawingPartManagerHelpers_DrawingSerializationHelper.a = new DrawingPartManagerHelpers_DrawingSerializationHelper();
    return DrawingPartManagerHelpers_DrawingSerializationHelper;
}(Base));
export { DrawingPartManagerHelpers_DrawingSerializationHelper };
var EmfPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(EmfPartManager, _super);
    function EmfPartManager() {
        return _super.call(this) || this;
    }
    EmfPartManager.prototype.get_s = function () {
        return "/xl/media/image.emf";
    };
    Object.defineProperty(EmfPartManager.prototype, "s", {
        get: function () {
            return this.get_s();
        },
        enumerable: true,
        configurable: true
    });
    EmfPartManager.prototype.get_t = function () {
        return "/ppt/media/image.emf";
    };
    Object.defineProperty(EmfPartManager.prototype, "t", {
        get: function () {
            return this.get_t();
        },
        enumerable: true,
        configurable: true
    });
    EmfPartManager.prototype.get_u = function () {
        return "/word/media/image.emf";
    };
    Object.defineProperty(EmfPartManager.prototype, "u", {
        get: function () {
            return this.get_u();
        },
        enumerable: true,
        configurable: true
    });
    EmfPartManager.prototype.get_m = function () {
        return "image/x-emf";
    };
    Object.defineProperty(EmfPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    EmfPartManager.prototype.r = function (a) {
        return ImageFormat.c;
    };
    EmfPartManager.$t = markType(EmfPartManager, 'EmfPartManager', ImagePartManagerBase.$);
    EmfPartManager.y = new EmfPartManager();
    return EmfPartManager;
}(ImagePartManagerBase));
export { EmfPartManager };
var ExtendedPropertiesPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(ExtendedPropertiesPartManager, _super);
    function ExtendedPropertiesPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ExtendedPropertiesPartManager.prototype.get_m = function () {
        return ExtendedPropertiesPartManager.a2;
    };
    Object.defineProperty(ExtendedPropertiesPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    ExtendedPropertiesPartManager.prototype.n = function (a) {
        return "/docProps/app.xml";
    };
    ExtendedPropertiesPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return ExtendedPropertiesPartManager.a5;
            case 1: return ExtendedPropertiesPartManager.a4;
            default: return ExtendedPropertiesPartManager.a5;
        }
    };
    ExtendedPropertiesPartManager.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(ExtendedPropertiesPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ExtendedPropertiesPartManager.$t = markType(ExtendedPropertiesPartManager, 'ExtendedPropertiesPartManager', XmlPartManagerBase.$);
    ExtendedPropertiesPartManager.a2 = "application/vnd.openxmlformats-officedocument.extended-properties+xml";
    ExtendedPropertiesPartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/extended-properties";
    ExtendedPropertiesPartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/extendedProperties";
    return ExtendedPropertiesPartManager;
}(XmlPartManagerBase));
export { ExtendedPropertiesPartManager };
var OfficeExtensibilityPartManagerBase = /** @class */ (function (_super) {
    tslib_1.__extends(OfficeExtensibilityPartManagerBase, _super);
    function OfficeExtensibilityPartManagerBase() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OfficeExtensibilityPartManagerBase.prototype.get_m = function () {
        return "application/xml";
    };
    Object.defineProperty(OfficeExtensibilityPartManagerBase.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    OfficeExtensibilityPartManagerBase.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(OfficeExtensibilityPartManagerBase.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    OfficeExtensibilityPartManagerBase.prototype.f = function (a, b) {
        var c = PackageUtilities.ak(b);
        return new RoundTripDataPartManager(a.contentType, c.toString(), b.relationshipType, this.d);
    };
    OfficeExtensibilityPartManagerBase.prototype.a = function () {
        var a = RoundTripDataPartManager.r(this.d, this.l, this.m);
        this.a2 = a;
        return WorkItem.g(Base.$, a);
    };
    OfficeExtensibilityPartManagerBase.prototype.b = function (a) {
        var b = this.a2;
        if (b == null) {
            return null;
        }
        return RoundTripDataPartManager.s(b, this.d, this.l, true);
    };
    OfficeExtensibilityPartManagerBase.prototype.u = function (a) {
        throw new NotImplementedException(0);
    };
    OfficeExtensibilityPartManagerBase.$t = markType(OfficeExtensibilityPartManagerBase, 'OfficeExtensibilityPartManagerBase', XmlPartManagerBase.$);
    return OfficeExtensibilityPartManagerBase;
}(XmlPartManagerBase));
export { OfficeExtensibilityPartManagerBase };
var Office2007ExtensibilityPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(Office2007ExtensibilityPartManager, _super);
    function Office2007ExtensibilityPartManager() {
        return _super.call(this) || this;
    }
    Office2007ExtensibilityPartManager.prototype.get_a2 = function () {
        return this.d._h;
    };
    Office2007ExtensibilityPartManager.prototype.set_a2 = function (a) {
        this.d._h = a;
    };
    Object.defineProperty(Office2007ExtensibilityPartManager.prototype, "a2", {
        get: function () {
            return this.get_a2();
        },
        set: function (a) {
            this.set_a2(a);
        },
        enumerable: true,
        configurable: true
    });
    Office2007ExtensibilityPartManager.prototype.n = function (a) {
        return "/customUI/customUI.xml";
    };
    Office2007ExtensibilityPartManager.prototype.o = function (a) {
        switch (a) {
            case 0:
            case 1: return Office2007ExtensibilityPartManager.a6;
            default: return Office2007ExtensibilityPartManager.a6;
        }
    };
    Office2007ExtensibilityPartManager.$t = markType(Office2007ExtensibilityPartManager, 'Office2007ExtensibilityPartManager', OfficeExtensibilityPartManagerBase.$);
    Office2007ExtensibilityPartManager.a6 = "http://schemas.microsoft.com/office/2006/relationships/ui/extensibility";
    Office2007ExtensibilityPartManager.a4 = new Office2007ExtensibilityPartManager();
    return Office2007ExtensibilityPartManager;
}(OfficeExtensibilityPartManagerBase));
export { Office2007ExtensibilityPartManager };
var Office2010ExtensibilityPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(Office2010ExtensibilityPartManager, _super);
    function Office2010ExtensibilityPartManager() {
        return _super.call(this) || this;
    }
    Office2010ExtensibilityPartManager.prototype.get_a2 = function () {
        return this.d._i;
    };
    Office2010ExtensibilityPartManager.prototype.set_a2 = function (a) {
        this.d._i = a;
    };
    Object.defineProperty(Office2010ExtensibilityPartManager.prototype, "a2", {
        get: function () {
            return this.get_a2();
        },
        set: function (a) {
            this.set_a2(a);
        },
        enumerable: true,
        configurable: true
    });
    Office2010ExtensibilityPartManager.prototype.n = function (a) {
        return "/customUI/customUI14.xml";
    };
    Office2010ExtensibilityPartManager.prototype.o = function (a) {
        switch (a) {
            case 0:
            case 1: return Office2010ExtensibilityPartManager.a6;
            default: return Office2010ExtensibilityPartManager.a6;
        }
    };
    Office2010ExtensibilityPartManager.$t = markType(Office2010ExtensibilityPartManager, 'Office2010ExtensibilityPartManager', OfficeExtensibilityPartManagerBase.$);
    Office2010ExtensibilityPartManager.a6 = "http://schemas.microsoft.com/office/2007/relationships/ui/extensibility";
    Office2010ExtensibilityPartManager.a4 = new Office2010ExtensibilityPartManager();
    return Office2010ExtensibilityPartManager;
}(OfficeExtensibilityPartManagerBase));
export { Office2010ExtensibilityPartManager };
var GifPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(GifPartManager, _super);
    function GifPartManager() {
        return _super.call(this) || this;
    }
    GifPartManager.prototype.get_s = function () {
        return "/xl/media/image.gif";
    };
    Object.defineProperty(GifPartManager.prototype, "s", {
        get: function () {
            return this.get_s();
        },
        enumerable: true,
        configurable: true
    });
    GifPartManager.prototype.get_t = function () {
        return "/ppt/media/image.gif";
    };
    Object.defineProperty(GifPartManager.prototype, "t", {
        get: function () {
            return this.get_t();
        },
        enumerable: true,
        configurable: true
    });
    GifPartManager.prototype.get_u = function () {
        return "/word/media/image.gif";
    };
    Object.defineProperty(GifPartManager.prototype, "u", {
        get: function () {
            return this.get_u();
        },
        enumerable: true,
        configurable: true
    });
    GifPartManager.prototype.get_m = function () {
        return "image/gif";
    };
    Object.defineProperty(GifPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    GifPartManager.prototype.r = function (a) {
        return ImageFormat.d;
    };
    GifPartManager.$t = markType(GifPartManager, 'GifPartManager', ImagePartManagerBase.$);
    GifPartManager.y = new GifPartManager();
    return GifPartManager;
}(ImagePartManagerBase));
export { GifPartManager };
var JpegPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(JpegPartManager, _super);
    function JpegPartManager() {
        return _super.call(this) || this;
    }
    JpegPartManager.prototype.get_s = function () {
        return "/xl/media/image.jpeg";
    };
    Object.defineProperty(JpegPartManager.prototype, "s", {
        get: function () {
            return this.get_s();
        },
        enumerable: true,
        configurable: true
    });
    JpegPartManager.prototype.get_t = function () {
        return "/ppt/media/image.jpeg";
    };
    Object.defineProperty(JpegPartManager.prototype, "t", {
        get: function () {
            return this.get_t();
        },
        enumerable: true,
        configurable: true
    });
    JpegPartManager.prototype.get_u = function () {
        return "/word/media/image.jpeg";
    };
    Object.defineProperty(JpegPartManager.prototype, "u", {
        get: function () {
            return this.get_u();
        },
        enumerable: true,
        configurable: true
    });
    JpegPartManager.prototype.get_m = function () {
        return "image/jpeg";
    };
    Object.defineProperty(JpegPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    JpegPartManager.prototype.r = function (a) {
        return ImageFormat.e;
    };
    JpegPartManager.$t = markType(JpegPartManager, 'JpegPartManager', ImagePartManagerBase.$);
    JpegPartManager.y = new JpegPartManager();
    return JpegPartManager;
}(ImagePartManagerBase));
export { JpegPartManager };
var PngPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(PngPartManager, _super);
    function PngPartManager() {
        return _super.call(this) || this;
    }
    PngPartManager.prototype.get_s = function () {
        return "/xl/media/image.png";
    };
    Object.defineProperty(PngPartManager.prototype, "s", {
        get: function () {
            return this.get_s();
        },
        enumerable: true,
        configurable: true
    });
    PngPartManager.prototype.get_t = function () {
        return "/ppt/media/image.png";
    };
    Object.defineProperty(PngPartManager.prototype, "t", {
        get: function () {
            return this.get_t();
        },
        enumerable: true,
        configurable: true
    });
    PngPartManager.prototype.get_u = function () {
        return "/word/media/image.png";
    };
    Object.defineProperty(PngPartManager.prototype, "u", {
        get: function () {
            return this.get_u();
        },
        enumerable: true,
        configurable: true
    });
    PngPartManager.prototype.get_m = function () {
        return "image/png";
    };
    Object.defineProperty(PngPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    PngPartManager.prototype.r = function (a) {
        return ImageFormat.f;
    };
    PngPartManager.$t = markType(PngPartManager, 'PngPartManager', ImagePartManagerBase.$);
    PngPartManager.y = new PngPartManager();
    return PngPartManager;
}(ImagePartManagerBase));
export { PngPartManager };
var PrinterSettingsPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(PrinterSettingsPartManager, _super);
    function PrinterSettingsPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PrinterSettingsPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl" + "/printerSettings/printerSettings.bin";
            default: return null;
        }
    };
    PrinterSettingsPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return PrinterSettingsPartManager.a6;
            case 1: return PrinterSettingsPartManager.a5;
            default: return PrinterSettingsPartManager.a6;
        }
    };
    PrinterSettingsPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(PrinterSettingsPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    PrinterSettingsPartManager.prototype.a = function () {
        return WorkItem.g(Base.$, new BinaryData(DocCoreUtils.c(this.l)));
    };
    PrinterSettingsPartManager.prototype.b = function (a) {
        var b = typeCast(BinaryData.$, a);
        if (b == null) {
            return null;
        }
        this.l.write(b.a, 0, b.a.length);
        return null;
    };
    PrinterSettingsPartManager.prototype.u = function (a) {
        throw new InvalidOperationException(0);
    };
    PrinterSettingsPartManager.$t = markType(PrinterSettingsPartManager, 'PrinterSettingsPartManager', XmlPartManagerBase.$);
    PrinterSettingsPartManager.a3 = "application/vnd.openxmlformats-officedocument.spreadsheetml.printerSettings";
    PrinterSettingsPartManager.a4 = "application/vnd.openxmlformats-officedocument.wordprocessingml.printerSettings";
    PrinterSettingsPartManager.a6 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/printerSettings";
    PrinterSettingsPartManager.a5 = "http://purl.oclc.org/ooxml/officeDocument/relationships/printerSettings";
    return PrinterSettingsPartManager;
}(XmlPartManagerBase));
export { PrinterSettingsPartManager };
var RoundTripDataPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(RoundTripDataPartManager, _super);
    function RoundTripDataPartManager(a, b, c, d) {
        var _this = _super.call(this) || this;
        _this.u = null;
        _this.v = null;
        _this.w = null;
        _this.t = null;
        _this.u = a;
        _this.v = b;
        _this.w = c;
        _this.t = d;
        return _this;
    }
    RoundTripDataPartManager.prototype.a = function () {
        return WorkItem.g(Base.$, new BinaryData(DocCoreUtils.c(this.l)));
    };
    RoundTripDataPartManager.prototype.b = function (a) {
        var b = typeCast(BinaryData.$, a);
        if (b == null) {
            return null;
        }
        this.l.write(b.a, 0, b.a.length);
        return null;
    };
    RoundTripDataPartManager.prototype.n = function (a) {
        return this.v;
    };
    RoundTripDataPartManager.prototype.o = function (a) {
        return this.t._a7(a, this.w);
    };
    RoundTripDataPartManager.prototype.get_m = function () {
        return this.u;
    };
    Object.defineProperty(RoundTripDataPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    RoundTripDataPartManager.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(RoundTripDataPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    RoundTripDataPartManager.r = function (a, b, c) {
        var d = new RoundTripControlData(c, a._d.uri.toString(), DocCoreUtils.c(b));
        var _loop_3 = function (e) {
            if (e.targetMode != 0) {
                return "continue";
            }
            var f = typeCast(BinaryData.$, a._as(e));
            if (f == null) {
                return "continue";
            }
            var g = PackageUtilities.ak(e);
            var h = a._e(g);
            var i = PackageUtilities.ak(e).toString();
            d.c.add(((function () {
                var $ret = new RoundTripPartData();
                $ret.b = h.contentType;
                $ret.d = e.id;
                $ret.a = f;
                $ret.e = e.relationshipType;
                $ret.c = g.toString();
                return $ret;
            })()));
        };
        try {
            for (var _0 = tslib_1.__values(fromEnum(a._d.getRelationships())), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                _loop_3(e);
            }
        }
        catch (e_28_1) { e_28 = { error: e_28_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_28) throw e_28.error; }
        }
        return d;
        var e_28, _2;
    };
    RoundTripDataPartManager.s = function (a, b, c, d) {
        if (d === void 0) { d = false; }
        return WorkItemExtensions.a(Async.d(RoundTripPartData.$, a.c, function (e) {
            if (d) {
                var f = ((function (g) { return g != null ? g : e.e; })(b._a7(b._z, e.e)));
                var g = new RoundTripDataPartManager(e.b, e.c, f, b);
                return b._j(g, e.a, e.d);
            }
            return WorkItemExtensions.e(Tuple$2.$.specialize(Uri.$, String_$type), b._l(e.b, e.c, e.a, e.d), function (h) {
            });
        }), function () { return c.write(a.a, 0, a.a.length); });
    };
    RoundTripDataPartManager.$t = markType(RoundTripDataPartManager, 'RoundTripDataPartManager', PartManagerBase.$);
    return RoundTripDataPartManager;
}(PartManagerBase));
export { RoundTripDataPartManager };
var ThemeManagerPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(ThemeManagerPartManager, _super);
    function ThemeManagerPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ThemeManagerPartManager.prototype.get_m = function () {
        return ThemeManagerPartManager.a2;
    };
    Object.defineProperty(ThemeManagerPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    ThemeManagerPartManager.prototype.n = function (a) {
        switch (a) {
            case 0:
            case 1: return "/theme/theme/themeManager.xml";
            default: return null;
        }
    };
    ThemeManagerPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return ThemeManagerPartManager.a5;
            case 1: return ThemeManagerPartManager.a4;
            default: return ThemeManagerPartManager.a5;
        }
    };
    ThemeManagerPartManager.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(ThemeManagerPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ThemeManagerPartManager.$t = markType(ThemeManagerPartManager, 'ThemeManagerPartManager', XmlPartManagerBase.$);
    ThemeManagerPartManager.a2 = "application/vnd.openxmlformats-officedocument.themeManager+xml";
    ThemeManagerPartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument";
    ThemeManagerPartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/officeDocument";
    return ThemeManagerPartManager;
}(XmlPartManagerBase));
export { ThemeManagerPartManager };
var ThemePartManager = /** @class */ (function (_super) {
    tslib_1.__extends(ThemePartManager, _super);
    function ThemePartManager(a) {
        var _this = _super.call(this) || this;
        _this.a2 = false;
        _this.a2 = a;
        return _this;
    }
    ThemePartManager.prototype.get_m = function () {
        return ThemePartManager.a6;
    };
    Object.defineProperty(ThemePartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    ThemePartManager.prototype.n = function (a) {
        if (this.a2) {
            switch (a) {
                case 0: return "/theme/theme/theme.xml";
                case 1: return "/theme/theme/theme.xml";
                default: return null;
            }
        }
        else {
            switch (a) {
                case 0: return "/xl/theme/theme.xml";
                case 1: return "/word/theme/theme.xml";
                default: return null;
            }
        }
    };
    ThemePartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return ThemePartManager.a8;
            case 1: return ThemePartManager.a7;
            default: return ThemePartManager.a8;
        }
    };
    ThemePartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(ThemePartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ThemePartManager.prototype.a = function () {
        this.d._af = true;
        return _super.prototype.a.call(this);
    };
    ThemePartManager.$t = markType(ThemePartManager, 'ThemePartManager', XmlPartManagerBase.$);
    ThemePartManager.a6 = "application/vnd.openxmlformats-officedocument.theme+xml";
    ThemePartManager.a8 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/theme";
    ThemePartManager.a7 = "http://purl.oclc.org/ooxml/officeDocument/relationships/theme";
    return ThemePartManager;
}(XmlPartManagerBase));
export { ThemePartManager };
var TiffPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(TiffPartManager, _super);
    function TiffPartManager() {
        return _super.call(this) || this;
    }
    TiffPartManager.prototype.get_s = function () {
        return "/xl/media/image.tiff";
    };
    Object.defineProperty(TiffPartManager.prototype, "s", {
        get: function () {
            return this.get_s();
        },
        enumerable: true,
        configurable: true
    });
    TiffPartManager.prototype.get_t = function () {
        return "/ppt/media/image.tiff";
    };
    Object.defineProperty(TiffPartManager.prototype, "t", {
        get: function () {
            return this.get_t();
        },
        enumerable: true,
        configurable: true
    });
    TiffPartManager.prototype.get_u = function () {
        return "/word/media/image.tiff";
    };
    Object.defineProperty(TiffPartManager.prototype, "u", {
        get: function () {
            return this.get_u();
        },
        enumerable: true,
        configurable: true
    });
    TiffPartManager.prototype.get_m = function () {
        return "image/tiff";
    };
    Object.defineProperty(TiffPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    TiffPartManager.prototype.r = function (a) {
        return ImageFormat.g;
    };
    TiffPartManager.$t = markType(TiffPartManager, 'TiffPartManager', ImagePartManagerBase.$);
    TiffPartManager.y = new TiffPartManager();
    return TiffPartManager;
}(ImagePartManagerBase));
export { TiffPartManager };
var VbaProjectPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(VbaProjectPartManager, _super);
    function VbaProjectPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VbaProjectPartManager.prototype.get_m = function () {
        return "application/vnd.ms-office.vbaProject";
    };
    Object.defineProperty(VbaProjectPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    VbaProjectPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/vbaProject.bin";
            case 1: return "/word/vbaProject.bin";
            default: return null;
        }
    };
    VbaProjectPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return VbaProjectPartManager.u;
            case 1: return VbaProjectPartManager.u;
            default: return VbaProjectPartManager.u;
        }
    };
    VbaProjectPartManager.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(VbaProjectPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    VbaProjectPartManager.$t = markType(VbaProjectPartManager, 'VbaProjectPartManager', PartManagerBase.$);
    VbaProjectPartManager.u = "http://schemas.microsoft.com/office/2006/relationships/vbaProject";
    return VbaProjectPartManager;
}(PartManagerBase));
export { VbaProjectPartManager };
var VmlDrawingPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(VmlDrawingPartManager, _super);
    function VmlDrawingPartManager(a) {
        var _this = _super.call(this) || this;
        _this.a2 = false;
        _this.a2 = a;
        return _this;
    }
    VmlDrawingPartManager.prototype.get_m = function () {
        return VmlDrawingPartManager.a6;
    };
    Object.defineProperty(VmlDrawingPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    VmlDrawingPartManager.prototype.a0 = function () {
        var _this = this;
        return ((function () {
            var $ret = new SgmlReader();
            $ret._b7 = new StreamReader(_this.l);
            return $ret;
        })());
    };
    VmlDrawingPartManager.prototype.n = function (a) {
        if (this.a2) {
            switch (a) {
                case 1: return "/theme/drawings/vmlDrawing.vml";
                default: return null;
            }
        }
        else {
            switch (a) {
                case 0: return "/xl/drawings/vmlDrawing.vml";
                case 1: return "/word/drawings/vmlDrawing.vml";
                default: return null;
            }
        }
    };
    VmlDrawingPartManager.prototype.o = function (a) {
        switch (a) {
            case 0:
            case 1: return VmlDrawingPartManager.a7;
            default: return VmlDrawingPartManager.a7;
        }
    };
    VmlDrawingPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(VmlDrawingPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    VmlDrawingPartManager.$t = markType(VmlDrawingPartManager, 'VmlDrawingPartManager', XmlPartManagerBase.$);
    VmlDrawingPartManager.a6 = "application/vnd.openxmlformats-officedocument.vmlDrawing";
    VmlDrawingPartManager.a7 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/vmlDrawing";
    return VmlDrawingPartManager;
}(XmlPartManagerBase));
export { VmlDrawingPartManager };
var WmfPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(WmfPartManager, _super);
    function WmfPartManager() {
        return _super.call(this) || this;
    }
    WmfPartManager.prototype.get_s = function () {
        return "/xl/media/image.wmf";
    };
    Object.defineProperty(WmfPartManager.prototype, "s", {
        get: function () {
            return this.get_s();
        },
        enumerable: true,
        configurable: true
    });
    WmfPartManager.prototype.get_t = function () {
        return "/ppt/media/image.wmf";
    };
    Object.defineProperty(WmfPartManager.prototype, "t", {
        get: function () {
            return this.get_t();
        },
        enumerable: true,
        configurable: true
    });
    WmfPartManager.prototype.get_u = function () {
        return "/word/media/image.wmf";
    };
    Object.defineProperty(WmfPartManager.prototype, "u", {
        get: function () {
            return this.get_u();
        },
        enumerable: true,
        configurable: true
    });
    WmfPartManager.prototype.get_m = function () {
        return "image/x-wmf";
    };
    Object.defineProperty(WmfPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    WmfPartManager.prototype.r = function (a) {
        return ImageFormat.h;
    };
    WmfPartManager.$t = markType(WmfPartManager, 'WmfPartManager', ImagePartManagerBase.$);
    WmfPartManager.y = new WmfPartManager();
    return WmfPartManager;
}(ImagePartManagerBase));
export { WmfPartManager };
var XmlNamespaceDefinitionBase = /** @class */ (function (_super) {
    tslib_1.__extends(XmlNamespaceDefinitionBase, _super);
    function XmlNamespaceDefinitionBase() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    XmlNamespaceDefinitionBase.k = function (a, b) {
    };
    XmlNamespaceDefinitionBase.g = function ($t, a, b, c) {
        if (c == false && EqualityComparer$1.defaultEqualityComparerValue($t).equalsC(a, b)) {
            return null;
        }
        return XmlNamespaceDefinitionBase.f($t, a);
    };
    XmlNamespaceDefinitionBase.f = function ($t, value_) {
        var a = $t;
        if (a == ST_FillMethod_$type && Base.equalsStatic(getBoxIfEnum($t, value_), enumGetBox(ST_FillMethod_$type, 4))) {
            return "linear sigma";
        }
        var b = stringToString$1($t, value_);
        if (b.charAt(0) == '_') {
            return b.substr(1);
        }
        return b;
    };
    XmlNamespaceDefinitionBase.h = function (a) {
        var b = a.lastIndexOf('/');
        if (b < 0) {
            return a;
        }
        return a.substr(b + 1);
    };
    XmlNamespaceDefinitionBase.b = function ($t, a, b) {
        if (b === void 0) { b = Type.createInstance($t); }
        if (stringIsNullOrEmpty(a)) {
            return b;
        }
        var c = false;
        switch (a) {
            case "continue":
            case "decimal":
            case "default":
            case "double":
            case "fixed":
            case "long":
            case "short":
                c = true;
                break;
            case "linear sigma":
                a = EnumUtil.getName(ST_FillMethod_$type, 4);
                break;
            default:
                if ('0'.charCodeAt(0) <= a.charAt(0).charCodeAt(0) && a.charAt(0).charCodeAt(0) <= '9'.charCodeAt(0)) {
                    c = true;
                }
                break;
        }
        var d;
        if (c == false && ((function () { var e = EnumUtil.tryParse$1($t, a, false, d); d = e.p2; return e.ret; })())) {
            return d;
        }
        if (((function () { var e = EnumUtil.tryParse$1($t, "_" + a, false, d); d = e.p2; return e.ret; })())) {
            return d;
        }
        return b;
    };
    XmlNamespaceDefinitionBase.c = function ($t, a, b, c) {
        if (stringIsNullOrEmpty(a.d)) {
            return b;
        }
        return c(a.d);
    };
    XmlNamespaceDefinitionBase.e = function ($t, a, b) {
        var c = new List$1($t, 0);
        var d = -1;
        for (var e = 0; e < a.length; e++) {
            switch (a.charAt(e)) {
                case ' ':
                case '\t':
                case '\r':
                case '\n':
                    if (d != -1) {
                        c.add(b(a.substr(d, e - d)));
                        d = -1;
                    }
                    break;
                default:
                    if (d == -1) {
                        d = e;
                    }
                    break;
            }
        }
        if (d != -1) {
            c.add(b(a.substr(d)));
        }
        return c;
    };
    XmlNamespaceDefinitionBase.l = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_29_1) { e_29 = { error: e_29_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_29) throw e_29.error; }
        }
        if (((function () { var e = tryParseBool(a.ab.ad, c); c = e.p1; return e.ret; })()) == false) {
            c = ST_OnOff.e(a.ab.ad);
        }
        return {
            p2: c
        };
        var e_29, _2;
    };
    XmlNamespaceDefinitionBase.z = function (a, b, c, d) {
        a.ad.p(b, c);
        a.ad.u(d.toString().toLowerCase());
    };
    XmlNamespaceDefinitionBase.m = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_30_1) { e_30 = { error: e_30_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_30) throw e_30.error; }
        }
        c = parseInt8_1(a.ab.ad, CultureInfo.invariantCulture);
        return {
            p2: c
        };
        var e_30, _2;
    };
    XmlNamespaceDefinitionBase.aa = function (a, b, c, d) {
        a.ad.p(b, c);
        a.ad.u(d.toString());
    };
    XmlNamespaceDefinitionBase.n = function (a, b, c) {
        var d = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case XmlSchemaInstance.aq:
                        d = a.ab.ag(e.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_31_1) { e_31 = { error: e_31_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_31) throw e_31.error; }
        }
        c = PackageUtilities.i(a.ab.ad);
        return {
            p2: c
        };
        var e_31, _2;
    };
    XmlNamespaceDefinitionBase.ab = function (a, b, c, d) {
        a.ad.p(b, c);
        var e = new QualifiedNameInfo(1, DcTerms.an.j, DcTerms.an.i(a.d._z), XmlNamespaceDefinitionBase.h("http://purl.org/dc/terms/W3CDTF"));
        a.ad.h(XmlSchemaInstance.aq, e.toString());
        a.ad.u(PackageUtilities.k(d));
    };
    XmlNamespaceDefinitionBase.o = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_32_1) { e_32 = { error: e_32_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_32) throw e_32.error; }
        }
        c = parseNumber(a.ab.ad, CultureInfo.invariantCulture);
        return {
            p2: c
        };
        var e_32, _2;
    };
    XmlNamespaceDefinitionBase.ac = function (a, b, c, d) {
        a.ad.p(b, c);
        a.ad.u(numberToString(d, CultureInfo.invariantCulture));
    };
    XmlNamespaceDefinitionBase.p = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_33_1) { e_33 = { error: e_33_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_33) throw e_33.error; }
        }
        c = parseNumber(a.ab.ad, CultureInfo.invariantCulture);
        return {
            p2: c
        };
        var e_33, _2;
    };
    XmlNamespaceDefinitionBase.ad = function (a, b, c, d) {
        a.ad.p(b, c);
        a.ad.u(numberToString(d, CultureInfo.invariantCulture));
    };
    XmlNamespaceDefinitionBase.q = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_34_1) { e_34 = { error: e_34_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_34) throw e_34.error; }
        }
        c = parseNumber(a.ab.ad, CultureInfo.invariantCulture);
        return {
            p2: c
        };
        var e_34, _2;
    };
    XmlNamespaceDefinitionBase.ae = function (a, b, c, d) {
        a.ad.p(b, c);
        a.ad.u(numberToString(d, CultureInfo.invariantCulture));
    };
    XmlNamespaceDefinitionBase.r = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_35_1) { e_35 = { error: e_35_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_35) throw e_35.error; }
        }
        c = parseInt32_1(a.ab.ad, CultureInfo.invariantCulture);
        return {
            p2: c
        };
        var e_35, _2;
    };
    XmlNamespaceDefinitionBase.af = function (a, b, c, d) {
        a.ad.p(b, c);
        a.ad.u(d.toString());
    };
    XmlNamespaceDefinitionBase.s = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_36_1) { e_36 = { error: e_36_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_36) throw e_36.error; }
        }
        c = parseInt64_1(a.ab.ad, CultureInfo.invariantCulture);
        return {
            p2: c
        };
        var e_36, _2;
    };
    XmlNamespaceDefinitionBase.ag = function (a, b, c, d) {
        a.ad.p(b, c);
        a.ad.u(d.toString());
    };
    XmlNamespaceDefinitionBase.t = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_37_1) { e_37 = { error: e_37_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_37) throw e_37.error; }
        }
        c = parseInt16_1(a.ab.ad, CultureInfo.invariantCulture);
        return {
            p2: c
        };
        var e_37, _2;
    };
    XmlNamespaceDefinitionBase.ah = function (a, b, c, d) {
        a.ad.p(b, c);
        a.ad.u(d.toString());
    };
    XmlNamespaceDefinitionBase.d = function (a) {
        switch (a) {
            case ' ':
            case '\r':
            case '\n':
            case '\t': return true;
            default: return false;
        }
    };
    XmlNamespaceDefinitionBase.u = function (a, b, c, d) {
        if (d === void 0) { d = 0; }
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case XmlNamespace.ar:
                        if (e.d == "preserve") {
                            d = 6;
                        }
                        break;
                    default: break;
                }
            }
        }
        catch (e_38_1) { e_38 = { error: e_38_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_38) throw e_38.error; }
        }
        c = a.ab.ad;
        if (c != null) {
            if ((d & 2) == 0) {
                c = trimStart.apply(void 0, tslib_1.__spread([c], XmlNamespaceDefinitionBase.a));
            }
            if ((d & 4) == 0 && stringIsNullOrWhiteSpace(c) == false) {
                c = trimEnd.apply(void 0, tslib_1.__spread([c], XmlNamespaceDefinitionBase.a));
            }
        }
        return {
            p2: c
        };
        var e_38, _2;
    };
    XmlNamespaceDefinitionBase.ai = function (a, b, c, d, e, f) {
        if (e === void 0) { e = null; }
        if (f === void 0) { f = 0; }
        a.ad.p(b, c);
        if (f != 6) {
            if (stringIsNullOrEmpty(d) == false) {
                if ((XmlNamespaceDefinitionBase.d(d.charAt(0)) && (f & 2) == 0) || (XmlNamespaceDefinitionBase.d(d.charAt(d.length - 1)) && (f & 4) == 0)) {
                    XmlNamespace.as(a.ad);
                }
            }
        }
        if (e != null) {
            e();
        }
        a.ad.u(d);
    };
    XmlNamespaceDefinitionBase.v = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_39_1) { e_39 = { error: e_39_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_39) throw e_39.error; }
        }
        c = parseUInt8_1(a.ab.ad, CultureInfo.invariantCulture);
        return {
            p2: c
        };
        var e_39, _2;
    };
    XmlNamespaceDefinitionBase.aj = function (a, b, c, d) {
        a.ad.p(b, c);
        a.ad.u(d.toString());
    };
    XmlNamespaceDefinitionBase.w = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_40_1) { e_40 = { error: e_40_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_40) throw e_40.error; }
        }
        c = parseUInt32_1(a.ab.ad, CultureInfo.invariantCulture);
        return {
            p2: c
        };
        var e_40, _2;
    };
    XmlNamespaceDefinitionBase.ak = function (a, b, c, d) {
        a.ad.p(b, c);
        a.ad.u(d.toString());
    };
    XmlNamespaceDefinitionBase.x = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_41_1) { e_41 = { error: e_41_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_41) throw e_41.error; }
        }
        c = parseUInt64_1(a.ab.ad, CultureInfo.invariantCulture);
        return {
            p2: c
        };
        var e_41, _2;
    };
    XmlNamespaceDefinitionBase.al = function (a, b, c, d) {
        a.ad.p(b, c);
        a.ad.u(d.toString());
    };
    XmlNamespaceDefinitionBase.y = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_42_1) { e_42 = { error: e_42_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_42) throw e_42.error; }
        }
        c = parseUInt16_1(a.ab.ad, CultureInfo.invariantCulture);
        return {
            p2: c
        };
        var e_42, _2;
    };
    XmlNamespaceDefinitionBase.am = function (a, b, c, d) {
        a.ad.p(b, c);
        a.ad.u(d.toString());
    };
    XmlNamespaceDefinitionBase.$t = markType(XmlNamespaceDefinitionBase, 'XmlNamespaceDefinitionBase');
    XmlNamespaceDefinitionBase.a = [' ', '\r', '\n', '\t'];
    return XmlNamespaceDefinitionBase;
}(Base));
export { XmlNamespaceDefinitionBase };
var CoreProperties = /** @class */ (function (_super) {
    tslib_1.__extends(CoreProperties, _super);
    function CoreProperties() {
        return _super.call(this) || this;
    }
    CoreProperties.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return CoreProperties.au;
            default: return CoreProperties.au;
        }
    };
    CoreProperties.prototype.get_j = function () {
        return "cp";
    };
    Object.defineProperty(CoreProperties.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    CoreProperties.ax = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, CoreProperties.ap, b, 6);
        b = c.p2;
        return {
            p1: b
        };
    };
    CoreProperties.a4 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, CoreProperties.ap, "cp", b, void 0, 6);
    };
    CoreProperties.ay = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, CoreProperties.aq, b, 6);
        b = c.p2;
        return {
            p1: b
        };
    };
    CoreProperties.a5 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, CoreProperties.aq, "cp", b, void 0, 6);
    };
    CoreProperties.az = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_43_1) { e_43 = { error: e_43_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_43) throw e_43.error; }
        }
        var e_43, _2;
    };
    CoreProperties.a6 = function (a) {
        a.ad.p(CoreProperties.ar, "cp");
        var b = a.d._z;
        a.ad.l(CoreProperties.an);
        a.ad.l(DcElements.an);
        a.ad.l(DcTerms.an);
        a.ad.l(DcDcmiType.an);
        a.ad.l(XmlSchemaInstance.an);
    };
    CoreProperties.a0 = function (a, b, c) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case XmlNamespace.ap:
                        b = d.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_44_1) { e_44 = { error: e_44_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_44) throw e_44.error; }
        }
        c = a.ab.ad;
        return {
            p1: b,
            p2: c
        };
        var e_44, _2;
    };
    CoreProperties.a7 = function (a, b, c) {
        a.ad.p(CoreProperties.as, "cp");
        var d;
        d = b;
        a.ad.h(XmlNamespace.ap, d);
        a.ad.u(c);
    };
    CoreProperties.a1 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, CoreProperties.at, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    CoreProperties.a8 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, CoreProperties.at, "cp", b);
    };
    CoreProperties.a2 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, CoreProperties.av, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    CoreProperties.a9 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, CoreProperties.av, "cp", b);
    };
    CoreProperties.a3 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, CoreProperties.aw, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    CoreProperties.ba = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, CoreProperties.aw, "cp", b);
    };
    CoreProperties.$t = markType(CoreProperties, 'CoreProperties', XmlNamespaceDefinitionBase.$);
    CoreProperties.au = "http://schemas.openxmlformats.org/package/2006/metadata/core-properties";
    CoreProperties.ap = CoreProperties.au + "/category";
    CoreProperties.aq = CoreProperties.au + "/contentStatus";
    CoreProperties.ar = CoreProperties.au + "/coreProperties";
    CoreProperties.as = CoreProperties.au + "/keywords";
    CoreProperties.at = CoreProperties.au + "/lastModifiedBy";
    CoreProperties.av = CoreProperties.au + "/revision";
    CoreProperties.aw = CoreProperties.au + "/version";
    CoreProperties.an = new CoreProperties();
    return CoreProperties;
}(XmlNamespaceDefinitionBase));
export { CoreProperties };
var DcDcmiType = /** @class */ (function (_super) {
    tslib_1.__extends(DcDcmiType, _super);
    function DcDcmiType() {
        return _super.call(this) || this;
    }
    DcDcmiType.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return "http://purl.org/dc/dcmitype/";
            default: return "http://purl.org/dc/dcmitype/";
        }
    };
    DcDcmiType.prototype.get_j = function () {
        return "dcmitype";
    };
    Object.defineProperty(DcDcmiType.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    DcDcmiType.$t = markType(DcDcmiType, 'DcDcmiType', XmlNamespaceDefinitionBase.$);
    DcDcmiType.an = new DcDcmiType();
    return DcDcmiType;
}(XmlNamespaceDefinitionBase));
export { DcDcmiType };
var DcElements = /** @class */ (function (_super) {
    tslib_1.__extends(DcElements, _super);
    function DcElements() {
        return _super.call(this) || this;
    }
    DcElements.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return "http://purl.org/dc/elements/1.1/";
            default: return "http://purl.org/dc/elements/1.1/";
        }
    };
    DcElements.prototype.get_j = function () {
        return "dc";
    };
    Object.defineProperty(DcElements.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    DcElements.au = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, "http://purl.org/dc/elements/1.1/creator", b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DcElements.ay = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, "http://purl.org/dc/elements/1.1/creator", "dc", b);
    };
    DcElements.av = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, DcElements.aq, b, 6);
        b = c.p2;
        return {
            p1: b
        };
    };
    DcElements.az = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, DcElements.aq, "dc", b, void 0, 6);
    };
    DcElements.aw = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, "http://purl.org/dc/elements/1.1/subject", b, 6);
        b = c.p2;
        return {
            p1: b
        };
    };
    DcElements.a0 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, "http://purl.org/dc/elements/1.1/subject", "dc", b, void 0, 6);
    };
    DcElements.ax = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, "http://purl.org/dc/elements/1.1/title", b, 6);
        b = c.p2;
        return {
            p1: b
        };
    };
    DcElements.a1 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, "http://purl.org/dc/elements/1.1/title", "dc", b, void 0, 6);
    };
    DcElements.$t = markType(DcElements, 'DcElements', XmlNamespaceDefinitionBase.$);
    DcElements.aq = "http://purl.org/dc/elements/1.1/" + "description";
    DcElements.an = new DcElements();
    return DcElements;
}(XmlNamespaceDefinitionBase));
export { DcElements };
var DcTerms = /** @class */ (function (_super) {
    tslib_1.__extends(DcTerms, _super);
    function DcTerms() {
        return _super.call(this) || this;
    }
    DcTerms.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return "http://purl.org/dc/terms/";
            default: return "http://purl.org/dc/terms/";
        }
    };
    DcTerms.prototype.get_j = function () {
        return "dcterms";
    };
    Object.defineProperty(DcTerms.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    DcTerms.at = function (a, b) {
        var c = XmlNamespaceDefinitionBase.n(a, "http://purl.org/dc/terms/created", b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DcTerms.av = function (a, b) {
        XmlNamespaceDefinitionBase.ab(a, "http://purl.org/dc/terms/created", "dcterms", b);
    };
    DcTerms.au = function (a, b) {
        var c = XmlNamespaceDefinitionBase.n(a, "http://purl.org/dc/terms/modified", b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DcTerms.aw = function (a, b) {
        XmlNamespaceDefinitionBase.ab(a, "http://purl.org/dc/terms/modified", "dcterms", b);
    };
    DcTerms.$t = markType(DcTerms, 'DcTerms', XmlNamespaceDefinitionBase.$);
    DcTerms.an = new DcTerms();
    return DcTerms;
}(XmlNamespaceDefinitionBase));
export { DcTerms };
var Drawing2010Main = /** @class */ (function (_super) {
    tslib_1.__extends(Drawing2010Main, _super);
    function Drawing2010Main() {
        return _super.call(this) || this;
    }
    Drawing2010Main.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return Drawing2010Main.ap;
            default: return Drawing2010Main.ap;
        }
    };
    Drawing2010Main.prototype.get_j = function () {
        return "a14";
    };
    Object.defineProperty(Drawing2010Main.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    Drawing2010Main.$t = markType(Drawing2010Main, 'Drawing2010Main', XmlNamespaceDefinitionBase.$);
    Drawing2010Main.ap = "http://schemas.microsoft.com/office/drawing/2010/main";
    Drawing2010Main.an = new Drawing2010Main();
    return Drawing2010Main;
}(XmlNamespaceDefinitionBase));
export { Drawing2010Main };
var Drawing2010Slicer = /** @class */ (function (_super) {
    tslib_1.__extends(Drawing2010Slicer, _super);
    function Drawing2010Slicer() {
        return _super.call(this) || this;
    }
    Drawing2010Slicer.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return Drawing2010Slicer.ar;
            default: return Drawing2010Slicer.ar;
        }
    };
    Drawing2010Slicer.prototype.get_j = function () {
        return "sle";
    };
    Object.defineProperty(Drawing2010Slicer.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    Drawing2010Slicer.at = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "name":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_45_1) { e_45 = { error: e_45_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_45) throw e_45.error; }
        }
        return {
            p1: b
        };
        var e_45, _2;
    };
    Drawing2010Slicer.au = function (a, b) {
        a.ad.p(Drawing2010Slicer.as, "sle");
        var c;
        c = b;
        a.ad.h("name", c);
    };
    Drawing2010Slicer.$t = markType(Drawing2010Slicer, 'Drawing2010Slicer', XmlNamespaceDefinitionBase.$);
    Drawing2010Slicer.ar = "http://schemas.microsoft.com/office/drawing/2010/slicer";
    Drawing2010Slicer.as = Drawing2010Slicer.ar + "/slicer";
    Drawing2010Slicer.an = new Drawing2010Slicer();
    return Drawing2010Slicer;
}(XmlNamespaceDefinitionBase));
export { Drawing2010Slicer };
var DrawingMLChart = /** @class */ (function (_super) {
    tslib_1.__extends(DrawingMLChart, _super);
    function DrawingMLChart() {
        return _super.call(this) || this;
    }
    DrawingMLChart.prototype.i = function (a) {
        switch (a) {
            case 0: return DrawingMLChart.dx;
            case 1: return DrawingMLChart.dw;
            default: return DrawingMLChart.dx;
        }
    };
    DrawingMLChart.prototype.get_j = function () {
        return "c";
    };
    Object.defineProperty(DrawingMLChart.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    DrawingMLChart.gx = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_46_1) { e_46 = { error: e_46_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_46) throw e_46.error; }
        }
        return {
            p1: b
        };
        var e_46, _2;
    };
    DrawingMLChart.gy = function (a, b) {
        if (b === void 0) { b = null; }
        a.ad.p(DrawingMLChart.be, "c");
        a.ad.l(DrawingMLChart.an);
        a.ad.l(OfficeDocumentRelationships.an);
        var c;
        c = b;
        a.ad.h(OfficeDocumentRelationships.ar, c);
    };
    DrawingMLChart.$t = markType(DrawingMLChart, 'DrawingMLChart', XmlNamespaceDefinitionBase.$);
    DrawingMLChart.dx = "http://schemas.openxmlformats.org/drawingml/2006/chart";
    DrawingMLChart.dw = "http://purl.oclc.org/ooxml/drawingml/chart";
    DrawingMLChart.ap = DrawingMLChart.dw + "/applyToEnd";
    DrawingMLChart.aq = DrawingMLChart.dw + "/applyToFront";
    DrawingMLChart.ar = DrawingMLChart.dw + "/applyToSides";
    DrawingMLChart.as = DrawingMLChart.dw + "/area3DChart";
    DrawingMLChart.at = DrawingMLChart.dw + "/areaChart";
    DrawingMLChart.au = DrawingMLChart.dw + "/auto";
    DrawingMLChart.av = DrawingMLChart.dw + "/autoTitleDeleted";
    DrawingMLChart.aw = DrawingMLChart.dw + "/autoUpdate";
    DrawingMLChart.ax = DrawingMLChart.dw + "/axId";
    DrawingMLChart.ay = DrawingMLChart.dw + "/axPos";
    DrawingMLChart.az = DrawingMLChart.dw + "/backWall";
    DrawingMLChart.a0 = DrawingMLChart.dw + "/backward";
    DrawingMLChart.a1 = DrawingMLChart.dw + "/bandFmt";
    DrawingMLChart.a2 = DrawingMLChart.dw + "/bandFmts";
    DrawingMLChart.a3 = DrawingMLChart.dw + "/bar3DChart";
    DrawingMLChart.a4 = DrawingMLChart.dw + "/barChart";
    DrawingMLChart.a5 = DrawingMLChart.dw + "/barDir";
    DrawingMLChart.a6 = DrawingMLChart.dw + "/baseTimeUnit";
    DrawingMLChart.a7 = DrawingMLChart.dw + "/bubble3D";
    DrawingMLChart.a8 = DrawingMLChart.dw + "/bubbleChart";
    DrawingMLChart.a9 = DrawingMLChart.dw + "/bubbleScale";
    DrawingMLChart.ba = DrawingMLChart.dw + "/bubbleSize";
    DrawingMLChart.bb = DrawingMLChart.dw + "/builtInUnit";
    DrawingMLChart.bc = DrawingMLChart.dw + "/cat";
    DrawingMLChart.bd = DrawingMLChart.dw + "/catAx";
    DrawingMLChart.be = DrawingMLChart.dw + "/chart";
    DrawingMLChart.bf = DrawingMLChart.dw + "/chartObject";
    DrawingMLChart.bg = DrawingMLChart.dw + "/chartSpace";
    DrawingMLChart.bh = DrawingMLChart.dw + "/clrMapOvr";
    DrawingMLChart.bi = DrawingMLChart.dw + "/crossAx";
    DrawingMLChart.bj = DrawingMLChart.dw + "/crossBetween";
    DrawingMLChart.bk = DrawingMLChart.dw + "/crosses";
    DrawingMLChart.bl = DrawingMLChart.dw + "/crossesAt";
    DrawingMLChart.bm = DrawingMLChart.dw + "/custSplit";
    DrawingMLChart.bn = DrawingMLChart.dw + "/custUnit";
    DrawingMLChart.bo = DrawingMLChart.dw + "/data";
    DrawingMLChart.bp = DrawingMLChart.dw + "/date1904";
    DrawingMLChart.bq = DrawingMLChart.dw + "/dateAx";
    DrawingMLChart.br = DrawingMLChart.dw + "/delete";
    DrawingMLChart.bs = DrawingMLChart.dw + "/depthPercent";
    DrawingMLChart.bt = DrawingMLChart.dw + "/dispBlanksAs";
    DrawingMLChart.bu = DrawingMLChart.dw + "/dispEq";
    DrawingMLChart.bv = DrawingMLChart.dw + "/dispRSqr";
    DrawingMLChart.bw = DrawingMLChart.dw + "/dispUnits";
    DrawingMLChart.bx = DrawingMLChart.dw + "/dispUnitsLbl";
    DrawingMLChart.by = DrawingMLChart.dw + "/dLbl";
    DrawingMLChart.bz = DrawingMLChart.dw + "/dLblPos";
    DrawingMLChart.b0 = DrawingMLChart.dw + "/dLbls";
    DrawingMLChart.b1 = DrawingMLChart.dw + "/doughnutChart";
    DrawingMLChart.b2 = DrawingMLChart.dw + "/downBars";
    DrawingMLChart.b3 = DrawingMLChart.dw + "/dPt";
    DrawingMLChart.b4 = DrawingMLChart.dw + "/dropLines";
    DrawingMLChart.b5 = DrawingMLChart.dw + "/dTable";
    DrawingMLChart.b6 = DrawingMLChart.dw + "/errBars";
    DrawingMLChart.b7 = DrawingMLChart.dw + "/errBarType";
    DrawingMLChart.b8 = DrawingMLChart.dw + "/errDir";
    DrawingMLChart.b9 = DrawingMLChart.dw + "/errValType";
    DrawingMLChart.ca = DrawingMLChart.dw + "/evenFooter";
    DrawingMLChart.cb = DrawingMLChart.dw + "/evenHeader";
    DrawingMLChart.cc = DrawingMLChart.dw + "/explosion";
    DrawingMLChart.cd = DrawingMLChart.dw + "/ext";
    DrawingMLChart.ce = DrawingMLChart.dw + "/externalData";
    DrawingMLChart.cf = DrawingMLChart.dw + "/extLst";
    DrawingMLChart.cg = DrawingMLChart.dw + "/f";
    DrawingMLChart.ch = DrawingMLChart.dw + "/firstFooter";
    DrawingMLChart.ci = DrawingMLChart.dw + "/firstHeader";
    DrawingMLChart.cj = DrawingMLChart.dw + "/firstSliceAng";
    DrawingMLChart.ck = DrawingMLChart.dw + "/floor";
    DrawingMLChart.cl = DrawingMLChart.dw + "/fmtId";
    DrawingMLChart.cm = DrawingMLChart.dw + "/formatCode";
    DrawingMLChart.cn = DrawingMLChart.dw + "/formatting";
    DrawingMLChart.co = DrawingMLChart.dw + "/forward";
    DrawingMLChart.cp = DrawingMLChart.dw + "/gapDepth";
    DrawingMLChart.cq = DrawingMLChart.dw + "/gapWidth";
    DrawingMLChart.cr = DrawingMLChart.dw + "/grouping";
    DrawingMLChart.cs = DrawingMLChart.dw + "/h";
    DrawingMLChart.ct = DrawingMLChart.dw + "/headerFooter";
    DrawingMLChart.cu = DrawingMLChart.dw + "/hiLowLines";
    DrawingMLChart.cv = DrawingMLChart.dw + "/hMode";
    DrawingMLChart.cw = DrawingMLChart.dw + "/holeSize";
    DrawingMLChart.cx = DrawingMLChart.dw + "/hPercent";
    DrawingMLChart.cy = DrawingMLChart.dw + "/idx";
    DrawingMLChart.cz = DrawingMLChart.dw + "/intercept";
    DrawingMLChart.c0 = DrawingMLChart.dw + "/invertIfNegative";
    DrawingMLChart.c1 = DrawingMLChart.dw + "/lang";
    DrawingMLChart.c2 = DrawingMLChart.dw + "/layout";
    DrawingMLChart.c3 = DrawingMLChart.dw + "/layoutTarget";
    DrawingMLChart.c4 = DrawingMLChart.dw + "/lblAlgn";
    DrawingMLChart.c5 = DrawingMLChart.dw + "/lblOffset";
    DrawingMLChart.c6 = DrawingMLChart.dw + "/leaderLines";
    DrawingMLChart.c7 = DrawingMLChart.dw + "/legacyDrawingHF";
    DrawingMLChart.c8 = DrawingMLChart.dw + "/legend";
    DrawingMLChart.c9 = DrawingMLChart.dw + "/legendEntry";
    DrawingMLChart.da = DrawingMLChart.dw + "/legendPos";
    DrawingMLChart.db = DrawingMLChart.dw + "/line3DChart";
    DrawingMLChart.dc = DrawingMLChart.dw + "/lineChart";
    DrawingMLChart.dd = DrawingMLChart.dw + "/logBase";
    DrawingMLChart.de = DrawingMLChart.dw + "/lvl";
    DrawingMLChart.df = DrawingMLChart.dw + "/majorGridlines";
    DrawingMLChart.dg = DrawingMLChart.dw + "/majorTickMark";
    DrawingMLChart.dh = DrawingMLChart.dw + "/majorTimeUnit";
    DrawingMLChart.di = DrawingMLChart.dw + "/majorUnit";
    DrawingMLChart.dj = DrawingMLChart.dw + "/manualLayout";
    DrawingMLChart.dk = DrawingMLChart.dw + "/marker";
    DrawingMLChart.dl = DrawingMLChart.dw + "/max";
    DrawingMLChart.dm = DrawingMLChart.dw + "/min";
    DrawingMLChart.dn = DrawingMLChart.dw + "/minorGridlines";
    DrawingMLChart.dp = DrawingMLChart.dw + "/minorTickMark";
    DrawingMLChart.dq = DrawingMLChart.dw + "/minorTimeUnit";
    DrawingMLChart.dr = DrawingMLChart.dw + "/minorUnit";
    DrawingMLChart.ds = DrawingMLChart.dw + "/minus";
    DrawingMLChart.dt = DrawingMLChart.dw + "/multiLvlStrCache";
    DrawingMLChart.du = DrawingMLChart.dw + "/multiLvlStrRef";
    DrawingMLChart.dv = DrawingMLChart.dw + "/name";
    DrawingMLChart.dy = DrawingMLChart.dw + "/noEndCap";
    DrawingMLChart.dz = DrawingMLChart.dw + "/noMultiLvlLbl";
    DrawingMLChart.d0 = DrawingMLChart.dw + "/numCache";
    DrawingMLChart.d1 = DrawingMLChart.dw + "/numFmt";
    DrawingMLChart.d2 = DrawingMLChart.dw + "/numLit";
    DrawingMLChart.d3 = DrawingMLChart.dw + "/numRef";
    DrawingMLChart.d4 = DrawingMLChart.dw + "/oddFooter";
    DrawingMLChart.d5 = DrawingMLChart.dw + "/oddHeader";
    DrawingMLChart.d6 = DrawingMLChart.dw + "/ofPieChart";
    DrawingMLChart.d7 = DrawingMLChart.dw + "/ofPieType";
    DrawingMLChart.d8 = DrawingMLChart.dw + "/order";
    DrawingMLChart.d9 = DrawingMLChart.dw + "/orientation";
    DrawingMLChart.ea = DrawingMLChart.dw + "/overlap";
    DrawingMLChart.eb = DrawingMLChart.dw + "/overlay";
    DrawingMLChart.ec = DrawingMLChart.dw + "/pageMargins";
    DrawingMLChart.ed = DrawingMLChart.dw + "/pageSetup";
    DrawingMLChart.ee = DrawingMLChart.dw + "/period";
    DrawingMLChart.ef = DrawingMLChart.dw + "/perspective";
    DrawingMLChart.eg = DrawingMLChart.dw + "/pictureFormat";
    DrawingMLChart.eh = DrawingMLChart.dw + "/pictureOptions";
    DrawingMLChart.ei = DrawingMLChart.dw + "/pictureStackUnit";
    DrawingMLChart.ej = DrawingMLChart.dw + "/pie3DChart";
    DrawingMLChart.ek = DrawingMLChart.dw + "/pieChart";
    DrawingMLChart.el = DrawingMLChart.dw + "/pivotFmt";
    DrawingMLChart.em = DrawingMLChart.dw + "/pivotFmts";
    DrawingMLChart.en = DrawingMLChart.dw + "/pivotSource";
    DrawingMLChart.eo = DrawingMLChart.dw + "/plotArea";
    DrawingMLChart.ep = DrawingMLChart.dw + "/plotVisOnly";
    DrawingMLChart.eq = DrawingMLChart.dw + "/plus";
    DrawingMLChart.er = DrawingMLChart.dw + "/printSettings";
    DrawingMLChart.es = DrawingMLChart.dw + "/protection";
    DrawingMLChart.et = DrawingMLChart.dw + "/pt";
    DrawingMLChart.eu = DrawingMLChart.dw + "/ptCount";
    DrawingMLChart.ev = DrawingMLChart.dw + "/radarChart";
    DrawingMLChart.ew = DrawingMLChart.dw + "/radarStyle";
    DrawingMLChart.ex = DrawingMLChart.dw + "/rAngAx";
    DrawingMLChart.ey = DrawingMLChart.dw + "/rich";
    DrawingMLChart.ez = DrawingMLChart.dw + "/rotX";
    DrawingMLChart.e0 = DrawingMLChart.dw + "/rotY";
    DrawingMLChart.e1 = DrawingMLChart.dw + "/roundedCorners";
    DrawingMLChart.e2 = DrawingMLChart.dw + "/scaling";
    DrawingMLChart.e3 = DrawingMLChart.dw + "/scatterChart";
    DrawingMLChart.e4 = DrawingMLChart.dw + "/scatterStyle";
    DrawingMLChart.e5 = DrawingMLChart.dw + "/secondPiePt";
    DrawingMLChart.e6 = DrawingMLChart.dw + "/secondPieSize";
    DrawingMLChart.e7 = DrawingMLChart.dw + "/selection";
    DrawingMLChart.e8 = DrawingMLChart.dw + "/separator";
    DrawingMLChart.e9 = DrawingMLChart.dw + "/ser";
    DrawingMLChart.fa = DrawingMLChart.dw + "/serAx";
    DrawingMLChart.fb = DrawingMLChart.dw + "/serLines";
    DrawingMLChart.fc = DrawingMLChart.dw + "/shape";
    DrawingMLChart.fd = DrawingMLChart.dw + "/showBubbleSize";
    DrawingMLChart.fe = DrawingMLChart.dw + "/showCatName";
    DrawingMLChart.ff = DrawingMLChart.dw + "/showDLblsOverMax";
    DrawingMLChart.fg = DrawingMLChart.dw + "/showHorzBorder";
    DrawingMLChart.fh = DrawingMLChart.dw + "/showKeys";
    DrawingMLChart.fi = DrawingMLChart.dw + "/showLeaderLines";
    DrawingMLChart.fj = DrawingMLChart.dw + "/showLegendKey";
    DrawingMLChart.fk = DrawingMLChart.dw + "/showNegBubbles";
    DrawingMLChart.fl = DrawingMLChart.dw + "/showOutline";
    DrawingMLChart.fm = DrawingMLChart.dw + "/showPercent";
    DrawingMLChart.fn = DrawingMLChart.dw + "/showSerName";
    DrawingMLChart.fo = DrawingMLChart.dw + "/showVal";
    DrawingMLChart.fp = DrawingMLChart.dw + "/showVertBorder";
    DrawingMLChart.fq = DrawingMLChart.dw + "/sideWall";
    DrawingMLChart.fr = DrawingMLChart.dw + "/size";
    DrawingMLChart.fs = DrawingMLChart.dw + "/sizeRepresents";
    DrawingMLChart.ft = DrawingMLChart.dw + "/smooth";
    DrawingMLChart.fu = DrawingMLChart.dw + "/splitPos";
    DrawingMLChart.fv = DrawingMLChart.dw + "/splitType";
    DrawingMLChart.fw = DrawingMLChart.dw + "/spPr";
    DrawingMLChart.fx = DrawingMLChart.dw + "/stockChart";
    DrawingMLChart.fy = DrawingMLChart.dw + "/strCache";
    DrawingMLChart.fz = DrawingMLChart.dw + "/strLit";
    DrawingMLChart.f0 = DrawingMLChart.dw + "/strRef";
    DrawingMLChart.f1 = DrawingMLChart.dw + "/style";
    DrawingMLChart.f2 = DrawingMLChart.dw + "/surface3DChart";
    DrawingMLChart.f3 = DrawingMLChart.dw + "/surfaceChart";
    DrawingMLChart.f4 = DrawingMLChart.dw + "/symbol";
    DrawingMLChart.f5 = DrawingMLChart.dw + "/thickness";
    DrawingMLChart.f6 = DrawingMLChart.dw + "/tickLblPos";
    DrawingMLChart.f7 = DrawingMLChart.dw + "/tickLblSkip";
    DrawingMLChart.f8 = DrawingMLChart.dw + "/tickMarkSkip";
    DrawingMLChart.f9 = DrawingMLChart.dw + "/title";
    DrawingMLChart.ga = DrawingMLChart.dw + "/trendline";
    DrawingMLChart.gb = DrawingMLChart.dw + "/trendlineLbl";
    DrawingMLChart.gc = DrawingMLChart.dw + "/trendlineType";
    DrawingMLChart.gd = DrawingMLChart.dw + "/tx";
    DrawingMLChart.ge = DrawingMLChart.dw + "/txPr";
    DrawingMLChart.gf = DrawingMLChart.dw + "/upBars";
    DrawingMLChart.gg = DrawingMLChart.dw + "/upDownBars";
    DrawingMLChart.gh = DrawingMLChart.dw + "/userInterface";
    DrawingMLChart.gi = DrawingMLChart.dw + "/userShapes";
    DrawingMLChart.gj = DrawingMLChart.dw + "/v";
    DrawingMLChart.gk = DrawingMLChart.dw + "/val";
    DrawingMLChart.gl = DrawingMLChart.dw + "/valAx";
    DrawingMLChart.gm = DrawingMLChart.dw + "/varyColors";
    DrawingMLChart.gn = DrawingMLChart.dw + "/view3D";
    DrawingMLChart.go = DrawingMLChart.dw + "/w";
    DrawingMLChart.gp = DrawingMLChart.dw + "/wireframe";
    DrawingMLChart.gq = DrawingMLChart.dw + "/wMode";
    DrawingMLChart.gr = DrawingMLChart.dw + "/x";
    DrawingMLChart.gs = DrawingMLChart.dw + "/xMode";
    DrawingMLChart.gt = DrawingMLChart.dw + "/xVal";
    DrawingMLChart.gu = DrawingMLChart.dw + "/y";
    DrawingMLChart.gv = DrawingMLChart.dw + "/yMode";
    DrawingMLChart.gw = DrawingMLChart.dw + "/yVal";
    DrawingMLChart.an = new DrawingMLChart();
    return DrawingMLChart;
}(XmlNamespaceDefinitionBase));
export { DrawingMLChart };
var DrawingMLMain = /** @class */ (function (_super) {
    tslib_1.__extends(DrawingMLMain, _super);
    function DrawingMLMain() {
        return _super.call(this) || this;
    }
    DrawingMLMain.prototype.i = function (a) {
        switch (a) {
            case 0: return DrawingMLMain.gp;
            case 1: return DrawingMLMain.go;
            default: return DrawingMLMain.gp;
        }
    };
    DrawingMLMain.prototype.get_j = function () {
        return "a";
    };
    Object.defineProperty(DrawingMLMain.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    DrawingMLMain.kv = function (a, b, c) {
        c = ST_Angle.a(0);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "val":
                        c = ST_Angle.b(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_47_1) { e_47 = { error: e_47_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_47) throw e_47.error; }
        }
        return {
            p2: c
        };
        var e_47, _2;
    };
    DrawingMLMain.nw = function (a, b, c) {
        a.ad.p(b, "a");
        var d;
        d = c.toString();
        a.ad.h("val", d);
    };
    DrawingMLMain.kw = function (a, b) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_48_1) { e_48 = { error: e_48_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_48) throw e_48.error; }
        }
        var e_48, _2;
    };
    DrawingMLMain.nx = function (a, b) {
        a.ad.p(b, "a");
    };
    DrawingMLMain.kx = function (a, b, c) {
        c = new ST_FixedPercentage();
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "val":
                        c = ST_FixedPercentage.c(d.d, a.d._z);
                        break;
                    default: break;
                }
            }
        }
        catch (e_49_1) { e_49 = { error: e_49_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_49) throw e_49.error; }
        }
        return {
            p2: c
        };
        var e_49, _2;
    };
    DrawingMLMain.ny = function (a, b, c) {
        a.ad.p(b, "a");
        var d;
        d = c.s(a.d._z);
        a.ad.h("val", d);
    };
    DrawingMLMain.ky = function (a, b, c, d, e) {
        c = Nullable$1.toNullable(ST_LineEndType_$type, null);
        d = Nullable$1.toNullable(ST_LineEndWidth_$type, null);
        e = Nullable$1.toNullable(ST_LineEndLength_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "type":
                        c = Nullable$1.toNullable(ST_LineEndType_$type, XmlNamespaceDefinitionBase.b(ST_LineEndType_$type, f.d));
                        break;
                    case "w":
                        d = Nullable$1.toNullable(ST_LineEndWidth_$type, XmlNamespaceDefinitionBase.b(ST_LineEndWidth_$type, f.d));
                        break;
                    case "len":
                        e = Nullable$1.toNullable(ST_LineEndLength_$type, XmlNamespaceDefinitionBase.b(ST_LineEndLength_$type, f.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_50_1) { e_50 = { error: e_50_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_50) throw e_50.error; }
        }
        return {
            p2: c,
            p3: d,
            p4: e
        };
        var e_50, _2;
    };
    DrawingMLMain.nz = function (a, b, c, d, e) {
        a.ad.p(b, "a");
        var f;
        if (nullableNotEquals(c, null)) {
            f = XmlNamespaceDefinitionBase.f(ST_LineEndType_$type, c.value);
            a.ad.h("type", f);
        }
        if (nullableNotEquals(d, null)) {
            f = XmlNamespaceDefinitionBase.f(ST_LineEndWidth_$type, d.value);
            a.ad.h("w", f);
        }
        if (nullableNotEquals(e, null)) {
            f = XmlNamespaceDefinitionBase.f(ST_LineEndLength_$type, e.value);
            a.ad.h("len", f);
        }
    };
    DrawingMLMain.kz = function (a, b, c, d, e, f, g) {
        c = new ST_DrawingElementId();
        d = null;
        e = null;
        f = false;
        g = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var h = _1.value;
                switch (h.a.e(a.d)) {
                    case "id":
                        c = ST_DrawingElementId.c(h.d);
                        break;
                    case "name":
                        d = h.d;
                        break;
                    case "descr":
                        e = h.d;
                        break;
                    case "hidden":
                        f = ST_OnOff.e(h.d);
                        break;
                    case "title":
                        g = h.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_51_1) { e_51 = { error: e_51_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_51) throw e_51.error; }
        }
        return {
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g
        };
        var e_51, _2;
    };
    DrawingMLMain.n0 = function (a, b, c, d, e, f, g) {
        a.ad.p(b, "a");
        var h;
        h = c.toString();
        a.ad.h("id", h);
        h = d;
        a.ad.h("name", h);
        h = e;
        a.ad.h("descr", h);
        if (f != false) {
            h = ST_OnOff.g(f);
            a.ad.h("hidden", h);
        }
        h = g;
        a.ad.h("title", h);
    };
    DrawingMLMain.k0 = function (a, b, c) {
        c = new ST_Percentage();
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "val":
                        c = ST_Percentage.c(d.d, a.d._z);
                        break;
                    default: break;
                }
            }
        }
        catch (e_52_1) { e_52 = { error: e_52_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_52) throw e_52.error; }
        }
        return {
            p2: c
        };
        var e_52, _2;
    };
    DrawingMLMain.n1 = function (a, b, c) {
        a.ad.p(b, "a");
        var d;
        d = c.p(a.d._z);
        a.ad.h("val", d);
    };
    DrawingMLMain.k1 = function (a, b, c, d) {
        c = new ST_Coordinate();
        d = new ST_Coordinate();
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "x":
                        c = ST_Coordinate.h(e.d);
                        break;
                    case "y":
                        d = ST_Coordinate.h(e.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_53_1) { e_53 = { error: e_53_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_53) throw e_53.error; }
        }
        return {
            p2: c,
            p3: d
        };
        var e_53, _2;
    };
    DrawingMLMain.n2 = function (a, b, c, d) {
        a.ad.p(b, "a");
        var e;
        e = c.toString();
        a.ad.h("x", e);
        e = d.toString();
        a.ad.h("y", e);
    };
    DrawingMLMain.k2 = function (a, b, c) {
        c = ST_PositiveFixedAngle.e(ST_Angle.a(0));
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "val":
                        c = ST_PositiveFixedAngle.g(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_54_1) { e_54 = { error: e_54_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_54) throw e_54.error; }
        }
        return {
            p2: c
        };
        var e_54, _2;
    };
    DrawingMLMain.n3 = function (a, b, c) {
        a.ad.p(b, "a");
        var d;
        d = c.toString();
        a.ad.h("val", d);
    };
    DrawingMLMain.k3 = function (a, b, c) {
        c = new ST_PositiveFixedPercentage();
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "val":
                        c = ST_PositiveFixedPercentage.f(d.d, a.d._z);
                        break;
                    default: break;
                }
            }
        }
        catch (e_55_1) { e_55 = { error: e_55_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_55) throw e_55.error; }
        }
        return {
            p2: c
        };
        var e_55, _2;
    };
    DrawingMLMain.n4 = function (a, b, c) {
        a.ad.p(b, "a");
        var d;
        d = c.u(a.d._z);
        a.ad.h("val", d);
    };
    DrawingMLMain.k4 = function (a, b, c) {
        c = new ST_PositivePercentage();
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "val":
                        c = ST_PositivePercentage.f(d.d, a.d._z);
                        break;
                    default: break;
                }
            }
        }
        catch (e_56_1) { e_56 = { error: e_56_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_56) throw e_56.error; }
        }
        return {
            p2: c
        };
        var e_56, _2;
    };
    DrawingMLMain.n5 = function (a, b, c) {
        a.ad.p(b, "a");
        var d;
        d = c.s(a.d._z);
        a.ad.h("val", d);
    };
    DrawingMLMain.k5 = function (a, b, c, d) {
        c = new ST_PositiveCoordinate();
        d = new ST_PositiveCoordinate();
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "cx":
                        c = ST_PositiveCoordinate.c(e.d);
                        break;
                    case "cy":
                        d = ST_PositiveCoordinate.c(e.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_57_1) { e_57 = { error: e_57_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_57) throw e_57.error; }
        }
        return {
            p2: c,
            p3: d
        };
        var e_57, _2;
    };
    DrawingMLMain.n6 = function (a, b, c, d) {
        a.ad.p(b, "a");
        var e;
        e = c.toString();
        a.ad.h("cx", e);
        e = d.toString();
        a.ad.h("cy", e);
    };
    DrawingMLMain.k6 = function (a, b, c, d, e, f) {
        c = ST_Percentage.a(0);
        d = ST_Percentage.a(0);
        e = ST_Percentage.a(0);
        f = ST_Percentage.a(0);
        var g = a.d._z;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var h = _1.value;
                switch (h.a.e(a.d)) {
                    case "l":
                        c = ST_Percentage.c(h.d, g);
                        break;
                    case "t":
                        d = ST_Percentage.c(h.d, g);
                        break;
                    case "r":
                        e = ST_Percentage.c(h.d, g);
                        break;
                    case "b":
                        f = ST_Percentage.c(h.d, g);
                        break;
                    default: break;
                }
            }
        }
        catch (e_58_1) { e_58 = { error: e_58_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_58) throw e_58.error; }
        }
        return {
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
        var e_58, _2;
    };
    DrawingMLMain.n7 = function (a, b, c, d, e, f) {
        a.ad.p(b, "a");
        var g;
        var h = a.d._z;
        if (ST_Percentage.f(c, ST_Percentage.a(0))) {
            g = c.p(h);
            a.ad.h("l", g);
        }
        if (ST_Percentage.f(d, ST_Percentage.a(0))) {
            g = d.p(h);
            a.ad.h("t", g);
        }
        if (ST_Percentage.f(e, ST_Percentage.a(0))) {
            g = e.p(h);
            a.ad.h("r", g);
        }
        if (ST_Percentage.f(f, ST_Percentage.a(0))) {
            g = f.p(h);
            a.ad.h("b", g);
        }
    };
    DrawingMLMain.k7 = function (a, b, c) {
        c = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "idx":
                        c = parseUInt32_1(d.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_59_1) { e_59 = { error: e_59_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_59) throw e_59.error; }
        }
        return {
            p2: c
        };
        var e_59, _2;
    };
    DrawingMLMain.n8 = function (a, b, c) {
        a.ad.p(b, "a");
        var d;
        d = c.toString();
        a.ad.h("idx", d);
    };
    DrawingMLMain.k8 = function (a, b, c, d, e, f, g) {
        if (g === void 0) { g = true; }
        c = null;
        d = null;
        e = Nullable$1.toNullable(Number_$type, null);
        f = Nullable$1.toNullable(Number_$type, null);
        var h = 1;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var i = _1.value;
                switch (i.a.e(a.d)) {
                    case "typeface":
                        c = i.d;
                        break;
                    case "panose":
                        d = ST_Panose.b(i.d);
                        break;
                    case "pitchFamily":
                        e = Nullable$1.toNullable(Number_$type, parseInt8_1(i.d, CultureInfo.invariantCulture));
                        break;
                    case "charset":
                        f = Nullable$1.toNullable(Number_$type, parseInt8_1(i.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_60_1) { e_60 = { error: e_60_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_60) throw e_60.error; }
        }
        if (g && f.hasValue == false) {
            f = Nullable$1.toNullable(Number_$type, h);
        }
        return {
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
        var e_60, _2;
    };
    DrawingMLMain.n9 = function (a, b, c, d, e, f) {
        a.ad.p(b, "a");
        var g;
        g = c != null ? c : "";
        a.ad.h("typeface", g);
        if (d != null) {
            g = d.toString();
            a.ad.h("panose", g);
        }
        if (nullableNotEquals(e, null)) {
            g = e.value.toString();
            a.ad.h("pitchFamily", g);
        }
        if (f != 1) {
            g = f.toString();
            a.ad.h("charset", g);
        }
    };
    DrawingMLMain.ka = function (a) {
    };
    DrawingMLMain.nb = function (a) {
        DrawingMLMain.nx(a, DrawingMLMain.aq);
    };
    DrawingMLMain.kb = function (a) {
    };
    DrawingMLMain.nc = function (a) {
        DrawingMLMain.nx(a, DrawingMLMain.ar);
    };
    DrawingMLMain.kc = function (a) {
    };
    DrawingMLMain.nd = function (a) {
        DrawingMLMain.nx(a, DrawingMLMain.as);
    };
    DrawingMLMain.kd = function (a) {
    };
    DrawingMLMain.ne = function (a) {
        DrawingMLMain.nx(a, DrawingMLMain.at);
    };
    DrawingMLMain.ke = function (a) {
    };
    DrawingMLMain.nf = function (a) {
        DrawingMLMain.nx(a, DrawingMLMain.au);
    };
    DrawingMLMain.kf = function (a) {
    };
    DrawingMLMain.ng = function (a) {
        DrawingMLMain.nx(a, DrawingMLMain.av);
    };
    DrawingMLMain.kg = function (a, b) {
        var c = DrawingMLMain.k3(a, DrawingMLMain.a1, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.nh = function (a, b) {
        DrawingMLMain.n4(a, DrawingMLMain.a1, b);
    };
    DrawingMLMain.kh = function (a, b) {
        var c = DrawingMLMain.k4(a, DrawingMLMain.a6, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.ni = function (a, b) {
        DrawingMLMain.n5(a, DrawingMLMain.a6, b);
    };
    DrawingMLMain.ki = function (a, b) {
        var c = DrawingMLMain.kx(a, DrawingMLMain.a8, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.nj = function (a, b) {
        DrawingMLMain.ny(a, DrawingMLMain.a8, b);
    };
    DrawingMLMain.kj = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_61_1) { e_61 = { error: e_61_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_61) throw e_61.error; }
        }
        var e_61, _2;
    };
    DrawingMLMain.nk = function (a) {
        a.ad.p(DrawingMLMain.bg, "a");
    };
    DrawingMLMain.kk = function (a, b, c, d, e) {
        if (e === void 0) { e = true; }
        b = null;
        c = null;
        if (e) {
            d = Nullable$1.toNullable(ST_BlipCompression_$type, 0);
        }
        else {
            d = Nullable$1.toNullable(ST_BlipCompression_$type, null);
        }
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case OfficeDocumentRelationships.ap:
                        b = f.d;
                        break;
                    case OfficeDocumentRelationships.as:
                        c = f.d;
                        break;
                    case "cstate":
                        d = Nullable$1.toNullable(ST_BlipCompression_$type, XmlNamespaceDefinitionBase.b(ST_BlipCompression_$type, f.d, 0));
                        break;
                    default: break;
                }
            }
        }
        catch (e_62_1) { e_62 = { error: e_62_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_62) throw e_62.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_62, _2;
    };
    DrawingMLMain.nl = function (a, b, c, d) {
        a.ad.p(DrawingMLMain.bs, "a");
        var e;
        e = b;
        a.ad.h(OfficeDocumentRelationships.ap, e);
        e = c;
        a.ad.h(OfficeDocumentRelationships.as, e);
        if (d.hasValue && d.value != 0) {
            e = XmlNamespaceDefinitionBase.f(ST_BlipCompression_$type, d.value);
            a.ad.h("cstate", e);
        }
    };
    DrawingMLMain.kl = function (a, b, c) {
        b = Nullable$1.toNullable(Number_$type, null);
        c = Nullable$1.toNullable(Boolean_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "dpi":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(d.d, CultureInfo.invariantCulture));
                        break;
                    case "rotWithShape":
                        c = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(d.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_63_1) { e_63 = { error: e_63_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_63) throw e_63.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_63, _2;
    };
    DrawingMLMain.nm = function (a, b, c) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        if (c === void 0) { c = Nullable$1.toNullable(Boolean_$type, null); }
        a.ad.p(DrawingMLMain.bt, "a");
        var d;
        if (nullableNotEquals(b, null)) {
            d = b.value.toString();
            a.ad.h("dpi", d);
        }
        if (nullableNotEquals(c, null)) {
            d = ST_OnOff.g(c.value);
            a.ad.h("rotWithShape", d);
        }
    };
    DrawingMLMain.km = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.bu, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.nn = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.bu, b);
    };
    DrawingMLMain.kn = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.bv, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.no = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.bv, b);
    };
    DrawingMLMain.ko = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.bw, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.np = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.bw, b);
    };
    DrawingMLMain.kp = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t) {
        b = Nullable$1.toNullable(Number_$type, null);
        c = Nullable$1.toNullable(Boolean_$type, null);
        d = Nullable$1.toNullable(ST_TextVertOverflowType_$type, null);
        e = Nullable$1.toNullable(ST_TextHorzOverflowType_$type, null);
        f = Nullable$1.toNullable(ST_TextVerticalType_$type, null);
        g = Nullable$1.toNullable(ST_TextWrappingType_$type, null);
        h = Nullable$1.toNullable(ST_Coordinate32.$, null);
        i = Nullable$1.toNullable(ST_Coordinate32.$, null);
        j = Nullable$1.toNullable(ST_Coordinate32.$, null);
        k = Nullable$1.toNullable(ST_Coordinate32.$, null);
        l = Nullable$1.toNullable(Number_$type, null);
        m = Nullable$1.toNullable(Number_$type, null);
        n = Nullable$1.toNullable(Boolean_$type, null);
        o = Nullable$1.toNullable(Boolean_$type, null);
        p = Nullable$1.toNullable(ST_TextAnchoringType_$type, null);
        q = Nullable$1.toNullable(Boolean_$type, null);
        r = Nullable$1.toNullable(Boolean_$type, null);
        s = false;
        t = Nullable$1.toNullable(Boolean_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var u = _1.value;
                switch (u.a.e(a.d)) {
                    case "rot":
                        b = Nullable$1.toNullable(Number_$type, parseInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "spcFirstLastPara":
                        c = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(u.d));
                        break;
                    case "vertOverflow":
                        d = Nullable$1.toNullable(ST_TextVertOverflowType_$type, XmlNamespaceDefinitionBase.b(ST_TextVertOverflowType_$type, u.d));
                        break;
                    case "horzOverflow":
                        e = Nullable$1.toNullable(ST_TextHorzOverflowType_$type, XmlNamespaceDefinitionBase.b(ST_TextHorzOverflowType_$type, u.d));
                        break;
                    case "vert":
                        f = Nullable$1.toNullable(ST_TextVerticalType_$type, XmlNamespaceDefinitionBase.b(ST_TextVerticalType_$type, u.d));
                        break;
                    case "wrap":
                        g = Nullable$1.toNullable(ST_TextWrappingType_$type, XmlNamespaceDefinitionBase.b(ST_TextWrappingType_$type, u.d));
                        break;
                    case "lIns":
                        h = Nullable$1.toNullable(ST_Coordinate32.$, ST_Coordinate32.g(u.d));
                        break;
                    case "tIns":
                        i = Nullable$1.toNullable(ST_Coordinate32.$, ST_Coordinate32.g(u.d));
                        break;
                    case "rIns":
                        j = Nullable$1.toNullable(ST_Coordinate32.$, ST_Coordinate32.g(u.d));
                        break;
                    case "bIns":
                        k = Nullable$1.toNullable(ST_Coordinate32.$, ST_Coordinate32.g(u.d));
                        break;
                    case "numCol":
                        l = Nullable$1.toNullable(Number_$type, parseInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "spcCol":
                        m = Nullable$1.toNullable(Number_$type, parseInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "rtlCol":
                        n = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(u.d));
                        break;
                    case "fromWordArt":
                        o = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(u.d));
                        break;
                    case "anchor":
                        p = Nullable$1.toNullable(ST_TextAnchoringType_$type, XmlNamespaceDefinitionBase.b(ST_TextAnchoringType_$type, u.d));
                        break;
                    case "anchorCtr":
                        q = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(u.d));
                        break;
                    case "forceAA":
                        r = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(u.d));
                        break;
                    case "upright":
                        s = ST_OnOff.e(u.d);
                        break;
                    case "compatLnSpc":
                        t = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(u.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_64_1) { e_64 = { error: e_64_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_64) throw e_64.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t
        };
        var e_64, _2;
    };
    DrawingMLMain.nq = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        if (c === void 0) { c = Nullable$1.toNullable(Boolean_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(ST_TextVertOverflowType_$type, null); }
        if (e === void 0) { e = Nullable$1.toNullable(ST_TextHorzOverflowType_$type, null); }
        if (f === void 0) { f = Nullable$1.toNullable(ST_TextVerticalType_$type, null); }
        if (g === void 0) { g = Nullable$1.toNullable(ST_TextWrappingType_$type, null); }
        if (h === void 0) { h = Nullable$1.toNullable(ST_Coordinate32.$, null); }
        if (i === void 0) { i = Nullable$1.toNullable(ST_Coordinate32.$, null); }
        if (j === void 0) { j = Nullable$1.toNullable(ST_Coordinate32.$, null); }
        if (k === void 0) { k = Nullable$1.toNullable(ST_Coordinate32.$, null); }
        if (l === void 0) { l = Nullable$1.toNullable(Number_$type, null); }
        if (m === void 0) { m = Nullable$1.toNullable(Number_$type, null); }
        if (n === void 0) { n = Nullable$1.toNullable(Boolean_$type, null); }
        if (o === void 0) { o = Nullable$1.toNullable(Boolean_$type, null); }
        if (p === void 0) { p = Nullable$1.toNullable(ST_TextAnchoringType_$type, null); }
        if (q === void 0) { q = Nullable$1.toNullable(Boolean_$type, null); }
        if (r === void 0) { r = Nullable$1.toNullable(Boolean_$type, null); }
        if (s === void 0) { s = false; }
        if (t === void 0) { t = Nullable$1.toNullable(Boolean_$type, null); }
        a.ad.p(DrawingMLMain.bz, "a");
        var u;
        if (nullableNotEquals(b, null)) {
            u = b.value.toString();
            a.ad.h("rot", u);
        }
        if (nullableNotEquals(c, null)) {
            u = ST_OnOff.g(c.value);
            a.ad.h("spcFirstLastPara", u);
        }
        if (nullableNotEquals(d, null)) {
            u = XmlNamespaceDefinitionBase.f(ST_TextVertOverflowType_$type, d.value);
            a.ad.h("vertOverflow", u);
        }
        if (nullableNotEquals(e, null)) {
            u = XmlNamespaceDefinitionBase.f(ST_TextHorzOverflowType_$type, e.value);
            a.ad.h("horzOverflow", u);
        }
        if (nullableNotEquals(f, null)) {
            u = XmlNamespaceDefinitionBase.f(ST_TextVerticalType_$type, f.value);
            a.ad.h("vert", u);
        }
        if (nullableNotEquals(g, null)) {
            u = XmlNamespaceDefinitionBase.f(ST_TextWrappingType_$type, g.value);
            a.ad.h("wrap", u);
        }
        if (nullableNotEquals(h, null)) {
            u = h.value.toString();
            a.ad.h("lIns", u);
        }
        if (nullableNotEquals(i, null)) {
            u = i.value.toString();
            a.ad.h("tIns", u);
        }
        if (nullableNotEquals(j, null)) {
            u = j.value.toString();
            a.ad.h("rIns", u);
        }
        if (nullableNotEquals(k, null)) {
            u = k.value.toString();
            a.ad.h("bIns", u);
        }
        if (nullableNotEquals(l, null)) {
            u = l.value.toString();
            a.ad.h("numCol", u);
        }
        if (nullableNotEquals(m, null)) {
            u = m.value.toString();
            a.ad.h("spcCol", u);
        }
        if (nullableNotEquals(n, null)) {
            u = ST_OnOff.g(n.value);
            a.ad.h("rtlCol", u);
        }
        if (nullableNotEquals(o, null)) {
            u = ST_OnOff.g(o.value);
            a.ad.h("fromWordArt", u);
        }
        if (nullableNotEquals(p, null)) {
            u = XmlNamespaceDefinitionBase.f(ST_TextAnchoringType_$type, p.value);
            a.ad.h("anchor", u);
        }
        if (nullableNotEquals(q, null)) {
            u = ST_OnOff.g(q.value);
            a.ad.h("anchorCtr", u);
        }
        if (nullableNotEquals(r, null)) {
            u = ST_OnOff.g(r.value);
            a.ad.h("forceAA", u);
        }
        if (s != false) {
            u = ST_OnOff.g(s);
            a.ad.h("upright", u);
        }
        if (nullableNotEquals(t, null)) {
            u = ST_OnOff.g(t.value);
            a.ad.h("compatLnSpc", u);
        }
    };
    DrawingMLMain.kq = function (a, b, c) {
        var d = DrawingMLMain.k5(a, DrawingMLMain.cg, b, c);
        b = d.p2;
        c = d.p3;
        return {
            p1: b,
            p2: c
        };
    };
    DrawingMLMain.nr = function (a, b, c) {
        DrawingMLMain.n6(a, DrawingMLMain.cg, b, c);
    };
    DrawingMLMain.kr = function (a, b, c) {
        var d = DrawingMLMain.k1(a, DrawingMLMain.ch, b, c);
        b = d.p2;
        c = d.p3;
        return {
            p1: b,
            p2: c
        };
    };
    DrawingMLMain.ns = function (a, b, c) {
        DrawingMLMain.n2(a, DrawingMLMain.ch, b, c);
    };
    DrawingMLMain.ks = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "name":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_65_1) { e_65 = { error: e_65_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_65) throw e_65.error; }
        }
        return {
            p1: b
        };
        var e_65, _2;
    };
    DrawingMLMain.nt = function (a, b) {
        a.ad.p(DrawingMLMain.cm, "a");
        var c;
        c = b;
        a.ad.h("name", c);
    };
    DrawingMLMain.kt = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_66_1) { e_66 = { error: e_66_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_66) throw e_66.error; }
        }
        var e_66, _2;
    };
    DrawingMLMain.nu = function (a) {
        a.ad.p(DrawingMLMain.cp, "a");
    };
    DrawingMLMain.ku = function (a, b, c, d, e, f) {
        if (f === void 0) { f = true; }
        var g = DrawingMLMain.k8(a, DrawingMLMain.ct, b, c, d, e);
        b = g.p2;
        c = g.p3;
        d = g.p4;
        e = g.p5;
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
    };
    DrawingMLMain.nv = function (a, b, c, d, e) {
        if (c === void 0) { c = null; }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = 1; }
        DrawingMLMain.n9(a, DrawingMLMain.ct, b, c, d, e);
    };
    DrawingMLMain.k9 = function (a, b) {
        b = "";
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "name":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_67_1) { e_67 = { error: e_67_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_67) throw e_67.error; }
        }
        return {
            p1: b
        };
        var e_67, _2;
    };
    DrawingMLMain.oa = function (a, b) {
        if (b === void 0) { b = ""; }
        a.ad.p(DrawingMLMain.cw, "a");
        var c;
        if (b != "") {
            c = b;
            a.ad.h("name", c);
        }
    };
    DrawingMLMain.la = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_68_1) { e_68 = { error: e_68_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_68) throw e_68.error; }
        }
        var e_68, _2;
    };
    DrawingMLMain.ob = function (a) {
        a.ad.p(DrawingMLMain.cx, "a");
    };
    DrawingMLMain.lb = function (a) {
    };
    DrawingMLMain.oc = function (a) {
        DrawingMLMain.nx(a, DrawingMLMain.c9);
    };
    DrawingMLMain.lc = function (a) {
    };
    DrawingMLMain.od = function (a) {
        DrawingMLMain.nx(a, DrawingMLMain.da);
    };
    DrawingMLMain.ld = function (a, b, c, d, e) {
        var f = Nullable$1.toNullable(Number_$type, null);
        var g = DrawingMLMain.k8(a, DrawingMLMain.de, b, c, d, f);
        b = g.p2;
        c = g.p3;
        d = g.p4;
        f = g.p5;
        e = f.hasValue ? f.value : 1;
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
    };
    DrawingMLMain.oe = function (a, b, c, d, e) {
        if (c === void 0) { c = null; }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = 1; }
        DrawingMLMain.n9(a, DrawingMLMain.de, b, c, d, e);
    };
    DrawingMLMain.le = function (a, b) {
        var c = DrawingMLMain.k7(a, DrawingMLMain.dj, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.of = function (a, b) {
        DrawingMLMain.n8(a, DrawingMLMain.dj, b);
    };
    DrawingMLMain.lf = function (a, b, c) {
        var d = DrawingMLMain.k5(a, DrawingMLMain.dq, b, c);
        b = d.p2;
        c = d.p3;
        return {
            p1: b,
            p2: c
        };
    };
    DrawingMLMain.og = function (a, b, c) {
        DrawingMLMain.n6(a, DrawingMLMain.dq, b, c);
    };
    DrawingMLMain.lg = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_69_1) { e_69 = { error: e_69_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_69) throw e_69.error; }
        }
        var e_69, _2;
    };
    DrawingMLMain.oh = function (a) {
        a.ad.p(DrawingMLMain.dr, "a");
    };
    DrawingMLMain.lh = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_70_1) { e_70 = { error: e_70_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_70) throw e_70.error; }
        }
        var e_70, _2;
    };
    DrawingMLMain.oi = function (a) {
        a.ad.p(DrawingMLMain.ds, "a");
    };
    DrawingMLMain.li = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_71_1) { e_71 = { error: e_71_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_71) throw e_71.error; }
        }
        var e_71, _2;
    };
    DrawingMLMain.oj = function (a) {
        a.ad.p(DrawingMLMain.dt, "a");
    };
    DrawingMLMain.lj = function (a, b, c, d, e) {
        var f = DrawingMLMain.k6(a, DrawingMLMain.dy, b, c, d, e);
        b = f.p2;
        c = f.p3;
        d = f.p4;
        e = f.p5;
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
    };
    DrawingMLMain.ok = function (a, b, c, d, e) {
        DrawingMLMain.n7(a, DrawingMLMain.dy, b, c, d, e);
    };
    DrawingMLMain.lk = function (a, b) {
        var c = DrawingMLMain.k7(a, DrawingMLMain.dz, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.ol = function (a, b) {
        DrawingMLMain.n8(a, DrawingMLMain.dz, b);
    };
    DrawingMLMain.ll = function (a) {
    };
    DrawingMLMain.om = function (a) {
        DrawingMLMain.nx(a, DrawingMLMain.d8);
    };
    DrawingMLMain.lm = function (a, b, c) {
        b = null;
        c = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "script":
                        b = d.d;
                        break;
                    case "typeface":
                        c = d.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_72_1) { e_72 = { error: e_72_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_72) throw e_72.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_72, _2;
    };
    DrawingMLMain.on = function (a, b, c) {
        a.ad.p(DrawingMLMain.d9, "a");
        var d;
        d = b;
        a.ad.h("script", d);
        d = c;
        a.ad.h("typeface", d);
    };
    DrawingMLMain.ln = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "idx":
                        b = XmlNamespaceDefinitionBase.b(ST_FontCollectionIndex_$type, c.d, b);
                        break;
                    default: break;
                }
            }
        }
        catch (e_73_1) { e_73 = { error: e_73_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_73) throw e_73.error; }
        }
        return {
            p1: b
        };
        var e_73, _2;
    };
    DrawingMLMain.oo = function (a, b) {
        a.ad.p(DrawingMLMain.eb, "a");
        var c;
        c = XmlNamespaceDefinitionBase.f(ST_FontCollectionIndex_$type, b);
        a.ad.h("idx", c);
    };
    DrawingMLMain.lo = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "name":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_74_1) { e_74 = { error: e_74_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_74) throw e_74.error; }
        }
        return {
            p1: b
        };
        var e_74, _2;
    };
    DrawingMLMain.op = function (a, b) {
        a.ad.p(DrawingMLMain.ec, "a");
        var c;
        c = b;
        a.ad.h("name", c);
    };
    DrawingMLMain.lp = function (a, b, c) {
        b = null;
        c = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "name":
                        b = d.d;
                        break;
                    case "fmla":
                        c = d.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_75_1) { e_75 = { error: e_75_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_75) throw e_75.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_75, _2;
    };
    DrawingMLMain.oq = function (a, b, c) {
        a.ad.p(DrawingMLMain.eg, "a");
        var d;
        d = b;
        a.ad.h("name", d);
        d = c;
        a.ad.h("fmla", d);
    };
    DrawingMLMain.lq = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "uri":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_76_1) { e_76 = { error: e_76_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_76) throw e_76.error; }
        }
        return {
            p1: b
        };
        var e_76, _2;
    };
    DrawingMLMain.or = function (a, b) {
        a.ad.p(DrawingMLMain.el, "a");
        var c;
        c = b;
        a.ad.h("uri", c);
    };
    DrawingMLMain.lr = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_77_1) { e_77 = { error: e_77_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_77) throw e_77.error; }
        }
        var e_77, _2;
    };
    DrawingMLMain.os = function (a) {
        a.ad.p(DrawingMLMain.ek, "a");
    };
    DrawingMLMain.ls = function (a, b, c, d, e, f, g) {
        b = false;
        c = false;
        d = false;
        e = false;
        f = false;
        g = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var h = _1.value;
                switch (h.a.e(a.d)) {
                    case "noGrp":
                        b = ST_OnOff.e(h.d);
                        break;
                    case "noDrilldown":
                        c = ST_OnOff.e(h.d);
                        break;
                    case "noSelect":
                        d = ST_OnOff.e(h.d);
                        break;
                    case "noChangeAspect":
                        e = ST_OnOff.e(h.d);
                        break;
                    case "noMove":
                        f = ST_OnOff.e(h.d);
                        break;
                    case "noResize":
                        g = ST_OnOff.e(h.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_78_1) { e_78 = { error: e_78_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_78) throw e_78.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g
        };
        var e_78, _2;
    };
    DrawingMLMain.ot = function (a, b, c, d, e, f, g) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = false; }
        a.ad.p(DrawingMLMain.em, "a");
        var h;
        if (b != false) {
            h = ST_OnOff.g(b);
            a.ad.h("noGrp", h);
        }
        if (c != false) {
            h = ST_OnOff.g(c);
            a.ad.h("noDrilldown", h);
        }
        if (d != false) {
            h = ST_OnOff.g(d);
            a.ad.h("noSelect", h);
        }
        if (e != false) {
            h = ST_OnOff.g(e);
            a.ad.h("noChangeAspect", h);
        }
        if (f != false) {
            h = ST_OnOff.g(f);
            a.ad.h("noMove", h);
        }
        if (g != false) {
            h = ST_OnOff.g(g);
            a.ad.h("noResize", h);
        }
    };
    DrawingMLMain.lt = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_79_1) { e_79 = { error: e_79_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_79) throw e_79.error; }
        }
        var e_79, _2;
    };
    DrawingMLMain.ou = function (a) {
        a.ad.p(DrawingMLMain.en, "a");
    };
    DrawingMLMain.lu = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.ep, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.ov = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.ep, b);
    };
    DrawingMLMain.lv = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.eq, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.ow = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.eq, b);
    };
    DrawingMLMain.lw = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.er, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.ox = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.er, b);
    };
    DrawingMLMain.lx = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_80_1) { e_80 = { error: e_80_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_80) throw e_80.error; }
        }
        var e_80, _2;
    };
    DrawingMLMain.oy = function (a) {
        a.ad.p(DrawingMLMain.es, "a");
    };
    DrawingMLMain.ly = function (a, b, c, d) {
        var e = DrawingMLMain.ky(a, DrawingMLMain.ew, b, c, d);
        b = e.p2;
        c = e.p3;
        d = e.p4;
        return {
            p1: b,
            p2: c,
            p3: d
        };
    };
    DrawingMLMain.oz = function (a, b, c, d) {
        DrawingMLMain.nz(a, DrawingMLMain.ew, b, c, d);
    };
    DrawingMLMain.lz = function (a, b, c, d, e, f, g, h, i) {
        b = null;
        c = "";
        d = "";
        e = "";
        f = "";
        g = true;
        h = false;
        i = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var j = _1.value;
                switch (j.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = j.d;
                        break;
                    case "invalidUrl":
                        c = j.d;
                        break;
                    case "action":
                        d = j.d;
                        break;
                    case "tgtFrame":
                        e = j.d;
                        break;
                    case "tooltip":
                        f = j.d;
                        break;
                    case "history":
                        g = ST_OnOff.e(j.d);
                        break;
                    case "highlightClick":
                        h = ST_OnOff.e(j.d);
                        break;
                    case "endSnd":
                        i = ST_OnOff.e(j.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_81_1) { e_81 = { error: e_81_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_81) throw e_81.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i
        };
        var e_81, _2;
    };
    DrawingMLMain.o0 = function (a, b, c, d, e, f, g, h, i) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = ""; }
        if (d === void 0) { d = ""; }
        if (e === void 0) { e = ""; }
        if (f === void 0) { f = ""; }
        if (g === void 0) { g = true; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = false; }
        a.ad.p(DrawingMLMain.e2, "a");
        var j;
        j = b;
        a.ad.h(OfficeDocumentRelationships.ar, j);
        j = c;
        a.ad.h("invalidUrl", j);
        j = d;
        a.ad.h("action", j);
        j = e;
        a.ad.h("tgtFrame", j);
        j = f;
        a.ad.h("tooltip", j);
        if (g != true) {
            j = ST_OnOff.g(g);
            a.ad.h("history", j);
        }
        if (h != false) {
            j = ST_OnOff.g(h);
            a.ad.h("highlightClick", j);
        }
        if (i != false) {
            j = ST_OnOff.g(i);
            a.ad.h("endSnd", j);
        }
    };
    DrawingMLMain.l0 = function (a) {
    };
    DrawingMLMain.o1 = function (a) {
        DrawingMLMain.nx(a, DrawingMLMain.e1);
    };
    DrawingMLMain.l1 = function (a, b) {
        var c = DrawingMLMain.k2(a, DrawingMLMain.e8, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.o2 = function (a, b) {
        DrawingMLMain.n3(a, DrawingMLMain.e8, b);
    };
    DrawingMLMain.l2 = function (a, b) {
        var c = DrawingMLMain.k4(a, DrawingMLMain.e9, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.o3 = function (a, b) {
        DrawingMLMain.n5(a, DrawingMLMain.e9, b);
    };
    DrawingMLMain.l3 = function (a, b) {
        var c = DrawingMLMain.kv(a, DrawingMLMain.fa, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.o4 = function (a, b) {
        DrawingMLMain.nw(a, DrawingMLMain.fa, b);
    };
    DrawingMLMain.l4 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_82_1) { e_82 = { error: e_82_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_82) throw e_82.error; }
        }
        var e_82, _2;
    };
    DrawingMLMain.o5 = function (a) {
        a.ad.p(DrawingMLMain.fg, "a");
    };
    DrawingMLMain.l5 = function (a, b, c, d, e) {
        var f = Nullable$1.toNullable(Number_$type, null);
        var g = DrawingMLMain.k8(a, DrawingMLMain.fq, b, c, d, f);
        b = g.p2;
        c = g.p3;
        d = g.p4;
        f = g.p5;
        e = f.hasValue ? f.value : 1;
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
    };
    DrawingMLMain.o6 = function (a, b, c, d, e) {
        if (c === void 0) { c = null; }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = 1; }
        DrawingMLMain.n9(a, DrawingMLMain.fq, b, c, d, e);
    };
    DrawingMLMain.l6 = function (a, b, c, d, e) {
        b = Nullable$1.toNullable(ST_LineWidth.$, null);
        c = Nullable$1.toNullable(ST_LineCap_$type, null);
        d = Nullable$1.toNullable(ST_CompoundLine_$type, null);
        e = Nullable$1.toNullable(ST_PenAlignment_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "w":
                        b = Nullable$1.toNullable(ST_LineWidth.$, ST_LineWidth.f(f.d));
                        break;
                    case "cap":
                        c = Nullable$1.toNullable(ST_LineCap_$type, XmlNamespaceDefinitionBase.b(ST_LineCap_$type, f.d));
                        break;
                    case "cmpd":
                        d = Nullable$1.toNullable(ST_CompoundLine_$type, XmlNamespaceDefinitionBase.b(ST_CompoundLine_$type, f.d));
                        break;
                    case "algn":
                        e = Nullable$1.toNullable(ST_PenAlignment_$type, XmlNamespaceDefinitionBase.b(ST_PenAlignment_$type, f.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_83_1) { e_83 = { error: e_83_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_83) throw e_83.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_83, _2;
    };
    DrawingMLMain.o7 = function (a, b, c, d, e) {
        a.ad.p(DrawingMLMain.fw, "a");
        var f;
        if (ST_LineWidth.j(b, Nullable$1.toNullable(ST_LineWidth.$, null))) {
            f = b.toString();
            a.ad.h("w", f);
        }
        if (nullableNotEquals(c, null)) {
            f = XmlNamespaceDefinitionBase.f(ST_LineCap_$type, c.value);
            a.ad.h("cap", f);
        }
        if (nullableNotEquals(d, null)) {
            f = XmlNamespaceDefinitionBase.f(ST_CompoundLine_$type, d.value);
            a.ad.h("cmpd", f);
        }
        if (nullableNotEquals(e, null)) {
            f = XmlNamespaceDefinitionBase.f(ST_PenAlignment_$type, e.value);
            a.ad.h("algn", f);
        }
    };
    DrawingMLMain.l7 = function (a, b) {
        var c = DrawingMLMain.k7(a, DrawingMLMain.fx, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.o8 = function (a, b) {
        DrawingMLMain.n8(a, DrawingMLMain.fx, b);
    };
    DrawingMLMain.l8 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_84_1) { e_84 = { error: e_84_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_84) throw e_84.error; }
        }
        var e_84, _2;
    };
    DrawingMLMain.o9 = function (a) {
        a.ad.p(DrawingMLMain.f1, "a");
    };
    DrawingMLMain.l9 = function (a) {
    };
    DrawingMLMain.pa = function (a) {
        DrawingMLMain.nx(a, DrawingMLMain.f2);
    };
    DrawingMLMain.ma = function (a) {
    };
    DrawingMLMain.pb = function (a) {
        DrawingMLMain.nx(a, DrawingMLMain.f3);
    };
    DrawingMLMain.mb = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.f4, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.pc = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.f4, b);
    };
    DrawingMLMain.mc = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.f5, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.pd = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.f5, b);
    };
    DrawingMLMain.md = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.f6, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.pe = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.f6, b);
    };
    DrawingMLMain.me = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_85_1) { e_85 = { error: e_85_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_85) throw e_85.error; }
        }
        var e_85, _2;
    };
    DrawingMLMain.pf = function (a) {
        a.ad.p(DrawingMLMain.gh, "a");
    };
    DrawingMLMain.mf = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_86_1) { e_86 = { error: e_86_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_86) throw e_86.error; }
        }
        var e_86, _2;
    };
    DrawingMLMain.pg = function (a) {
        a.ad.p(DrawingMLMain.gk, "a");
    };
    DrawingMLMain.mg = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_87_1) { e_87 = { error: e_87_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_87) throw e_87.error; }
        }
        var e_87, _2;
    };
    DrawingMLMain.ph = function (a) {
        a.ad.p(DrawingMLMain.gy, "a");
    };
    DrawingMLMain.mh = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_88_1) { e_88 = { error: e_88_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_88) throw e_88.error; }
        }
        var e_88, _2;
    };
    DrawingMLMain.pi = function (a) {
        a.ad.p(DrawingMLMain.ha, "a");
    };
    DrawingMLMain.mi = function (a, b, c) {
        var d = DrawingMLMain.k1(a, DrawingMLMain.hb, b, c);
        b = d.p2;
        c = d.p3;
        return {
            p1: b,
            p2: c
        };
    };
    DrawingMLMain.pj = function (a, b, c) {
        DrawingMLMain.n2(a, DrawingMLMain.hb, b, c);
    };
    DrawingMLMain.mj = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_89_1) { e_89 = { error: e_89_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_89) throw e_89.error; }
        }
        var e_89, _2;
    };
    DrawingMLMain.pk = function (a) {
        a.ad.p(DrawingMLMain.hd, "a");
    };
    DrawingMLMain.mk = function (a, b, c, d, e, f, g, h, i, j, k, l) {
        b = false;
        c = false;
        d = false;
        e = false;
        f = false;
        g = false;
        h = false;
        i = false;
        j = false;
        k = false;
        l = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var m = _1.value;
                switch (m.a.e(a.d)) {
                    case "noGrp":
                        b = ST_OnOff.e(m.d);
                        break;
                    case "noSelect":
                        c = ST_OnOff.e(m.d);
                        break;
                    case "noRot":
                        d = ST_OnOff.e(m.d);
                        break;
                    case "noChangeAspect":
                        e = ST_OnOff.e(m.d);
                        break;
                    case "noMove":
                        f = ST_OnOff.e(m.d);
                        break;
                    case "noResize":
                        g = ST_OnOff.e(m.d);
                        break;
                    case "noEditPoints":
                        h = ST_OnOff.e(m.d);
                        break;
                    case "noAdjustHandles":
                        i = ST_OnOff.e(m.d);
                        break;
                    case "noChangeArrowheads":
                        j = ST_OnOff.e(m.d);
                        break;
                    case "noChangeShapeType":
                        k = ST_OnOff.e(m.d);
                        break;
                    case "noCrop":
                        l = ST_OnOff.e(m.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_90_1) { e_90 = { error: e_90_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_90) throw e_90.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l
        };
        var e_90, _2;
    };
    DrawingMLMain.pl = function (a, b, c, d, e, f, g, h, i, j, k, l) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = false; }
        if (k === void 0) { k = false; }
        if (l === void 0) { l = false; }
        a.ad.p(DrawingMLMain.hi, "a");
        var m;
        if (b != false) {
            m = ST_OnOff.g(b);
            a.ad.h("noGrp", m);
        }
        if (c != false) {
            m = ST_OnOff.g(c);
            a.ad.h("noSelect", m);
        }
        if (d != false) {
            m = ST_OnOff.g(d);
            a.ad.h("noRot", m);
        }
        if (e != false) {
            m = ST_OnOff.g(e);
            a.ad.h("noChangeAspect", m);
        }
        if (f != false) {
            m = ST_OnOff.g(f);
            a.ad.h("noMove", m);
        }
        if (g != false) {
            m = ST_OnOff.g(g);
            a.ad.h("noResize", m);
        }
        if (h != false) {
            m = ST_OnOff.g(h);
            a.ad.h("noEditPoints", m);
        }
        if (i != false) {
            m = ST_OnOff.g(i);
            a.ad.h("noAdjustHandles", m);
        }
        if (j != false) {
            m = ST_OnOff.g(j);
            a.ad.h("noChangeArrowheads", m);
        }
        if (k != false) {
            m = ST_OnOff.g(k);
            a.ad.h("noChangeShapeType", m);
        }
        if (l != false) {
            m = ST_OnOff.g(l);
            a.ad.h("noCrop", m);
        }
    };
    DrawingMLMain.ml = function (a, b, c, d, e, f, g, h, i, j, k, l) {
        b = Nullable$1.toNullable(ST_TextMargin.$, null);
        c = Nullable$1.toNullable(ST_TextMargin.$, null);
        d = Nullable$1.toNullable(ST_TextIndentLevelType.$, null);
        e = Nullable$1.toNullable(ST_TextIndent.$, null);
        f = Nullable$1.toNullable(ST_TextAlignType_$type, null);
        g = Nullable$1.toNullable(ST_Coordinate32.$, null);
        h = Nullable$1.toNullable(Boolean_$type, null);
        i = Nullable$1.toNullable(Boolean_$type, null);
        j = Nullable$1.toNullable(ST_TextFontAlignType_$type, null);
        k = Nullable$1.toNullable(Boolean_$type, null);
        l = Nullable$1.toNullable(Boolean_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var m = _1.value;
                switch (m.a.e(a.d)) {
                    case "marL":
                        b = Nullable$1.toNullable(ST_TextMargin.$, ST_TextMargin.c(m.d));
                        break;
                    case "marR":
                        c = Nullable$1.toNullable(ST_TextMargin.$, ST_TextMargin.c(m.d));
                        break;
                    case "lvl":
                        d = Nullable$1.toNullable(ST_TextIndentLevelType.$, ST_TextIndentLevelType.c(m.d));
                        break;
                    case "indent":
                        e = Nullable$1.toNullable(ST_TextIndent.$, ST_TextIndent.c(m.d));
                        break;
                    case "algn":
                        f = Nullable$1.toNullable(ST_TextAlignType_$type, XmlNamespaceDefinitionBase.b(ST_TextAlignType_$type, m.d));
                        break;
                    case "defTabSz":
                        g = Nullable$1.toNullable(ST_Coordinate32.$, ST_Coordinate32.g(m.d));
                        break;
                    case "rtl":
                        h = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(m.d));
                        break;
                    case "eaLnBrk":
                        i = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(m.d));
                        break;
                    case "fontAlgn":
                        j = Nullable$1.toNullable(ST_TextFontAlignType_$type, XmlNamespaceDefinitionBase.b(ST_TextFontAlignType_$type, m.d));
                        break;
                    case "latinLnBrk":
                        k = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(m.d));
                        break;
                    case "hangingPunct":
                        l = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(m.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_91_1) { e_91 = { error: e_91_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_91) throw e_91.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l
        };
        var e_91, _2;
    };
    DrawingMLMain.pm = function (a, b, c, d, e, f, g, h, i, j, k, l) {
        if (b === void 0) { b = Nullable$1.toNullable(ST_TextMargin.$, null); }
        if (c === void 0) { c = Nullable$1.toNullable(ST_TextMargin.$, null); }
        if (d === void 0) { d = Nullable$1.toNullable(ST_TextIndentLevelType.$, null); }
        if (e === void 0) { e = Nullable$1.toNullable(ST_TextIndent.$, null); }
        if (f === void 0) { f = Nullable$1.toNullable(ST_TextAlignType_$type, null); }
        if (g === void 0) { g = Nullable$1.toNullable(ST_Coordinate32.$, null); }
        if (h === void 0) { h = Nullable$1.toNullable(Boolean_$type, null); }
        if (i === void 0) { i = Nullable$1.toNullable(Boolean_$type, null); }
        if (j === void 0) { j = Nullable$1.toNullable(ST_TextFontAlignType_$type, null); }
        if (k === void 0) { k = Nullable$1.toNullable(Boolean_$type, null); }
        if (l === void 0) { l = Nullable$1.toNullable(Boolean_$type, null); }
        a.ad.p(DrawingMLMain.hl, "a");
        var m;
        if (nullableNotEquals(b, null)) {
            m = b.value.toString();
            a.ad.h("marL", m);
        }
        if (nullableNotEquals(c, null)) {
            m = c.value.toString();
            a.ad.h("marR", m);
        }
        if (nullableNotEquals(d, null)) {
            m = d.value.toString();
            a.ad.h("lvl", m);
        }
        if (nullableNotEquals(e, null)) {
            m = e.value.toString();
            a.ad.h("indent", m);
        }
        if (nullableNotEquals(f, null)) {
            m = XmlNamespaceDefinitionBase.f(ST_TextAlignType_$type, f.value);
            a.ad.h("algn", m);
        }
        if (nullableNotEquals(g, null)) {
            m = g.value.toString();
            a.ad.h("defTabSz", m);
        }
        if (nullableNotEquals(h, null)) {
            m = ST_OnOff.g(h.value);
            a.ad.h("rtl", m);
        }
        if (nullableNotEquals(i, null)) {
            m = ST_OnOff.g(i.value);
            a.ad.h("eaLnBrk", m);
        }
        if (nullableNotEquals(j, null)) {
            m = XmlNamespaceDefinitionBase.f(ST_TextFontAlignType_$type, j.value);
            a.ad.h("fontAlgn", m);
        }
        if (nullableNotEquals(k, null)) {
            m = ST_OnOff.g(k.value);
            a.ad.h("latinLnBrk", m);
        }
        if (nullableNotEquals(l, null)) {
            m = ST_OnOff.g(l.value);
            a.ad.h("hangingPunct", m);
        }
    };
    DrawingMLMain.mm = function (a, b) {
        b = 7;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = XmlNamespaceDefinitionBase.b(ST_PresetColorVal_$type, c.d, b);
                        break;
                    default: break;
                }
            }
        }
        catch (e_92_1) { e_92 = { error: e_92_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_92) throw e_92.error; }
        }
        return {
            p1: b
        };
        var e_92, _2;
    };
    DrawingMLMain.pn = function (a, b) {
        a.ad.p(DrawingMLMain.hn, "a");
        var c;
        c = XmlNamespaceDefinitionBase.f(ST_PresetColorVal_$type, b);
        a.ad.h("val", c);
    };
    DrawingMLMain.mn = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "prst":
                        b = XmlNamespaceDefinitionBase.b(ST_ShapeType_$type, c.d, b);
                        break;
                    default: break;
                }
            }
        }
        catch (e_93_1) { e_93 = { error: e_93_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_93) throw e_93.error; }
        }
        return {
            p1: b
        };
        var e_93, _2;
    };
    DrawingMLMain.po = function (a, b) {
        a.ad.p(DrawingMLMain.hp, "a");
        var c;
        c = XmlNamespaceDefinitionBase.f(ST_ShapeType_$type, b);
        a.ad.h("prst", c);
    };
    DrawingMLMain.mo = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.hx, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.pp = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.hx, b);
    };
    DrawingMLMain.mp = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.hy, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.pq = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.hy, b);
    };
    DrawingMLMain.mq = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.hz, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.pr = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.hz, b);
    };
    DrawingMLMain.mr = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_94_1) { e_94 = { error: e_94_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_94) throw e_94.error; }
        }
        var e_94, _2;
    };
    DrawingMLMain.ps = function (a) {
        a.ad.p(DrawingMLMain.hu, "a");
    };
    DrawingMLMain.ms = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v) {
        if (u === void 0) { u = DrawingMLMain.h7; }
        if (v === void 0) { v = true; }
        b = Nullable$1.toNullable(Boolean_$type, null);
        c = null;
        d = null;
        e = Nullable$1.toNullable(ST_TextFontSize.$, null);
        f = Nullable$1.toNullable(Boolean_$type, null);
        g = Nullable$1.toNullable(Boolean_$type, null);
        h = Nullable$1.toNullable(ST_TextUnderlineType_$type, null);
        i = Nullable$1.toNullable(ST_TextStrikeType_$type, null);
        j = Nullable$1.toNullable(Number_$type, null);
        k = Nullable$1.toNullable(ST_TextCapsType_$type, null);
        l = Nullable$1.toNullable(ST_TextPoint.$, null);
        m = Nullable$1.toNullable(Boolean_$type, null);
        n = Nullable$1.toNullable(ST_Percentage.$, null);
        o = Nullable$1.toNullable(Boolean_$type, null);
        p = Nullable$1.toNullable(Boolean_$type, null);
        q = Nullable$1.toNullable(Boolean_$type, null);
        r = Nullable$1.toNullable(Boolean_$type, null);
        s = Nullable$1.toNullable(Number_$type, null);
        var w = true;
        var x = false;
        var y = true;
        var z = 0;
        t = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var aa = _1.value;
                switch (aa.a.e(a.d)) {
                    case "kumimoji":
                        b = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(aa.d));
                        break;
                    case "lang":
                        c = aa.d;
                        break;
                    case "altLang":
                        d = aa.d;
                        break;
                    case "sz":
                        e = Nullable$1.toNullable(ST_TextFontSize.$, ST_TextFontSize.c(aa.d));
                        break;
                    case "b":
                        f = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(aa.d));
                        break;
                    case "i":
                        g = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(aa.d));
                        break;
                    case "u":
                        h = Nullable$1.toNullable(ST_TextUnderlineType_$type, XmlNamespaceDefinitionBase.b(ST_TextUnderlineType_$type, aa.d));
                        break;
                    case "strike":
                        i = Nullable$1.toNullable(ST_TextStrikeType_$type, XmlNamespaceDefinitionBase.b(ST_TextStrikeType_$type, aa.d));
                        break;
                    case "kern":
                        j = Nullable$1.toNullable(Number_$type, parseInt32_1(aa.d, CultureInfo.invariantCulture));
                        break;
                    case "cap":
                        k = Nullable$1.toNullable(ST_TextCapsType_$type, XmlNamespaceDefinitionBase.b(ST_TextCapsType_$type, aa.d));
                        break;
                    case "spc":
                        l = Nullable$1.toNullable(ST_TextPoint.$, ST_TextPoint.a(aa.d));
                        break;
                    case "normalizeH":
                        m = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(aa.d));
                        break;
                    case "baseline":
                        n = Nullable$1.toNullable(ST_Percentage.$, ST_Percentage.c(aa.d, a.d._z));
                        break;
                    case "noProof":
                        o = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(aa.d));
                        break;
                    case "dirty":
                        p = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(aa.d));
                        break;
                    case "err":
                        q = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(aa.d));
                        break;
                    case "smtClean":
                        r = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(aa.d));
                        break;
                    case "smtId":
                        s = Nullable$1.toNullable(Number_$type, parseUInt32_1(aa.d, CultureInfo.invariantCulture));
                        break;
                    case "bmk":
                        t = aa.d;
                        break;
                    default: break;
                }
                if (v) {
                    if (p.hasValue == false) {
                        p = Nullable$1.toNullable(Boolean_$type, w);
                    }
                    if (q.hasValue == false) {
                        q = Nullable$1.toNullable(Boolean_$type, x);
                    }
                    if (r.hasValue == false) {
                        r = Nullable$1.toNullable(Boolean_$type, y);
                    }
                    if (s.hasValue == false) {
                        s = Nullable$1.toNullable(Number_$type, z);
                    }
                }
            }
        }
        catch (e_95_1) { e_95 = { error: e_95_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_95) throw e_95.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t
        };
        var e_95, _2;
    };
    DrawingMLMain.pt = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t) {
        if (b === void 0) { b = Nullable$1.toNullable(Boolean_$type, null); }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = Nullable$1.toNullable(ST_TextFontSize.$, null); }
        if (f === void 0) { f = Nullable$1.toNullable(Boolean_$type, null); }
        if (g === void 0) { g = Nullable$1.toNullable(Boolean_$type, null); }
        if (h === void 0) { h = Nullable$1.toNullable(ST_TextUnderlineType_$type, null); }
        if (i === void 0) { i = Nullable$1.toNullable(ST_TextStrikeType_$type, null); }
        if (j === void 0) { j = Nullable$1.toNullable(Number_$type, null); }
        if (k === void 0) { k = Nullable$1.toNullable(ST_TextCapsType_$type, null); }
        if (l === void 0) { l = Nullable$1.toNullable(ST_TextPoint.$, null); }
        if (m === void 0) { m = Nullable$1.toNullable(Boolean_$type, null); }
        if (n === void 0) { n = Nullable$1.toNullable(ST_Percentage.$, null); }
        if (o === void 0) { o = Nullable$1.toNullable(Boolean_$type, null); }
        if (p === void 0) { p = Nullable$1.toNullable(Boolean_$type, true); }
        if (q === void 0) { q = Nullable$1.toNullable(Boolean_$type, false); }
        if (r === void 0) { r = Nullable$1.toNullable(Boolean_$type, true); }
        if (s === void 0) { s = Nullable$1.toNullable(Number_$type, 0); }
        if (t === void 0) { t = null; }
        a.ad.p(DrawingMLMain.h7, "a");
        var u;
        if (nullableNotEquals(b, null)) {
            u = ST_OnOff.g(b.value);
            a.ad.h("kumimoji", u);
        }
        u = c;
        a.ad.h("lang", u);
        u = d;
        a.ad.h("altLang", u);
        if (nullableNotEquals(e, null)) {
            u = e.value.toString();
            a.ad.h("sz", u);
        }
        if (nullableNotEquals(f, null)) {
            u = ST_OnOff.g(f.value);
            a.ad.h("b", u);
        }
        if (nullableNotEquals(g, null)) {
            u = ST_OnOff.g(g.value);
            a.ad.h("i", u);
        }
        if (nullableNotEquals(h, null)) {
            u = XmlNamespaceDefinitionBase.f(ST_TextUnderlineType_$type, h.value);
            a.ad.h("u", u);
        }
        if (nullableNotEquals(i, null)) {
            u = XmlNamespaceDefinitionBase.f(ST_TextStrikeType_$type, i.value);
            a.ad.h("strike", u);
        }
        if (nullableNotEquals(j, null)) {
            u = j.value.toString();
            a.ad.h("kern", u);
        }
        if (nullableNotEquals(k, null)) {
            u = XmlNamespaceDefinitionBase.f(ST_TextCapsType_$type, k.value);
            a.ad.h("cap", u);
        }
        if (nullableNotEquals(l, null)) {
            u = l.value.toString();
            a.ad.h("spc", u);
        }
        if (nullableNotEquals(m, null)) {
            u = ST_OnOff.g(m.value);
            a.ad.h("normalizeH", u);
        }
        if (ST_Percentage.g(n, Nullable$1.toNullable(ST_Percentage.$, null))) {
            u = n.value.p(a.d._z);
            a.ad.h("baseline", u);
        }
        if (nullableNotEquals(o, null)) {
            u = ST_OnOff.g(o.value);
            a.ad.h("noProof", u);
        }
        if (p.hasValue && nullableNotEquals(p, true)) {
            u = ST_OnOff.g(p.value);
            a.ad.h("dirty", u);
        }
        if (q.hasValue && nullableNotEquals(q, false)) {
            u = ST_OnOff.g(q.value);
            a.ad.h("err", u);
        }
        if (r.hasValue && nullableNotEquals(r, true)) {
            u = ST_OnOff.g(r.value);
            a.ad.h("smtClean", u);
        }
        if (s.hasValue && nullableNotEquals(s, 0)) {
            u = s.value.toString();
            a.ad.h("smtId", u);
        }
        u = t;
        a.ad.h("bmk", u);
    };
    DrawingMLMain.mt = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.ia, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.pu = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.ia, b);
    };
    DrawingMLMain.mu = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.ib, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.pv = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.ib, b);
    };
    DrawingMLMain.mv = function (a, b) {
        var c = DrawingMLMain.k0(a, DrawingMLMain.ic, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.pw = function (a, b) {
        DrawingMLMain.n1(a, DrawingMLMain.ic, b);
    };
    DrawingMLMain.mw = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = XmlNamespaceDefinitionBase.b(ST_SchemeColorVal_$type, c.d, b);
                        break;
                    default: break;
                }
            }
        }
        catch (e_96_1) { e_96 = { error: e_96_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_96) throw e_96.error; }
        }
        return {
            p1: b
        };
        var e_96, _2;
    };
    DrawingMLMain.px = function (a, b) {
        a.ad.p(DrawingMLMain.ie, "a");
        var c;
        c = XmlNamespaceDefinitionBase.f(ST_SchemeColorVal_$type, b);
        a.ad.h("val", c);
    };
    DrawingMLMain.mx = function (a, b) {
        var c = DrawingMLMain.k3(a, DrawingMLMain.ii, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.py = function (a, b) {
        DrawingMLMain.n4(a, DrawingMLMain.ii, b);
    };
    DrawingMLMain.my = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_97_1) { e_97 = { error: e_97_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_97) throw e_97.error; }
        }
        var e_97, _2;
    };
    DrawingMLMain.pz = function (a) {
        a.ad.p(DrawingMLMain.io, "a");
    };
    DrawingMLMain.mz = function (a, b, c, d, e, f, g, h, i, j, k, l) {
        b = false;
        c = false;
        d = false;
        e = false;
        f = false;
        g = false;
        h = false;
        i = false;
        j = false;
        k = false;
        l = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var m = _1.value;
                switch (m.a.e(a.d)) {
                    case "noGrp":
                        b = ST_OnOff.e(m.d);
                        break;
                    case "noSelect":
                        c = ST_OnOff.e(m.d);
                        break;
                    case "noRot":
                        d = ST_OnOff.e(m.d);
                        break;
                    case "noChangeAspect":
                        e = ST_OnOff.e(m.d);
                        break;
                    case "noMove":
                        f = ST_OnOff.e(m.d);
                        break;
                    case "noResize":
                        g = ST_OnOff.e(m.d);
                        break;
                    case "noEditPoints":
                        h = ST_OnOff.e(m.d);
                        break;
                    case "noAdjustHandles":
                        i = ST_OnOff.e(m.d);
                        break;
                    case "noChangeArrowheads":
                        j = ST_OnOff.e(m.d);
                        break;
                    case "noChangeShapeType":
                        k = ST_OnOff.e(m.d);
                        break;
                    case "noTextEdit":
                        l = ST_OnOff.e(m.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_98_1) { e_98 = { error: e_98_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_98) throw e_98.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l
        };
        var e_98, _2;
    };
    DrawingMLMain.p0 = function (a, b, c, d, e, f, g, h, i, j, k, l) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = false; }
        if (k === void 0) { k = false; }
        if (l === void 0) { l = false; }
        a.ad.p(DrawingMLMain.iy, "a");
        var m;
        if (b != false) {
            m = ST_OnOff.g(b);
            a.ad.h("noGrp", m);
        }
        if (c != false) {
            m = ST_OnOff.g(c);
            a.ad.h("noSelect", m);
        }
        if (d != false) {
            m = ST_OnOff.g(d);
            a.ad.h("noRot", m);
        }
        if (e != false) {
            m = ST_OnOff.g(e);
            a.ad.h("noChangeAspect", m);
        }
        if (f != false) {
            m = ST_OnOff.g(f);
            a.ad.h("noMove", m);
        }
        if (g != false) {
            m = ST_OnOff.g(g);
            a.ad.h("noResize", m);
        }
        if (h != false) {
            m = ST_OnOff.g(h);
            a.ad.h("noEditPoints", m);
        }
        if (i != false) {
            m = ST_OnOff.g(i);
            a.ad.h("noAdjustHandles", m);
        }
        if (j != false) {
            m = ST_OnOff.g(j);
            a.ad.h("noChangeArrowheads", m);
        }
        if (k != false) {
            m = ST_OnOff.g(k);
            a.ad.h("noChangeShapeType", m);
        }
        if (l != false) {
            m = ST_OnOff.g(l);
            a.ad.h("noTextEdit", m);
        }
    };
    DrawingMLMain.m0 = function (a, b, c, d, e) {
        var f = DrawingMLMain.k6(a, DrawingMLMain.iz, b, c, d, e);
        b = f.p2;
        c = f.p3;
        d = f.p4;
        e = f.p5;
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
    };
    DrawingMLMain.p1 = function (a, b, c, d, e) {
        DrawingMLMain.n7(a, DrawingMLMain.iz, b, c, d, e);
    };
    DrawingMLMain.m1 = function (a, b) {
        b = ST_HexColorRGB.a;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = ST_HexColorRGB.d(c.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_99_1) { e_99 = { error: e_99_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_99) throw e_99.error; }
        }
        return {
            p1: b
        };
        var e_99, _2;
    };
    DrawingMLMain.p2 = function (a, b) {
        a.ad.p(DrawingMLMain.i0, "a");
        var c;
        c = b.toString();
        a.ad.h("val", c);
    };
    DrawingMLMain.m2 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_100_1) { e_100 = { error: e_100_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_100) throw e_100.error; }
        }
        var e_100, _2;
    };
    DrawingMLMain.p3 = function (a) {
        a.ad.p(DrawingMLMain.i2, "a");
    };
    DrawingMLMain.m3 = function (a, b, c) {
        b = 0;
        c = ST_HexColorRGB.a;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "val":
                        b = XmlNamespaceDefinitionBase.b(ST_SystemColorVal_$type, d.d, b);
                        break;
                    case "lastClr":
                        c = ST_HexColorRGB.d(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_101_1) { e_101 = { error: e_101_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_101) throw e_101.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_101, _2;
    };
    DrawingMLMain.p4 = function (a, b, c) {
        a.ad.p(DrawingMLMain.i8, "a");
        var d;
        d = XmlNamespaceDefinitionBase.f(ST_SystemColorVal_$type, b);
        a.ad.h("val", d);
        d = c.toString();
        a.ad.h("lastClr", d);
    };
    DrawingMLMain.m4 = function (a, b, c, d) {
        var e = DrawingMLMain.ky(a, DrawingMLMain.je, b, c, d);
        b = e.p2;
        c = e.p3;
        d = e.p4;
        return {
            p1: b,
            p2: c,
            p3: d
        };
    };
    DrawingMLMain.p5 = function (a, b, c, d) {
        DrawingMLMain.nz(a, DrawingMLMain.je, b, c, d);
    };
    DrawingMLMain.m5 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, DrawingMLMain.ja, b, 6);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.p6 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, DrawingMLMain.ja, "a", b, void 0, 6);
    };
    DrawingMLMain.m6 = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "name":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_102_1) { e_102 = { error: e_102_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_102) throw e_102.error; }
        }
        return {
            p1: b
        };
        var e_102, _2;
    };
    DrawingMLMain.p7 = function (a, b) {
        a.ad.p(DrawingMLMain.jg, "a");
        var c;
        c = b;
        a.ad.h("name", c);
        a.ad.l(IGOfficeExtensions.an, true);
    };
    DrawingMLMain.m7 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_103_1) { e_103 = { error: e_103_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_103) throw e_103.error; }
        }
        var e_103, _2;
    };
    DrawingMLMain.p8 = function (a) {
        a.ad.p(DrawingMLMain.jh, "a");
    };
    DrawingMLMain.m8 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_104_1) { e_104 = { error: e_104_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_104) throw e_104.error; }
        }
        var e_104, _2;
    };
    DrawingMLMain.p9 = function (a) {
        a.ad.p(DrawingMLMain.ji, "a");
    };
    DrawingMLMain.m9 = function (a, b) {
        var c = DrawingMLMain.k3(a, DrawingMLMain.jm, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLMain.qa = function (a, b) {
        DrawingMLMain.n4(a, DrawingMLMain.jm, b);
    };
    DrawingMLMain.na = function (a, b, c, d) {
        b = ST_Angle.a(0);
        c = false;
        d = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "rot":
                        b = ST_Angle.b(e.d);
                        break;
                    case "flipH":
                        c = ST_OnOff.e(e.d);
                        break;
                    case "flipV":
                        d = ST_OnOff.e(e.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_105_1) { e_105 = { error: e_105_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_105) throw e_105.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_105, _2;
    };
    DrawingMLMain.qb = function (a, b, c, d) {
        if (b === void 0) { b = new ST_Angle(); }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        a.ad.p(DrawingMLMain.j8, "a");
        var e;
        if (b.n() != 0) {
            e = b.toString();
            a.ad.h("rot", e);
        }
        if (c != false) {
            e = ST_OnOff.g(c);
            a.ad.h("flipH", e);
        }
        if (d != false) {
            e = ST_OnOff.g(d);
            a.ad.h("flipV", e);
        }
    };
    DrawingMLMain.$t = markType(DrawingMLMain, 'DrawingMLMain', XmlNamespaceDefinitionBase.$);
    DrawingMLMain.gp = "http://schemas.openxmlformats.org/drawingml/2006/main";
    DrawingMLMain.go = "http://purl.oclc.org/ooxml/drawingml/main";
    DrawingMLMain.aq = DrawingMLMain.go + "/accent1";
    DrawingMLMain.ar = DrawingMLMain.go + "/accent2";
    DrawingMLMain.as = DrawingMLMain.go + "/accent3";
    DrawingMLMain.at = DrawingMLMain.go + "/accent4";
    DrawingMLMain.au = DrawingMLMain.go + "/accent5";
    DrawingMLMain.av = DrawingMLMain.go + "/accent6";
    DrawingMLMain.ay = DrawingMLMain.go + "/ahPolar";
    DrawingMLMain.az = DrawingMLMain.go + "/ahXY";
    DrawingMLMain.a1 = DrawingMLMain.go + "/alpha";
    DrawingMLMain.a6 = DrawingMLMain.go + "/alphaMod";
    DrawingMLMain.a8 = DrawingMLMain.go + "/alphaOff";
    DrawingMLMain.bf = DrawingMLMain.go + "/arcTo";
    DrawingMLMain.bg = DrawingMLMain.go + "/avLst";
    DrawingMLMain.bs = DrawingMLMain.go + "/blip";
    DrawingMLMain.bt = DrawingMLMain.go + "/blipFill";
    DrawingMLMain.bu = DrawingMLMain.go + "/blue";
    DrawingMLMain.bv = DrawingMLMain.go + "/blueMod";
    DrawingMLMain.bw = DrawingMLMain.go + "/blueOff";
    DrawingMLMain.bz = DrawingMLMain.go + "/bodyPr";
    DrawingMLMain.cg = DrawingMLMain.go + "/chExt";
    DrawingMLMain.ch = DrawingMLMain.go + "/chOff";
    DrawingMLMain.ci = DrawingMLMain.go + "/close";
    DrawingMLMain.cm = DrawingMLMain.go + "/clrScheme";
    DrawingMLMain.cp = DrawingMLMain.go + "/comp";
    DrawingMLMain.ct = DrawingMLMain.go + "/cs";
    DrawingMLMain.cv = DrawingMLMain.go + "/cubicBezTo";
    DrawingMLMain.cw = DrawingMLMain.go + "/custClr";
    DrawingMLMain.cx = DrawingMLMain.go + "/custClrLst";
    DrawingMLMain.cz = DrawingMLMain.go + "/custGeom";
    DrawingMLMain.c9 = DrawingMLMain.go + "/dk1";
    DrawingMLMain.da = DrawingMLMain.go + "/dk2";
    DrawingMLMain.de = DrawingMLMain.go + "/ea";
    DrawingMLMain.dj = DrawingMLMain.go + "/effectRef";
    DrawingMLMain.dq = DrawingMLMain.go + "/ext";
    DrawingMLMain.dr = DrawingMLMain.go + "/extLst";
    DrawingMLMain.ds = DrawingMLMain.go + "/extraClrScheme";
    DrawingMLMain.dt = DrawingMLMain.go + "/extraClrSchemeLst";
    DrawingMLMain.dy = DrawingMLMain.go + "/fillRect";
    DrawingMLMain.dz = DrawingMLMain.go + "/fillRef";
    DrawingMLMain.d7 = DrawingMLMain.go + "/fmtScheme";
    DrawingMLMain.d8 = DrawingMLMain.go + "/folHlink";
    DrawingMLMain.d9 = DrawingMLMain.go + "/font";
    DrawingMLMain.eb = DrawingMLMain.go + "/fontRef";
    DrawingMLMain.ec = DrawingMLMain.go + "/fontScheme";
    DrawingMLMain.eg = DrawingMLMain.go + "/gd";
    DrawingMLMain.ek = DrawingMLMain.go + "/graphic";
    DrawingMLMain.el = DrawingMLMain.go + "/graphicData";
    DrawingMLMain.em = DrawingMLMain.go + "/graphicFrameLocks";
    DrawingMLMain.en = DrawingMLMain.go + "/gray";
    DrawingMLMain.ep = DrawingMLMain.go + "/green";
    DrawingMLMain.eq = DrawingMLMain.go + "/greenMod";
    DrawingMLMain.er = DrawingMLMain.go + "/greenOff";
    DrawingMLMain.es = DrawingMLMain.go + "/grpFill";
    DrawingMLMain.ew = DrawingMLMain.go + "/headEnd";
    DrawingMLMain.e1 = DrawingMLMain.go + "/hlink";
    DrawingMLMain.e2 = DrawingMLMain.go + "/hlinkClick";
    DrawingMLMain.e8 = DrawingMLMain.go + "/hue";
    DrawingMLMain.e9 = DrawingMLMain.go + "/hueMod";
    DrawingMLMain.fa = DrawingMLMain.go + "/hueOff";
    DrawingMLMain.fg = DrawingMLMain.go + "/inv";
    DrawingMLMain.fq = DrawingMLMain.go + "/latin";
    DrawingMLMain.fw = DrawingMLMain.go + "/ln";
    DrawingMLMain.fx = DrawingMLMain.go + "/lnRef";
    DrawingMLMain.f0 = DrawingMLMain.go + "/lnTo";
    DrawingMLMain.f1 = DrawingMLMain.go + "/lstStyle";
    DrawingMLMain.f2 = DrawingMLMain.go + "/lt1";
    DrawingMLMain.f3 = DrawingMLMain.go + "/lt2";
    DrawingMLMain.f4 = DrawingMLMain.go + "/lum";
    DrawingMLMain.f5 = DrawingMLMain.go + "/lumMod";
    DrawingMLMain.f6 = DrawingMLMain.go + "/lumOff";
    DrawingMLMain.gh = DrawingMLMain.go + "/majorFont";
    DrawingMLMain.gk = DrawingMLMain.go + "/minorFont";
    DrawingMLMain.gm = DrawingMLMain.go + "/moveTo";
    DrawingMLMain.gy = DrawingMLMain.go + "/noFill";
    DrawingMLMain.ha = DrawingMLMain.go + "/objectDefaults";
    DrawingMLMain.hb = DrawingMLMain.go + "/off";
    DrawingMLMain.hd = DrawingMLMain.go + "/p";
    DrawingMLMain.hi = DrawingMLMain.go + "/picLocks";
    DrawingMLMain.hl = DrawingMLMain.go + "/pPr";
    DrawingMLMain.hn = DrawingMLMain.go + "/prstClr";
    DrawingMLMain.hp = DrawingMLMain.go + "/prstGeom";
    DrawingMLMain.hs = DrawingMLMain.go + "/pt";
    DrawingMLMain.ht = DrawingMLMain.go + "/quadBezTo";
    DrawingMLMain.hu = DrawingMLMain.go + "/r";
    DrawingMLMain.hx = DrawingMLMain.go + "/red";
    DrawingMLMain.hy = DrawingMLMain.go + "/redMod";
    DrawingMLMain.hz = DrawingMLMain.go + "/redOff";
    DrawingMLMain.h7 = DrawingMLMain.go + "/rPr";
    DrawingMLMain.ia = DrawingMLMain.go + "/sat";
    DrawingMLMain.ib = DrawingMLMain.go + "/satMod";
    DrawingMLMain.ic = DrawingMLMain.go + "/satOff";
    DrawingMLMain.ie = DrawingMLMain.go + "/schemeClr";
    DrawingMLMain.ii = DrawingMLMain.go + "/shade";
    DrawingMLMain.io = DrawingMLMain.go + "/solidFill";
    DrawingMLMain.iy = DrawingMLMain.go + "/spLocks";
    DrawingMLMain.iz = DrawingMLMain.go + "/srcRect";
    DrawingMLMain.i0 = DrawingMLMain.go + "/srgbClr";
    DrawingMLMain.i2 = DrawingMLMain.go + "/stretch";
    DrawingMLMain.i8 = DrawingMLMain.go + "/sysClr";
    DrawingMLMain.ja = DrawingMLMain.go + "/t";
    DrawingMLMain.je = DrawingMLMain.go + "/tailEnd";
    DrawingMLMain.jg = DrawingMLMain.go + "/theme";
    DrawingMLMain.jh = DrawingMLMain.go + "/themeElements";
    DrawingMLMain.ji = DrawingMLMain.go + "/themeManager";
    DrawingMLMain.jm = DrawingMLMain.go + "/tint";
    DrawingMLMain.j8 = DrawingMLMain.go + "/xfrm";
    DrawingMLMain.gr = DrawingMLMain.go + "/noAutofit";
    DrawingMLMain.g5 = DrawingMLMain.go + "/normAutofit";
    DrawingMLMain.hr = DrawingMLMain.go + "/prstTxWarp";
    DrawingMLMain.id = DrawingMLMain.go + "/scene3d";
    DrawingMLMain.ip = DrawingMLMain.go + "/sp3d";
    DrawingMLMain.iq = DrawingMLMain.go + "/spAutoFit";
    DrawingMLMain.bi = DrawingMLMain.go + "/backdrop";
    DrawingMLMain.bl = DrawingMLMain.go + "/bevelB";
    DrawingMLMain.bm = DrawingMLMain.go + "/bevelT";
    DrawingMLMain.cd = DrawingMLMain.go + "/camera";
    DrawingMLMain.ft = DrawingMLMain.go + "/lightRig";
    DrawingMLMain.hc = DrawingMLMain.go + "/outerShdw";
    DrawingMLMain.bc = DrawingMLMain.go + "/anchor";
    DrawingMLMain.g3 = DrawingMLMain.go + "/norm";
    DrawingMLMain.jy = DrawingMLMain.go + "/up";
    DrawingMLMain.h3 = DrawingMLMain.go + "/rot";
    DrawingMLMain.cs = DrawingMLMain.go + "/contourClr";
    DrawingMLMain.du = DrawingMLMain.go + "/extrusionClr";
    DrawingMLMain.e7 = DrawingMLMain.go + "/hslClr";
    DrawingMLMain.ig = DrawingMLMain.go + "/scrgbClr";
    DrawingMLMain.ef = DrawingMLMain.go + "/gamma";
    DrawingMLMain.fi = DrawingMLMain.go + "/invGamma";
    DrawingMLMain.dh = DrawingMLMain.go + "/effectDag";
    DrawingMLMain.di = DrawingMLMain.go + "/effectLst";
    DrawingMLMain.ej = DrawingMLMain.go + "/gradFill";
    DrawingMLMain.ey = DrawingMLMain.go + "/highlight";
    DrawingMLMain.e3 = DrawingMLMain.go + "/hlinkMouseOver";
    DrawingMLMain.hh = DrawingMLMain.go + "/pattFill";
    DrawingMLMain.i7 = DrawingMLMain.go + "/sym";
    DrawingMLMain.ju = DrawingMLMain.go + "/uFill";
    DrawingMLMain.jv = DrawingMLMain.go + "/uFillTx";
    DrawingMLMain.jw = DrawingMLMain.go + "/uLn";
    DrawingMLMain.jx = DrawingMLMain.go + "/uLnTx";
    DrawingMLMain.a2 = DrawingMLMain.go + "/alphaBiLevel";
    DrawingMLMain.a3 = DrawingMLMain.go + "/alphaCeiling";
    DrawingMLMain.a4 = DrawingMLMain.go + "/alphaFloor";
    DrawingMLMain.a5 = DrawingMLMain.go + "/alphaInv";
    DrawingMLMain.a7 = DrawingMLMain.go + "/alphaModFix";
    DrawingMLMain.ba = DrawingMLMain.go + "/alphaRepl";
    DrawingMLMain.a9 = DrawingMLMain.go + "/alphaOutset";
    DrawingMLMain.br = DrawingMLMain.go + "/blend";
    DrawingMLMain.jj = DrawingMLMain.go + "/tile";
    DrawingMLMain.bp = DrawingMLMain.go + "/biLevel";
    DrawingMLMain.bx = DrawingMLMain.go + "/blur";
    DrawingMLMain.cj = DrawingMLMain.go + "/clrChange";
    DrawingMLMain.cl = DrawingMLMain.go + "/clrRepl";
    DrawingMLMain.dd = DrawingMLMain.go + "/duotone";
    DrawingMLMain.dg = DrawingMLMain.go + "/effect";
    DrawingMLMain.dw = DrawingMLMain.go + "/fill";
    DrawingMLMain.dx = DrawingMLMain.go + "/fillOverlay";
    DrawingMLMain.eo = DrawingMLMain.go + "/grayscl";
    DrawingMLMain.e6 = DrawingMLMain.go + "/hsl";
    DrawingMLMain.ck = DrawingMLMain.go + "/clrFrom";
    DrawingMLMain.cn = DrawingMLMain.go + "/clrTo";
    DrawingMLMain.ei = DrawingMLMain.go + "/glow";
    DrawingMLMain.ff = DrawingMLMain.go + "/innerShdw";
    DrawingMLMain.hq = DrawingMLMain.go + "/prstShdw";
    DrawingMLMain.h0 = DrawingMLMain.go + "/reflection";
    DrawingMLMain.im = DrawingMLMain.go + "/softEdge";
    DrawingMLMain.eu = DrawingMLMain.go + "/gsLst";
    DrawingMLMain.fu = DrawingMLMain.go + "/lin";
    DrawingMLMain.hf = DrawingMLMain.go + "/path";
    DrawingMLMain.jk = DrawingMLMain.go + "/tileRect";
    DrawingMLMain.et = DrawingMLMain.go + "/gs";
    DrawingMLMain.il = DrawingMLMain.go + "/snd";
    DrawingMLMain.bk = DrawingMLMain.go + "/bevel";
    DrawingMLMain.cy = DrawingMLMain.go + "/custDash";
    DrawingMLMain.ho = DrawingMLMain.go + "/prstDash";
    DrawingMLMain.gl = DrawingMLMain.go + "/miter";
    DrawingMLMain.h6 = DrawingMLMain.go + "/round";
    DrawingMLMain.dc = DrawingMLMain.go + "/ds";
    DrawingMLMain.bn = DrawingMLMain.go + "/bgClr";
    DrawingMLMain.dv = DrawingMLMain.go + "/fgClr";
    DrawingMLMain.ax = DrawingMLMain.go + "/ahLst";
    DrawingMLMain.c2 = DrawingMLMain.go + "/cxnLst";
    DrawingMLMain.eh = DrawingMLMain.go + "/gdLst";
    DrawingMLMain.hg = DrawingMLMain.go + "/pathLst";
    DrawingMLMain.hw = DrawingMLMain.go + "/rect";
    DrawingMLMain.c1 = DrawingMLMain.go + "/cxn";
    DrawingMLMain.hk = DrawingMLMain.go + "/pos";
    DrawingMLMain.d2 = DrawingMLMain.go + "/flatTx";
    DrawingMLMain.bo = DrawingMLMain.go + "/bgFillStyleLst";
    DrawingMLMain.dl = DrawingMLMain.go + "/effectStyleLst";
    DrawingMLMain.d0 = DrawingMLMain.go + "/fillStyleLst";
    DrawingMLMain.fz = DrawingMLMain.go + "/lnStyleLst";
    DrawingMLMain.cr = DrawingMLMain.go + "/cont";
    DrawingMLMain.d1 = DrawingMLMain.go + "/fillToRect";
    DrawingMLMain.dk = DrawingMLMain.go + "/effectStyle";
    DrawingMLMain.h1 = DrawingMLMain.go + "/relOff";
    DrawingMLMain.c4 = DrawingMLMain.go + "/defPPr";
    DrawingMLMain.f8 = DrawingMLMain.go + "/lvl1pPr";
    DrawingMLMain.f9 = DrawingMLMain.go + "/lvl2pPr";
    DrawingMLMain.ga = DrawingMLMain.go + "/lvl3pPr";
    DrawingMLMain.gb = DrawingMLMain.go + "/lvl4pPr";
    DrawingMLMain.gc = DrawingMLMain.go + "/lvl5pPr";
    DrawingMLMain.gd = DrawingMLMain.go + "/lvl6pPr";
    DrawingMLMain.ge = DrawingMLMain.go + "/lvl7pPr";
    DrawingMLMain.gf = DrawingMLMain.go + "/lvl8pPr";
    DrawingMLMain.gg = DrawingMLMain.go + "/lvl9pPr";
    DrawingMLMain.fy = DrawingMLMain.go + "/lnSpc";
    DrawingMLMain.is = DrawingMLMain.go + "/spcAft";
    DrawingMLMain.it = DrawingMLMain.go + "/spcBef";
    DrawingMLMain.iw = DrawingMLMain.go + "/spcPct";
    DrawingMLMain.ix = DrawingMLMain.go + "/spcPts";
    DrawingMLMain.b4 = DrawingMLMain.go + "/buClr";
    DrawingMLMain.b5 = DrawingMLMain.go + "/buClrTx";
    DrawingMLMain.b6 = DrawingMLMain.go + "/buFont";
    DrawingMLMain.b7 = DrawingMLMain.go + "/buFontTx";
    DrawingMLMain.b9 = DrawingMLMain.go + "/buSzPct";
    DrawingMLMain.ca = DrawingMLMain.go + "/buSzPts";
    DrawingMLMain.cb = DrawingMLMain.go + "/buSzTx";
    DrawingMLMain.b1 = DrawingMLMain.go + "/buAutoNum";
    DrawingMLMain.b8 = DrawingMLMain.go + "/buNone";
    DrawingMLMain.b2 = DrawingMLMain.go + "/buBlip";
    DrawingMLMain.b3 = DrawingMLMain.go + "/buChar";
    DrawingMLMain.c5 = DrawingMLMain.go + "/defRPr";
    DrawingMLMain.jc = DrawingMLMain.go + "/tab";
    DrawingMLMain.b0 = DrawingMLMain.go + "/br";
    DrawingMLMain.d3 = DrawingMLMain.go + "/fld";
    DrawingMLMain.dm = DrawingMLMain.go + "/endParaRPr";
    DrawingMLMain.jd = DrawingMLMain.go + "/tabLst";
    DrawingMLMain.an = new DrawingMLMain();
    return DrawingMLMain;
}(XmlNamespaceDefinitionBase));
export { DrawingMLMain };
var DrawingNamespaceDefinitionBase = /** @class */ (function (_super) {
    tslib_1.__extends(DrawingNamespaceDefinitionBase, _super);
    function DrawingNamespaceDefinitionBase(a, b) {
        var _this = _super.call(this) || this;
        _this.an = null;
        _this.ap = null;
        _this.aq = null;
        _this.ar = null;
        _this.as = null;
        _this.at = null;
        _this.au = null;
        _this.av = null;
        _this.aw = null;
        _this.ay = null;
        _this.a3 = null;
        _this.a4 = null;
        _this.a5 = null;
        _this.a6 = null;
        _this.bn = null;
        _this.bo = null;
        _this.bp = null;
        _this.bq = null;
        _this.br = null;
        _this.bs = null;
        _this.bw = null;
        _this.bx = null;
        _this.by = null;
        _this.bz = null;
        _this.b1 = null;
        _this.b3 = null;
        _this.ba = null;
        _this.bb = null;
        _this.ba = a;
        _this.bb = b;
        _this.an = a + "/blipFill";
        _this.ap = a + "/cNvCxnSpPr";
        _this.aq = a + "/cNvGraphicFramePr";
        _this.ar = a + "/cNvGrpSpPr";
        _this.as = a + "/cNvPicPr";
        _this.at = a + "/cNvPr";
        _this.au = a + "/cNvSpPr";
        _this.av = a + "/cxnSp";
        _this.aw = a + "/cxnSpLocks";
        _this.ay = a + "/endCxn";
        _this.a3 = a + "/graphicFrame";
        _this.a4 = a + "/grpSp";
        _this.a5 = a + "/grpSpLocks";
        _this.a6 = a + "/grpSpPr";
        _this.bn = a + "/nvCxnSpPr";
        _this.bo = a + "/nvGraphicFramePr";
        _this.bp = a + "/nvGrpSpPr";
        _this.bq = a + "/nvPicPr";
        _this.br = a + "/nvSpPr";
        _this.bs = a + "/pic";
        _this.bw = a + "/sp";
        _this.bx = a + "/spPr";
        _this.by = a + "/stCxn";
        _this.bz = a + "/style";
        _this.b1 = a + "/txBody";
        _this.b3 = a + "/xfrm";
        return _this;
    }
    DrawingNamespaceDefinitionBase.prototype.i = function (a) {
        switch (a) {
            case 0: return this.bb;
            case 1: return this.ba;
            default: return this.bb;
        }
    };
    DrawingNamespaceDefinitionBase.prototype.cb = function (a, b, c, d) {
        c = 0;
        d = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "id":
                        c = parseUInt32_1(e.d, CultureInfo.invariantCulture);
                        break;
                    case "idx":
                        d = parseUInt32_1(e.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_106_1) { e_106 = { error: e_106_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_106) throw e_106.error; }
        }
        return {
            p2: c,
            p3: d
        };
        var e_106, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.c2 = function (a, b, c, d) {
        if (c === void 0) { c = 0; }
        if (d === void 0) { d = 0; }
        a.ad.p(b, this.j);
        var e;
        if (c != 0) {
            e = c.toString();
            a.ad.h("id", e);
        }
        if (d != 0) {
            e = d.toString();
            a.ad.h("idx", e);
        }
    };
    DrawingNamespaceDefinitionBase.da = function (a, b) {
        if (stringIsNullOrEmpty(b)) {
            return;
        }
        DrawingNamespaceDefinitionBase.da(a, b);
    };
    DrawingNamespaceDefinitionBase.prototype.b4 = function (a, b, c) {
        b = Nullable$1.toNullable(Number_$type, null);
        c = Nullable$1.toNullable(Boolean_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "dpi":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(d.d, CultureInfo.invariantCulture));
                        break;
                    case "rotWithShape":
                        c = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(d.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_107_1) { e_107 = { error: e_107_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_107) throw e_107.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_107, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.cv = function (a, b, c) {
        a.ad.p(this.an, this.j);
        var d;
        if (nullableNotEquals(b, null)) {
            d = b.value.toString();
            a.ad.h("dpi", d);
        }
        if (nullableNotEquals(c, null)) {
            d = ST_OnOff.g(c.value);
            a.ad.h("rotWithShape", d);
        }
    };
    DrawingNamespaceDefinitionBase.prototype.b5 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_108_1) { e_108 = { error: e_108_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_108) throw e_108.error; }
        }
        var e_108, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.cw = function (a) {
        a.ad.p(this.ap, this.j);
    };
    DrawingNamespaceDefinitionBase.prototype.b6 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_109_1) { e_109 = { error: e_109_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_109) throw e_109.error; }
        }
        var e_109, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.cx = function (a) {
        a.ad.p(this.aq, this.j);
    };
    DrawingNamespaceDefinitionBase.prototype.b7 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_110_1) { e_110 = { error: e_110_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_110) throw e_110.error; }
        }
        var e_110, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.cy = function (a) {
        a.ad.p(this.ar, this.j);
    };
    DrawingNamespaceDefinitionBase.prototype.b8 = function (a, b) {
        b = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "preferRelativeResize":
                        b = ST_OnOff.e(c.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_111_1) { e_111 = { error: e_111_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_111) throw e_111.error; }
        }
        return {
            p1: b
        };
        var e_111, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.cz = function (a, b) {
        if (b === void 0) { b = true; }
        a.ad.p(this.as, this.j);
        var c;
        if (b != true) {
            c = ST_OnOff.g(b);
            a.ad.h("preferRelativeResize", c);
        }
    };
    DrawingNamespaceDefinitionBase.prototype.b9 = function (a, b, c, d, e, f) {
        var g = DrawingMLMain.kz(a, this.at, b, c, d, e, f);
        b = g.p2;
        c = g.p3;
        d = g.p4;
        e = g.p5;
        f = g.p6;
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
    };
    DrawingNamespaceDefinitionBase.prototype.c0 = function (a, b, c, d, e, f) {
        if (d === void 0) { d = null; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = null; }
        DrawingMLMain.n0(a, this.at, b, c, d, e, f);
    };
    DrawingNamespaceDefinitionBase.prototype.ca = function (a, b) {
        b = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "txBox":
                        b = ST_OnOff.e(c.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_112_1) { e_112 = { error: e_112_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_112) throw e_112.error; }
        }
        return {
            p1: b
        };
        var e_112, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.c1 = function (a, b) {
        if (b === void 0) { b = false; }
        a.ad.p(this.au, this.j);
        var c;
        if (b != false) {
            c = ST_OnOff.g(b);
            a.ad.h("txBox", c);
        }
    };
    DrawingNamespaceDefinitionBase.prototype.cc = function (a, b, c) {
        b = null;
        c = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "macro":
                        b = d.d;
                        break;
                    case "fPublished":
                        c = ST_OnOff.e(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_113_1) { e_113 = { error: e_113_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_113) throw e_113.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_113, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.c3 = function (a, b, c) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = false; }
        a.ad.p(this.av, this.j);
        var d;
        d = b;
        DrawingNamespaceDefinitionBase.da(a, d);
        if (c != false) {
            d = ST_OnOff.g(c);
            a.ad.h("fPublished", d);
        }
    };
    DrawingNamespaceDefinitionBase.prototype.cd = function (a, b, c, d, e, f, g, h, i, j, k) {
        b = false;
        c = false;
        d = false;
        e = false;
        f = false;
        g = false;
        h = false;
        i = false;
        j = false;
        k = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var l = _1.value;
                switch (l.a.e(a.d)) {
                    case "noGrp":
                        b = ST_OnOff.e(l.d);
                        break;
                    case "noSelect":
                        c = ST_OnOff.e(l.d);
                        break;
                    case "noRot":
                        d = ST_OnOff.e(l.d);
                        break;
                    case "noChangeAspect":
                        e = ST_OnOff.e(l.d);
                        break;
                    case "noMove":
                        f = ST_OnOff.e(l.d);
                        break;
                    case "noResize":
                        g = ST_OnOff.e(l.d);
                        break;
                    case "noEditPoints":
                        h = ST_OnOff.e(l.d);
                        break;
                    case "noAdjustHandles":
                        i = ST_OnOff.e(l.d);
                        break;
                    case "noChangeArrowheads":
                        j = ST_OnOff.e(l.d);
                        break;
                    case "noChangeShapeType":
                        k = ST_OnOff.e(l.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_114_1) { e_114 = { error: e_114_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_114) throw e_114.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k
        };
        var e_114, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.c4 = function (a, b, c, d, e, f, g, h, i, j, k) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = false; }
        if (k === void 0) { k = false; }
        a.ad.p(this.aw, this.j);
        var l;
        if (b != false) {
            l = ST_OnOff.g(b);
            a.ad.h("noGrp", l);
        }
        if (c != false) {
            l = ST_OnOff.g(c);
            a.ad.h("noSelect", l);
        }
        if (d != false) {
            l = ST_OnOff.g(d);
            a.ad.h("noRot", l);
        }
        if (e != false) {
            l = ST_OnOff.g(e);
            a.ad.h("noChangeAspect", l);
        }
        if (f != false) {
            l = ST_OnOff.g(f);
            a.ad.h("noMove", l);
        }
        if (g != false) {
            l = ST_OnOff.g(g);
            a.ad.h("noResize", l);
        }
        if (h != false) {
            l = ST_OnOff.g(h);
            a.ad.h("noEditPoints", l);
        }
        if (i != false) {
            l = ST_OnOff.g(i);
            a.ad.h("noAdjustHandles", l);
        }
        if (j != false) {
            l = ST_OnOff.g(j);
            a.ad.h("noChangeArrowheads", l);
        }
        if (k != false) {
            l = ST_OnOff.g(k);
            a.ad.h("noChangeShapeType", l);
        }
    };
    DrawingNamespaceDefinitionBase.prototype.ce = function (a, b, c) {
        var d = this.cb(a, this.ay, b, c);
        b = d.p2;
        c = d.p3;
        return {
            p1: b,
            p2: c
        };
    };
    DrawingNamespaceDefinitionBase.prototype.c5 = function (a, b, c) {
        if (b === void 0) { b = 0; }
        if (c === void 0) { c = 0; }
        this.c2(a, this.ay, b, c);
    };
    DrawingNamespaceDefinitionBase.prototype.cf = function (a, b, c) {
        b = null;
        c = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "macro":
                        b = d.d;
                        break;
                    case "fPublished":
                        c = ST_OnOff.e(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_115_1) { e_115 = { error: e_115_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_115) throw e_115.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_115, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.c6 = function (a, b, c) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = false; }
        a.ad.p(this.a3, this.j);
        var d;
        d = b;
        DrawingNamespaceDefinitionBase.da(a, d);
        if (c != false) {
            d = ST_OnOff.g(c);
            a.ad.h("fPublished", d);
        }
    };
    DrawingNamespaceDefinitionBase.prototype.cg = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_116_1) { e_116 = { error: e_116_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_116) throw e_116.error; }
        }
        var e_116, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.c7 = function (a) {
        a.ad.p(this.a4, this.j);
    };
    DrawingNamespaceDefinitionBase.prototype.ch = function (a, b, c, d, e, f, g, h) {
        b = false;
        c = false;
        d = false;
        e = false;
        f = false;
        g = false;
        h = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var i = _1.value;
                switch (i.a.e(a.d)) {
                    case "noGrp":
                        b = ST_OnOff.e(i.d);
                        break;
                    case "noUngrp":
                        c = ST_OnOff.e(i.d);
                        break;
                    case "noSelect":
                        d = ST_OnOff.e(i.d);
                        break;
                    case "noRot":
                        e = ST_OnOff.e(i.d);
                        break;
                    case "noChangeAspect":
                        f = ST_OnOff.e(i.d);
                        break;
                    case "noMove":
                        g = ST_OnOff.e(i.d);
                        break;
                    case "noResize":
                        h = ST_OnOff.e(i.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_117_1) { e_117 = { error: e_117_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_117) throw e_117.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h
        };
        var e_117, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.c8 = function (a, b, c, d, e, f, g, h) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        a.ad.p(this.a5, this.j);
        var i;
        if (b != false) {
            i = ST_OnOff.g(b);
            a.ad.h("noGrp", i);
        }
        if (c != false) {
            i = ST_OnOff.g(c);
            a.ad.h("noUngrp", i);
        }
        if (d != false) {
            i = ST_OnOff.g(d);
            a.ad.h("noSelect", i);
        }
        if (e != false) {
            i = ST_OnOff.g(e);
            a.ad.h("noRot", i);
        }
        if (f != false) {
            i = ST_OnOff.g(f);
            a.ad.h("noChangeAspect", i);
        }
        if (g != false) {
            i = ST_OnOff.g(g);
            a.ad.h("noMove", i);
        }
        if (h != false) {
            i = ST_OnOff.g(h);
            a.ad.h("noResize", i);
        }
    };
    DrawingNamespaceDefinitionBase.prototype.ci = function (a, b) {
        b = Nullable$1.toNullable(ST_BlackWhiteMode_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "bwMode":
                        b = Nullable$1.toNullable(ST_BlackWhiteMode_$type, XmlNamespaceDefinitionBase.b(ST_BlackWhiteMode_$type, c.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_118_1) { e_118 = { error: e_118_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_118) throw e_118.error; }
        }
        return {
            p1: b
        };
        var e_118, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.c9 = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(ST_BlackWhiteMode_$type, null); }
        a.ad.p(this.a6, this.j);
        var c;
        if (nullableNotEquals(b, null)) {
            c = XmlNamespaceDefinitionBase.f(ST_BlackWhiteMode_$type, b.value);
            a.ad.h("bwMode", c);
        }
    };
    DrawingNamespaceDefinitionBase.prototype.cj = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_119_1) { e_119 = { error: e_119_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_119) throw e_119.error; }
        }
        var e_119, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.db = function (a) {
        a.ad.p(this.bn, this.j);
    };
    DrawingNamespaceDefinitionBase.prototype.ck = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_120_1) { e_120 = { error: e_120_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_120) throw e_120.error; }
        }
        var e_120, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.dc = function (a) {
        a.ad.p(this.bo, this.j);
    };
    DrawingNamespaceDefinitionBase.prototype.cl = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_121_1) { e_121 = { error: e_121_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_121) throw e_121.error; }
        }
        var e_121, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.dd = function (a) {
        a.ad.p(this.bp, this.j);
    };
    DrawingNamespaceDefinitionBase.prototype.cm = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_122_1) { e_122 = { error: e_122_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_122) throw e_122.error; }
        }
        var e_122, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.de = function (a) {
        a.ad.p(this.bq, this.j);
    };
    DrawingNamespaceDefinitionBase.prototype.cn = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_123_1) { e_123 = { error: e_123_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_123) throw e_123.error; }
        }
        var e_123, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.df = function (a) {
        a.ad.p(this.br, this.j);
    };
    DrawingNamespaceDefinitionBase.prototype.co = function (a, b, c) {
        b = "";
        c = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "macro":
                        b = d.d;
                        break;
                    case "fPublished":
                        c = ST_OnOff.e(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_124_1) { e_124 = { error: e_124_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_124) throw e_124.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_124, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.dg = function (a, b, c) {
        if (b === void 0) { b = ""; }
        if (c === void 0) { c = false; }
        a.ad.p(this.bs, this.j);
        var d;
        d = b;
        DrawingNamespaceDefinitionBase.da(a, d);
        if (c != false) {
            d = ST_OnOff.g(c);
            a.ad.h("fPublished", d);
        }
    };
    DrawingNamespaceDefinitionBase.prototype.cp = function (a, b, c, d, e) {
        b = null;
        c = null;
        d = true;
        e = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "macro":
                        b = f.d;
                        break;
                    case "textlink":
                        c = f.d;
                        break;
                    case "fLocksText":
                        d = ST_OnOff.e(f.d);
                        break;
                    case "fPublished":
                        e = ST_OnOff.e(f.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_125_1) { e_125 = { error: e_125_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_125) throw e_125.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_125, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.dh = function (a, b, c, d, e) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = true; }
        if (e === void 0) { e = false; }
        a.ad.p(this.bw, this.j);
        var f;
        f = b;
        DrawingNamespaceDefinitionBase.da(a, f);
        f = c;
        a.ad.h("textlink", f);
        if (d != true) {
            f = ST_OnOff.g(d);
            a.ad.h("fLocksText", f);
        }
        if (e != false) {
            f = ST_OnOff.g(e);
            a.ad.h("fPublished", f);
        }
    };
    DrawingNamespaceDefinitionBase.prototype.cq = function (a, b) {
        b = Nullable$1.toNullable(ST_BlackWhiteMode_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "bwMode":
                        b = Nullable$1.toNullable(ST_BlackWhiteMode_$type, XmlNamespaceDefinitionBase.b(ST_BlackWhiteMode_$type, c.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_126_1) { e_126 = { error: e_126_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_126) throw e_126.error; }
        }
        return {
            p1: b
        };
        var e_126, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.di = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(ST_BlackWhiteMode_$type, null); }
        a.ad.p(this.bx, this.j);
        var c;
        if (nullableNotEquals(b, null)) {
            c = XmlNamespaceDefinitionBase.f(ST_BlackWhiteMode_$type, b.value);
            a.ad.h("bwMode", c);
        }
    };
    DrawingNamespaceDefinitionBase.prototype.cr = function (a, b, c) {
        var d = this.cb(a, this.by, b, c);
        b = d.p2;
        c = d.p3;
        return {
            p1: b,
            p2: c
        };
    };
    DrawingNamespaceDefinitionBase.prototype.dj = function (a, b, c) {
        if (b === void 0) { b = 0; }
        if (c === void 0) { c = 0; }
        this.c2(a, this.by, b, c);
    };
    DrawingNamespaceDefinitionBase.prototype.cs = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_127_1) { e_127 = { error: e_127_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_127) throw e_127.error; }
        }
        var e_127, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.dk = function (a) {
        a.ad.p(this.bz, this.j);
    };
    DrawingNamespaceDefinitionBase.prototype.ct = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_128_1) { e_128 = { error: e_128_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_128) throw e_128.error; }
        }
        var e_128, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.dl = function (a) {
        a.ad.p(this.b1, this.j);
    };
    DrawingNamespaceDefinitionBase.prototype.cu = function (a, b, c, d) {
        b = ST_Angle.a(0);
        c = false;
        d = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "rot":
                        b = ST_Angle.b(e.d);
                        break;
                    case "flipH":
                        c = ST_OnOff.e(e.d);
                        break;
                    case "flipV":
                        d = ST_OnOff.e(e.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_129_1) { e_129 = { error: e_129_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_129) throw e_129.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_129, _2;
    };
    DrawingNamespaceDefinitionBase.prototype.dm = function (a, b, c, d) {
        if (b === void 0) { b = new ST_Angle(); }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        a.ad.p(this.b3, this.j);
        var e;
        if (b.n() != 0) {
            e = b.toString();
            a.ad.h("rot", e);
        }
        if (c != false) {
            e = ST_OnOff.g(c);
            a.ad.h("flipH", e);
        }
        if (d != false) {
            e = ST_OnOff.g(d);
            a.ad.h("flipV", e);
        }
    };
    DrawingNamespaceDefinitionBase.$t = markType(DrawingNamespaceDefinitionBase, 'DrawingNamespaceDefinitionBase', XmlNamespaceDefinitionBase.$);
    return DrawingNamespaceDefinitionBase;
}(XmlNamespaceDefinitionBase));
export { DrawingNamespaceDefinitionBase };
var EmptyNamespace = /** @class */ (function (_super) {
    tslib_1.__extends(EmptyNamespace, _super);
    function EmptyNamespace() {
        return _super.call(this) || this;
    }
    EmptyNamespace.prototype.i = function (a) {
        return stringEmpty();
    };
    EmptyNamespace.prototype.get_j = function () {
        return stringEmpty();
    };
    Object.defineProperty(EmptyNamespace.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    EmptyNamespace.ap = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_130_1) { e_130 = { error: e_130_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_130) throw e_130.error; }
        }
        var e_130, _2;
    };
    EmptyNamespace.aq = function (a, b, c) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        a.ad.o("xml");
        var d = a.d._z;
        a.ad.l(VmlNamespace.an);
        a.ad.l(OfficeNamespace.an);
    };
    EmptyNamespace.$t = markType(EmptyNamespace, 'EmptyNamespace', XmlNamespaceDefinitionBase.$);
    EmptyNamespace.an = new EmptyNamespace();
    return EmptyNamespace;
}(XmlNamespaceDefinitionBase));
export { EmptyNamespace };
var IGOfficeExtensions = /** @class */ (function (_super) {
    tslib_1.__extends(IGOfficeExtensions, _super);
    function IGOfficeExtensions() {
        return _super.call(this) || this;
    }
    IGOfficeExtensions.prototype.i = function (a) {
        return IGOfficeExtensions.ar;
    };
    IGOfficeExtensions.prototype.get_j = function () {
        return "ig";
    };
    Object.defineProperty(IGOfficeExtensions.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    IGOfficeExtensions.$t = markType(IGOfficeExtensions, 'IGOfficeExtensions', XmlNamespaceDefinitionBase.$);
    IGOfficeExtensions.ar = "http://schemas.infragistics.com/officeExtensions";
    IGOfficeExtensions.ap = IGOfficeExtensions.ar + "/isSupported";
    IGOfficeExtensions.aq = IGOfficeExtensions.ar + "/listId";
    IGOfficeExtensions.as = IGOfficeExtensions.ar + "/nodeId";
    IGOfficeExtensions.at = IGOfficeExtensions.ar + "/unclosedParagraph";
    IGOfficeExtensions.an = new IGOfficeExtensions();
    return IGOfficeExtensions;
}(XmlNamespaceDefinitionBase));
export { IGOfficeExtensions };
var MarkupCompatibility2006 = /** @class */ (function (_super) {
    tslib_1.__extends(MarkupCompatibility2006, _super);
    function MarkupCompatibility2006() {
        return _super.call(this) || this;
    }
    MarkupCompatibility2006.prototype.i = function (a) {
        return MarkupCompatibility2006.at;
    };
    MarkupCompatibility2006.prototype.get_j = function () {
        return "mc";
    };
    Object.defineProperty(MarkupCompatibility2006.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    MarkupCompatibility2006.av = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_131_1) { e_131 = { error: e_131_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_131) throw e_131.error; }
        }
        var e_131, _2;
    };
    MarkupCompatibility2006.ay = function (a) {
        a.ad.p(MarkupCompatibility2006.ap, "mc");
    };
    MarkupCompatibility2006.aw = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "Requires":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_132_1) { e_132 = { error: e_132_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_132) throw e_132.error; }
        }
        return {
            p1: b
        };
        var e_132, _2;
    };
    MarkupCompatibility2006.az = function (a, b) {
        MarkupCompatibility2006.a0(a, stringJoin1(String_$type, " ", Enumerable.o(XmlNamespaceDefinitionBase.$, String_$type, b, function (c) { return c.j; })));
    };
    MarkupCompatibility2006.a0 = function (a, b) {
        a.ad.p(MarkupCompatibility2006.aq, "mc");
        var c;
        c = b;
        a.ad.h("Requires", c);
    };
    MarkupCompatibility2006.ax = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_133_1) { e_133 = { error: e_133_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_133) throw e_133.error; }
        }
        var e_133, _2;
    };
    MarkupCompatibility2006.a1 = function (a) {
        a.ad.p(MarkupCompatibility2006.ar, "mc");
    };
    MarkupCompatibility2006.$t = markType(MarkupCompatibility2006, 'MarkupCompatibility2006', XmlNamespaceDefinitionBase.$);
    MarkupCompatibility2006.at = "http://schemas.openxmlformats.org/markup-compatibility/2006";
    MarkupCompatibility2006.ap = MarkupCompatibility2006.at + "/AlternateContent";
    MarkupCompatibility2006.aq = MarkupCompatibility2006.at + "/Choice";
    MarkupCompatibility2006.ar = MarkupCompatibility2006.at + "/Fallback";
    MarkupCompatibility2006.as = MarkupCompatibility2006.at + "/Ignorable";
    MarkupCompatibility2006.an = new MarkupCompatibility2006();
    return MarkupCompatibility2006;
}(XmlNamespaceDefinitionBase));
export { MarkupCompatibility2006 };
var OfficeDocumentDocPropsVTypes = /** @class */ (function (_super) {
    tslib_1.__extends(OfficeDocumentDocPropsVTypes, _super);
    function OfficeDocumentDocPropsVTypes() {
        return _super.call(this) || this;
    }
    OfficeDocumentDocPropsVTypes.prototype.i = function (a) {
        switch (a) {
            case 0: return OfficeDocumentDocPropsVTypes.a1;
            case 1: return OfficeDocumentDocPropsVTypes.a0;
            default: return OfficeDocumentDocPropsVTypes.a1;
        }
    };
    OfficeDocumentDocPropsVTypes.prototype.get_j = function () {
        return "vt";
    };
    Object.defineProperty(OfficeDocumentDocPropsVTypes.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    OfficeDocumentDocPropsVTypes.bt = function (a, b) {
        var c = XmlNamespaceDefinitionBase.o(a, OfficeDocumentDocPropsVTypes.at, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.cf = function (a, b) {
        XmlNamespaceDefinitionBase.ac(a, OfficeDocumentDocPropsVTypes.at, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.bu = function (a, b) {
        var c = XmlNamespaceDefinitionBase.o(a, OfficeDocumentDocPropsVTypes.ao, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.cg = function (a, b) {
        XmlNamespaceDefinitionBase.ac(a, OfficeDocumentDocPropsVTypes.ao, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.bv = function (a, b) {
        var c = XmlNamespaceDefinitionBase.m(a, OfficeDocumentDocPropsVTypes.au, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.ch = function (a, b) {
        XmlNamespaceDefinitionBase.aa(a, OfficeDocumentDocPropsVTypes.au, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.bw = function (a, b) {
        var c = XmlNamespaceDefinitionBase.t(a, OfficeDocumentDocPropsVTypes.av, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.ci = function (a, b) {
        XmlNamespaceDefinitionBase.ah(a, OfficeDocumentDocPropsVTypes.av, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.bx = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentDocPropsVTypes.aw, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.cj = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentDocPropsVTypes.aw, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.by = function (a, b) {
        var c = XmlNamespaceDefinitionBase.s(a, OfficeDocumentDocPropsVTypes.ax, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.ck = function (a, b) {
        XmlNamespaceDefinitionBase.ag(a, OfficeDocumentDocPropsVTypes.ax, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.bz = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentDocPropsVTypes.ap, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.cl = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentDocPropsVTypes.ap, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.b0 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, OfficeDocumentDocPropsVTypes.ay, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.cm = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, OfficeDocumentDocPropsVTypes.ay, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.b1 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, OfficeDocumentDocPropsVTypes.az, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.cn = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, OfficeDocumentDocPropsVTypes.az, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.b2 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.q(a, OfficeDocumentDocPropsVTypes.a2, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.co = function (a, b) {
        XmlNamespaceDefinitionBase.ae(a, OfficeDocumentDocPropsVTypes.a2, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.b3 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.p(a, OfficeDocumentDocPropsVTypes.a3, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.cp = function (a, b) {
        XmlNamespaceDefinitionBase.ad(a, OfficeDocumentDocPropsVTypes.a3, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.b4 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.v(a, OfficeDocumentDocPropsVTypes.a5, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.cq = function (a, b) {
        XmlNamespaceDefinitionBase.aj(a, OfficeDocumentDocPropsVTypes.a5, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.b5 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.y(a, OfficeDocumentDocPropsVTypes.a6, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.cr = function (a, b) {
        XmlNamespaceDefinitionBase.am(a, OfficeDocumentDocPropsVTypes.a6, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.b6 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.w(a, OfficeDocumentDocPropsVTypes.a7, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.cs = function (a, b) {
        XmlNamespaceDefinitionBase.ak(a, OfficeDocumentDocPropsVTypes.a7, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.b7 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.x(a, OfficeDocumentDocPropsVTypes.a8, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.ct = function (a, b) {
        XmlNamespaceDefinitionBase.al(a, OfficeDocumentDocPropsVTypes.a8, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.b8 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.w(a, OfficeDocumentDocPropsVTypes.a7, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentDocPropsVTypes.cu = function (a, b) {
        XmlNamespaceDefinitionBase.ak(a, OfficeDocumentDocPropsVTypes.a7, "vt", b);
    };
    OfficeDocumentDocPropsVTypes.b9 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_134_1) { e_134 = { error: e_134_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_134) throw e_134.error; }
        }
        var e_134, _2;
    };
    OfficeDocumentDocPropsVTypes.cv = function (a) {
        a.ad.p(OfficeDocumentDocPropsVTypes.a9, "vt");
    };
    OfficeDocumentDocPropsVTypes.ca = function (a, b, c) {
        b = 0;
        c = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "baseType":
                        b = XmlNamespaceDefinitionBase.b(ST_VectorBaseType_$type, d.d, b);
                        break;
                    case "size":
                        c = parseUInt32_1(d.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_135_1) { e_135 = { error: e_135_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_135) throw e_135.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_135, _2;
    };
    OfficeDocumentDocPropsVTypes.cw = function (a, b, c) {
        a.ad.p(OfficeDocumentDocPropsVTypes.ba, "vt");
        var d;
        d = XmlNamespaceDefinitionBase.f(ST_VectorBaseType_$type, b);
        a.ad.h("baseType", d);
        d = c.toString();
        a.ad.h("size", d);
    };
    OfficeDocumentDocPropsVTypes.bb = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.bu(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bc = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.bu(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bd = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.bv(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.be = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.bw(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bf = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.bx(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bg = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.by(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bh = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.bz(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bi = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.b0(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bj = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.b1(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bk = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.b2(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bl = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.b3(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bm = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.b4(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bn = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.b5(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bo = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.b6(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bp = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.b7(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.bq = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c;
        var d = OfficeDocumentDocPropsVTypes.b8(a, c);
        c = d.p1;
        b.setValue(c, a.ab.ab);
    };
    OfficeDocumentDocPropsVTypes.br = function (a) {
        var b = a.s.a(IVariantValueContainer_$type);
        if (b == null) {
            return;
        }
        var c = new OfficeDocumentDocPropsVTypes_VariantPlaceholder(b, a.ab.ab);
        a.s.k(c);
    };
    OfficeDocumentDocPropsVTypes.bs = function (a) {
        var b;
        var c;
        var d = OfficeDocumentDocPropsVTypes.ca(a, b, c);
        b = d.p1;
        c = d.p2;
        var e = new CT_Vector(0, c, b);
        a.s.k(e);
    };
    OfficeDocumentDocPropsVTypes.cb = function (a) {
        a.ay(OfficeDocumentDocPropsVTypes.at, OfficeDocumentDocPropsVTypes.bb);
        a.ay(OfficeDocumentDocPropsVTypes.ao, OfficeDocumentDocPropsVTypes.bc);
        a.ay(OfficeDocumentDocPropsVTypes.au, OfficeDocumentDocPropsVTypes.bd);
        a.ay(OfficeDocumentDocPropsVTypes.av, OfficeDocumentDocPropsVTypes.be);
        a.ay(OfficeDocumentDocPropsVTypes.aw, OfficeDocumentDocPropsVTypes.bf);
        a.ay(OfficeDocumentDocPropsVTypes.ax, OfficeDocumentDocPropsVTypes.bg);
        a.ay(OfficeDocumentDocPropsVTypes.ap, OfficeDocumentDocPropsVTypes.bh);
        a.ay(OfficeDocumentDocPropsVTypes.ay, OfficeDocumentDocPropsVTypes.bi);
        a.ay(OfficeDocumentDocPropsVTypes.az, OfficeDocumentDocPropsVTypes.bj);
        a.ay(OfficeDocumentDocPropsVTypes.a2, OfficeDocumentDocPropsVTypes.bk);
        a.ay(OfficeDocumentDocPropsVTypes.a3, OfficeDocumentDocPropsVTypes.bl);
        a.ay(OfficeDocumentDocPropsVTypes.a5, OfficeDocumentDocPropsVTypes.bm);
        a.ay(OfficeDocumentDocPropsVTypes.a6, OfficeDocumentDocPropsVTypes.bn);
        a.ay(OfficeDocumentDocPropsVTypes.a7, OfficeDocumentDocPropsVTypes.bo);
        a.ay(OfficeDocumentDocPropsVTypes.a8, OfficeDocumentDocPropsVTypes.bp);
        a.ay(OfficeDocumentDocPropsVTypes.ar, OfficeDocumentDocPropsVTypes.bq);
        a.ay(OfficeDocumentDocPropsVTypes.a9, OfficeDocumentDocPropsVTypes.br);
        a.ay(OfficeDocumentDocPropsVTypes.ba, OfficeDocumentDocPropsVTypes.bs);
    };
    OfficeDocumentDocPropsVTypes.cc = function (a, b) {
        var c = typeCast(String_$type, b);
        if (c != null) {
            OfficeDocumentDocPropsVTypes.cm(a, c);
        }
        else if (typeof b === 'number') {
            OfficeDocumentDocPropsVTypes.cj(a, typeGetValue(b));
        }
        else if (typeof b === 'number') {
            OfficeDocumentDocPropsVTypes.ch(a, typeGetValue(b));
        }
        else if (typeof b === 'number') {
            OfficeDocumentDocPropsVTypes.ci(a, typeGetValue(b));
        }
        else if (typeof b === 'number') {
            OfficeDocumentDocPropsVTypes.ck(a, typeGetValue(b));
        }
        else if (typeof b === 'number') {
            OfficeDocumentDocPropsVTypes.cq(a, typeGetValue(b));
        }
        else if (typeof b === 'number') {
            OfficeDocumentDocPropsVTypes.cr(a, typeGetValue(b));
        }
        else if (typeof b === 'number') {
            OfficeDocumentDocPropsVTypes.cs(a, typeGetValue(b));
        }
        else if (typeof b === 'number') {
            OfficeDocumentDocPropsVTypes.ct(a, typeGetValue(b));
        }
        else if (typeof b === 'number') {
            OfficeDocumentDocPropsVTypes.co(a, b);
        }
        else if (typeof b === 'number') {
            OfficeDocumentDocPropsVTypes.cp(a, b);
        }
        else if (typeof b === 'number') {
            OfficeDocumentDocPropsVTypes.cg(a, b);
        }
        else {
            return;
        }
        a.ad.k();
    };
    OfficeDocumentDocPropsVTypes.cd = function (a, b) {
        OfficeDocumentDocPropsVTypes.cv(a);
        OfficeDocumentDocPropsVTypes.cc(a, b);
        a.ad.k();
    };
    OfficeDocumentDocPropsVTypes.ce = function (a, b) {
        OfficeDocumentDocPropsVTypes.cw(a, b.b, (b.a.length));
        if (b.b == 0) {
            DocCoreUtils.am(Base.$, b.a, function (c) { return OfficeDocumentDocPropsVTypes.cd(a, c); });
        }
        else {
            DocCoreUtils.am(Base.$, b.a, function (c) { return OfficeDocumentDocPropsVTypes.cc(a, c); });
        }
        a.ad.k();
    };
    OfficeDocumentDocPropsVTypes.$t = markType(OfficeDocumentDocPropsVTypes, 'OfficeDocumentDocPropsVTypes', XmlNamespaceDefinitionBase.$);
    OfficeDocumentDocPropsVTypes.a1 = "http://schemas.openxmlformats.org/officeDocument/2006/docPropsVTypes";
    OfficeDocumentDocPropsVTypes.a0 = "http://purl.oclc.org/ooxml/officeDocument/docPropsVTypes";
    OfficeDocumentDocPropsVTypes.at = OfficeDocumentDocPropsVTypes.a0 + "/cy";
    OfficeDocumentDocPropsVTypes.ao = OfficeDocumentDocPropsVTypes.a0 + "/decimal";
    OfficeDocumentDocPropsVTypes.au = OfficeDocumentDocPropsVTypes.a0 + "/i1";
    OfficeDocumentDocPropsVTypes.av = OfficeDocumentDocPropsVTypes.a0 + "/i2";
    OfficeDocumentDocPropsVTypes.aw = OfficeDocumentDocPropsVTypes.a0 + "/i4";
    OfficeDocumentDocPropsVTypes.ax = OfficeDocumentDocPropsVTypes.a0 + "/i8";
    OfficeDocumentDocPropsVTypes.ap = OfficeDocumentDocPropsVTypes.a0 + "/int";
    OfficeDocumentDocPropsVTypes.a2 = OfficeDocumentDocPropsVTypes.a0 + "/r4";
    OfficeDocumentDocPropsVTypes.a3 = OfficeDocumentDocPropsVTypes.a0 + "/r8";
    OfficeDocumentDocPropsVTypes.a5 = OfficeDocumentDocPropsVTypes.a0 + "/ui1";
    OfficeDocumentDocPropsVTypes.a6 = OfficeDocumentDocPropsVTypes.a0 + "/ui2";
    OfficeDocumentDocPropsVTypes.a7 = OfficeDocumentDocPropsVTypes.a0 + "/ui4";
    OfficeDocumentDocPropsVTypes.a8 = OfficeDocumentDocPropsVTypes.a0 + "/ui8";
    OfficeDocumentDocPropsVTypes.ar = OfficeDocumentDocPropsVTypes.a0 + "/uint";
    OfficeDocumentDocPropsVTypes.ay = OfficeDocumentDocPropsVTypes.a0 + "/lpstr";
    OfficeDocumentDocPropsVTypes.az = OfficeDocumentDocPropsVTypes.a0 + "/lpwstr";
    OfficeDocumentDocPropsVTypes.a9 = OfficeDocumentDocPropsVTypes.a0 + "/variant";
    OfficeDocumentDocPropsVTypes.ba = OfficeDocumentDocPropsVTypes.a0 + "/vector";
    OfficeDocumentDocPropsVTypes.an = new OfficeDocumentDocPropsVTypes();
    return OfficeDocumentDocPropsVTypes;
}(XmlNamespaceDefinitionBase));
export { OfficeDocumentDocPropsVTypes };
export var IVariantValueContainer_$type = new Type(null, 'IVariantValueContainer');
var OfficeDocumentDocPropsVTypes_VariantPlaceholder = /** @class */ (function (_super) {
    tslib_1.__extends(OfficeDocumentDocPropsVTypes_VariantPlaceholder, _super);
    function OfficeDocumentDocPropsVTypes_VariantPlaceholder(a, b) {
        var _this = _super.call(this) || this;
        _this.a = null;
        _this.b = 0;
        _this.a = a;
        _this.b = b;
        return _this;
    }
    OfficeDocumentDocPropsVTypes_VariantPlaceholder.prototype.setValue = function (a, b) {
        this.a.setValue(a, this.b);
    };
    OfficeDocumentDocPropsVTypes_VariantPlaceholder.$t = markType(OfficeDocumentDocPropsVTypes_VariantPlaceholder, 'OfficeDocumentDocPropsVTypes_VariantPlaceholder', Base.$, [IVariantValueContainer_$type]);
    return OfficeDocumentDocPropsVTypes_VariantPlaceholder;
}(Base));
export { OfficeDocumentDocPropsVTypes_VariantPlaceholder };
var CT_Vector = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Vector, _super);
    function CT_Vector(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.b = 0;
        _this.a = null;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    _this.b = d;
                    _this.a = new Array(c);
                }
                break;
            case 1:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    _this.b = d;
                    _this.a = c.toArray();
                }
                break;
        }
        return _this;
    }
    CT_Vector.prototype.setValue = function (a, b) {
        this.a[b] = a;
    };
    CT_Vector.$t = markType(CT_Vector, 'CT_Vector', Base.$, [IVariantValueContainer_$type]);
    return CT_Vector;
}(Base));
export { CT_Vector };
var OfficeDocumentExtendedProperties = /** @class */ (function (_super) {
    tslib_1.__extends(OfficeDocumentExtendedProperties, _super);
    function OfficeDocumentExtendedProperties() {
        return _super.call(this) || this;
    }
    OfficeDocumentExtendedProperties.prototype.i = function (a) {
        switch (a) {
            case 0: return OfficeDocumentExtendedProperties.a4;
            case 1: return OfficeDocumentExtendedProperties.a3;
            default: return OfficeDocumentExtendedProperties.a4;
        }
    };
    OfficeDocumentExtendedProperties.prototype.get_j = function () {
        return null;
    };
    Object.defineProperty(OfficeDocumentExtendedProperties.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    OfficeDocumentExtendedProperties.bh = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, OfficeDocumentExtendedProperties.ap, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.b8 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, OfficeDocumentExtendedProperties.ap, null, b);
    };
    OfficeDocumentExtendedProperties.bi = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, OfficeDocumentExtendedProperties.aq, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.b9 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, OfficeDocumentExtendedProperties.aq, null, b);
    };
    OfficeDocumentExtendedProperties.bj = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentExtendedProperties.ar, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.ca = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentExtendedProperties.ar, null, b);
    };
    OfficeDocumentExtendedProperties.bk = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentExtendedProperties.as, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cb = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentExtendedProperties.as, null, b);
    };
    OfficeDocumentExtendedProperties.bl = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, OfficeDocumentExtendedProperties.at, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cc = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, OfficeDocumentExtendedProperties.at, null, b);
    };
    OfficeDocumentExtendedProperties.bm = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentExtendedProperties.au, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cd = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentExtendedProperties.au, null, b);
    };
    OfficeDocumentExtendedProperties.bn = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_136_1) { e_136 = { error: e_136_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_136) throw e_136.error; }
        }
        var e_136, _2;
    };
    OfficeDocumentExtendedProperties.ce = function (a) {
        a.ad.p(OfficeDocumentExtendedProperties.av, null);
    };
    OfficeDocumentExtendedProperties.bo = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentExtendedProperties.aw, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cf = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentExtendedProperties.aw, null, b);
    };
    OfficeDocumentExtendedProperties.bp = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, OfficeDocumentExtendedProperties.ax, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cg = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, OfficeDocumentExtendedProperties.ax, null, b);
    };
    OfficeDocumentExtendedProperties.bq = function (a, b) {
        var c = XmlNamespaceDefinitionBase.l(a, OfficeDocumentExtendedProperties.ay, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.ch = function (a, b) {
        XmlNamespaceDefinitionBase.z(a, OfficeDocumentExtendedProperties.ay, null, b);
    };
    OfficeDocumentExtendedProperties.br = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentExtendedProperties.az, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.ci = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentExtendedProperties.az, null, b);
    };
    OfficeDocumentExtendedProperties.bs = function (a, b) {
        var c = XmlNamespaceDefinitionBase.l(a, OfficeDocumentExtendedProperties.a0, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cj = function (a, b) {
        XmlNamespaceDefinitionBase.z(a, OfficeDocumentExtendedProperties.a0, null, b);
    };
    OfficeDocumentExtendedProperties.bt = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, OfficeDocumentExtendedProperties.a1, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.ck = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, OfficeDocumentExtendedProperties.a1, null, b);
    };
    OfficeDocumentExtendedProperties.bu = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentExtendedProperties.a2, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cl = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentExtendedProperties.a2, null, b);
    };
    OfficeDocumentExtendedProperties.bv = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentExtendedProperties.a5, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cm = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentExtendedProperties.a5, null, b);
    };
    OfficeDocumentExtendedProperties.bw = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentExtendedProperties.a6, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cn = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentExtendedProperties.a6, null, b);
    };
    OfficeDocumentExtendedProperties.bx = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentExtendedProperties.a7, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.co = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentExtendedProperties.a7, null, b);
    };
    OfficeDocumentExtendedProperties.by = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, OfficeDocumentExtendedProperties.a8, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cp = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, OfficeDocumentExtendedProperties.a8, null, b);
    };
    OfficeDocumentExtendedProperties.bz = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_137_1) { e_137 = { error: e_137_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_137) throw e_137.error; }
        }
        var e_137, _2;
    };
    OfficeDocumentExtendedProperties.cq = function (a) {
        a.ad.p(OfficeDocumentExtendedProperties.a9, null);
        var b = a.d._z;
        a.ad.l(OfficeDocumentExtendedProperties.an);
        a.ad.l(OfficeDocumentDocPropsVTypes.an);
    };
    OfficeDocumentExtendedProperties.b0 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.l(a, OfficeDocumentExtendedProperties.ba, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cr = function (a, b) {
        XmlNamespaceDefinitionBase.z(a, OfficeDocumentExtendedProperties.ba, null, b);
    };
    OfficeDocumentExtendedProperties.b1 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.l(a, OfficeDocumentExtendedProperties.bb, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cs = function (a, b) {
        XmlNamespaceDefinitionBase.z(a, OfficeDocumentExtendedProperties.bb, null, b);
    };
    OfficeDocumentExtendedProperties.b2 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentExtendedProperties.bc, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.b7 = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentExtendedProperties.bc, null, b);
    };
    OfficeDocumentExtendedProperties.b3 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, OfficeDocumentExtendedProperties.bd, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.ct = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, OfficeDocumentExtendedProperties.bd, null, b);
    };
    OfficeDocumentExtendedProperties.b4 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_138_1) { e_138 = { error: e_138_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_138) throw e_138.error; }
        }
        var e_138, _2;
    };
    OfficeDocumentExtendedProperties.cu = function (a) {
        a.ad.p(OfficeDocumentExtendedProperties.be, null);
    };
    OfficeDocumentExtendedProperties.b5 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentExtendedProperties.bf, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cv = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentExtendedProperties.bf, null, b);
    };
    OfficeDocumentExtendedProperties.b6 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, OfficeDocumentExtendedProperties.bg, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    OfficeDocumentExtendedProperties.cw = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, OfficeDocumentExtendedProperties.bg, null, b);
    };
    OfficeDocumentExtendedProperties.$t = markType(OfficeDocumentExtendedProperties, 'OfficeDocumentExtendedProperties', XmlNamespaceDefinitionBase.$);
    OfficeDocumentExtendedProperties.a4 = "http://schemas.openxmlformats.org/officeDocument/2006/extended-properties";
    OfficeDocumentExtendedProperties.a3 = "http://purl.oclc.org/ooxml/officeDocument/extendedProperties";
    OfficeDocumentExtendedProperties.ap = OfficeDocumentExtendedProperties.a3 + "/Application";
    OfficeDocumentExtendedProperties.aq = OfficeDocumentExtendedProperties.a3 + "/AppVersion";
    OfficeDocumentExtendedProperties.ar = OfficeDocumentExtendedProperties.a3 + "/Characters";
    OfficeDocumentExtendedProperties.as = OfficeDocumentExtendedProperties.a3 + "/CharactersWithSpaces";
    OfficeDocumentExtendedProperties.at = OfficeDocumentExtendedProperties.a3 + "/Company";
    OfficeDocumentExtendedProperties.au = OfficeDocumentExtendedProperties.a3 + "/DocSecurity";
    OfficeDocumentExtendedProperties.av = OfficeDocumentExtendedProperties.a3 + "/HeadingPairs";
    OfficeDocumentExtendedProperties.aw = OfficeDocumentExtendedProperties.a3 + "/HiddenSlides";
    OfficeDocumentExtendedProperties.ax = OfficeDocumentExtendedProperties.a3 + "/HyperlinkBase";
    OfficeDocumentExtendedProperties.ay = OfficeDocumentExtendedProperties.a3 + "/HyperlinksChanged";
    OfficeDocumentExtendedProperties.az = OfficeDocumentExtendedProperties.a3 + "/Lines";
    OfficeDocumentExtendedProperties.a0 = OfficeDocumentExtendedProperties.a3 + "/LinksUpToDate";
    OfficeDocumentExtendedProperties.a1 = OfficeDocumentExtendedProperties.a3 + "/Manager";
    OfficeDocumentExtendedProperties.a2 = OfficeDocumentExtendedProperties.a3 + "/MMClips";
    OfficeDocumentExtendedProperties.a5 = OfficeDocumentExtendedProperties.a3 + "/Notes";
    OfficeDocumentExtendedProperties.a6 = OfficeDocumentExtendedProperties.a3 + "/Pages";
    OfficeDocumentExtendedProperties.a7 = OfficeDocumentExtendedProperties.a3 + "/Paragraphs";
    OfficeDocumentExtendedProperties.a9 = OfficeDocumentExtendedProperties.a3 + "/Properties";
    OfficeDocumentExtendedProperties.a8 = OfficeDocumentExtendedProperties.a3 + "/PresentationFormat";
    OfficeDocumentExtendedProperties.ba = OfficeDocumentExtendedProperties.a3 + "/ScaleCrop";
    OfficeDocumentExtendedProperties.bb = OfficeDocumentExtendedProperties.a3 + "/SharedDoc";
    OfficeDocumentExtendedProperties.bc = OfficeDocumentExtendedProperties.a3 + "/Slides";
    OfficeDocumentExtendedProperties.bd = OfficeDocumentExtendedProperties.a3 + "/Template";
    OfficeDocumentExtendedProperties.be = OfficeDocumentExtendedProperties.a3 + "/TitlesOfParts";
    OfficeDocumentExtendedProperties.bf = OfficeDocumentExtendedProperties.a3 + "/TotalTime";
    OfficeDocumentExtendedProperties.bg = OfficeDocumentExtendedProperties.a3 + "/Words";
    OfficeDocumentExtendedProperties.an = new OfficeDocumentExtendedProperties();
    return OfficeDocumentExtendedProperties;
}(XmlNamespaceDefinitionBase));
export { OfficeDocumentExtendedProperties };
var OfficeDocumentRelationships = /** @class */ (function (_super) {
    tslib_1.__extends(OfficeDocumentRelationships, _super);
    function OfficeDocumentRelationships() {
        return _super.call(this) || this;
    }
    OfficeDocumentRelationships.prototype.i = function (a) {
        switch (a) {
            case 0: return OfficeDocumentRelationships.au;
            case 1: return OfficeDocumentRelationships.at;
            default: return OfficeDocumentRelationships.au;
        }
    };
    OfficeDocumentRelationships.prototype.get_j = function () {
        return "r";
    };
    Object.defineProperty(OfficeDocumentRelationships.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    OfficeDocumentRelationships.$t = markType(OfficeDocumentRelationships, 'OfficeDocumentRelationships', XmlNamespaceDefinitionBase.$);
    OfficeDocumentRelationships.au = "http://schemas.openxmlformats.org/officeDocument/2006/relationships";
    OfficeDocumentRelationships.at = "http://purl.oclc.org/ooxml/officeDocument/relationships";
    OfficeDocumentRelationships.ap = OfficeDocumentRelationships.at + "/embed";
    OfficeDocumentRelationships.aq = OfficeDocumentRelationships.at + "/href";
    OfficeDocumentRelationships.ar = OfficeDocumentRelationships.at + "/id";
    OfficeDocumentRelationships.as = OfficeDocumentRelationships.at + "/link";
    OfficeDocumentRelationships.av = OfficeDocumentRelationships.at + "/pict";
    OfficeDocumentRelationships.an = new OfficeDocumentRelationships();
    return OfficeDocumentRelationships;
}(XmlNamespaceDefinitionBase));
export { OfficeDocumentRelationships };
var OfficeNamespace = /** @class */ (function (_super) {
    tslib_1.__extends(OfficeNamespace, _super);
    function OfficeNamespace() {
        return _super.call(this) || this;
    }
    OfficeNamespace.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return "urn:schemas-microsoft-com:office:office";
            default: return "urn:schemas-microsoft-com:office:office";
        }
    };
    OfficeNamespace.prototype.get_j = function () {
        return "o";
    };
    Object.defineProperty(OfficeNamespace.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    OfficeNamespace.ch = function (a, b, c) {
        b = Nullable$1.toNullable(ST_Ext_$type, null);
        c = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "urn:schemas-microsoft-com:vml/ext":
                        b = Nullable$1.toNullable(ST_Ext_$type, XmlNamespaceDefinitionBase.b(ST_Ext_$type, d.d));
                        break;
                    case "data":
                        c = d.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_139_1) { e_139 = { error: e_139_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_139) throw e_139.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_139, _2;
    };
    OfficeNamespace.ck = function (a, b, c) {
        if (b === void 0) { b = Nullable$1.toNullable(ST_Ext_$type, null); }
        if (c === void 0) { c = null; }
        a.ad.p(OfficeNamespace.br, "o");
        var d;
        if (nullableNotEquals(b, null)) {
            d = XmlNamespaceDefinitionBase.f(ST_Ext_$type, b.value);
            a.ad.h("urn:schemas-microsoft-com:vml/ext", d);
        }
        d = c;
        a.ad.h("data", d);
    };
    OfficeNamespace.ci = function (a, b, c, d, e, f, g, h, i, j, k, l, m) {
        b = Nullable$1.toNullable(ST_Ext_$type, null);
        c = Nullable$1.toNullable(Boolean_$type, null);
        d = Nullable$1.toNullable(Boolean_$type, null);
        e = Nullable$1.toNullable(Boolean_$type, null);
        f = Nullable$1.toNullable(Boolean_$type, null);
        g = Nullable$1.toNullable(Boolean_$type, null);
        h = Nullable$1.toNullable(Boolean_$type, null);
        i = Nullable$1.toNullable(Boolean_$type, null);
        j = Nullable$1.toNullable(Boolean_$type, null);
        k = Nullable$1.toNullable(Boolean_$type, null);
        l = Nullable$1.toNullable(Boolean_$type, null);
        m = Nullable$1.toNullable(Boolean_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var n = _1.value;
                switch (n.a.e(a.d)) {
                    case "urn:schemas-microsoft-com:vml/ext":
                        b = Nullable$1.toNullable(ST_Ext_$type, XmlNamespaceDefinitionBase.b(ST_Ext_$type, n.d));
                        break;
                    case "position":
                        c = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(n.d)));
                        break;
                    case "selection":
                        d = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(n.d)));
                        break;
                    case "grouping":
                        e = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(n.d)));
                        break;
                    case "ungrouping":
                        f = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(n.d)));
                        break;
                    case "rotation":
                        g = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(n.d)));
                        break;
                    case "cropping":
                        h = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(n.d)));
                        break;
                    case "verticies":
                        i = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(n.d)));
                        break;
                    case "adjusthandles":
                        j = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(n.d)));
                        break;
                    case "text":
                        k = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(n.d)));
                        break;
                    case "aspectratio":
                        l = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(n.d)));
                        break;
                    case "shapetype":
                        m = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(n.d)));
                        break;
                    default: break;
                }
            }
        }
        catch (e_140_1) { e_140 = { error: e_140_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_140) throw e_140.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m
        };
        var e_140, _2;
    };
    OfficeNamespace.cl = function (a, b, c, d, e, f, g, h, i, j, k, l, m) {
        if (b === void 0) { b = Nullable$1.toNullable(ST_Ext_$type, null); }
        if (c === void 0) { c = Nullable$1.toNullable(Boolean_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(Boolean_$type, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Boolean_$type, null); }
        if (f === void 0) { f = Nullable$1.toNullable(Boolean_$type, null); }
        if (g === void 0) { g = Nullable$1.toNullable(Boolean_$type, null); }
        if (h === void 0) { h = Nullable$1.toNullable(Boolean_$type, null); }
        if (i === void 0) { i = Nullable$1.toNullable(Boolean_$type, null); }
        if (j === void 0) { j = Nullable$1.toNullable(Boolean_$type, null); }
        if (k === void 0) { k = Nullable$1.toNullable(Boolean_$type, null); }
        if (l === void 0) { l = Nullable$1.toNullable(Boolean_$type, null); }
        if (m === void 0) { m = Nullable$1.toNullable(Boolean_$type, null); }
        a.ad.p(OfficeNamespace.ao, "o");
        var n;
        if (nullableNotEquals(b, null)) {
            n = XmlNamespaceDefinitionBase.f(ST_Ext_$type, b.value);
            a.ad.h("urn:schemas-microsoft-com:vml/ext", n);
        }
        if (nullableNotEquals(c, null)) {
            n = ST_TrueFalse.k(ST_TrueFalse.b(c.value));
            a.ad.h("position", n);
        }
        if (nullableNotEquals(d, null)) {
            n = ST_TrueFalse.k(ST_TrueFalse.b(d.value));
            a.ad.h("selection", n);
        }
        if (nullableNotEquals(e, null)) {
            n = ST_TrueFalse.k(ST_TrueFalse.b(e.value));
            a.ad.h("grouping", n);
        }
        if (nullableNotEquals(f, null)) {
            n = ST_TrueFalse.k(ST_TrueFalse.b(f.value));
            a.ad.h("ungrouping", n);
        }
        if (nullableNotEquals(g, null)) {
            n = ST_TrueFalse.k(ST_TrueFalse.b(g.value));
            a.ad.h("rotation", n);
        }
        if (nullableNotEquals(h, null)) {
            n = ST_TrueFalse.k(ST_TrueFalse.b(h.value));
            a.ad.h("cropping", n);
        }
        if (nullableNotEquals(i, null)) {
            n = ST_TrueFalse.k(ST_TrueFalse.b(i.value));
            a.ad.h("verticies", n);
        }
        if (nullableNotEquals(j, null)) {
            n = ST_TrueFalse.k(ST_TrueFalse.b(j.value));
            a.ad.h("adjusthandles", n);
        }
        if (nullableNotEquals(k, null)) {
            n = ST_TrueFalse.k(ST_TrueFalse.b(k.value));
            a.ad.h("text", n);
        }
        if (nullableNotEquals(l, null)) {
            n = ST_TrueFalse.k(ST_TrueFalse.b(l.value));
            a.ad.h("aspectratio", n);
        }
        if (nullableNotEquals(m, null)) {
            n = ST_TrueFalse.k(ST_TrueFalse.b(m.value));
            a.ad.h("shapetype", n);
        }
    };
    OfficeNamespace.cj = function (a, b) {
        b = Nullable$1.toNullable(ST_Ext_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "urn:schemas-microsoft-com:vml/ext":
                        b = Nullable$1.toNullable(ST_Ext_$type, XmlNamespaceDefinitionBase.b(ST_Ext_$type, c.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_141_1) { e_141 = { error: e_141_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_141) throw e_141.error; }
        }
        return {
            p1: b
        };
        var e_141, _2;
    };
    OfficeNamespace.cm = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(ST_Ext_$type, null); }
        a.ad.p(OfficeNamespace.b6, "o");
        var c;
        if (nullableNotEquals(b, null)) {
            c = XmlNamespaceDefinitionBase.f(ST_Ext_$type, b.value);
            a.ad.h("urn:schemas-microsoft-com:vml/ext", c);
        }
    };
    OfficeNamespace.$t = markType(OfficeNamespace, 'OfficeNamespace', XmlNamespaceDefinitionBase.$);
    OfficeNamespace.br = "urn:schemas-microsoft-com:office:office" + "/idmap";
    OfficeNamespace.ao = "urn:schemas-microsoft-com:office:office" + "/lock";
    OfficeNamespace.b6 = "urn:schemas-microsoft-com:office:office" + "/shapelayout";
    OfficeNamespace.ar = "urn:schemas-microsoft-com:office:office" + "/allowincell";
    OfficeNamespace.at = "urn:schemas-microsoft-com:office:office" + "/althref";
    OfficeNamespace.as = "urn:schemas-microsoft-com:office:office" + "/allowoverlap";
    OfficeNamespace.a1 = "urn:schemas-microsoft-com:office:office" + "/bwmode";
    OfficeNamespace.a2 = "urn:schemas-microsoft-com:office:office" + "/bwnormal";
    OfficeNamespace.a3 = "urn:schemas-microsoft-com:office:office" + "/bwpure";
    OfficeNamespace.av = "urn:schemas-microsoft-com:office:office" + "/borderbottomcolor";
    OfficeNamespace.aw = "urn:schemas-microsoft-com:office:office" + "/borderleftcolor";
    OfficeNamespace.ax = "urn:schemas-microsoft-com:office:office" + "/borderrightcolor";
    OfficeNamespace.ay = "urn:schemas-microsoft-com:office:office" + "/bordertopcolor";
    OfficeNamespace.az = "urn:schemas-microsoft-com:office:office" + "/bullet";
    OfficeNamespace.a0 = "urn:schemas-microsoft-com:office:office" + "/button";
    OfficeNamespace.a4 = "urn:schemas-microsoft-com:office:office" + "/clip";
    OfficeNamespace.a5 = "urn:schemas-microsoft-com:office:office" + "/cliptowrap";
    OfficeNamespace.a6 = "urn:schemas-microsoft-com:office:office" + "/connectangles";
    OfficeNamespace.a7 = "urn:schemas-microsoft-com:office:office" + "/connectlocs";
    OfficeNamespace.a8 = "urn:schemas-microsoft-com:office:office" + "/connectortype";
    OfficeNamespace.a9 = "urn:schemas-microsoft-com:office:office" + "/connecttype";
    OfficeNamespace.bc = "urn:schemas-microsoft-com:office:office" + "/detectmouseclick";
    OfficeNamespace.bd = "urn:schemas-microsoft-com:office:office" + "/dgmlayout";
    OfficeNamespace.be = "urn:schemas-microsoft-com:office:office" + "/dgmlayoutmru";
    OfficeNamespace.bf = "urn:schemas-microsoft-com:office:office" + "/dgmnodekind";
    OfficeNamespace.bg = "urn:schemas-microsoft-com:office:office" + "/doubleclicknotify";
    OfficeNamespace.bh = "urn:schemas-microsoft-com:office:office" + "/extrusionok";
    OfficeNamespace.bi = "urn:schemas-microsoft-com:office:office" + "/forcedash";
    OfficeNamespace.bj = "urn:schemas-microsoft-com:office:office" + "/gfxdata";
    OfficeNamespace.bl = "urn:schemas-microsoft-com:office:office" + "/hr";
    OfficeNamespace.bm = "urn:schemas-microsoft-com:office:office" + "/hralign";
    OfficeNamespace.bn = "urn:schemas-microsoft-com:office:office" + "/href";
    OfficeNamespace.bo = "urn:schemas-microsoft-com:office:office" + "/hrnoshade";
    OfficeNamespace.bp = "urn:schemas-microsoft-com:office:office" + "/hrpct";
    OfficeNamespace.bq = "urn:schemas-microsoft-com:office:office" + "/hrstd";
    OfficeNamespace.bs = "urn:schemas-microsoft-com:office:office" + "/insetmode";
    OfficeNamespace.bt = "urn:schemas-microsoft-com:office:office" + "/movie";
    OfficeNamespace.bv = "urn:schemas-microsoft-com:office:office" + "/ole";
    OfficeNamespace.bw = "urn:schemas-microsoft-com:office:office" + "/oleicon";
    OfficeNamespace.bx = "urn:schemas-microsoft-com:office:office" + "/oleid";
    OfficeNamespace.by = "urn:schemas-microsoft-com:office:office" + "/oned";
    OfficeNamespace.bz = "urn:schemas-microsoft-com:office:office" + "/opacity2";
    OfficeNamespace.b1 = "urn:schemas-microsoft-com:office:office" + "/preferrelative";
    OfficeNamespace.b2 = "urn:schemas-microsoft-com:office:office" + "/regroupid";
    OfficeNamespace.b3 = "urn:schemas-microsoft-com:office:office" + "/relid";
    OfficeNamespace.b8 = "urn:schemas-microsoft-com:office:office" + "/singleclick";
    OfficeNamespace.b9 = "urn:schemas-microsoft-com:office:office" + "/spid";
    OfficeNamespace.ca = "urn:schemas-microsoft-com:office:office" + "/spt";
    OfficeNamespace.cc = "urn:schemas-microsoft-com:office:office" + "/title";
    OfficeNamespace.ce = "urn:schemas-microsoft-com:office:office" + "/userdrawn";
    OfficeNamespace.cf = "urn:schemas-microsoft-com:office:office" + "/userhidden";
    OfficeNamespace.an = new OfficeNamespace();
    return OfficeNamespace;
}(XmlNamespaceDefinitionBase));
export { OfficeNamespace };
var VmlNamespace = /** @class */ (function (_super) {
    tslib_1.__extends(VmlNamespace, _super);
    function VmlNamespace() {
        return _super.call(this) || this;
    }
    VmlNamespace.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return "urn:schemas-microsoft-com:vml";
            default: return "urn:schemas-microsoft-com:vml";
        }
    };
    VmlNamespace.prototype.get_j = function () {
        return "v";
    };
    Object.defineProperty(VmlNamespace.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    VmlNamespace.dn = function (a, b, c) {
        b = Nullable$1.toNullable(Number_$type, null);
        c = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "startAngle":
                        b = Nullable$1.toNullable(Number_$type, parseNumber(d.d, CultureInfo.invariantCulture));
                        break;
                    case "endAngle":
                        c = Nullable$1.toNullable(Number_$type, parseNumber(d.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_142_1) { e_142 = { error: e_142_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_142) throw e_142.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_142, _2;
    };
    VmlNamespace.dx = function (a, b, c) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p("urn:schemas-microsoft-com:vml/arc", "v");
        var d;
        if (nullableNotEquals(b, null)) {
            d = numberToString(b.value, CultureInfo.invariantCulture);
            a.ad.h("startAngle", d);
        }
        if (nullableNotEquals(c, null)) {
            d = numberToString(c.value, CultureInfo.invariantCulture);
            a.ad.h("endAngle", d);
        }
    };
    VmlNamespace.dp = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y, z, aa, ab) {
        b = null;
        c = Nullable$1.toNullable(ST_FillType_$type, null);
        d = Nullable$1.toNullable(Boolean_$type, null);
        e = null;
        f = null;
        g = null;
        h = null;
        i = null;
        j = null;
        k = null;
        l = null;
        m = null;
        n = Nullable$1.toNullable(ST_ImageAspect_$type, null);
        o = null;
        p = Nullable$1.toNullable(Number_$type, null);
        q = Nullable$1.toNullable(Boolean_$type, null);
        r = null;
        s = null;
        t = null;
        u = Nullable$1.toNullable(ST_FillMethod_$type, null);
        v = Nullable$1.toNullable(Boolean_$type, null);
        w = null;
        x = null;
        y = Nullable$1.toNullable(Boolean_$type, null);
        z = Nullable$1.toNullable(Boolean_$type, null);
        aa = null;
        ab = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var ac = _1.value;
                switch (ac.a.e(a.d)) {
                    case "id":
                        b = ac.d;
                        break;
                    case "type":
                        c = Nullable$1.toNullable(ST_FillType_$type, XmlNamespaceDefinitionBase.b(ST_FillType_$type, ac.d));
                        break;
                    case "on":
                        d = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(ac.d)));
                        break;
                    case "color":
                        e = ac.d;
                        break;
                    case "opacity":
                        f = ac.d;
                        break;
                    case "color2":
                        g = ac.d;
                        break;
                    case "src":
                        h = ac.d;
                        break;
                    case OfficeNamespace.bn:
                        i = ac.d;
                        break;
                    case OfficeNamespace.at:
                        j = ac.d;
                        break;
                    case "size":
                        k = ac.d;
                        break;
                    case "origin":
                        l = ac.d;
                        break;
                    case "position":
                        m = ac.d;
                        break;
                    case "aspect":
                        n = Nullable$1.toNullable(ST_ImageAspect_$type, XmlNamespaceDefinitionBase.b(ST_ImageAspect_$type, ac.d));
                        break;
                    case "colors":
                        o = ac.d;
                        break;
                    case "angle":
                        p = Nullable$1.toNullable(Number_$type, parseNumber(ac.d, CultureInfo.invariantCulture));
                        break;
                    case "alignshape":
                        q = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(ac.d)));
                        break;
                    case "focus":
                        r = ac.d;
                        break;
                    case "focussize":
                        s = ac.d;
                        break;
                    case "focusposition":
                        t = ac.d;
                        break;
                    case "method":
                        u = Nullable$1.toNullable(ST_FillMethod_$type, XmlNamespaceDefinitionBase.b(ST_FillMethod_$type, ac.d));
                        break;
                    case OfficeNamespace.bc:
                        v = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(ac.d)));
                        break;
                    case OfficeNamespace.cc:
                        w = ac.d;
                        break;
                    case OfficeNamespace.bz:
                        x = ac.d;
                        break;
                    case "recolor":
                        y = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(ac.d)));
                        break;
                    case "rotate":
                        z = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(ac.d)));
                        break;
                    case OfficeDocumentRelationships.ar:
                        aa = ac.d;
                        break;
                    case OfficeNamespace.b3:
                        ab = ac.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_143_1) { e_143 = { error: e_143_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_143) throw e_143.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t,
            p20: u,
            p21: v,
            p22: w,
            p23: x,
            p24: y,
            p25: z,
            p26: aa,
            p27: ab
        };
        var e_143, _2;
    };
    VmlNamespace.dy = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y, z, aa, ab) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = Nullable$1.toNullable(ST_FillType_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(Boolean_$type, null); }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = null; }
        if (g === void 0) { g = null; }
        if (h === void 0) { h = null; }
        if (i === void 0) { i = null; }
        if (j === void 0) { j = null; }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = null; }
        if (m === void 0) { m = null; }
        if (n === void 0) { n = Nullable$1.toNullable(ST_ImageAspect_$type, null); }
        if (o === void 0) { o = null; }
        if (p === void 0) { p = Nullable$1.toNullable(Number_$type, null); }
        if (q === void 0) { q = Nullable$1.toNullable(Boolean_$type, null); }
        if (r === void 0) { r = null; }
        if (s === void 0) { s = null; }
        if (t === void 0) { t = null; }
        if (u === void 0) { u = Nullable$1.toNullable(ST_FillMethod_$type, null); }
        if (v === void 0) { v = Nullable$1.toNullable(Boolean_$type, null); }
        if (w === void 0) { w = null; }
        if (x === void 0) { x = null; }
        if (y === void 0) { y = Nullable$1.toNullable(Boolean_$type, null); }
        if (z === void 0) { z = Nullable$1.toNullable(Boolean_$type, null); }
        if (aa === void 0) { aa = null; }
        if (ab === void 0) { ab = null; }
        a.ad.p("urn:schemas-microsoft-com:vml/fill", "v");
        var ac;
        ac = b;
        a.ad.h("id", ac);
        if (nullableNotEquals(c, null)) {
            ac = XmlNamespaceDefinitionBase.f(ST_FillType_$type, c.value);
            a.ad.h("type", ac);
        }
        if (nullableNotEquals(d, null)) {
            ac = ST_TrueFalse.k(ST_TrueFalse.b(d.value));
            a.ad.h("on", ac);
        }
        ac = e;
        a.ad.h("color", ac);
        ac = f;
        a.ad.h("opacity", ac);
        ac = g;
        a.ad.h("color2", ac);
        ac = h;
        a.ad.h("src", ac);
        ac = i;
        a.ad.h(OfficeNamespace.bn, ac);
        ac = j;
        a.ad.h(OfficeNamespace.at, ac);
        ac = k;
        a.ad.h("size", ac);
        ac = l;
        a.ad.h("origin", ac);
        ac = m;
        a.ad.h("position", ac);
        if (nullableNotEquals(n, null)) {
            ac = XmlNamespaceDefinitionBase.f(ST_ImageAspect_$type, n.value);
            a.ad.h("aspect", ac);
        }
        ac = o;
        a.ad.h("colors", ac);
        if (nullableNotEquals(p, null)) {
            ac = numberToString(p.value, CultureInfo.invariantCulture);
            a.ad.h("angle", ac);
        }
        if (nullableNotEquals(q, null)) {
            ac = ST_TrueFalse.k(ST_TrueFalse.b(q.value));
            a.ad.h("alignshape", ac);
        }
        ac = r;
        a.ad.h("focus", ac);
        ac = s;
        a.ad.h("focussize", ac);
        ac = t;
        a.ad.h("focusposition", ac);
        if (nullableNotEquals(u, null)) {
            ac = XmlNamespaceDefinitionBase.f(ST_FillMethod_$type, u.value);
            a.ad.h("method", ac);
        }
        if (nullableNotEquals(v, null)) {
            ac = ST_TrueFalse.k(ST_TrueFalse.b(v.value));
            a.ad.h(OfficeNamespace.bc, ac);
        }
        ac = w;
        a.ad.h(OfficeNamespace.cc, ac);
        ac = x;
        a.ad.h(OfficeNamespace.bz, ac);
        if (nullableNotEquals(y, null)) {
            ac = ST_TrueFalse.k(ST_TrueFalse.b(y.value));
            a.ad.h("recolor", ac);
        }
        if (nullableNotEquals(z, null)) {
            ac = ST_TrueFalse.k(ST_TrueFalse.b(z.value));
            a.ad.h("rotate", ac);
        }
        ac = aa;
        a.ad.h(OfficeDocumentRelationships.ar, ac);
        ac = ab;
        a.ad.h(OfficeNamespace.b3, ac);
    };
    VmlNamespace.dq = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y) {
        b = null;
        c = null;
        d = null;
        e = null;
        f = null;
        g = null;
        h = null;
        i = null;
        j = null;
        k = Nullable$1.toNullable(Boolean_$type, null);
        l = Nullable$1.toNullable(Boolean_$type, null);
        m = null;
        n = null;
        o = null;
        p = null;
        q = null;
        r = null;
        s = Nullable$1.toNullable(Number_$type, null);
        t = Nullable$1.toNullable(Boolean_$type, null);
        u = Nullable$1.toNullable(Number_$type, null);
        v = null;
        w = null;
        x = null;
        y = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var z = _1.value;
                switch (z.a.e(a.d)) {
                    case "id":
                        b = z.d;
                        break;
                    case "src":
                        c = z.d;
                        break;
                    case "cropleft":
                        d = z.d;
                        break;
                    case "croptop":
                        e = z.d;
                        break;
                    case "cropright":
                        f = z.d;
                        break;
                    case "cropbottom":
                        g = z.d;
                        break;
                    case "gain":
                        h = z.d;
                        break;
                    case "blacklevel":
                        i = z.d;
                        break;
                    case "gamma":
                        j = z.d;
                        break;
                    case "grayscale":
                        k = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(z.d)));
                        break;
                    case "bilevel":
                        l = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(z.d)));
                        break;
                    case "chromakey":
                        m = z.d;
                        break;
                    case "embosscolor":
                        n = z.d;
                        break;
                    case "recolortarget":
                        o = z.d;
                        break;
                    case OfficeNamespace.bn:
                        p = z.d;
                        break;
                    case OfficeNamespace.at:
                        q = z.d;
                        break;
                    case OfficeNamespace.cc:
                        r = z.d;
                        break;
                    case OfficeNamespace.bx:
                        s = Nullable$1.toNullable(Number_$type, parseNumber(z.d, CultureInfo.invariantCulture));
                        break;
                    case OfficeNamespace.bc:
                        t = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(z.d)));
                        break;
                    case OfficeNamespace.bt:
                        u = Nullable$1.toNullable(Number_$type, parseNumber(z.d, CultureInfo.invariantCulture));
                        break;
                    case OfficeNamespace.b3:
                        v = z.d;
                        break;
                    case OfficeDocumentRelationships.ar:
                        w = z.d;
                        break;
                    case OfficeDocumentRelationships.av:
                        x = z.d;
                        break;
                    case OfficeDocumentRelationships.aq:
                        y = z.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_144_1) { e_144 = { error: e_144_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_144) throw e_144.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t,
            p20: u,
            p21: v,
            p22: w,
            p23: x,
            p24: y
        };
        var e_144, _2;
    };
    VmlNamespace.dz = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = null; }
        if (g === void 0) { g = null; }
        if (h === void 0) { h = null; }
        if (i === void 0) { i = null; }
        if (j === void 0) { j = null; }
        if (k === void 0) { k = Nullable$1.toNullable(Boolean_$type, null); }
        if (l === void 0) { l = Nullable$1.toNullable(Boolean_$type, null); }
        if (m === void 0) { m = null; }
        if (n === void 0) { n = null; }
        if (o === void 0) { o = null; }
        if (p === void 0) { p = null; }
        if (q === void 0) { q = null; }
        if (r === void 0) { r = null; }
        if (s === void 0) { s = Nullable$1.toNullable(Number_$type, null); }
        if (t === void 0) { t = Nullable$1.toNullable(Boolean_$type, null); }
        if (u === void 0) { u = Nullable$1.toNullable(Number_$type, null); }
        if (v === void 0) { v = null; }
        if (w === void 0) { w = null; }
        if (x === void 0) { x = null; }
        if (y === void 0) { y = null; }
        a.ad.p("urn:schemas-microsoft-com:vml/imagedata", "v");
        var z;
        z = b;
        a.ad.h("id", z);
        z = c;
        a.ad.h("src", z);
        z = d;
        a.ad.h("cropleft", z);
        z = e;
        a.ad.h("croptop", z);
        z = f;
        a.ad.h("cropright", z);
        z = g;
        a.ad.h("cropbottom", z);
        z = h;
        a.ad.h("gain", z);
        z = i;
        a.ad.h("blacklevel", z);
        z = j;
        a.ad.h("gamma", z);
        if (nullableNotEquals(k, null)) {
            z = ST_TrueFalse.k(ST_TrueFalse.b(k.value));
            a.ad.h("grayscale", z);
        }
        if (nullableNotEquals(l, null)) {
            z = ST_TrueFalse.k(ST_TrueFalse.b(l.value));
            a.ad.h("bilevel", z);
        }
        z = m;
        a.ad.h("chromakey", z);
        z = n;
        a.ad.h("embosscolor", z);
        z = o;
        a.ad.h("recolortarget", z);
        z = p;
        a.ad.h(OfficeNamespace.bn, z);
        z = q;
        a.ad.h(OfficeNamespace.at, z);
        z = r;
        a.ad.h(OfficeNamespace.cc, z);
        if (nullableNotEquals(s, null)) {
            z = numberToString(s.value, CultureInfo.invariantCulture);
            a.ad.h(OfficeNamespace.bx, z);
        }
        if (nullableNotEquals(t, null)) {
            z = ST_TrueFalse.k(ST_TrueFalse.b(t.value));
            a.ad.h(OfficeNamespace.bc, z);
        }
        if (nullableNotEquals(u, null)) {
            z = numberToString(u.value, CultureInfo.invariantCulture);
            a.ad.h(OfficeNamespace.bt, z);
        }
        z = v;
        a.ad.h(OfficeNamespace.b3, z);
        z = w;
        a.ad.h(OfficeDocumentRelationships.ar, z);
        z = x;
        a.ad.h(OfficeDocumentRelationships.av, z);
        z = y;
        a.ad.h(OfficeDocumentRelationships.aq, z);
    };
    VmlNamespace.dr = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p) {
        b = null;
        c = null;
        d = null;
        e = null;
        f = Nullable$1.toNullable(Boolean_$type, null);
        g = Nullable$1.toNullable(Boolean_$type, null);
        h = Nullable$1.toNullable(Boolean_$type, null);
        i = Nullable$1.toNullable(Boolean_$type, null);
        j = Nullable$1.toNullable(Boolean_$type, null);
        k = Nullable$1.toNullable(Boolean_$type, null);
        l = Nullable$1.toNullable(Boolean_$type, null);
        m = Nullable$1.toNullable(ST_ConnectType_$type, null);
        n = null;
        o = null;
        p = Nullable$1.toNullable(Boolean_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var q = _1.value;
                switch (q.a.e(a.d)) {
                    case "id":
                        b = q.d;
                        break;
                    case "v":
                        c = q.d;
                        break;
                    case "limo":
                        d = q.d;
                        break;
                    case "textboxrect":
                        e = q.d;
                        break;
                    case "fillok":
                        f = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(q.d)));
                        break;
                    case "strokeok":
                        g = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(q.d)));
                        break;
                    case "shadowok":
                        h = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(q.d)));
                        break;
                    case "arrowok":
                        i = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(q.d)));
                        break;
                    case "gradientshapeok":
                        j = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(q.d)));
                        break;
                    case "textpathok":
                        k = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(q.d)));
                        break;
                    case "insetpenok":
                        l = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(q.d)));
                        break;
                    case OfficeNamespace.a9:
                        m = Nullable$1.toNullable(ST_ConnectType_$type, XmlNamespaceDefinitionBase.b(ST_ConnectType_$type, q.d));
                        break;
                    case OfficeNamespace.a7:
                        n = q.d;
                        break;
                    case OfficeNamespace.a6:
                        o = q.d;
                        break;
                    case OfficeNamespace.bh:
                        p = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(q.d)));
                        break;
                    default: break;
                }
            }
        }
        catch (e_145_1) { e_145 = { error: e_145_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_145) throw e_145.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p
        };
        var e_145, _2;
    };
    VmlNamespace.d0 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = Nullable$1.toNullable(Boolean_$type, null); }
        if (g === void 0) { g = Nullable$1.toNullable(Boolean_$type, null); }
        if (h === void 0) { h = Nullable$1.toNullable(Boolean_$type, null); }
        if (i === void 0) { i = Nullable$1.toNullable(Boolean_$type, null); }
        if (j === void 0) { j = Nullable$1.toNullable(Boolean_$type, null); }
        if (k === void 0) { k = Nullable$1.toNullable(Boolean_$type, null); }
        if (l === void 0) { l = Nullable$1.toNullable(Boolean_$type, null); }
        if (m === void 0) { m = Nullable$1.toNullable(ST_ConnectType_$type, null); }
        if (n === void 0) { n = null; }
        if (o === void 0) { o = null; }
        if (p === void 0) { p = Nullable$1.toNullable(Boolean_$type, null); }
        a.ad.p("urn:schemas-microsoft-com:vml/path", "v");
        var q;
        q = b;
        a.ad.h("id", q);
        q = c;
        a.ad.h("v", q);
        q = d;
        a.ad.h("limo", q);
        q = e;
        a.ad.h("textboxrect", q);
        if (nullableNotEquals(f, null)) {
            q = ST_TrueFalse.k(ST_TrueFalse.b(f.value));
            a.ad.h("fillok", q);
        }
        if (nullableNotEquals(g, null)) {
            q = ST_TrueFalse.k(ST_TrueFalse.b(g.value));
            a.ad.h("strokeok", q);
        }
        if (nullableNotEquals(h, null)) {
            q = ST_TrueFalse.k(ST_TrueFalse.b(h.value));
            a.ad.h("shadowok", q);
        }
        if (nullableNotEquals(i, null)) {
            q = ST_TrueFalse.k(ST_TrueFalse.b(i.value));
            a.ad.h("arrowok", q);
        }
        if (nullableNotEquals(j, null)) {
            q = ST_TrueFalse.k(ST_TrueFalse.b(j.value));
            a.ad.h("gradientshapeok", q);
        }
        if (nullableNotEquals(k, null)) {
            q = ST_TrueFalse.k(ST_TrueFalse.b(k.value));
            a.ad.h("textpathok", q);
        }
        if (nullableNotEquals(l, null)) {
            q = ST_TrueFalse.k(ST_TrueFalse.b(l.value));
            a.ad.h("insetpenok", q);
        }
        if (nullableNotEquals(m, null)) {
            q = XmlNamespaceDefinitionBase.f(ST_ConnectType_$type, m.value);
            a.ad.h(OfficeNamespace.a9, q);
        }
        q = n;
        a.ad.h(OfficeNamespace.a7, q);
        q = o;
        a.ad.h(OfficeNamespace.a6, q);
        if (nullableNotEquals(p, null)) {
            q = ST_TrueFalse.k(ST_TrueFalse.b(p.value));
            a.ad.h(OfficeNamespace.bh, q);
        }
    };
    VmlNamespace.ds = function (a, b, c, d, e, f, g, h, i, j, k, l) {
        b = null;
        c = Nullable$1.toNullable(Boolean_$type, null);
        d = Nullable$1.toNullable(ST_ShadowType_$type, null);
        e = Nullable$1.toNullable(Boolean_$type, null);
        f = null;
        g = null;
        h = null;
        i = null;
        j = null;
        k = null;
        l = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var m = _1.value;
                switch (m.a.e(a.d)) {
                    case "id":
                        b = m.d;
                        break;
                    case "on":
                        c = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(m.d)));
                        break;
                    case "type":
                        d = Nullable$1.toNullable(ST_ShadowType_$type, XmlNamespaceDefinitionBase.b(ST_ShadowType_$type, m.d));
                        break;
                    case "obscured":
                        e = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(m.d)));
                        break;
                    case "color":
                        f = m.d;
                        break;
                    case "opacity":
                        g = m.d;
                        break;
                    case "offset":
                        h = m.d;
                        break;
                    case "color2":
                        i = m.d;
                        break;
                    case "offset2":
                        j = m.d;
                        break;
                    case "origin":
                        k = m.d;
                        break;
                    case "matrix":
                        l = m.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_146_1) { e_146 = { error: e_146_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_146) throw e_146.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l
        };
        var e_146, _2;
    };
    VmlNamespace.d1 = function (a, b, c, d, e, f, g, h, i, j, k, l) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = Nullable$1.toNullable(Boolean_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(ST_ShadowType_$type, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Boolean_$type, null); }
        if (f === void 0) { f = null; }
        if (g === void 0) { g = null; }
        if (h === void 0) { h = null; }
        if (i === void 0) { i = null; }
        if (j === void 0) { j = null; }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = null; }
        a.ad.p("urn:schemas-microsoft-com:vml/shadow", "v");
        var m;
        m = b;
        a.ad.h("id", m);
        if (nullableNotEquals(c, null)) {
            m = ST_TrueFalse.k(ST_TrueFalse.b(c.value));
            a.ad.h("on", m);
        }
        if (nullableNotEquals(d, null)) {
            m = XmlNamespaceDefinitionBase.f(ST_ShadowType_$type, d.value);
            a.ad.h("type", m);
        }
        if (nullableNotEquals(e, null)) {
            m = ST_TrueFalse.k(ST_TrueFalse.b(e.value));
            a.ad.h("obscured", m);
        }
        m = f;
        a.ad.h("color", m);
        m = g;
        a.ad.h("opacity", m);
        m = h;
        a.ad.h("offset", m);
        m = i;
        a.ad.h("color2", m);
        m = j;
        a.ad.h("offset2", m);
        m = k;
        a.ad.h("origin", m);
        m = l;
        a.ad.h("matrix", m);
    };
    VmlNamespace.dt = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y, z, aa, ab, ac, ad, ae, af, ag, ah, ai, aj, ak, al, am, an, ao, ap, aq, ar, as, at, au, av, aw, ax, ay, az, a0, a1, a2, a3, a4, a5, a6) {
        b = null;
        c = null;
        d = null;
        e = null;
        f = null;
        g = null;
        h = null;
        i = null;
        j = null;
        k = null;
        l = Nullable$1.toNullable(Boolean_$type, null);
        m = null;
        n = Nullable$1.toNullable(Boolean_$type, null);
        o = null;
        p = Nullable$1.toNullable(Boolean_$type, null);
        q = Nullable$1.toNullable(Boolean_$type, null);
        r = Nullable$1.toNullable(Boolean_$type, null);
        s = Nullable$1.toNullable(Boolean_$type, null);
        t = Nullable$1.toNullable(Boolean_$type, null);
        u = Nullable$1.toNullable(Boolean_$type, null);
        v = Nullable$1.toNullable(Boolean_$type, null);
        w = Nullable$1.toNullable(Number_$type, null);
        x = Nullable$1.toNullable(ST_HrAlign_$type, null);
        y = Nullable$1.toNullable(Boolean_$type, null);
        z = Nullable$1.toNullable(Boolean_$type, null);
        aa = Nullable$1.toNullable(Boolean_$type, null);
        ab = null;
        ac = null;
        ad = null;
        ae = null;
        af = null;
        ag = null;
        ah = null;
        ai = Nullable$1.toNullable(ST_InsetMode_$type, null);
        aj = null;
        ak = Nullable$1.toNullable(Boolean_$type, null);
        al = null;
        am = null;
        an = Nullable$1.toNullable(Boolean_$type, null);
        ao = null;
        ap = null;
        aq = Nullable$1.toNullable(Boolean_$type, null);
        ar = Nullable$1.toNullable(Number_$type, null);
        as = Nullable$1.toNullable(ST_ConnectorType_$type, null);
        at = Nullable$1.toNullable(ST_BWMode_$type, null);
        au = Nullable$1.toNullable(ST_BWMode_$type, null);
        av = Nullable$1.toNullable(ST_BWMode_$type, null);
        aw = Nullable$1.toNullable(Boolean_$type, null);
        ax = Nullable$1.toNullable(Boolean_$type, null);
        ay = Nullable$1.toNullable(Boolean_$type, null);
        az = Nullable$1.toNullable(Boolean_$type, null);
        a0 = Nullable$1.toNullable(Boolean_$type, null);
        a1 = Nullable$1.toNullable(Boolean_$type, null);
        a2 = null;
        a3 = null;
        a4 = null;
        a5 = null;
        a6 = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var a7 = _1.value;
                switch (a7.a.e(a.d)) {
                    case "id":
                        b = a7.d;
                        break;
                    case "style":
                        c = a7.d;
                        break;
                    case "href":
                        d = a7.d;
                        break;
                    case "target":
                        e = a7.d;
                        break;
                    case "class":
                        f = a7.d;
                        break;
                    case "title":
                        g = a7.d;
                        break;
                    case "alt":
                        h = a7.d;
                        break;
                    case "coordsize":
                        i = a7.d;
                        break;
                    case "coordorigin":
                        j = a7.d;
                        break;
                    case "wrapcoords":
                        k = a7.d;
                        break;
                    case "print":
                        l = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.b9:
                        m = a7.d;
                        break;
                    case OfficeNamespace.by:
                        n = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.b2:
                        o = a7.d;
                        break;
                    case OfficeNamespace.bg:
                        p = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.a0:
                        q = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.cf:
                        r = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.az:
                        s = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.bl:
                        t = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.bq:
                        u = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.bo:
                        v = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.bp:
                        w = Nullable$1.toNullable(Number_$type, parseNumber(a7.d, CultureInfo.invariantCulture));
                        break;
                    case OfficeNamespace.bm:
                        x = Nullable$1.toNullable(ST_HrAlign_$type, XmlNamespaceDefinitionBase.b(ST_HrAlign_$type, a7.d));
                        break;
                    case OfficeNamespace.ar:
                        y = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.as:
                        z = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.ce:
                        aa = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case "bordertopcolor":
                        ab = a7.d;
                        break;
                    case "borderleftcolor":
                        ac = a7.d;
                        break;
                    case "borderbottomcolor":
                        ad = a7.d;
                        break;
                    case "borderrightcolor":
                        ae = a7.d;
                        break;
                    case OfficeNamespace.bd:
                        af = a7.d;
                        break;
                    case OfficeNamespace.bf:
                        ag = a7.d;
                        break;
                    case OfficeNamespace.be:
                        ah = a7.d;
                        break;
                    case OfficeNamespace.bs:
                        ai = Nullable$1.toNullable(ST_InsetMode_$type, XmlNamespaceDefinitionBase.b(ST_InsetMode_$type, a7.d));
                        break;
                    case "chromakey":
                        aj = a7.d;
                        break;
                    case "filled":
                        ak = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case "fillcolor":
                        al = a7.d;
                        break;
                    case "opacity":
                        am = a7.d;
                        break;
                    case "stroked":
                        an = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case "strokecolor":
                        ao = a7.d;
                        break;
                    case "strokeweight":
                        ap = a7.d;
                        break;
                    case "insetpen":
                        aq = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.ca:
                        ar = Nullable$1.toNullable(Number_$type, parseNumber(a7.d, CultureInfo.invariantCulture));
                        break;
                    case OfficeNamespace.a8:
                        as = Nullable$1.toNullable(ST_ConnectorType_$type, XmlNamespaceDefinitionBase.b(ST_ConnectorType_$type, a7.d));
                        break;
                    case "bwmode":
                        at = Nullable$1.toNullable(ST_BWMode_$type, XmlNamespaceDefinitionBase.b(ST_BWMode_$type, a7.d));
                        break;
                    case "bwpure":
                        au = Nullable$1.toNullable(ST_BWMode_$type, XmlNamespaceDefinitionBase.b(ST_BWMode_$type, a7.d));
                        break;
                    case "bwnormal":
                        av = Nullable$1.toNullable(ST_BWMode_$type, XmlNamespaceDefinitionBase.b(ST_BWMode_$type, a7.d));
                        break;
                    case OfficeNamespace.bi:
                        aw = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.bw:
                        ax = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.bv:
                        ay = Nullable$1.toNullable(Boolean_$type, ST_TrueFalseBlank.d(a7.d));
                        break;
                    case OfficeNamespace.b1:
                        az = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.a5:
                        a0 = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case OfficeNamespace.a4:
                        a1 = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a7.d)));
                        break;
                    case "type":
                        a2 = a7.d;
                        break;
                    case "adj":
                        a3 = a7.d;
                        break;
                    case "path":
                        a4 = a7.d;
                        break;
                    case "gfxdata":
                        a5 = a7.d;
                        break;
                    case "equationxml":
                        a6 = a7.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_147_1) { e_147 = { error: e_147_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_147) throw e_147.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t,
            p20: u,
            p21: v,
            p22: w,
            p23: x,
            p24: y,
            p25: z,
            p26: aa,
            p27: ab,
            p28: ac,
            p29: ad,
            p30: ae,
            p31: af,
            p32: ag,
            p33: ah,
            p34: ai,
            p35: aj,
            p36: ak,
            p37: al,
            p38: am,
            p39: an,
            p40: ao,
            p41: ap,
            p42: aq,
            p43: ar,
            p44: as,
            p45: at,
            p46: au,
            p47: av,
            p48: aw,
            p49: ax,
            p50: ay,
            p51: az,
            p52: a0,
            p53: a1,
            p54: a2,
            p55: a3,
            p56: a4,
            p57: a5,
            p58: a6
        };
        var e_147, _2;
    };
    VmlNamespace.d2 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y, z, aa, ab, ac, ad, ae, af, ag, ah, ai, aj, ak, al, am, an, ao, ap, aq, ar, as, at, au, av, aw, ax, ay, az, a0, a1, a2, a3, a4, a5, a6) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = null; }
        if (g === void 0) { g = null; }
        if (h === void 0) { h = null; }
        if (i === void 0) { i = null; }
        if (j === void 0) { j = null; }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = Nullable$1.toNullable(Boolean_$type, null); }
        if (m === void 0) { m = null; }
        if (n === void 0) { n = Nullable$1.toNullable(Boolean_$type, null); }
        if (o === void 0) { o = null; }
        if (p === void 0) { p = Nullable$1.toNullable(Boolean_$type, null); }
        if (q === void 0) { q = Nullable$1.toNullable(Boolean_$type, null); }
        if (r === void 0) { r = Nullable$1.toNullable(Boolean_$type, null); }
        if (s === void 0) { s = Nullable$1.toNullable(Boolean_$type, null); }
        if (t === void 0) { t = Nullable$1.toNullable(Boolean_$type, null); }
        if (u === void 0) { u = Nullable$1.toNullable(Boolean_$type, null); }
        if (v === void 0) { v = Nullable$1.toNullable(Boolean_$type, null); }
        if (w === void 0) { w = Nullable$1.toNullable(Number_$type, null); }
        if (x === void 0) { x = Nullable$1.toNullable(ST_HrAlign_$type, null); }
        if (y === void 0) { y = Nullable$1.toNullable(Boolean_$type, null); }
        if (z === void 0) { z = Nullable$1.toNullable(Boolean_$type, null); }
        if (aa === void 0) { aa = Nullable$1.toNullable(Boolean_$type, null); }
        if (ab === void 0) { ab = null; }
        if (ac === void 0) { ac = null; }
        if (ad === void 0) { ad = null; }
        if (ae === void 0) { ae = null; }
        if (af === void 0) { af = null; }
        if (ag === void 0) { ag = null; }
        if (ah === void 0) { ah = null; }
        if (ai === void 0) { ai = Nullable$1.toNullable(ST_InsetMode_$type, null); }
        if (aj === void 0) { aj = null; }
        if (ak === void 0) { ak = Nullable$1.toNullable(Boolean_$type, null); }
        if (al === void 0) { al = null; }
        if (am === void 0) { am = null; }
        if (an === void 0) { an = Nullable$1.toNullable(Boolean_$type, null); }
        if (ao === void 0) { ao = null; }
        if (ap === void 0) { ap = null; }
        if (aq === void 0) { aq = Nullable$1.toNullable(Boolean_$type, null); }
        if (ar === void 0) { ar = Nullable$1.toNullable(Number_$type, null); }
        if (as === void 0) { as = Nullable$1.toNullable(ST_ConnectorType_$type, null); }
        if (at === void 0) { at = Nullable$1.toNullable(ST_BWMode_$type, null); }
        if (au === void 0) { au = Nullable$1.toNullable(ST_BWMode_$type, null); }
        if (av === void 0) { av = Nullable$1.toNullable(ST_BWMode_$type, null); }
        if (aw === void 0) { aw = Nullable$1.toNullable(Boolean_$type, null); }
        if (ax === void 0) { ax = Nullable$1.toNullable(Boolean_$type, null); }
        if (ay === void 0) { ay = Nullable$1.toNullable(Boolean_$type, null); }
        if (az === void 0) { az = Nullable$1.toNullable(Boolean_$type, null); }
        if (a0 === void 0) { a0 = Nullable$1.toNullable(Boolean_$type, null); }
        if (a1 === void 0) { a1 = Nullable$1.toNullable(Boolean_$type, null); }
        if (a2 === void 0) { a2 = null; }
        if (a3 === void 0) { a3 = null; }
        if (a4 === void 0) { a4 = null; }
        if (a5 === void 0) { a5 = null; }
        if (a6 === void 0) { a6 = null; }
        a.ad.p("urn:schemas-microsoft-com:vml/shape", "v");
        var a7;
        a7 = b;
        a.ad.h("id", a7);
        a7 = c;
        a.ad.h("style", a7);
        a7 = d;
        a.ad.h("href", a7);
        a7 = e;
        a.ad.h("target", a7);
        a7 = f;
        a.ad.h("class", a7);
        a7 = g;
        a.ad.h("title", a7);
        a7 = h;
        a.ad.h("alt", a7);
        a7 = i;
        a.ad.h("coordsize", a7);
        a7 = j;
        a.ad.h("coordorigin", a7);
        a7 = k;
        a.ad.h("wrapcoords", a7);
        if (nullableNotEquals(l, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(l.value));
            a.ad.h("print", a7);
        }
        a7 = m;
        a.ad.h(OfficeNamespace.b9, a7);
        if (nullableNotEquals(n, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(n.value));
            a.ad.h(OfficeNamespace.by, a7);
        }
        a7 = o;
        a.ad.h(OfficeNamespace.b2, a7);
        if (nullableNotEquals(p, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(p.value));
            a.ad.h(OfficeNamespace.bg, a7);
        }
        if (nullableNotEquals(q, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(q.value));
            a.ad.h(OfficeNamespace.a0, a7);
        }
        if (nullableNotEquals(r, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(r.value));
            a.ad.h(OfficeNamespace.cf, a7);
        }
        if (nullableNotEquals(s, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(s.value));
            a.ad.h(OfficeNamespace.az, a7);
        }
        if (nullableNotEquals(t, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(t.value));
            a.ad.h(OfficeNamespace.bl, a7);
        }
        if (nullableNotEquals(u, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(u.value));
            a.ad.h(OfficeNamespace.bq, a7);
        }
        if (nullableNotEquals(v, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(v.value));
            a.ad.h(OfficeNamespace.bo, a7);
        }
        if (nullableNotEquals(w, null)) {
            a7 = numberToString(w.value, CultureInfo.invariantCulture);
            a.ad.h(OfficeNamespace.bp, a7);
        }
        if (nullableNotEquals(x, null)) {
            a7 = XmlNamespaceDefinitionBase.f(ST_HrAlign_$type, x.value);
            a.ad.h(OfficeNamespace.bm, a7);
        }
        if (nullableNotEquals(y, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(y.value));
            a.ad.h(OfficeNamespace.ar, a7);
        }
        if (nullableNotEquals(z, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(z.value));
            a.ad.h(OfficeNamespace.as, a7);
        }
        if (nullableNotEquals(aa, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(aa.value));
            a.ad.h(OfficeNamespace.ce, a7);
        }
        a7 = ab;
        a.ad.h("bordertopcolor", a7);
        a7 = ac;
        a.ad.h("borderleftcolor", a7);
        a7 = ad;
        a.ad.h("borderbottomcolor", a7);
        a7 = ae;
        a.ad.h("borderrightcolor", a7);
        a7 = af;
        a.ad.h(OfficeNamespace.bd, a7);
        a7 = ag;
        a.ad.h(OfficeNamespace.bf, a7);
        a7 = ah;
        a.ad.h(OfficeNamespace.be, a7);
        if (nullableNotEquals(ai, null)) {
            a7 = XmlNamespaceDefinitionBase.f(ST_InsetMode_$type, ai.value);
            a.ad.h(OfficeNamespace.bs, a7);
        }
        a7 = aj;
        a.ad.h("chromakey", a7);
        if (nullableNotEquals(ak, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(ak.value));
            a.ad.h("filled", a7);
        }
        a7 = al;
        a.ad.h("fillcolor", a7);
        a7 = am;
        a.ad.h("opacity", a7);
        if (nullableNotEquals(an, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(an.value));
            a.ad.h("stroked", a7);
        }
        a7 = ao;
        a.ad.h("strokecolor", a7);
        a7 = ap;
        a.ad.h("strokeweight", a7);
        if (nullableNotEquals(aq, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(aq.value));
            a.ad.h("insetpen", a7);
        }
        if (nullableNotEquals(ar, null)) {
            a7 = numberToString(ar.value, CultureInfo.invariantCulture);
            a.ad.h(OfficeNamespace.ca, a7);
        }
        if (nullableNotEquals(as, null)) {
            a7 = XmlNamespaceDefinitionBase.f(ST_ConnectorType_$type, as.value);
            a.ad.h(OfficeNamespace.a8, a7);
        }
        if (nullableNotEquals(at, null)) {
            a7 = XmlNamespaceDefinitionBase.f(ST_BWMode_$type, at.value);
            a.ad.h("bwmode", a7);
        }
        if (nullableNotEquals(au, null)) {
            a7 = XmlNamespaceDefinitionBase.f(ST_BWMode_$type, au.value);
            a.ad.h("bwpure", a7);
        }
        if (nullableNotEquals(av, null)) {
            a7 = XmlNamespaceDefinitionBase.f(ST_BWMode_$type, av.value);
            a.ad.h("bwnormal", a7);
        }
        if (nullableNotEquals(aw, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(aw.value));
            a.ad.h(OfficeNamespace.bi, a7);
        }
        if (nullableNotEquals(ax, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(ax.value));
            a.ad.h(OfficeNamespace.bw, a7);
        }
        if (nullableNotEquals(ay, null)) {
            a7 = ST_TrueFalseBlank.f(ay.value);
            a.ad.h(OfficeNamespace.bv, a7);
        }
        if (nullableNotEquals(az, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(az.value));
            a.ad.h(OfficeNamespace.b1, a7);
        }
        if (nullableNotEquals(a0, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(a0.value));
            a.ad.h(OfficeNamespace.a5, a7);
        }
        if (nullableNotEquals(a1, null)) {
            a7 = ST_TrueFalse.k(ST_TrueFalse.b(a1.value));
            a.ad.h(OfficeNamespace.a4, a7);
        }
        a7 = a2;
        a.ad.h("type", a7);
        a7 = a3;
        a.ad.h("adj", a7);
        a7 = a4;
        a.ad.h("path", a7);
        a7 = a5;
        a.ad.h("gfxdata", a7);
        a7 = a6;
        a.ad.h("equationxml", a7);
    };
    VmlNamespace.du = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y, z, aa, ab, ac, ad, ae, af, ag, ah, ai, aj, ak, al, am, an, ao, ap, aq, ar, as, at, au, av, aw, ax, ay, az, a0, a1, a2, a3, a4) {
        b = null;
        c = null;
        d = null;
        e = null;
        f = null;
        g = null;
        h = null;
        i = null;
        j = null;
        k = null;
        l = Nullable$1.toNullable(Boolean_$type, null);
        m = null;
        n = Nullable$1.toNullable(Boolean_$type, null);
        o = null;
        p = Nullable$1.toNullable(Boolean_$type, null);
        q = Nullable$1.toNullable(Boolean_$type, null);
        r = Nullable$1.toNullable(Boolean_$type, null);
        s = Nullable$1.toNullable(Boolean_$type, null);
        t = Nullable$1.toNullable(Boolean_$type, null);
        u = Nullable$1.toNullable(Boolean_$type, null);
        v = Nullable$1.toNullable(Boolean_$type, null);
        w = Nullable$1.toNullable(Number_$type, null);
        x = Nullable$1.toNullable(ST_HrAlign_$type, null);
        y = Nullable$1.toNullable(Boolean_$type, null);
        z = Nullable$1.toNullable(Boolean_$type, null);
        aa = Nullable$1.toNullable(Boolean_$type, null);
        ab = null;
        ac = null;
        ad = null;
        ae = null;
        af = null;
        ag = null;
        ah = null;
        ai = Nullable$1.toNullable(ST_InsetMode_$type, null);
        aj = null;
        ak = Nullable$1.toNullable(Boolean_$type, null);
        al = null;
        am = null;
        an = Nullable$1.toNullable(Boolean_$type, null);
        ao = null;
        ap = null;
        aq = Nullable$1.toNullable(Boolean_$type, null);
        ar = Nullable$1.toNullable(Number_$type, null);
        as = Nullable$1.toNullable(ST_ConnectorType_$type, null);
        at = Nullable$1.toNullable(ST_BWMode_$type, null);
        au = Nullable$1.toNullable(ST_BWMode_$type, null);
        av = Nullable$1.toNullable(ST_BWMode_$type, null);
        aw = Nullable$1.toNullable(Boolean_$type, null);
        ax = Nullable$1.toNullable(Boolean_$type, null);
        ay = Nullable$1.toNullable(Boolean_$type, null);
        az = Nullable$1.toNullable(Boolean_$type, null);
        a0 = Nullable$1.toNullable(Boolean_$type, null);
        a1 = Nullable$1.toNullable(Boolean_$type, null);
        a2 = null;
        a3 = null;
        a4 = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var a5 = _1.value;
                switch (a5.a.e(a.d)) {
                    case "id":
                        b = a5.d;
                        break;
                    case "style":
                        c = a5.d;
                        break;
                    case "href":
                        d = a5.d;
                        break;
                    case "target":
                        e = a5.d;
                        break;
                    case "class":
                        f = a5.d;
                        break;
                    case "title":
                        g = a5.d;
                        break;
                    case "alt":
                        h = a5.d;
                        break;
                    case "coordsize":
                        i = a5.d;
                        break;
                    case "coordorigin":
                        j = a5.d;
                        break;
                    case "wrapcoords":
                        k = a5.d;
                        break;
                    case "print":
                        l = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.b9:
                        m = a5.d;
                        break;
                    case OfficeNamespace.by:
                        n = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.b2:
                        o = a5.d;
                        break;
                    case OfficeNamespace.bg:
                        p = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.a0:
                        q = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.cf:
                        r = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.az:
                        s = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.bl:
                        t = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.bq:
                        u = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.bo:
                        v = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.bp:
                        w = Nullable$1.toNullable(Number_$type, parseNumber(a5.d, CultureInfo.invariantCulture));
                        break;
                    case OfficeNamespace.bm:
                        x = Nullable$1.toNullable(ST_HrAlign_$type, XmlNamespaceDefinitionBase.b(ST_HrAlign_$type, a5.d));
                        break;
                    case OfficeNamespace.ar:
                        y = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.as:
                        z = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.ce:
                        aa = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case "bordertopcolor":
                        ab = a5.d;
                        break;
                    case "borderleftcolor":
                        ac = a5.d;
                        break;
                    case "borderbottomcolor":
                        ad = a5.d;
                        break;
                    case "borderrightcolor":
                        ae = a5.d;
                        break;
                    case OfficeNamespace.bd:
                        af = a5.d;
                        break;
                    case OfficeNamespace.bf:
                        ag = a5.d;
                        break;
                    case OfficeNamespace.be:
                        ah = a5.d;
                        break;
                    case OfficeNamespace.bs:
                        ai = Nullable$1.toNullable(ST_InsetMode_$type, XmlNamespaceDefinitionBase.b(ST_InsetMode_$type, a5.d));
                        break;
                    case "chromakey":
                        aj = a5.d;
                        break;
                    case "filled":
                        ak = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case "fillcolor":
                        al = a5.d;
                        break;
                    case "opacity":
                        am = a5.d;
                        break;
                    case "stroked":
                        an = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case "strokecolor":
                        ao = a5.d;
                        break;
                    case "strokeweight":
                        ap = a5.d;
                        break;
                    case "insetpen":
                        aq = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.ca:
                        ar = Nullable$1.toNullable(Number_$type, parseNumber(a5.d, CultureInfo.invariantCulture));
                        break;
                    case OfficeNamespace.a8:
                        as = Nullable$1.toNullable(ST_ConnectorType_$type, XmlNamespaceDefinitionBase.b(ST_ConnectorType_$type, a5.d));
                        break;
                    case "bwmode":
                        at = Nullable$1.toNullable(ST_BWMode_$type, XmlNamespaceDefinitionBase.b(ST_BWMode_$type, a5.d));
                        break;
                    case "bwpure":
                        au = Nullable$1.toNullable(ST_BWMode_$type, XmlNamespaceDefinitionBase.b(ST_BWMode_$type, a5.d));
                        break;
                    case "bwnormal":
                        av = Nullable$1.toNullable(ST_BWMode_$type, XmlNamespaceDefinitionBase.b(ST_BWMode_$type, a5.d));
                        break;
                    case OfficeNamespace.bi:
                        aw = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.bw:
                        ax = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.bv:
                        ay = Nullable$1.toNullable(Boolean_$type, ST_TrueFalseBlank.d(a5.d));
                        break;
                    case OfficeNamespace.b1:
                        az = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.a5:
                        a0 = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case OfficeNamespace.a4:
                        a1 = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(a5.d)));
                        break;
                    case "adj":
                        a2 = a5.d;
                        break;
                    case "path":
                        a3 = a5.d;
                        break;
                    case "master":
                        a4 = a5.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_148_1) { e_148 = { error: e_148_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_148) throw e_148.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t,
            p20: u,
            p21: v,
            p22: w,
            p23: x,
            p24: y,
            p25: z,
            p26: aa,
            p27: ab,
            p28: ac,
            p29: ad,
            p30: ae,
            p31: af,
            p32: ag,
            p33: ah,
            p34: ai,
            p35: aj,
            p36: ak,
            p37: al,
            p38: am,
            p39: an,
            p40: ao,
            p41: ap,
            p42: aq,
            p43: ar,
            p44: as,
            p45: at,
            p46: au,
            p47: av,
            p48: aw,
            p49: ax,
            p50: ay,
            p51: az,
            p52: a0,
            p53: a1,
            p54: a2,
            p55: a3,
            p56: a4
        };
        var e_148, _2;
    };
    VmlNamespace.d3 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y, z, aa, ab, ac, ad, ae, af, ag, ah, ai, aj, ak, al, am, an, ao, ap, aq, ar, as, at, au, av, aw, ax, ay, az, a0, a1, a2, a3, a4) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = null; }
        if (g === void 0) { g = null; }
        if (h === void 0) { h = null; }
        if (i === void 0) { i = null; }
        if (j === void 0) { j = null; }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = Nullable$1.toNullable(Boolean_$type, null); }
        if (m === void 0) { m = null; }
        if (n === void 0) { n = Nullable$1.toNullable(Boolean_$type, null); }
        if (o === void 0) { o = null; }
        if (p === void 0) { p = Nullable$1.toNullable(Boolean_$type, null); }
        if (q === void 0) { q = Nullable$1.toNullable(Boolean_$type, null); }
        if (r === void 0) { r = Nullable$1.toNullable(Boolean_$type, null); }
        if (s === void 0) { s = Nullable$1.toNullable(Boolean_$type, null); }
        if (t === void 0) { t = Nullable$1.toNullable(Boolean_$type, null); }
        if (u === void 0) { u = Nullable$1.toNullable(Boolean_$type, null); }
        if (v === void 0) { v = Nullable$1.toNullable(Boolean_$type, null); }
        if (w === void 0) { w = Nullable$1.toNullable(Number_$type, null); }
        if (x === void 0) { x = Nullable$1.toNullable(ST_HrAlign_$type, null); }
        if (y === void 0) { y = Nullable$1.toNullable(Boolean_$type, null); }
        if (z === void 0) { z = Nullable$1.toNullable(Boolean_$type, null); }
        if (aa === void 0) { aa = Nullable$1.toNullable(Boolean_$type, null); }
        if (ab === void 0) { ab = null; }
        if (ac === void 0) { ac = null; }
        if (ad === void 0) { ad = null; }
        if (ae === void 0) { ae = null; }
        if (af === void 0) { af = null; }
        if (ag === void 0) { ag = null; }
        if (ah === void 0) { ah = null; }
        if (ai === void 0) { ai = Nullable$1.toNullable(ST_InsetMode_$type, null); }
        if (aj === void 0) { aj = null; }
        if (ak === void 0) { ak = Nullable$1.toNullable(Boolean_$type, null); }
        if (al === void 0) { al = null; }
        if (am === void 0) { am = null; }
        if (an === void 0) { an = Nullable$1.toNullable(Boolean_$type, null); }
        if (ao === void 0) { ao = null; }
        if (ap === void 0) { ap = null; }
        if (aq === void 0) { aq = Nullable$1.toNullable(Boolean_$type, null); }
        if (ar === void 0) { ar = Nullable$1.toNullable(Number_$type, null); }
        if (as === void 0) { as = Nullable$1.toNullable(ST_ConnectorType_$type, null); }
        if (at === void 0) { at = Nullable$1.toNullable(ST_BWMode_$type, null); }
        if (au === void 0) { au = Nullable$1.toNullable(ST_BWMode_$type, null); }
        if (av === void 0) { av = Nullable$1.toNullable(ST_BWMode_$type, null); }
        if (aw === void 0) { aw = Nullable$1.toNullable(Boolean_$type, null); }
        if (ax === void 0) { ax = Nullable$1.toNullable(Boolean_$type, null); }
        if (ay === void 0) { ay = Nullable$1.toNullable(Boolean_$type, null); }
        if (az === void 0) { az = Nullable$1.toNullable(Boolean_$type, null); }
        if (a0 === void 0) { a0 = Nullable$1.toNullable(Boolean_$type, null); }
        if (a1 === void 0) { a1 = Nullable$1.toNullable(Boolean_$type, null); }
        if (a2 === void 0) { a2 = null; }
        if (a3 === void 0) { a3 = null; }
        if (a4 === void 0) { a4 = null; }
        a.ad.p("urn:schemas-microsoft-com:vml/shapetype", "v");
        var a5;
        a5 = b;
        a.ad.h("id", a5);
        a5 = c;
        a.ad.h("style", a5);
        a5 = d;
        a.ad.h("href", a5);
        a5 = e;
        a.ad.h("target", a5);
        a5 = f;
        a.ad.h("class", a5);
        a5 = g;
        a.ad.h("title", a5);
        a5 = h;
        a.ad.h("alt", a5);
        a5 = i;
        a.ad.h("coordsize", a5);
        a5 = j;
        a.ad.h("coordorigin", a5);
        a5 = k;
        a.ad.h("wrapcoords", a5);
        if (nullableNotEquals(l, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(l.value));
            a.ad.h("print", a5);
        }
        a5 = m;
        a.ad.h(OfficeNamespace.b9, a5);
        if (nullableNotEquals(n, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(n.value));
            a.ad.h(OfficeNamespace.by, a5);
        }
        a5 = o;
        a.ad.h(OfficeNamespace.b2, a5);
        if (nullableNotEquals(p, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(p.value));
            a.ad.h(OfficeNamespace.bg, a5);
        }
        if (nullableNotEquals(q, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(q.value));
            a.ad.h(OfficeNamespace.a0, a5);
        }
        if (nullableNotEquals(r, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(r.value));
            a.ad.h(OfficeNamespace.cf, a5);
        }
        if (nullableNotEquals(s, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(s.value));
            a.ad.h(OfficeNamespace.az, a5);
        }
        if (nullableNotEquals(t, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(t.value));
            a.ad.h(OfficeNamespace.bl, a5);
        }
        if (nullableNotEquals(u, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(u.value));
            a.ad.h(OfficeNamespace.bq, a5);
        }
        if (nullableNotEquals(v, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(v.value));
            a.ad.h(OfficeNamespace.bo, a5);
        }
        if (nullableNotEquals(w, null)) {
            a5 = numberToString(w.value, CultureInfo.invariantCulture);
            a.ad.h(OfficeNamespace.bp, a5);
        }
        if (nullableNotEquals(x, null)) {
            a5 = XmlNamespaceDefinitionBase.f(ST_HrAlign_$type, x.value);
            a.ad.h(OfficeNamespace.bm, a5);
        }
        if (nullableNotEquals(y, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(y.value));
            a.ad.h(OfficeNamespace.ar, a5);
        }
        if (nullableNotEquals(z, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(z.value));
            a.ad.h(OfficeNamespace.as, a5);
        }
        if (nullableNotEquals(aa, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(aa.value));
            a.ad.h(OfficeNamespace.ce, a5);
        }
        a5 = ab;
        a.ad.h("bordertopcolor", a5);
        a5 = ac;
        a.ad.h("borderleftcolor", a5);
        a5 = ad;
        a.ad.h("borderbottomcolor", a5);
        a5 = ae;
        a.ad.h("borderrightcolor", a5);
        a5 = af;
        a.ad.h(OfficeNamespace.bd, a5);
        a5 = ag;
        a.ad.h(OfficeNamespace.bf, a5);
        a5 = ah;
        a.ad.h(OfficeNamespace.be, a5);
        if (nullableNotEquals(ai, null)) {
            a5 = XmlNamespaceDefinitionBase.f(ST_InsetMode_$type, ai.value);
            a.ad.h(OfficeNamespace.bs, a5);
        }
        a5 = aj;
        a.ad.h("chromakey", a5);
        if (nullableNotEquals(ak, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(ak.value));
            a.ad.h("filled", a5);
        }
        a5 = al;
        a.ad.h("fillcolor", a5);
        a5 = am;
        a.ad.h("opacity", a5);
        if (nullableNotEquals(an, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(an.value));
            a.ad.h("stroked", a5);
        }
        a5 = ao;
        a.ad.h("strokecolor", a5);
        a5 = ap;
        a.ad.h("strokeweight", a5);
        if (nullableNotEquals(aq, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(aq.value));
            a.ad.h("insetpen", a5);
        }
        if (nullableNotEquals(ar, null)) {
            a5 = numberToString(ar.value, CultureInfo.invariantCulture);
            a.ad.h(OfficeNamespace.ca, a5);
        }
        if (nullableNotEquals(as, null)) {
            a5 = XmlNamespaceDefinitionBase.f(ST_ConnectorType_$type, as.value);
            a.ad.h(OfficeNamespace.a8, a5);
        }
        if (nullableNotEquals(at, null)) {
            a5 = XmlNamespaceDefinitionBase.f(ST_BWMode_$type, at.value);
            a.ad.h("bwmode", a5);
        }
        if (nullableNotEquals(au, null)) {
            a5 = XmlNamespaceDefinitionBase.f(ST_BWMode_$type, au.value);
            a.ad.h("bwpure", a5);
        }
        if (nullableNotEquals(av, null)) {
            a5 = XmlNamespaceDefinitionBase.f(ST_BWMode_$type, av.value);
            a.ad.h("bwnormal", a5);
        }
        if (nullableNotEquals(aw, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(aw.value));
            a.ad.h(OfficeNamespace.bi, a5);
        }
        if (nullableNotEquals(ax, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(ax.value));
            a.ad.h(OfficeNamespace.bw, a5);
        }
        if (nullableNotEquals(ay, null)) {
            a5 = ST_TrueFalseBlank.f(ay.value);
            a.ad.h(OfficeNamespace.bv, a5);
        }
        if (nullableNotEquals(az, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(az.value));
            a.ad.h(OfficeNamespace.b1, a5);
        }
        if (nullableNotEquals(a0, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(a0.value));
            a.ad.h(OfficeNamespace.a5, a5);
        }
        if (nullableNotEquals(a1, null)) {
            a5 = ST_TrueFalse.k(ST_TrueFalse.b(a1.value));
            a.ad.h(OfficeNamespace.a4, a5);
        }
        a5 = a2;
        a.ad.h("adj", a5);
        a5 = a3;
        a.ad.h("path", a5);
        a5 = a4;
        a.ad.h("master", a5);
    };
    VmlNamespace.dv = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y, z, aa, ab, ac, ad) {
        b = null;
        c = Nullable$1.toNullable(Boolean_$type, null);
        d = null;
        e = null;
        f = null;
        g = Nullable$1.toNullable(ST_StrokeLineStyle_$type, null);
        h = Nullable$1.toNullable(Number_$type, null);
        i = Nullable$1.toNullable(ST_StrokeJoinStyle_$type, null);
        j = Nullable$1.toNullable(ST_StrokeEndCap_$type, null);
        k = null;
        l = Nullable$1.toNullable(ST_FillType_$type, null);
        m = null;
        n = Nullable$1.toNullable(ST_ImageAspect_$type, null);
        o = null;
        p = Nullable$1.toNullable(Boolean_$type, null);
        q = null;
        r = Nullable$1.toNullable(ST_StrokeArrowType_$type, null);
        s = Nullable$1.toNullable(ST_StrokeArrowWidth_$type, null);
        t = Nullable$1.toNullable(ST_StrokeArrowLength_$type, null);
        u = Nullable$1.toNullable(ST_StrokeArrowType_$type, null);
        v = Nullable$1.toNullable(ST_StrokeArrowWidth_$type, null);
        w = Nullable$1.toNullable(ST_StrokeArrowLength_$type, null);
        x = null;
        y = null;
        z = null;
        aa = Nullable$1.toNullable(Boolean_$type, null);
        ab = null;
        ac = Nullable$1.toNullable(Boolean_$type, null);
        ad = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var ae = _1.value;
                switch (ae.a.e(a.d)) {
                    case "id":
                        b = ae.d;
                        break;
                    case "on":
                        c = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(ae.d)));
                        break;
                    case "weight":
                        d = ae.d;
                        break;
                    case "color":
                        e = ae.d;
                        break;
                    case "opacity":
                        f = ae.d;
                        break;
                    case "linestyle":
                        g = Nullable$1.toNullable(ST_StrokeLineStyle_$type, XmlNamespaceDefinitionBase.b(ST_StrokeLineStyle_$type, ae.d));
                        break;
                    case "miterlimit":
                        h = Nullable$1.toNullable(Number_$type, parseNumber(ae.d, CultureInfo.invariantCulture));
                        break;
                    case "joinstyle":
                        i = Nullable$1.toNullable(ST_StrokeJoinStyle_$type, XmlNamespaceDefinitionBase.b(ST_StrokeJoinStyle_$type, ae.d));
                        break;
                    case "endcap":
                        j = Nullable$1.toNullable(ST_StrokeEndCap_$type, XmlNamespaceDefinitionBase.b(ST_StrokeEndCap_$type, ae.d));
                        break;
                    case "dashstyle":
                        k = ae.d;
                        break;
                    case "filltype":
                        l = Nullable$1.toNullable(ST_FillType_$type, XmlNamespaceDefinitionBase.b(ST_FillType_$type, ae.d));
                        break;
                    case "src":
                        m = ae.d;
                        break;
                    case "imageaspect":
                        n = Nullable$1.toNullable(ST_ImageAspect_$type, XmlNamespaceDefinitionBase.b(ST_ImageAspect_$type, ae.d));
                        break;
                    case "imagesize":
                        o = ae.d;
                        break;
                    case "imagealignshape":
                        p = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(ae.d)));
                        break;
                    case "color2":
                        q = ae.d;
                        break;
                    case "startarrow":
                        r = Nullable$1.toNullable(ST_StrokeArrowType_$type, XmlNamespaceDefinitionBase.b(ST_StrokeArrowType_$type, ae.d));
                        break;
                    case "startarrowwidth":
                        s = Nullable$1.toNullable(ST_StrokeArrowWidth_$type, XmlNamespaceDefinitionBase.b(ST_StrokeArrowWidth_$type, ae.d));
                        break;
                    case "startarrowlength":
                        t = Nullable$1.toNullable(ST_StrokeArrowLength_$type, XmlNamespaceDefinitionBase.b(ST_StrokeArrowLength_$type, ae.d));
                        break;
                    case "endarrow":
                        u = Nullable$1.toNullable(ST_StrokeArrowType_$type, XmlNamespaceDefinitionBase.b(ST_StrokeArrowType_$type, ae.d));
                        break;
                    case "endarrowwidth":
                        v = Nullable$1.toNullable(ST_StrokeArrowWidth_$type, XmlNamespaceDefinitionBase.b(ST_StrokeArrowWidth_$type, ae.d));
                        break;
                    case "endarrowlength":
                        w = Nullable$1.toNullable(ST_StrokeArrowLength_$type, XmlNamespaceDefinitionBase.b(ST_StrokeArrowLength_$type, ae.d));
                        break;
                    case OfficeNamespace.bn:
                        x = ae.d;
                        break;
                    case OfficeNamespace.at:
                        y = ae.d;
                        break;
                    case OfficeNamespace.cc:
                        z = ae.d;
                        break;
                    case OfficeNamespace.bi:
                        aa = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(ae.d)));
                        break;
                    case OfficeDocumentRelationships.ar:
                        ab = ae.d;
                        break;
                    case "insetpen":
                        ac = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(ae.d)));
                        break;
                    case OfficeNamespace.b3:
                        ad = ae.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_149_1) { e_149 = { error: e_149_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_149) throw e_149.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t,
            p20: u,
            p21: v,
            p22: w,
            p23: x,
            p24: y,
            p25: z,
            p26: aa,
            p27: ab,
            p28: ac,
            p29: ad
        };
        var e_149, _2;
    };
    VmlNamespace.d4 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y, z, aa, ab, ac, ad) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = Nullable$1.toNullable(Boolean_$type, null); }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = null; }
        if (g === void 0) { g = Nullable$1.toNullable(ST_StrokeLineStyle_$type, null); }
        if (h === void 0) { h = Nullable$1.toNullable(Number_$type, null); }
        if (i === void 0) { i = Nullable$1.toNullable(ST_StrokeJoinStyle_$type, null); }
        if (j === void 0) { j = Nullable$1.toNullable(ST_StrokeEndCap_$type, null); }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = Nullable$1.toNullable(ST_FillType_$type, null); }
        if (m === void 0) { m = null; }
        if (n === void 0) { n = Nullable$1.toNullable(ST_ImageAspect_$type, null); }
        if (o === void 0) { o = null; }
        if (p === void 0) { p = Nullable$1.toNullable(Boolean_$type, null); }
        if (q === void 0) { q = null; }
        if (r === void 0) { r = Nullable$1.toNullable(ST_StrokeArrowType_$type, null); }
        if (s === void 0) { s = Nullable$1.toNullable(ST_StrokeArrowWidth_$type, null); }
        if (t === void 0) { t = Nullable$1.toNullable(ST_StrokeArrowLength_$type, null); }
        if (u === void 0) { u = Nullable$1.toNullable(ST_StrokeArrowType_$type, null); }
        if (v === void 0) { v = Nullable$1.toNullable(ST_StrokeArrowWidth_$type, null); }
        if (w === void 0) { w = Nullable$1.toNullable(ST_StrokeArrowLength_$type, null); }
        if (x === void 0) { x = null; }
        if (y === void 0) { y = null; }
        if (z === void 0) { z = null; }
        if (aa === void 0) { aa = Nullable$1.toNullable(Boolean_$type, null); }
        if (ab === void 0) { ab = null; }
        if (ac === void 0) { ac = Nullable$1.toNullable(Boolean_$type, null); }
        if (ad === void 0) { ad = null; }
        a.ad.p("urn:schemas-microsoft-com:vml/stroke", "v");
        var ae;
        ae = b;
        a.ad.h("id", ae);
        if (nullableNotEquals(c, null)) {
            ae = ST_TrueFalse.k(ST_TrueFalse.b(c.value));
            a.ad.h("on", ae);
        }
        ae = d;
        a.ad.h("weight", ae);
        ae = e;
        a.ad.h("color", ae);
        ae = f;
        a.ad.h("opacity", ae);
        if (nullableNotEquals(g, null)) {
            ae = XmlNamespaceDefinitionBase.f(ST_StrokeLineStyle_$type, g.value);
            a.ad.h("linestyle", ae);
        }
        if (nullableNotEquals(h, null)) {
            ae = numberToString(h.value, CultureInfo.invariantCulture);
            a.ad.h("miterlimit", ae);
        }
        if (nullableNotEquals(i, null)) {
            ae = XmlNamespaceDefinitionBase.f(ST_StrokeJoinStyle_$type, i.value);
            a.ad.h("joinstyle", ae);
        }
        if (nullableNotEquals(j, null)) {
            ae = XmlNamespaceDefinitionBase.f(ST_StrokeEndCap_$type, j.value);
            a.ad.h("endcap", ae);
        }
        ae = k;
        a.ad.h("dashstyle", ae);
        if (nullableNotEquals(l, null)) {
            ae = XmlNamespaceDefinitionBase.f(ST_FillType_$type, l.value);
            a.ad.h("filltype", ae);
        }
        ae = m;
        a.ad.h("src", ae);
        if (nullableNotEquals(n, null)) {
            ae = XmlNamespaceDefinitionBase.f(ST_ImageAspect_$type, n.value);
            a.ad.h("imageaspect", ae);
        }
        ae = o;
        a.ad.h("imagesize", ae);
        if (nullableNotEquals(p, null)) {
            ae = ST_TrueFalse.k(ST_TrueFalse.b(p.value));
            a.ad.h("imagealignshape", ae);
        }
        ae = q;
        a.ad.h("color2", ae);
        if (nullableNotEquals(r, null)) {
            ae = XmlNamespaceDefinitionBase.f(ST_StrokeArrowType_$type, r.value);
            a.ad.h("startarrow", ae);
        }
        if (nullableNotEquals(s, null)) {
            ae = XmlNamespaceDefinitionBase.f(ST_StrokeArrowWidth_$type, s.value);
            a.ad.h("startarrowwidth", ae);
        }
        if (nullableNotEquals(t, null)) {
            ae = XmlNamespaceDefinitionBase.f(ST_StrokeArrowLength_$type, t.value);
            a.ad.h("startarrowlength", ae);
        }
        if (nullableNotEquals(u, null)) {
            ae = XmlNamespaceDefinitionBase.f(ST_StrokeArrowType_$type, u.value);
            a.ad.h("endarrow", ae);
        }
        if (nullableNotEquals(v, null)) {
            ae = XmlNamespaceDefinitionBase.f(ST_StrokeArrowWidth_$type, v.value);
            a.ad.h("endarrowwidth", ae);
        }
        if (nullableNotEquals(w, null)) {
            ae = XmlNamespaceDefinitionBase.f(ST_StrokeArrowLength_$type, w.value);
            a.ad.h("endarrowlength", ae);
        }
        ae = x;
        a.ad.h(OfficeNamespace.bn, ae);
        ae = y;
        a.ad.h(OfficeNamespace.at, ae);
        ae = z;
        a.ad.h(OfficeNamespace.cc, ae);
        if (nullableNotEquals(aa, null)) {
            ae = ST_TrueFalse.k(ST_TrueFalse.b(aa.value));
            a.ad.h(OfficeNamespace.bi, ae);
        }
        ae = ab;
        a.ad.h(OfficeDocumentRelationships.ar, ae);
        if (nullableNotEquals(ac, null)) {
            ae = ST_TrueFalse.k(ST_TrueFalse.b(ac.value));
            a.ad.h("insetpen", ae);
        }
        ae = ad;
        a.ad.h(OfficeNamespace.b3, ae);
    };
    VmlNamespace.dw = function (a, b, c, d, e, f) {
        b = null;
        c = null;
        d = null;
        e = Nullable$1.toNullable(Boolean_$type, null);
        f = Nullable$1.toNullable(ST_InsetMode_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var g = _1.value;
                switch (g.a.e(a.d)) {
                    case "id":
                        b = g.d;
                        break;
                    case "style":
                        c = g.d;
                        break;
                    case "inset":
                        d = g.d;
                        break;
                    case OfficeNamespace.b8:
                        e = Nullable$1.toNullable(Boolean_$type, ST_TrueFalse.g(ST_TrueFalse.d(g.d)));
                        break;
                    case OfficeNamespace.bs:
                        f = Nullable$1.toNullable(ST_InsetMode_$type, XmlNamespaceDefinitionBase.b(ST_InsetMode_$type, g.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_150_1) { e_150 = { error: e_150_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_150) throw e_150.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
        var e_150, _2;
    };
    VmlNamespace.d5 = function (a, b, c, d, e, f) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = Nullable$1.toNullable(Boolean_$type, null); }
        if (f === void 0) { f = Nullable$1.toNullable(ST_InsetMode_$type, null); }
        a.ad.p("urn:schemas-microsoft-com:vml/textbox", "v");
        var g;
        g = b;
        a.ad.h("id", g);
        g = c;
        a.ad.h("style", g);
        g = d;
        a.ad.h("inset", g);
        if (nullableNotEquals(e, null)) {
            g = ST_TrueFalse.k(ST_TrueFalse.b(e.value));
            a.ad.h(OfficeNamespace.b8, g);
        }
        if (nullableNotEquals(f, null)) {
            g = XmlNamespaceDefinitionBase.f(ST_InsetMode_$type, f.value);
            a.ad.h(OfficeNamespace.bs, g);
        }
    };
    VmlNamespace.$t = markType(VmlNamespace, 'VmlNamespace', XmlNamespaceDefinitionBase.$);
    VmlNamespace.aw = "urn:schemas-microsoft-com:vml" + "/background";
    VmlNamespace.an = new VmlNamespace();
    return VmlNamespace;
}(XmlNamespaceDefinitionBase));
export { VmlNamespace };
var XmlNamespace = /** @class */ (function (_super) {
    tslib_1.__extends(XmlNamespace, _super);
    function XmlNamespace() {
        return _super.call(this) || this;
    }
    XmlNamespace.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return "http://www.w3.org/XML/1998/namespace";
            default: return "http://www.w3.org/XML/1998/namespace";
        }
    };
    XmlNamespace.prototype.get_j = function () {
        return "xml";
    };
    Object.defineProperty(XmlNamespace.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    XmlNamespace.as = function (a) {
        a.i("xml", "space", "http://www.w3.org/XML/1998/namespace", "preserve");
    };
    XmlNamespace.$t = markType(XmlNamespace, 'XmlNamespace', XmlNamespaceDefinitionBase.$);
    XmlNamespace.ap = "http://www.w3.org/XML/1998/namespace" + "/lang";
    XmlNamespace.ar = "http://www.w3.org/XML/1998/namespace" + "/space";
    XmlNamespace.an = new XmlNamespace();
    return XmlNamespace;
}(XmlNamespaceDefinitionBase));
export { XmlNamespace };
var XmlSchemaInstance = /** @class */ (function (_super) {
    tslib_1.__extends(XmlSchemaInstance, _super);
    function XmlSchemaInstance() {
        return _super.call(this) || this;
    }
    XmlSchemaInstance.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return XmlSchemaInstance.ap;
            default: return XmlSchemaInstance.ap;
        }
    };
    XmlSchemaInstance.prototype.get_j = function () {
        return "xsi";
    };
    Object.defineProperty(XmlSchemaInstance.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    XmlSchemaInstance.$t = markType(XmlSchemaInstance, 'XmlSchemaInstance', XmlNamespaceDefinitionBase.$);
    XmlSchemaInstance.ap = "http://www.w3.org/2001/XMLSchema-instance";
    XmlSchemaInstance.aq = XmlSchemaInstance.ap + "/type";
    XmlSchemaInstance.an = new XmlSchemaInstance();
    return XmlSchemaInstance;
}(XmlNamespaceDefinitionBase));
export { XmlSchemaInstance };
var EG_Anchor = /** @class */ (function (_super) {
    tslib_1.__extends(EG_Anchor, _super);
    function EG_Anchor() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        return _this;
    }
    EG_Anchor.$t = markType(EG_Anchor, 'EG_Anchor');
    return EG_Anchor;
}(Base));
export { EG_Anchor };
var CT_AbsoluteAnchor = /** @class */ (function (_super) {
    tslib_1.__extends(CT_AbsoluteAnchor, _super);
    function CT_AbsoluteAnchor() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = null;
        _this.d = null;
        return _this;
    }
    CT_AbsoluteAnchor.prototype.b = function ($tArg, $tResult, a, b) {
        if (b === void 0) { b = Type.getDefaultValue($tArg); }
        return a._visitCT_AbsoluteAnchor$i(this, b);
    };
    CT_AbsoluteAnchor.$t = markType(CT_AbsoluteAnchor, 'CT_AbsoluteAnchor', EG_Anchor.$);
    return CT_AbsoluteAnchor;
}(EG_Anchor));
export { CT_AbsoluteAnchor };
var CT_AnchorClientData = /** @class */ (function (_super) {
    tslib_1.__extends(CT_AnchorClientData, _super);
    function CT_AnchorClientData() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = false;
        _this.b = false;
        return _this;
    }
    CT_AnchorClientData.$t = markType(CT_AnchorClientData, 'CT_AnchorClientData');
    return CT_AnchorClientData;
}(Base));
export { CT_AnchorClientData };
var CT_OneCellAnchor = /** @class */ (function (_super) {
    tslib_1.__extends(CT_OneCellAnchor, _super);
    function CT_OneCellAnchor() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = null;
        _this.c = null;
        return _this;
    }
    CT_OneCellAnchor.prototype.b = function ($tArg, $tResult, a, b) {
        if (b === void 0) { b = Type.getDefaultValue($tArg); }
        return a._visitCT_OneCellAnchor$i(this, b);
    };
    CT_OneCellAnchor.$t = markType(CT_OneCellAnchor, 'CT_OneCellAnchor', EG_Anchor.$);
    return CT_OneCellAnchor;
}(EG_Anchor));
export { CT_OneCellAnchor };
var CT_TwoCellAnchor = /** @class */ (function (_super) {
    tslib_1.__extends(CT_TwoCellAnchor, _super);
    function CT_TwoCellAnchor() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = 0;
        _this.c = null;
        _this.d = null;
        return _this;
    }
    CT_TwoCellAnchor.prototype.b = function ($tArg, $tResult, a, b) {
        if (b === void 0) { b = Type.getDefaultValue($tArg); }
        return a._visitCT_TwoCellAnchor$i(this, b);
    };
    CT_TwoCellAnchor.$t = markType(CT_TwoCellAnchor, 'CT_TwoCellAnchor', EG_Anchor.$);
    return CT_TwoCellAnchor;
}(EG_Anchor));
export { CT_TwoCellAnchor };
export var IEG_AnchorVisitor$2_$type = new Type(null, 'IEG_AnchorVisitor$2');
var ExcelDocumentManager = /** @class */ (function (_super) {
    tslib_1.__extends(ExcelDocumentManager, _super);
    function ExcelDocumentManager(a, b, c, d) {
        return _super.call(this, a, b, c, d) || this;
    }
    ExcelDocumentManager.prototype.get__v = function () {
        return 0;
    };
    Object.defineProperty(ExcelDocumentManager.prototype, "_v", {
        get: function () {
            return this.get__v();
        },
        enumerable: true,
        configurable: true
    });
    ExcelDocumentManager.prototype._aa = function () {
        if (this._ac == false) {
            return 0;
        }
        try {
            for (var _0 = tslib_1.__values(fromEnum(this._b.getRelationships())), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var a = _1.value;
                switch (a.relationshipType) {
                    case WorkbookPartManagerBase.a6: return 0;
                    case WorkbookPartManagerBase.a5: return 1;
                }
            }
        }
        catch (e_151_1) { e_151 = { error: e_151_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_151) throw e_151.error; }
        }
        return 0;
        var e_151, _2;
    };
    ExcelDocumentManager.prototype._bh = function () {
        _super.prototype._bh.call(this);
        this._bk(DrawingMLSpreadsheetDrawing.dn);
        this._bk(ExcelNamespace.an);
        this._bk(Excel2006Main.an);
        this._bk(SpreadsheetMLMain.ao);
        this._bk(SpreadsheetML2009Main.an);
        this._bl(BmpPartManager.y);
        this._bl(EmfPartManager.y);
        this._bl(GifPartManager.y);
        this._bl(JpegPartManager.y);
        this._bl(PngPartManager.y);
        this._bl(TiffPartManager.y);
        this._bl(WmfPartManager.y);
    };
    ExcelDocumentManager.prototype.get__t = function () {
        return DrawingMLSpreadsheetDrawing.dn;
    };
    Object.defineProperty(ExcelDocumentManager.prototype, "_t", {
        get: function () {
            return this.get__t();
        },
        enumerable: true,
        configurable: true
    });
    ExcelDocumentManager.prototype._bq = function () {
        switch (this._z) {
            case 0: return ExcelDocumentManager._bp;
            case 1: return ExcelDocumentManager._bo;
            default: return ExcelDocumentManager._bp;
        }
    };
    ExcelDocumentManager.prototype._br = function () {
        switch (this._z) {
            case 0: return ExcelDocumentManager._bt;
            case 1: return ExcelDocumentManager._bs;
            default: return ExcelDocumentManager._bt;
        }
    };
    ExcelDocumentManager.$t = markType(ExcelDocumentManager, 'ExcelDocumentManager', OfficeDocumentManager.$);
    ExcelDocumentManager._bp = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/externalLinkPath";
    ExcelDocumentManager._bo = "http://purl.oclc.org/ooxml/officeDocument/relationships/externalLinkPath";
    ExcelDocumentManager._bt = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/oleObject";
    ExcelDocumentManager._bs = "http://purl.oclc.org/ooxml/officeDocument/relationships/oleObject";
    return ExcelDocumentManager;
}(OfficeDocumentManager));
export { ExcelDocumentManager };
var XLOpenXmlUtilities = /** @class */ (function (_super) {
    tslib_1.__extends(XLOpenXmlUtilities, _super);
    function XLOpenXmlUtilities() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    XLOpenXmlUtilities.a = function (a) {
        var t1 = a;
        L0: while (true) {
            switch (t1) {
                case 0: return "b";
                case 1: return "d";
                case 2: return "n";
                case 3: return "e";
                case 4: return "s";
                case 5: return "str";
                case 6: return "inlineStr";
                default:
                    t1 = 5;
                    continue L0;
            }
            break;
        }
    };
    XLOpenXmlUtilities.$t = markType(XLOpenXmlUtilities, 'XLOpenXmlUtilities');
    return XLOpenXmlUtilities;
}(Base));
export { XLOpenXmlUtilities };
var CT_Marker = /** @class */ (function (_super) {
    tslib_1.__extends(CT_Marker, _super);
    function CT_Marker() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = 0;
        _this.a = new ST_Coordinate();
        _this.d = 0;
        _this.b = new ST_Coordinate();
        return _this;
    }
    CT_Marker.$t = markType(CT_Marker, 'CT_Marker');
    return CT_Marker;
}(Base));
export { CT_Marker };
var ST_Guid = /** @class */ (function (_super) {
    tslib_1.__extends(ST_Guid, _super);
    function ST_Guid(a) {
        var _rest = [];
        for (var _0 = 1; _0 < arguments.length; _0++) {
            _rest[_0 - 1] = arguments[_0];
        }
        var _this = _super.call(this) || this;
        _this.d = new Guid();
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0: break;
            case 1:
                {
                    var c = _rest[0];
                    _this.d = c;
                }
                break;
        }
        return _this;
    }
    ST_Guid.c = function (a) {
        return ST_Guid.a(new Guid(3, a));
    };
    ST_Guid.prototype.toString = function () {
        return stringToLocaleUpper(this.d.toString2("B"), CultureInfo.invariantCulture);
    };
    ST_Guid.a = function (a) {
        return new ST_Guid(1, a);
    };
    ST_Guid.h = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(ST_Guid.$, null);
        }
        return Nullable$1.toNullable(ST_Guid.$, ST_Guid.a(a.value));
    };
    ST_Guid.e = function (a) {
        return a.d;
    };
    ST_Guid.g = function (a) {
        if (!a.hasValue) {
            return Nullable$1.toNullable(Guid.$, null);
        }
        return Nullable$1.toNullable(Guid.$, ST_Guid.e(a.value));
    };
    ST_Guid.$t = markStruct(ST_Guid, 'ST_Guid');
    return ST_Guid;
}(ValueType));
export { ST_Guid };
var CalcChainPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(CalcChainPartManager, _super);
    function CalcChainPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalcChainPartManager.prototype.get_m = function () {
        return CalcChainPartManager.a2;
    };
    Object.defineProperty(CalcChainPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    CalcChainPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/calcChain.xml";
            default: return null;
        }
    };
    CalcChainPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return CalcChainPartManager.a5;
            case 1: return CalcChainPartManager.a4;
            default: return CalcChainPartManager.a5;
        }
    };
    CalcChainPartManager.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(CalcChainPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    CalcChainPartManager.$t = markType(CalcChainPartManager, 'CalcChainPartManager', XmlPartManagerBase.$);
    CalcChainPartManager.a2 = "application/vnd.openxmlformats-officedocument.spreadsheetml.calcChain+xml";
    CalcChainPartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/calcChain";
    CalcChainPartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/calcChain";
    return CalcChainPartManager;
}(XmlPartManagerBase));
export { CalcChainPartManager };
var ChartColorStylePartManager = /** @class */ (function (_super) {
    tslib_1.__extends(ChartColorStylePartManager, _super);
    function ChartColorStylePartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartColorStylePartManager.prototype.get_m = function () {
        return ChartColorStylePartManager.a3;
    };
    Object.defineProperty(ChartColorStylePartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    ChartColorStylePartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/charts/colors.xml";
            default: return null;
        }
    };
    ChartColorStylePartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return ChartColorStylePartManager.a5;
            case 1: return ChartColorStylePartManager.a4;
            default: return ChartColorStylePartManager.a5;
        }
    };
    ChartColorStylePartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(ChartColorStylePartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ChartColorStylePartManager.$t = markType(ChartColorStylePartManager, 'ChartColorStylePartManager', XmlPartManagerBase.$);
    ChartColorStylePartManager.a3 = "application/vnd.ms-office.chartcolorstyle+xml";
    ChartColorStylePartManager.a5 = "http://schemas.microsoft.com/office/2011/relationships/chartColorStyle";
    ChartColorStylePartManager.a4 = "http://schemas.microsoft.com/office/2011/relationships/chartColorStyle";
    return ChartColorStylePartManager;
}(XmlPartManagerBase));
export { ChartColorStylePartManager };
var ChartPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(ChartPartManager, _super);
    function ChartPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartPartManager.prototype.get_m = function () {
        return ChartPartManager.a4;
    };
    Object.defineProperty(ChartPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    ChartPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/charts/chart.xml";
            default: return null;
        }
    };
    ChartPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return ChartPartManager.a6;
            case 1: return ChartPartManager.a5;
            default: return ChartPartManager.a6;
        }
    };
    ChartPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(ChartPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ChartPartManager.$t = markType(ChartPartManager, 'ChartPartManager', XmlPartManagerBase.$);
    ChartPartManager.a4 = "application/vnd.openxmlformats-officedocument.drawingml.chart+xml";
    ChartPartManager.a6 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/chart";
    ChartPartManager.a5 = "http://purl.oclc.org/ooxml/officeDocument/relationships/chart";
    return ChartPartManager;
}(XmlPartManagerBase));
export { ChartPartManager };
var ChartStylePartManager = /** @class */ (function (_super) {
    tslib_1.__extends(ChartStylePartManager, _super);
    function ChartStylePartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartStylePartManager.prototype.get_m = function () {
        return ChartStylePartManager.a3;
    };
    Object.defineProperty(ChartStylePartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    ChartStylePartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/charts/style.xml";
            default: return null;
        }
    };
    ChartStylePartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return ChartStylePartManager.a5;
            case 1: return ChartStylePartManager.a4;
            default: return ChartStylePartManager.a5;
        }
    };
    ChartStylePartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(ChartStylePartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ChartStylePartManager.$t = markType(ChartStylePartManager, 'ChartStylePartManager', XmlPartManagerBase.$);
    ChartStylePartManager.a3 = "application/vnd.ms-office.chartstyle+xml";
    ChartStylePartManager.a5 = "http://schemas.microsoft.com/office/2011/relationships/chartStyle";
    ChartStylePartManager.a4 = "http://schemas.microsoft.com/office/2011/relationships/chartStyle";
    return ChartStylePartManager;
}(XmlPartManagerBase));
export { ChartStylePartManager };
var ChartUserShapePartManager = /** @class */ (function (_super) {
    tslib_1.__extends(ChartUserShapePartManager, _super);
    function ChartUserShapePartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartUserShapePartManager.prototype.get_m = function () {
        return ChartUserShapePartManager.s;
    };
    Object.defineProperty(ChartUserShapePartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    ChartUserShapePartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/drawings/drawing.xml";
            default: return null;
        }
    };
    ChartUserShapePartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return ChartUserShapePartManager.u;
            case 1: return ChartUserShapePartManager.t;
            default: return ChartUserShapePartManager.u;
        }
    };
    ChartUserShapePartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(ChartUserShapePartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ChartUserShapePartManager.$t = markType(ChartUserShapePartManager, 'ChartUserShapePartManager', PartManagerBase.$);
    ChartUserShapePartManager.s = "application/vnd.openxmlformats-officedocument.drawingml.chartshapes+xml";
    ChartUserShapePartManager.u = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/chartUserShapes";
    ChartUserShapePartManager.t = "http://purl.oclc.org/ooxml/officeDocument/relationships/chart";
    return ChartUserShapePartManager;
}(PartManagerBase));
export { ChartUserShapePartManager };
var CommentsPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(CommentsPartManager, _super);
    function CommentsPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CommentsPartManager.prototype.get_m = function () {
        return CommentsPartManager.a3;
    };
    Object.defineProperty(CommentsPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    CommentsPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/comments.xml";
            default: return null;
        }
    };
    CommentsPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return CommentsPartManager.a5;
            case 1: return CommentsPartManager.a4;
            default: return CommentsPartManager.a5;
        }
    };
    CommentsPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(CommentsPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    CommentsPartManager.$t = markType(CommentsPartManager, 'CommentsPartManager', XmlPartManagerBase.$);
    CommentsPartManager.a3 = "application/vnd.openxmlformats-officedocument.spreadsheetml.comments+xml";
    CommentsPartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/comments";
    CommentsPartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/comments";
    return CommentsPartManager;
}(XmlPartManagerBase));
export { CommentsPartManager };
var ConnectionsPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(ConnectionsPartManager, _super);
    function ConnectionsPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ConnectionsPartManager.prototype.get_m = function () {
        return ConnectionsPartManager.a2;
    };
    Object.defineProperty(ConnectionsPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    ConnectionsPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/connections.xml";
            default: return null;
        }
    };
    ConnectionsPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return ConnectionsPartManager.a5;
            case 1: return ConnectionsPartManager.a4;
            default: return ConnectionsPartManager.a5;
        }
    };
    ConnectionsPartManager.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(ConnectionsPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ConnectionsPartManager.$t = markType(ConnectionsPartManager, 'ConnectionsPartManager', XmlPartManagerBase.$);
    ConnectionsPartManager.a2 = "application/vnd.openxmlformats-officedocument.spreadsheetml.connections+xml";
    ConnectionsPartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/connections";
    ConnectionsPartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/connections";
    return ConnectionsPartManager;
}(XmlPartManagerBase));
export { ConnectionsPartManager };
var CtrlPropPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(CtrlPropPartManager, _super);
    function CtrlPropPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CtrlPropPartManager.prototype.get_m = function () {
        return CtrlPropPartManager.s;
    };
    Object.defineProperty(CtrlPropPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    CtrlPropPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/ctrlProp.xml";
            default: return null;
        }
    };
    CtrlPropPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return CtrlPropPartManager.u;
            case 1: return CtrlPropPartManager.t;
            default: return CtrlPropPartManager.u;
        }
    };
    CtrlPropPartManager.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(CtrlPropPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    CtrlPropPartManager.$t = markType(CtrlPropPartManager, 'CtrlPropPartManager', PartManagerBase.$);
    CtrlPropPartManager.s = "application/vnd.ms-excel.controlproperties+xml";
    CtrlPropPartManager.u = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/ctrlProp";
    CtrlPropPartManager.t = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/ctrlProp";
    return CtrlPropPartManager;
}(PartManagerBase));
export { CtrlPropPartManager };
var DrawingPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(DrawingPartManager, _super);
    function DrawingPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DrawingPartManager.prototype.get_m = function () {
        return DrawingPartManager.a3;
    };
    Object.defineProperty(DrawingPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    DrawingPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/drawings/drawing.xml";
            default: return null;
        }
    };
    DrawingPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return DrawingPartManager.a5;
            case 1: return DrawingPartManager.a4;
            default: return DrawingPartManager.a5;
        }
    };
    DrawingPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(DrawingPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    DrawingPartManager.$t = markType(DrawingPartManager, 'DrawingPartManager', XmlPartManagerBase.$);
    DrawingPartManager.a3 = "application/vnd.openxmlformats-officedocument.drawing+xml";
    DrawingPartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing";
    DrawingPartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/drawing";
    return DrawingPartManager;
}(XmlPartManagerBase));
export { DrawingPartManager };
var ExternalLinkPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(ExternalLinkPartManager, _super);
    function ExternalLinkPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ExternalLinkPartManager.prototype.get_m = function () {
        return ExternalLinkPartManager.a3;
    };
    Object.defineProperty(ExternalLinkPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    ExternalLinkPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/externalLinks/externalLink.xml";
            default: return null;
        }
    };
    ExternalLinkPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return ExternalLinkPartManager.a5;
            case 1: return ExternalLinkPartManager.a4;
            default: return ExternalLinkPartManager.a5;
        }
    };
    ExternalLinkPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(ExternalLinkPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ExternalLinkPartManager.$t = markType(ExternalLinkPartManager, 'ExternalLinkPartManager', XmlPartManagerBase.$);
    ExternalLinkPartManager.a3 = "application/vnd.openxmlformats-officedocument.spreadsheetml.externalLink+xml";
    ExternalLinkPartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/externalLink";
    ExternalLinkPartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/externalLink";
    return ExternalLinkPartManager;
}(XmlPartManagerBase));
export { ExternalLinkPartManager };
var PivotCacheDefinitionPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(PivotCacheDefinitionPartManager, _super);
    function PivotCacheDefinitionPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PivotCacheDefinitionPartManager.prototype.get_m = function () {
        return PivotCacheDefinitionPartManager.a3;
    };
    Object.defineProperty(PivotCacheDefinitionPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    PivotCacheDefinitionPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/pivotCache/pivotCacheDefinition.xml";
            default: return null;
        }
    };
    PivotCacheDefinitionPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return PivotCacheDefinitionPartManager.a5;
            case 1: return PivotCacheDefinitionPartManager.a4;
            default: return PivotCacheDefinitionPartManager.a5;
        }
    };
    PivotCacheDefinitionPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(PivotCacheDefinitionPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    PivotCacheDefinitionPartManager.$t = markType(PivotCacheDefinitionPartManager, 'PivotCacheDefinitionPartManager', XmlPartManagerBase.$);
    PivotCacheDefinitionPartManager.a3 = "application/vnd.openxmlformats-officedocument.spreadsheetml.pivotCacheDefinition+xml";
    PivotCacheDefinitionPartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/pivotCacheDefinition";
    PivotCacheDefinitionPartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/pivotCacheDefinition";
    return PivotCacheDefinitionPartManager;
}(XmlPartManagerBase));
export { PivotCacheDefinitionPartManager };
var PivotCacheRecordsPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(PivotCacheRecordsPartManager, _super);
    function PivotCacheRecordsPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PivotCacheRecordsPartManager.prototype.get_m = function () {
        return PivotCacheRecordsPartManager.a3;
    };
    Object.defineProperty(PivotCacheRecordsPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    PivotCacheRecordsPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/pivotCache/pivotCacheDefinition.xml";
            default: return null;
        }
    };
    PivotCacheRecordsPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return PivotCacheRecordsPartManager.a5;
            case 1: return PivotCacheRecordsPartManager.a4;
            default: return PivotCacheRecordsPartManager.a5;
        }
    };
    PivotCacheRecordsPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(PivotCacheRecordsPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    PivotCacheRecordsPartManager.$t = markType(PivotCacheRecordsPartManager, 'PivotCacheRecordsPartManager', XmlPartManagerBase.$);
    PivotCacheRecordsPartManager.a3 = "application/vnd.openxmlformats-officedocument.spreadsheetml.pivotCacheRecords+xml";
    PivotCacheRecordsPartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/pivotCacheRecords";
    PivotCacheRecordsPartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/pivotCacheRecords";
    return PivotCacheRecordsPartManager;
}(XmlPartManagerBase));
export { PivotCacheRecordsPartManager };
var PivotTablePartManager = /** @class */ (function (_super) {
    tslib_1.__extends(PivotTablePartManager, _super);
    function PivotTablePartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PivotTablePartManager.prototype.get_m = function () {
        return PivotTablePartManager.a3;
    };
    Object.defineProperty(PivotTablePartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    PivotTablePartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/pivotTables/pivotTable.xml";
            default: return null;
        }
    };
    PivotTablePartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return PivotTablePartManager.a5;
            case 1: return PivotTablePartManager.a4;
            default: return PivotTablePartManager.a5;
        }
    };
    PivotTablePartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(PivotTablePartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    PivotTablePartManager.$t = markType(PivotTablePartManager, 'PivotTablePartManager', XmlPartManagerBase.$);
    PivotTablePartManager.a3 = "application/vnd.openxmlformats-officedocument.spreadsheetml.pivotTable+xml";
    PivotTablePartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/pivotTable";
    PivotTablePartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/pivotTable";
    return PivotTablePartManager;
}(XmlPartManagerBase));
export { PivotTablePartManager };
var SharedStringsPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(SharedStringsPartManager, _super);
    function SharedStringsPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SharedStringsPartManager.prototype.get_m = function () {
        return SharedStringsPartManager.a2;
    };
    Object.defineProperty(SharedStringsPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    SharedStringsPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/sharedStrings.xml";
            default: return null;
        }
    };
    SharedStringsPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return SharedStringsPartManager.a5;
            case 1: return SharedStringsPartManager.a4;
            default: return SharedStringsPartManager.a5;
        }
    };
    SharedStringsPartManager.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(SharedStringsPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    SharedStringsPartManager.$t = markType(SharedStringsPartManager, 'SharedStringsPartManager', XmlPartManagerBase.$);
    SharedStringsPartManager.a2 = "application/vnd.openxmlformats-officedocument.spreadsheetml.sharedStrings+xml";
    SharedStringsPartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/sharedStrings";
    SharedStringsPartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/sharedStrings";
    return SharedStringsPartManager;
}(XmlPartManagerBase));
export { SharedStringsPartManager };
var SlicerCachePartManager = /** @class */ (function (_super) {
    tslib_1.__extends(SlicerCachePartManager, _super);
    function SlicerCachePartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SlicerCachePartManager.prototype.get_m = function () {
        return SlicerCachePartManager.a3;
    };
    Object.defineProperty(SlicerCachePartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    SlicerCachePartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/slicerCaches/slicerCache.xml";
            default: return null;
        }
    };
    SlicerCachePartManager.prototype.o = function (a) {
        switch (a) {
            case 0:
            case 1: return SlicerCachePartManager.a4;
            default: return SlicerCachePartManager.a4;
        }
    };
    SlicerCachePartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(SlicerCachePartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    SlicerCachePartManager.$t = markType(SlicerCachePartManager, 'SlicerCachePartManager', XmlPartManagerBase.$);
    SlicerCachePartManager.a3 = "application/vnd.ms-excel.slicerCache+xml";
    SlicerCachePartManager.a4 = "http://schemas.microsoft.com/office/2007/relationships/slicerCache";
    return SlicerCachePartManager;
}(XmlPartManagerBase));
export { SlicerCachePartManager };
var SlicerPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(SlicerPartManager, _super);
    function SlicerPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SlicerPartManager.prototype.get_m = function () {
        return "application/vnd.ms-excel.slicer+xml";
    };
    Object.defineProperty(SlicerPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    SlicerPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/slicers/slicer.xml";
            default: return null;
        }
    };
    SlicerPartManager.prototype.o = function (a) {
        switch (a) {
            case 0:
            case 1: return SlicerPartManager.a4;
            default: return SlicerPartManager.a4;
        }
    };
    SlicerPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(SlicerPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    SlicerPartManager.$t = markType(SlicerPartManager, 'SlicerPartManager', XmlPartManagerBase.$);
    SlicerPartManager.a4 = "http://schemas.microsoft.com/office/2007/relationships/slicer";
    return SlicerPartManager;
}(XmlPartManagerBase));
export { SlicerPartManager };
var ExcelStylesPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(ExcelStylesPartManager, _super);
    function ExcelStylesPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ExcelStylesPartManager.prototype.get_m = function () {
        return ExcelStylesPartManager.a2;
    };
    Object.defineProperty(ExcelStylesPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    ExcelStylesPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/styles.xml";
            default: return null;
        }
    };
    ExcelStylesPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return ExcelStylesPartManager.a5;
            case 1: return ExcelStylesPartManager.a4;
            default: return ExcelStylesPartManager.a5;
        }
    };
    ExcelStylesPartManager.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(ExcelStylesPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    ExcelStylesPartManager.$t = markType(ExcelStylesPartManager, 'ExcelStylesPartManager', XmlPartManagerBase.$);
    ExcelStylesPartManager.a2 = "application/vnd.openxmlformats-officedocument.spreadsheetml.styles+xml";
    ExcelStylesPartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/styles";
    ExcelStylesPartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/styles";
    return ExcelStylesPartManager;
}(XmlPartManagerBase));
export { ExcelStylesPartManager };
var TablePartManager = /** @class */ (function (_super) {
    tslib_1.__extends(TablePartManager, _super);
    function TablePartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TablePartManager.prototype.get_m = function () {
        return TablePartManager.a3;
    };
    Object.defineProperty(TablePartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    TablePartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/tables/table.xml";
            default: return null;
        }
    };
    TablePartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return TablePartManager.a5;
            case 1: return TablePartManager.a4;
            default: return TablePartManager.a5;
        }
    };
    TablePartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(TablePartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    TablePartManager.$t = markType(TablePartManager, 'TablePartManager', XmlPartManagerBase.$);
    TablePartManager.a3 = "application/vnd.openxmlformats-officedocument.spreadsheetml.table+xml";
    TablePartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/table";
    TablePartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/table";
    return TablePartManager;
}(XmlPartManagerBase));
export { TablePartManager };
var WorkbookPartManagerBase = /** @class */ (function (_super) {
    tslib_1.__extends(WorkbookPartManagerBase, _super);
    function WorkbookPartManagerBase() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WorkbookPartManagerBase.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/workbook.xml";
            default: return null;
        }
    };
    WorkbookPartManagerBase.prototype.o = function (a) {
        switch (a) {
            case 0: return WorkbookPartManagerBase.a6;
            case 1: return WorkbookPartManagerBase.a5;
            default: return WorkbookPartManagerBase.a6;
        }
    };
    WorkbookPartManagerBase.prototype.get_g = function () {
        return false;
    };
    Object.defineProperty(WorkbookPartManagerBase.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    WorkbookPartManagerBase.$t = markType(WorkbookPartManagerBase, 'WorkbookPartManagerBase', XmlPartManagerBase.$);
    WorkbookPartManagerBase.a3 = "application/vnd.ms-excel.template.macroEnabled.main+xml";
    WorkbookPartManagerBase.a4 = "application/vnd.ms-excel.sheet.macroEnabled.main+xml";
    WorkbookPartManagerBase.a7 = "application/vnd.openxmlformats-officedocument.spreadsheetml.template.main+xml";
    WorkbookPartManagerBase.a8 = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml";
    WorkbookPartManagerBase.a6 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument";
    WorkbookPartManagerBase.a5 = "http://purl.oclc.org/ooxml/officeDocument/relationships/officeDocument";
    return WorkbookPartManagerBase;
}(XmlPartManagerBase));
export { WorkbookPartManagerBase };
var WorksheetPartManager = /** @class */ (function (_super) {
    tslib_1.__extends(WorksheetPartManager, _super);
    function WorksheetPartManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WorksheetPartManager.prototype.get_m = function () {
        return WorksheetPartManager.a3;
    };
    Object.defineProperty(WorksheetPartManager.prototype, "m", {
        get: function () {
            return this.get_m();
        },
        enumerable: true,
        configurable: true
    });
    WorksheetPartManager.prototype.n = function (a) {
        switch (a) {
            case 0: return "/xl/worksheets/sheet.xml";
            default: return null;
        }
    };
    WorksheetPartManager.prototype.o = function (a) {
        switch (a) {
            case 0: return WorksheetPartManager.a5;
            case 1: return WorksheetPartManager.a4;
            default: return WorksheetPartManager.a5;
        }
    };
    WorksheetPartManager.prototype.get_g = function () {
        return true;
    };
    Object.defineProperty(WorksheetPartManager.prototype, "g", {
        get: function () {
            return this.get_g();
        },
        enumerable: true,
        configurable: true
    });
    WorksheetPartManager.$t = markType(WorksheetPartManager, 'WorksheetPartManager', XmlPartManagerBase.$);
    WorksheetPartManager.a3 = "application/vnd.openxmlformats-officedocument.spreadsheetml.worksheet+xml";
    WorksheetPartManager.a5 = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/worksheet";
    WorksheetPartManager.a4 = "http://purl.oclc.org/ooxml/officeDocument/relationships/worksheet";
    return WorksheetPartManager;
}(XmlPartManagerBase));
export { WorksheetPartManager };
var DrawingMLSpreadsheetDrawing = /** @class */ (function (_super) {
    tslib_1.__extends(DrawingMLSpreadsheetDrawing, _super);
    function DrawingMLSpreadsheetDrawing() {
        return _super.call(this, DrawingMLSpreadsheetDrawing.dq, DrawingMLSpreadsheetDrawing.dr) || this;
    }
    DrawingMLSpreadsheetDrawing.prototype.get_j = function () {
        return "xdr";
    };
    Object.defineProperty(DrawingMLSpreadsheetDrawing.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    DrawingMLSpreadsheetDrawing.eh = function (a, b) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_152_1) { e_152 = { error: e_152_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_152) throw e_152.error; }
        }
        var e_152, _2;
    };
    DrawingMLSpreadsheetDrawing.ew = function (a, b) {
        a.ad.p(b, "xdr");
    };
    DrawingMLSpreadsheetDrawing.eo = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_153_1) { e_153 = { error: e_153_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_153) throw e_153.error; }
        }
        c = ST_Coordinate.h(a.ab.ad);
        return {
            p2: c
        };
        var e_153, _2;
    };
    DrawingMLSpreadsheetDrawing.e3 = function (a, b, c) {
        a.ad.p(b, "xdr");
        a.ad.u(c.toString());
    };
    DrawingMLSpreadsheetDrawing.ed = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_154_1) { e_154 = { error: e_154_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_154) throw e_154.error; }
        }
        var e_154, _2;
    };
    DrawingMLSpreadsheetDrawing.es = function (a) {
        a.ad.p(DrawingMLSpreadsheetDrawing.ds, "xdr");
    };
    DrawingMLSpreadsheetDrawing.ee = function (a, b, c) {
        b = true;
        c = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "fLocksWithSheet":
                        b = ST_OnOff.e(d.d);
                        break;
                    case "fPrintsWithSheet":
                        c = ST_OnOff.e(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_155_1) { e_155 = { error: e_155_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_155) throw e_155.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_155, _2;
    };
    DrawingMLSpreadsheetDrawing.et = function (a, b, c) {
        if (b === void 0) { b = true; }
        if (c === void 0) { c = true; }
        a.ad.p(DrawingMLSpreadsheetDrawing.dt, "xdr");
        var d;
        if (b != true) {
            d = ST_OnOff.g(b);
            a.ad.h("fLocksWithSheet", d);
        }
        if (c != true) {
            d = ST_OnOff.g(c);
            a.ad.h("fPrintsWithSheet", d);
        }
    };
    DrawingMLSpreadsheetDrawing.ef = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, DrawingMLSpreadsheetDrawing.du, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLSpreadsheetDrawing.eu = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, DrawingMLSpreadsheetDrawing.du, "xdr", b);
    };
    DrawingMLSpreadsheetDrawing.eg = function (a, b) {
        var c = DrawingMLSpreadsheetDrawing.eo(a, DrawingMLSpreadsheetDrawing.dv, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLSpreadsheetDrawing.ev = function (a, b) {
        DrawingMLSpreadsheetDrawing.e3(a, DrawingMLSpreadsheetDrawing.dv, b);
    };
    DrawingMLSpreadsheetDrawing.ei = function (a, b, c) {
        var d = DrawingMLMain.k5(a, DrawingMLSpreadsheetDrawing.dy, b, c);
        b = d.p2;
        c = d.p3;
        return {
            p1: b,
            p2: c
        };
    };
    DrawingMLSpreadsheetDrawing.ex = function (a, b, c) {
        DrawingMLMain.n6(a, DrawingMLSpreadsheetDrawing.dy, b, c);
    };
    DrawingMLSpreadsheetDrawing.ej = function (a) {
    };
    DrawingMLSpreadsheetDrawing.ey = function (a) {
        DrawingMLSpreadsheetDrawing.ew(a, DrawingMLSpreadsheetDrawing.d1);
    };
    DrawingMLSpreadsheetDrawing.ek = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_156_1) { e_156 = { error: e_156_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_156) throw e_156.error; }
        }
        var e_156, _2;
    };
    DrawingMLSpreadsheetDrawing.ez = function (a) {
        a.ad.p(DrawingMLSpreadsheetDrawing.d4, "xdr");
    };
    DrawingMLSpreadsheetDrawing.el = function (a, b, c) {
        var d = DrawingMLMain.k1(a, DrawingMLSpreadsheetDrawing.d6, b, c);
        b = d.p2;
        c = d.p3;
        return {
            p1: b,
            p2: c
        };
    };
    DrawingMLSpreadsheetDrawing.e0 = function (a, b, c) {
        DrawingMLMain.n2(a, DrawingMLSpreadsheetDrawing.d6, b, c);
    };
    DrawingMLSpreadsheetDrawing.em = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, DrawingMLSpreadsheetDrawing.d7, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLSpreadsheetDrawing.e1 = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, DrawingMLSpreadsheetDrawing.d7, "xdr", b);
    };
    DrawingMLSpreadsheetDrawing.en = function (a, b) {
        var c = DrawingMLSpreadsheetDrawing.eo(a, DrawingMLSpreadsheetDrawing.d8, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    DrawingMLSpreadsheetDrawing.e2 = function (a, b) {
        DrawingMLSpreadsheetDrawing.e3(a, DrawingMLSpreadsheetDrawing.d8, b);
    };
    DrawingMLSpreadsheetDrawing.ep = function (a) {
    };
    DrawingMLSpreadsheetDrawing.e4 = function (a) {
        DrawingMLSpreadsheetDrawing.ew(a, DrawingMLSpreadsheetDrawing.ea);
    };
    DrawingMLSpreadsheetDrawing.eq = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "editAs":
                        b = XmlNamespaceDefinitionBase.b(ST_EditAs_$type, c.d, b);
                        break;
                    default: break;
                }
            }
        }
        catch (e_157_1) { e_157 = { error: e_157_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_157) throw e_157.error; }
        }
        return {
            p1: b
        };
        var e_157, _2;
    };
    DrawingMLSpreadsheetDrawing.e5 = function (a, b) {
        if (b === void 0) { b = 0; }
        a.ad.p(DrawingMLSpreadsheetDrawing.eb, "xdr");
        var c;
        if (b != 0) {
            c = XmlNamespaceDefinitionBase.f(ST_EditAs_$type, b);
            a.ad.h("editAs", c);
        }
    };
    DrawingMLSpreadsheetDrawing.er = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_158_1) { e_158 = { error: e_158_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_158) throw e_158.error; }
        }
        var e_158, _2;
    };
    DrawingMLSpreadsheetDrawing.e6 = function (a) {
        a.ad.p(DrawingMLSpreadsheetDrawing.ec, "xdr");
        var b = a.d._z;
        a.ad.l(DrawingMLMain.an);
        a.ad.l(DrawingMLSpreadsheetDrawing.dn);
    };
    DrawingMLSpreadsheetDrawing.$t = markType(DrawingMLSpreadsheetDrawing, 'DrawingMLSpreadsheetDrawing', DrawingNamespaceDefinitionBase.$);
    DrawingMLSpreadsheetDrawing.dr = "http://schemas.openxmlformats.org/drawingml/2006/spreadsheetDrawing";
    DrawingMLSpreadsheetDrawing.dq = "http://purl.oclc.org/ooxml/drawingml/spreadsheetDrawing";
    DrawingMLSpreadsheetDrawing.ds = DrawingMLSpreadsheetDrawing.dq + "/absoluteAnchor";
    DrawingMLSpreadsheetDrawing.dt = DrawingMLSpreadsheetDrawing.dq + "/clientData";
    DrawingMLSpreadsheetDrawing.du = DrawingMLSpreadsheetDrawing.dq + "/col";
    DrawingMLSpreadsheetDrawing.dv = DrawingMLSpreadsheetDrawing.dq + "/colOff";
    DrawingMLSpreadsheetDrawing.dy = DrawingMLSpreadsheetDrawing.dq + "/ext";
    DrawingMLSpreadsheetDrawing.d1 = DrawingMLSpreadsheetDrawing.dq + "/from";
    DrawingMLSpreadsheetDrawing.d4 = DrawingMLSpreadsheetDrawing.dq + "/oneCellAnchor";
    DrawingMLSpreadsheetDrawing.d6 = DrawingMLSpreadsheetDrawing.dq + "/pos";
    DrawingMLSpreadsheetDrawing.d7 = DrawingMLSpreadsheetDrawing.dq + "/row";
    DrawingMLSpreadsheetDrawing.d8 = DrawingMLSpreadsheetDrawing.dq + "/rowOff";
    DrawingMLSpreadsheetDrawing.ea = DrawingMLSpreadsheetDrawing.dq + "/to";
    DrawingMLSpreadsheetDrawing.eb = DrawingMLSpreadsheetDrawing.dq + "/twoCellAnchor";
    DrawingMLSpreadsheetDrawing.ec = DrawingMLSpreadsheetDrawing.dq + "/wsDr";
    DrawingMLSpreadsheetDrawing.dw = DrawingMLSpreadsheetDrawing.dq + "/cxnSp";
    DrawingMLSpreadsheetDrawing.d2 = DrawingMLSpreadsheetDrawing.dq + "/graphicFrame";
    DrawingMLSpreadsheetDrawing.d3 = DrawingMLSpreadsheetDrawing.dq + "/grpSp";
    DrawingMLSpreadsheetDrawing.d5 = DrawingMLSpreadsheetDrawing.dq + "/pic";
    DrawingMLSpreadsheetDrawing.d9 = DrawingMLSpreadsheetDrawing.dq + "/sp";
    DrawingMLSpreadsheetDrawing.dn = new DrawingMLSpreadsheetDrawing();
    return DrawingMLSpreadsheetDrawing;
}(DrawingNamespaceDefinitionBase));
export { DrawingMLSpreadsheetDrawing };
var Excel2006Main = /** @class */ (function (_super) {
    tslib_1.__extends(Excel2006Main, _super);
    function Excel2006Main() {
        return _super.call(this) || this;
    }
    Excel2006Main.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return Excel2006Main.aq;
            default: return Excel2006Main.aq;
        }
    };
    Excel2006Main.prototype.get_j = function () {
        return "xm";
    };
    Object.defineProperty(Excel2006Main.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    Excel2006Main.as = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, Excel2006Main.ap, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    Excel2006Main.au = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, Excel2006Main.ap, "xm", b);
    };
    Excel2006Main.at = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, Excel2006Main.ar, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    Excel2006Main.av = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, Excel2006Main.ar, "xm", b);
    };
    Excel2006Main.$t = markType(Excel2006Main, 'Excel2006Main', XmlNamespaceDefinitionBase.$);
    Excel2006Main.aq = "http://schemas.microsoft.com/office/excel/2006/main";
    Excel2006Main.ap = Excel2006Main.aq + "/f";
    Excel2006Main.ar = Excel2006Main.aq + "/sqref";
    Excel2006Main.an = new Excel2006Main();
    return Excel2006Main;
}(XmlNamespaceDefinitionBase));
export { Excel2006Main };
var ExcelNamespace = /** @class */ (function (_super) {
    tslib_1.__extends(ExcelNamespace, _super);
    function ExcelNamespace() {
        return _super.call(this) || this;
    }
    ExcelNamespace.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return "urn:schemas-microsoft-com:office:excel";
            default: return "urn:schemas-microsoft-com:office:excel";
        }
    };
    ExcelNamespace.prototype.get_j = function () {
        return "x";
    };
    Object.defineProperty(ExcelNamespace.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    ExcelNamespace.cz = function (a, b, c) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_159_1) { e_159 = { error: e_159_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_159) throw e_159.error; }
        }
        c = ST_TrueFalseBlank.d(a.ab.ad);
        return {
            p2: c
        };
        var e_159, _2;
    };
    ExcelNamespace.d8 = function (a, b, c, d) {
        a.ad.p(b, c);
        var e = ST_TrueFalseBlank.f(d);
        if (stringIsNullOrEmpty(e) == false) {
            a.ad.u(e);
        }
    };
    ExcelNamespace.by = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, ExcelNamespace.ap, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.c6 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, ExcelNamespace.ap, "x", b);
    };
    ExcelNamespace.bz = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.aq, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.c7 = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.aq, "x", b);
    };
    ExcelNamespace.b0 = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.ar, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.c8 = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.ar, "x", b);
    };
    ExcelNamespace.b1 = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.as, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.c9 = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.as, "x", b);
    };
    ExcelNamespace.b2 = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.at, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.da = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.at, "x", b);
    };
    ExcelNamespace.b3 = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.au, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.db = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.au, "x", b);
    };
    ExcelNamespace.b4 = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.av, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dc = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.av, "x", b);
    };
    ExcelNamespace.b5 = function (a, b) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_160_1) { e_160 = { error: e_160_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_160) throw e_160.error; }
        }
        b = XmlNamespaceDefinitionBase.b(ST_CF_$type, a.ab.ad);
        return {
            p1: b
        };
        var e_160, _2;
    };
    ExcelNamespace.dd = function (a, b) {
        a.ad.p(ExcelNamespace.aw, "x");
        a.ad.u(XmlNamespaceDefinitionBase.f(ST_CF_$type, b));
    };
    ExcelNamespace.b6 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, ExcelNamespace.ax, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.de = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, ExcelNamespace.ax, "x", b);
    };
    ExcelNamespace.b7 = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "ObjectType":
                        b = XmlNamespaceDefinitionBase.b(ST_ObjectType_$type, c.d, b);
                        break;
                    default: break;
                }
            }
        }
        catch (e_161_1) { e_161 = { error: e_161_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_161) throw e_161.error; }
        }
        return {
            p1: b
        };
        var e_161, _2;
    };
    ExcelNamespace.df = function (a, b) {
        a.ad.p(ExcelNamespace.ay, "x");
        var c;
        c = XmlNamespaceDefinitionBase.f(ST_ObjectType_$type, b);
        a.ad.h("ObjectType", c);
    };
    ExcelNamespace.b8 = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.az, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dg = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.az, "x", b);
    };
    ExcelNamespace.b9 = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.a0, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dh = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.a0, "x", b);
    };
    ExcelNamespace.ca = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, ExcelNamespace.a1, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.di = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, ExcelNamespace.a1, "x", b);
    };
    ExcelNamespace.cb = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.a2, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dj = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.a2, "x", b);
    };
    ExcelNamespace.cc = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.a3, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dk = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.a3, "x", b);
    };
    ExcelNamespace.cd = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.a4, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dl = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.a4, "x", b);
    };
    ExcelNamespace.ce = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.a5, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dm = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.a5, "x", b);
    };
    ExcelNamespace.cf = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.a6, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dn = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.a6, "x", b);
    };
    ExcelNamespace.cg = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.a7, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dp = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.a7, "x", b);
    };
    ExcelNamespace.ch = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, ExcelNamespace.a8, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dq = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, ExcelNamespace.a8, "x", b);
    };
    ExcelNamespace.ci = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, ExcelNamespace.a9, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dr = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, ExcelNamespace.a9, "x", b);
    };
    ExcelNamespace.cj = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.ba, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.ds = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.ba, "x", b);
    };
    ExcelNamespace.ck = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bb, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dt = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bb, "x", b);
    };
    ExcelNamespace.cl = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bc, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.du = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bc, "x", b);
    };
    ExcelNamespace.cn = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.be, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dw = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.be, "x", b);
    };
    ExcelNamespace.cm = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bd, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dv = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bd, "x", b);
    };
    ExcelNamespace.co = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bf, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dx = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bf, "x", b);
    };
    ExcelNamespace.cp = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bg, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dy = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bg, "x", b);
    };
    ExcelNamespace.cq = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bh, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.dz = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bh, "x", b);
    };
    ExcelNamespace.cs = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bj, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.d1 = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bj, "x", b);
    };
    ExcelNamespace.cr = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bk, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.d0 = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bk, "x", b);
    };
    ExcelNamespace.ct = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bm, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.d2 = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bm, "x", b);
    };
    ExcelNamespace.cu = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bn, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.d3 = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bn, "x", b);
    };
    ExcelNamespace.cv = function (a, b) {
        var c = XmlNamespaceDefinitionBase.r(a, ExcelNamespace.bo, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.d4 = function (a, b) {
        XmlNamespaceDefinitionBase.af(a, ExcelNamespace.bo, "x", b);
    };
    ExcelNamespace.cw = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bp, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.d5 = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bp, "x", b);
    };
    ExcelNamespace.cx = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bq, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.d6 = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bq, "x", b);
    };
    ExcelNamespace.cy = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.br, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.d7 = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.br, "x", b);
    };
    ExcelNamespace.c0 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, ExcelNamespace.bs, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.d9 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, ExcelNamespace.bs, "x", b);
    };
    ExcelNamespace.c1 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, ExcelNamespace.bt, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.ea = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, ExcelNamespace.bt, "x", b);
    };
    ExcelNamespace.c2 = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bu, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.eb = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bu, "x", b);
    };
    ExcelNamespace.c5 = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bx, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.ee = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bx, "x", b);
    };
    ExcelNamespace.c3 = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bv, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.ec = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bv, "x", b);
    };
    ExcelNamespace.c4 = function (a, b) {
        var c = ExcelNamespace.cz(a, ExcelNamespace.bw, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    ExcelNamespace.ed = function (a, b) {
        ExcelNamespace.d8(a, ExcelNamespace.bw, "x", b);
    };
    ExcelNamespace.$t = markType(ExcelNamespace, 'ExcelNamespace', XmlNamespaceDefinitionBase.$);
    ExcelNamespace.ap = "urn:schemas-microsoft-com:office:excel" + "/Anchor";
    ExcelNamespace.aq = "urn:schemas-microsoft-com:office:excel" + "/AutoFill";
    ExcelNamespace.ar = "urn:schemas-microsoft-com:office:excel" + "/AutoLine";
    ExcelNamespace.as = "urn:schemas-microsoft-com:office:excel" + "/AutoPict";
    ExcelNamespace.at = "urn:schemas-microsoft-com:office:excel" + "/AutoScale";
    ExcelNamespace.au = "urn:schemas-microsoft-com:office:excel" + "/Camera";
    ExcelNamespace.av = "urn:schemas-microsoft-com:office:excel" + "/Cancel";
    ExcelNamespace.aw = "urn:schemas-microsoft-com:office:excel" + "/CF";
    ExcelNamespace.ax = "urn:schemas-microsoft-com:office:excel" + "/Checked";
    ExcelNamespace.ay = "urn:schemas-microsoft-com:office:excel" + "/ClientData";
    ExcelNamespace.az = "urn:schemas-microsoft-com:office:excel" + "/ColHidden";
    ExcelNamespace.a0 = "urn:schemas-microsoft-com:office:excel" + "/Colored";
    ExcelNamespace.a1 = "urn:schemas-microsoft-com:office:excel" + "/Column";
    ExcelNamespace.a2 = "urn:schemas-microsoft-com:office:excel" + "/DDE";
    ExcelNamespace.a3 = "urn:schemas-microsoft-com:office:excel" + "/Default";
    ExcelNamespace.a4 = "urn:schemas-microsoft-com:office:excel" + "/DefaultSize";
    ExcelNamespace.a5 = "urn:schemas-microsoft-com:office:excel" + "/Disabled";
    ExcelNamespace.a6 = "urn:schemas-microsoft-com:office:excel" + "/Dismiss";
    ExcelNamespace.a7 = "urn:schemas-microsoft-com:office:excel" + "/FirstButton";
    ExcelNamespace.a8 = "urn:schemas-microsoft-com:office:excel" + "/FmlaLink";
    ExcelNamespace.a9 = "urn:schemas-microsoft-com:office:excel" + "/FmlaMacro";
    ExcelNamespace.ba = "urn:schemas-microsoft-com:office:excel" + "/Help";
    ExcelNamespace.bb = "urn:schemas-microsoft-com:office:excel" + "/Horiz";
    ExcelNamespace.bc = "urn:schemas-microsoft-com:office:excel" + "/JustLastX";
    ExcelNamespace.be = "urn:schemas-microsoft-com:office:excel" + "/LockText";
    ExcelNamespace.bd = "urn:schemas-microsoft-com:office:excel" + "/Locked";
    ExcelNamespace.bf = "urn:schemas-microsoft-com:office:excel" + "/MapOCX";
    ExcelNamespace.bg = "urn:schemas-microsoft-com:office:excel" + "/MoveWithCells";
    ExcelNamespace.bh = "urn:schemas-microsoft-com:office:excel" + "/MultiLine";
    ExcelNamespace.bj = "urn:schemas-microsoft-com:office:excel" + "/NoThreeD";
    ExcelNamespace.bk = "urn:schemas-microsoft-com:office:excel" + "/NoThreeD2";
    ExcelNamespace.bm = "urn:schemas-microsoft-com:office:excel" + "/PrintObject";
    ExcelNamespace.bn = "urn:schemas-microsoft-com:office:excel" + "/RecalcAlways";
    ExcelNamespace.bo = "urn:schemas-microsoft-com:office:excel" + "/Row";
    ExcelNamespace.bp = "urn:schemas-microsoft-com:office:excel" + "/RowHidden";
    ExcelNamespace.bq = "urn:schemas-microsoft-com:office:excel" + "/SecretEdit";
    ExcelNamespace.br = "urn:schemas-microsoft-com:office:excel" + "/SizeWithCells";
    ExcelNamespace.bs = "urn:schemas-microsoft-com:office:excel" + "/TextHAlign";
    ExcelNamespace.bt = "urn:schemas-microsoft-com:office:excel" + "/TextVAlign";
    ExcelNamespace.bu = "urn:schemas-microsoft-com:office:excel" + "/UIObj";
    ExcelNamespace.bx = "urn:schemas-microsoft-com:office:excel" + "/VScroll";
    ExcelNamespace.bv = "urn:schemas-microsoft-com:office:excel" + "/ValidIds";
    ExcelNamespace.bw = "urn:schemas-microsoft-com:office:excel" + "/Visible";
    ExcelNamespace.an = new ExcelNamespace();
    return ExcelNamespace;
}(XmlNamespaceDefinitionBase));
export { ExcelNamespace };
var SpreadsheetML2009Main = /** @class */ (function (_super) {
    tslib_1.__extends(SpreadsheetML2009Main, _super);
    function SpreadsheetML2009Main() {
        return _super.call(this) || this;
    }
    SpreadsheetML2009Main.prototype.i = function (a) {
        switch (a) {
            case 0:
            case 1: return SpreadsheetML2009Main.b0;
            default: return SpreadsheetML2009Main.b0;
        }
    };
    SpreadsheetML2009Main.prototype.get_j = function () {
        return "x14";
    };
    Object.defineProperty(SpreadsheetML2009Main.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    SpreadsheetML2009Main.cy = function (a, b, c, d, e, f, g, h, i, j, k, l, m) {
        b = 0;
        c = 0;
        d = 0;
        e = 0;
        f = false;
        g = false;
        h = false;
        i = false;
        j = null;
        k = null;
        l = null;
        m = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var n = _1.value;
                switch (n.a.e(a.d)) {
                    case "type":
                        b = XmlNamespaceDefinitionBase.b(ST_DataValidationType_$type, n.d, b);
                        break;
                    case "errorStyle":
                        c = XmlNamespaceDefinitionBase.b(ST_DataValidationErrorStyle_$type, n.d, c);
                        break;
                    case "imeMode":
                        d = XmlNamespaceDefinitionBase.b(ST_DataValidationImeMode_$type, n.d, d);
                        break;
                    case "operator":
                        e = XmlNamespaceDefinitionBase.b(ST_DataValidationOperator_$type, n.d, e);
                        break;
                    case "allowBlank":
                        f = ST_OnOff.e(n.d);
                        break;
                    case "showDropDown":
                        g = ST_OnOff.e(n.d);
                        break;
                    case "showInputMessage":
                        h = ST_OnOff.e(n.d);
                        break;
                    case "showErrorMessage":
                        i = ST_OnOff.e(n.d);
                        break;
                    case "errorTitle":
                        j = n.d;
                        break;
                    case "error":
                        k = n.d;
                        break;
                    case "promptTitle":
                        l = n.d;
                        break;
                    case "prompt":
                        m = n.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_162_1) { e_162 = { error: e_162_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_162) throw e_162.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m
        };
        var e_162, _2;
    };
    SpreadsheetML2009Main.dg = function (a, b, c, d, e, f, g, h, i, j, k, l, m) {
        if (b === void 0) { b = 0; }
        if (c === void 0) { c = 0; }
        if (d === void 0) { d = 0; }
        if (e === void 0) { e = 0; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = null; }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = null; }
        if (m === void 0) { m = null; }
        a.ad.p(SpreadsheetML2009Main.bd, "x14");
        var n;
        if (b != 0) {
            n = XmlNamespaceDefinitionBase.f(ST_DataValidationType_$type, b);
            a.ad.h("type", n);
        }
        if (c != 0) {
            n = XmlNamespaceDefinitionBase.f(ST_DataValidationErrorStyle_$type, c);
            a.ad.h("errorStyle", n);
        }
        if (d != 0) {
            n = XmlNamespaceDefinitionBase.f(ST_DataValidationImeMode_$type, d);
            a.ad.h("imeMode", n);
        }
        if (e != 0) {
            n = XmlNamespaceDefinitionBase.f(ST_DataValidationOperator_$type, e);
            a.ad.h("operator", n);
        }
        if (f != false) {
            n = ST_OnOff.g(f);
            a.ad.h("allowBlank", n);
        }
        if (g != false) {
            n = ST_OnOff.g(g);
            a.ad.h("showDropDown", n);
        }
        if (h != false) {
            n = ST_OnOff.g(h);
            a.ad.h("showInputMessage", n);
        }
        if (i != false) {
            n = ST_OnOff.g(i);
            a.ad.h("showErrorMessage", n);
        }
        n = j;
        a.ad.h("errorTitle", n);
        n = k;
        a.ad.h("error", n);
        n = l;
        a.ad.h("promptTitle", n);
        n = m;
        a.ad.h("prompt", n);
    };
    SpreadsheetML2009Main.cz = function (a, b, c, d, e) {
        b = false;
        c = Nullable$1.toNullable(Number_$type, null);
        d = Nullable$1.toNullable(Number_$type, null);
        e = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "disablePrompts":
                        b = ST_OnOff.e(f.d);
                        break;
                    case "xWindow":
                        c = Nullable$1.toNullable(Number_$type, parseUInt32_1(f.d, CultureInfo.invariantCulture));
                        break;
                    case "yWindow":
                        d = Nullable$1.toNullable(Number_$type, parseUInt32_1(f.d, CultureInfo.invariantCulture));
                        break;
                    case "count":
                        e = Nullable$1.toNullable(Number_$type, parseUInt32_1(f.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_163_1) { e_163 = { error: e_163_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_163) throw e_163.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_163, _2;
    };
    SpreadsheetML2009Main.dh = function (a, b, c, d, e) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetML2009Main.be, "x14");
        var f;
        if (b != false) {
            f = ST_OnOff.g(b);
            a.ad.h("disablePrompts", f);
        }
        if (nullableNotEquals(c, null)) {
            f = c.value.toString();
            a.ad.h("xWindow", f);
        }
        if (nullableNotEquals(d, null)) {
            f = d.value.toString();
            a.ad.h("yWindow", f);
        }
        if (nullableNotEquals(e, null)) {
            f = e.value.toString();
            a.ad.h("count", f);
        }
    };
    SpreadsheetML2009Main.c0 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_164_1) { e_164 = { error: e_164_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_164) throw e_164.error; }
        }
        var e_164, _2;
    };
    SpreadsheetML2009Main.di = function (a) {
        a.ad.p(SpreadsheetML2009Main.bn, "x14");
    };
    SpreadsheetML2009Main.c1 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_165_1) { e_165 = { error: e_165_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_165) throw e_165.error; }
        }
        var e_165, _2;
    };
    SpreadsheetML2009Main.dj = function (a) {
        a.ad.p(SpreadsheetML2009Main.bo, "x14");
    };
    SpreadsheetML2009Main.c2 = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, SpreadsheetML2009Main.bv, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetML2009Main.dk = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, SpreadsheetML2009Main.bv, SpreadsheetML2009Main.b0, b);
    };
    SpreadsheetML2009Main.de = function (a) {
        a.ad.p(SpreadsheetML2009Main.a9, "x14");
    };
    SpreadsheetML2009Main.cw = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case SpreadsheetML2009Main.bv:
                        b = c.d;
                        break;
                }
            }
        }
        catch (e_166_1) { e_166 = { error: e_166_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_166) throw e_166.error; }
        }
        return {
            p1: b
        };
        var e_166, _2;
    };
    SpreadsheetML2009Main.dd = function (a, b, c) {
        a.ad.p(SpreadsheetML2009Main.a8, "x14");
        var d;
        if (stringIsNullOrEmpty(b) == false) {
            d = b;
            a.ad.i("xmlns", "xm", null, d);
        }
        if (c.hasValue && c.value) {
            d = ST_OnOff.g(c.value);
            a.ad.h("pivot", d);
        }
    };
    SpreadsheetML2009Main.dc = function (a) {
        a.ad.p(SpreadsheetML2009Main.a6, "x14");
    };
    SpreadsheetML2009Main.da = function (a, b, c, d, e, f, g) {
        if (c === void 0) { c = Nullable$1.toNullable(ST_CfType_$type, null); }
        if (d === void 0) { d = 0; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = Nullable$1.toNullable(ST_ConditionalFormattingOperator_$type, null); }
        if (g === void 0) { g = Nullable$1.toNullable(Boolean_$type, null); }
        var h = Nullable$1.toNullable(Number_$type, null);
        var i = Nullable$1.toNullable(Boolean_$type, null);
        var j = Nullable$1.toNullable(Boolean_$type, null);
        var k = Nullable$1.toNullable(Boolean_$type, null);
        var l = null;
        var m = Nullable$1.toNullable(ST_TimePeriod_$type, null);
        var n = Nullable$1.toNullable(Number_$type, null);
        var o = Nullable$1.toNullable(Number_$type, null);
        var p = Nullable$1.toNullable(Boolean_$type, null);
        SpreadsheetMLMain.zg(a, SpreadsheetML2009Main.aw, c, h, d, e, i, j, k, f, l, m, n, o, p, b, g);
    };
    SpreadsheetML2009Main.cv = function (a, b, c, d) {
        var e = SpreadsheetMLMain.t3(a, SpreadsheetML2009Main.ax, b, c, d);
        b = e.p2;
        c = e.p3;
        d = e.p4;
        return {
            p1: b,
            p2: c,
            p3: d
        };
    };
    SpreadsheetML2009Main.db = function (a, b, c) {
        if (c === void 0) { c = true; }
        a.ad.p(SpreadsheetML2009Main.ax, "x14");
        var d;
        d = XmlNamespaceDefinitionBase.f(ST_CfvoType_$type, b);
        a.ad.h("type", d);
        if (c != true) {
            d = ST_OnOff.g(c);
            a.ad.h("gte", d);
        }
    };
    SpreadsheetML2009Main.cx = function (a, b, c, d, e, f, g, h, i, j) {
        b = Nullable$1.toNullable(Number_$type, null);
        c = Nullable$1.toNullable(Number_$type, null);
        d = Nullable$1.toNullable(Boolean_$type, null);
        e = Nullable$1.toNullable(Boolean_$type, null);
        f = Nullable$1.toNullable(Boolean_$type, null);
        g = Nullable$1.toNullable(ST_DataBarDirection_$type, null);
        h = Nullable$1.toNullable(Boolean_$type, null);
        i = Nullable$1.toNullable(Boolean_$type, null);
        j = Nullable$1.toNullable(ST_DataBarAxisPosition_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var k = _1.value;
                switch (k.a.e(a.d)) {
                    case "minLength":
                        c = Nullable$1.toNullable(Number_$type, parseUInt32_1(k.d, CultureInfo.invariantCulture));
                        break;
                    case "maxLength":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(k.d, CultureInfo.invariantCulture));
                        break;
                    case "showValue":
                        d = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(k.d));
                        break;
                    case "border":
                        e = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(k.d));
                        break;
                    case "gradient":
                        f = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(k.d));
                        break;
                    case "direction":
                        g = Nullable$1.toNullable(ST_DataBarDirection_$type, XmlNamespaceDefinitionBase.b(ST_DataBarDirection_$type, k.d));
                        break;
                    case "negativeBarColorSameAsPositive":
                        h = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(k.d));
                        break;
                    case "negativeBarBorderColorSameAsPositive":
                        i = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(k.d));
                        break;
                    case "axisPosition":
                        j = Nullable$1.toNullable(ST_DataBarAxisPosition_$type, XmlNamespaceDefinitionBase.b(ST_DataBarAxisPosition_$type, k.d));
                        break;
                }
            }
        }
        catch (e_167_1) { e_167 = { error: e_167_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_167) throw e_167.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j
        };
        var e_167, _2;
    };
    SpreadsheetML2009Main.df = function (a, b, c, d, e, f, g, h, i, j) {
        a.ad.p(SpreadsheetML2009Main.bc, "x14");
        var k;
        if (b.hasValue) {
            k = b.value.toString();
            a.ad.h("minLength", k);
        }
        if (c.hasValue) {
            k = c.value.toString();
            a.ad.h("maxLength", k);
        }
        if (d.hasValue && d.value != true) {
            k = ST_OnOff.g(d.value);
            a.ad.h("showValue", k);
        }
        if (e.hasValue && e.value) {
            k = ST_OnOff.g(e.value);
            a.ad.h("border", k);
        }
        if (f.hasValue && f.value != true) {
            k = ST_OnOff.g(f.value);
            a.ad.h("gradient", k);
        }
        if (g.hasValue && g.value != 0) {
            k = XmlNamespaceDefinitionBase.f(ST_DataBarDirection_$type, g.value);
            a.ad.h("direction", k);
        }
        if (h.hasValue && h.value != false) {
            k = ST_OnOff.g(h.value);
            a.ad.h("negativeBarColorSameAsPositive", k);
        }
        if (i.hasValue && i.value != true) {
            k = ST_OnOff.g(i.value);
            a.ad.h("negativeBarBorderColorSameAsPositive", k);
        }
        if (j.hasValue && j.value != 0) {
            k = XmlNamespaceDefinitionBase.f(ST_DataBarAxisPosition_$type, j.value);
            a.ad.h("axisPosition", k);
        }
    };
    SpreadsheetML2009Main.cu = function (a, b, c) {
        b = 3;
        c = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "iconSet":
                        b = XmlNamespaceDefinitionBase.b(ST_IconSetType_$type, d.d);
                        break;
                    case "iconId":
                        c = parseUInt32_1(d.d);
                        break;
                }
            }
        }
        catch (e_168_1) { e_168 = { error: e_168_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_168) throw e_168.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_168, _2;
    };
    SpreadsheetML2009Main.c9 = function (a, b, c) {
        a.ad.p(SpreadsheetML2009Main.av, "x14");
        var d;
        d = XmlNamespaceDefinitionBase.f(ST_IconSetType_$type, b);
        a.ad.h("iconSet", d);
        d = c.toString();
        a.ad.h("iconId", d);
    };
    SpreadsheetML2009Main.c3 = function (a, b, c, d, e) {
        b = null;
        c = false;
        d = false;
        e = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "name":
                        b = f.d;
                        break;
                    case "icon":
                        c = ST_OnOff.e(f.d);
                        break;
                    case "advise":
                        d = ST_OnOff.e(f.d);
                        break;
                    case "preferPic":
                        e = ST_OnOff.e(f.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_169_1) { e_169 = { error: e_169_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_169) throw e_169.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_169, _2;
    };
    SpreadsheetML2009Main.dl = function (a, b, c, d, e) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = false; }
        a.ad.p(SpreadsheetML2009Main.b5, "x14");
        var f;
        f = b;
        a.ad.h("name", f);
        if (c != false) {
            f = ST_OnOff.g(c);
            a.ad.h("icon", f);
        }
        if (d != false) {
            f = ST_OnOff.g(d);
            a.ad.h("advise", f);
        }
        if (e != false) {
            f = ST_OnOff.g(e);
            a.ad.h("preferPic", f);
        }
    };
    SpreadsheetML2009Main.c4 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_170_1) { e_170 = { error: e_170_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_170) throw e_170.error; }
        }
        var e_170, _2;
    };
    SpreadsheetML2009Main.dm = function (a) {
        a.ad.p(SpreadsheetML2009Main.b7, "x14");
    };
    SpreadsheetML2009Main.c7 = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_171_1) { e_171 = { error: e_171_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_171) throw e_171.error; }
        }
        return {
            p1: b
        };
        var e_171, _2;
    };
    SpreadsheetML2009Main.dq = function (a, b) {
        a.ad.p(SpreadsheetML2009Main.cf, "x14");
        var c;
        c = b;
        a.ad.h(OfficeDocumentRelationships.ar, c);
    };
    SpreadsheetML2009Main.c5 = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_172_1) { e_172 = { error: e_172_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_172) throw e_172.error; }
        }
        return {
            p1: b
        };
        var e_172, _2;
    };
    SpreadsheetML2009Main.dn = function (a, b) {
        a.ad.p(SpreadsheetML2009Main.cg, "x14");
        var c;
        c = b;
        a.ad.h(OfficeDocumentRelationships.ar, c);
    };
    SpreadsheetML2009Main.c6 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_173_1) { e_173 = { error: e_173_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_173) throw e_173.error; }
        }
        var e_173, _2;
    };
    SpreadsheetML2009Main.dp = function (a) {
        a.ad.p(SpreadsheetML2009Main.ch, "x14");
    };
    SpreadsheetML2009Main.c8 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_174_1) { e_174 = { error: e_174_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_174) throw e_174.error; }
        }
        var e_174, _2;
    };
    SpreadsheetML2009Main.dr = function (a) {
        a.ad.p(SpreadsheetML2009Main.cj, "x14");
    };
    SpreadsheetML2009Main.$t = markType(SpreadsheetML2009Main, 'SpreadsheetML2009Main', XmlNamespaceDefinitionBase.$);
    SpreadsheetML2009Main.b0 = "http://schemas.microsoft.com/office/spreadsheetml/2009/9/main";
    SpreadsheetML2009Main.ar = SpreadsheetML2009Main.b0 + "/axisColor";
    SpreadsheetML2009Main.au = SpreadsheetML2009Main.b0 + "/borderColor";
    SpreadsheetML2009Main.a8 = SpreadsheetML2009Main.b0 + "/conditionalFormatting";
    SpreadsheetML2009Main.a9 = SpreadsheetML2009Main.b0 + "/conditionalFormattings";
    SpreadsheetML2009Main.av = SpreadsheetML2009Main.b0 + "/cfIcon";
    SpreadsheetML2009Main.aw = SpreadsheetML2009Main.b0 + "/cfRule";
    SpreadsheetML2009Main.ax = SpreadsheetML2009Main.b0 + "/cfvo";
    SpreadsheetML2009Main.ay = SpreadsheetML2009Main.b0 + "/color";
    SpreadsheetML2009Main.a6 = SpreadsheetML2009Main.b0 + "/colorScale";
    SpreadsheetML2009Main.bc = SpreadsheetML2009Main.b0 + "/dataBar";
    SpreadsheetML2009Main.bd = SpreadsheetML2009Main.b0 + "/dataValidation";
    SpreadsheetML2009Main.be = SpreadsheetML2009Main.b0 + "/dataValidations";
    SpreadsheetML2009Main.bi = SpreadsheetML2009Main.b0 + "/dxf";
    SpreadsheetML2009Main.bm = SpreadsheetML2009Main.b0 + "/fillColor";
    SpreadsheetML2009Main.bn = SpreadsheetML2009Main.b0 + "/formula1";
    SpreadsheetML2009Main.bo = SpreadsheetML2009Main.b0 + "/formula2";
    SpreadsheetML2009Main.br = SpreadsheetML2009Main.b0 + "/iconFilter";
    SpreadsheetML2009Main.bt = SpreadsheetML2009Main.b0 + "/iconSet";
    SpreadsheetML2009Main.bv = SpreadsheetML2009Main.b0 + "/id";
    SpreadsheetML2009Main.b3 = SpreadsheetML2009Main.b0 + "/negativeBorderColor";
    SpreadsheetML2009Main.b4 = SpreadsheetML2009Main.b0 + "/negativeFillColor";
    SpreadsheetML2009Main.b5 = SpreadsheetML2009Main.b0 + "/oleItem";
    SpreadsheetML2009Main.b7 = SpreadsheetML2009Main.b0 + "/pivotCaches";
    SpreadsheetML2009Main.cf = SpreadsheetML2009Main.b0 + "/slicer";
    SpreadsheetML2009Main.cg = SpreadsheetML2009Main.b0 + "/slicerCache";
    SpreadsheetML2009Main.ch = SpreadsheetML2009Main.b0 + "/slicerCaches";
    SpreadsheetML2009Main.cj = SpreadsheetML2009Main.b0 + "/slicerList";
    SpreadsheetML2009Main.cl = SpreadsheetML2009Main.b0 + "/sortCondition";
    SpreadsheetML2009Main.cm = SpreadsheetML2009Main.b0 + "/sparkline";
    SpreadsheetML2009Main.cn = SpreadsheetML2009Main.b0 + "/sparklineGroup";
    SpreadsheetML2009Main.co = SpreadsheetML2009Main.b0 + "/sparklineGroups";
    SpreadsheetML2009Main.cq = SpreadsheetML2009Main.b0 + "/sparklines";
    SpreadsheetML2009Main.az = SpreadsheetML2009Main.b0 + "/colorAxis";
    SpreadsheetML2009Main.a0 = SpreadsheetML2009Main.b0 + "/colorFirst";
    SpreadsheetML2009Main.a1 = SpreadsheetML2009Main.b0 + "/colorHigh";
    SpreadsheetML2009Main.a2 = SpreadsheetML2009Main.b0 + "/colorLast";
    SpreadsheetML2009Main.a3 = SpreadsheetML2009Main.b0 + "/colorLow";
    SpreadsheetML2009Main.a4 = SpreadsheetML2009Main.b0 + "/colorMarkers";
    SpreadsheetML2009Main.a5 = SpreadsheetML2009Main.b0 + "/colorNegative";
    SpreadsheetML2009Main.a7 = SpreadsheetML2009Main.b0 + "/colorSeries";
    SpreadsheetML2009Main.an = new SpreadsheetML2009Main();
    return SpreadsheetML2009Main;
}(XmlNamespaceDefinitionBase));
export { SpreadsheetML2009Main };
var SpreadsheetMLMain = /** @class */ (function (_super) {
    tslib_1.__extends(SpreadsheetMLMain, _super);
    function SpreadsheetMLMain() {
        return _super.call(this) || this;
    }
    SpreadsheetMLMain.prototype.i = function (a) {
        switch (a) {
            case 0: return SpreadsheetMLMain.le;
            case 1: return SpreadsheetMLMain.ld;
            default: return SpreadsheetMLMain.le;
        }
    };
    SpreadsheetMLMain.prototype.get_j = function () {
        return null;
    };
    Object.defineProperty(SpreadsheetMLMain.prototype, "j", {
        get: function () {
            return this.get_j();
        },
        enumerable: true,
        configurable: true
    });
    SpreadsheetMLMain.tg = function (a, b, c, d) {
        if (a == null) {
            a = new StringBuilder(1, b.length);
        }
        a.m(b, d, c - d);
        d = c + 1;
        return {
            p0: a,
            p3: d
        };
    };
    SpreadsheetMLMain.he = function (a) {
        if (a == null) {
            return null;
        }
        var b = null;
        var c = 0;
        for (var d = 0; d < a.length; d++) {
            var e = a.charAt(d);
            if (e == '_') {
                if (a.length <= d + 6 || a.charAt(d + 1) != 'x' || a.charAt(d + 6) != '_') {
                    continue;
                }
                if (DocCoreUtils.d(a.charAt(d + 2)) == false || DocCoreUtils.d(a.charAt(d + 3)) == false || DocCoreUtils.d(a.charAt(d + 4)) == false || DocCoreUtils.d(a.charAt(d + 5)) == false) {
                    continue;
                }
                var f = SpreadsheetMLMain.tg(b, a, d, c);
                b = f.p0;
                c = f.p3;
                b.l("_x005F_");
            }
            if (e.charCodeAt(0) == 9 || e.charCodeAt(0) == 10 || e.charCodeAt(0) == 13 || (32 <= e.charCodeAt(0) && e.charCodeAt(0) <= 55295) || (57344 <= e.charCodeAt(0) && e.charCodeAt(0) <= 65533)) {
                continue;
            }
            if (65535 <= e.charCodeAt(0)) {
                continue;
            }
            var g = SpreadsheetMLMain.tg(b, a, d, c);
            b = g.p0;
            c = g.p3;
            b.q("_x{0:X4}_", e.charCodeAt(0));
        }
        if (c == 0) {
            return a;
        }
        var h = SpreadsheetMLMain.tg(b, a, a.length, c);
        b = h.p0;
        c = h.p3;
        return b.toString();
    };
    SpreadsheetMLMain.rt = function (a, b) {
        if (b === void 0) { b = false; }
        if (a == null) {
            return null;
        }
        var c = null;
        var d = 0;
        var _loop_4 = function (e) {
            var f = a.charAt(e);
            if (f != '_') {
                if (b) {
                    if (f == '\n') {
                        var g = SpreadsheetMLMain.tg(c, a, e, d);
                        c = g.p0;
                        d = g.p3;
                    }
                    else if (f == '\r') {
                        var h = SpreadsheetMLMain.tg(c, a, e, d);
                        c = h.p0;
                        d = h.p3;
                        if (e + 1 < a.length && a.charAt(e + 1) == '\n') {
                            e++;
                            d++;
                        }
                    }
                }
                return out_e_1 = e, "continue";
            }
            if (a.length <= e + 6 || a.charAt(e + 1) != 'x' || a.charAt(e + 6) != '_') {
                return out_e_1 = e, "continue";
            }
            var i = a.substr(e + 2, 4);
            var j;
            if (((function () { var k = tryParseInt32_2(i, 515, CultureInfo.invariantCulture, j); j = k.p3; return k.ret; })()) == false) {
                return out_e_1 = e, "continue";
            }
            var k = SpreadsheetMLMain.tg(c, a, e, d);
            c = k.p0;
            d = k.p3;
            c.h(String.fromCharCode(j));
            e += 6;
            d += 6;
            out_e_1 = e;
        };
        var out_e_1;
        for (var e = 0; e < a.length; e++) {
            _loop_4(e);
            e = out_e_1;
        }
        if (d == 0) {
            return a;
        }
        var l = SpreadsheetMLMain.tg(c, a, a.length, d);
        c = l.p0;
        d = l.p3;
        return c.toString();
    };
    SpreadsheetMLMain.ui = function (a, b, c) {
        c = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "val":
                        c = ST_OnOff.e(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_175_1) { e_175 = { error: e_175_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_175) throw e_175.error; }
        }
        return {
            p2: c
        };
        var e_175, _2;
    };
    SpreadsheetMLMain.zx = function (a, b, c) {
        if (c === void 0) { c = true; }
        a.ad.p(b, null);
        var d;
        if (c != true) {
            d = ST_OnOff.g(c);
            a.ad.h("val", d);
        }
    };
    SpreadsheetMLMain.uj = function (a, b, c) {
        c = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "style":
                        c = XmlNamespaceDefinitionBase.b(ST_BorderStyle_$type, d.d, c);
                        break;
                    default: break;
                }
            }
        }
        catch (e_176_1) { e_176 = { error: e_176_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_176) throw e_176.error; }
        }
        return {
            p2: c
        };
        var e_176, _2;
    };
    SpreadsheetMLMain.zy = function (a, b, c) {
        if (c === void 0) { c = 0; }
        a.ad.p(b, null);
        var d;
        if (c != 0) {
            d = XmlNamespaceDefinitionBase.f(ST_BorderStyle_$type, c);
            a.ad.h("style", d);
        }
    };
    SpreadsheetMLMain.uk = function (a, b, c, d, e, f, g) {
        c = Nullable$1.toNullable(Boolean_$type, null);
        d = Nullable$1.toNullable(Number_$type, null);
        e = Nullable$1.toNullable(ST_UnsignedIntHex.$, null);
        f = Nullable$1.toNullable(Number_$type, null);
        g = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var h = _1.value;
                switch (h.a.e(a.d)) {
                    case "auto":
                        c = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(h.d));
                        break;
                    case "indexed":
                        d = Nullable$1.toNullable(Number_$type, parseUInt32_1(h.d, CultureInfo.invariantCulture));
                        break;
                    case "rgb":
                        e = Nullable$1.toNullable(ST_UnsignedIntHex.$, ST_UnsignedIntHex.d(h.d));
                        break;
                    case "theme":
                        f = Nullable$1.toNullable(Number_$type, parseUInt32_1(h.d, CultureInfo.invariantCulture));
                        break;
                    case "tint":
                        g = parseNumber(h.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_177_1) { e_177 = { error: e_177_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_177) throw e_177.error; }
        }
        return {
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g
        };
        var e_177, _2;
    };
    SpreadsheetMLMain.zz = function (a, b, c, d, e, f, g) {
        if (c === void 0) { c = Nullable$1.toNullable(Boolean_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = Nullable$1.toNullable(ST_UnsignedIntHex.$, null); }
        if (f === void 0) { f = Nullable$1.toNullable(Number_$type, null); }
        if (g === void 0) { g = 0; }
        a.ad.p(b, null);
        var h;
        if (nullableNotEquals(c, null)) {
            h = ST_OnOff.g(c.value);
            a.ad.h("auto", h);
        }
        if (nullableNotEquals(d, null)) {
            h = d.value.toString();
            a.ad.h("indexed", h);
        }
        if (nullableNotEquals(e, null)) {
            h = e.value.toString();
            a.ad.h("rgb", h);
        }
        if (nullableNotEquals(f, null)) {
            h = f.value.toString();
            a.ad.h("theme", h);
        }
        if (g != 0) {
            h = g.toString();
            a.ad.h("tint", h);
        }
    };
    SpreadsheetMLMain.ul = function (a, b, c) {
        var d = XmlNamespaceDefinitionBase.u(a, b, c);
        c = d.p2;
        return {
            p2: c
        };
    };
    SpreadsheetMLMain.z0 = function (a, b, c) {
        XmlNamespaceDefinitionBase.ai(a, b, null, c);
    };
    SpreadsheetMLMain.um = function (a, b, c, d) {
        c = 0;
        d = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "count":
                        c = parseUInt32_1(e.d, CultureInfo.invariantCulture);
                        break;
                    case "manualBreakCount":
                        d = parseUInt32_1(e.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_178_1) { e_178 = { error: e_178_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_178) throw e_178.error; }
        }
        return {
            p2: c,
            p3: d
        };
        var e_178, _2;
    };
    SpreadsheetMLMain.z1 = function (a, b, c, d) {
        if (c === void 0) { c = 0; }
        if (d === void 0) { d = 0; }
        a.ad.p(b, null);
        var e;
        if (c != 0) {
            e = c.toString();
            a.ad.h("count", e);
        }
        if (d != 0) {
            e = d.toString();
            a.ad.h("manualBreakCount", e);
        }
    };
    SpreadsheetMLMain.un = function (a, b, c, d) {
        d = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "array":
                        d = ST_OnOff.e(e.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_179_1) { e_179 = { error: e_179_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_179) throw e_179.error; }
        }
        c = a.ab.ad;
        return {
            p2: c,
            p3: d
        };
        var e_179, _2;
    };
    SpreadsheetMLMain.z2 = function (a, b, c, d) {
        if (d === void 0) { d = false; }
        a.ad.p(b, null);
        var e;
        if (d != false) {
            e = ST_OnOff.g(d);
            a.ad.h("array", e);
        }
        a.ad.u(c);
    };
    SpreadsheetMLMain.th = function (a, b, c, d, e, f, g, h, i, j) {
        b = Nullable$1.toNullable(ST_HorizontalAlignment_$type, null);
        c = Nullable$1.toNullable(ST_VerticalAlignment_$type, null);
        d = Nullable$1.toNullable(Number_$type, null);
        e = false;
        f = Nullable$1.toNullable(Number_$type, null);
        g = Nullable$1.toNullable(Number_$type, null);
        h = false;
        i = false;
        j = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var k = _1.value;
                switch (k.a.e(a.d)) {
                    case "horizontal":
                        b = Nullable$1.toNullable(ST_HorizontalAlignment_$type, XmlNamespaceDefinitionBase.b(ST_HorizontalAlignment_$type, k.d));
                        break;
                    case "vertical":
                        c = Nullable$1.toNullable(ST_VerticalAlignment_$type, XmlNamespaceDefinitionBase.b(ST_VerticalAlignment_$type, k.d));
                        break;
                    case "textRotation":
                        d = Nullable$1.toNullable(Number_$type, parseUInt32_1(k.d, CultureInfo.invariantCulture));
                        break;
                    case "wrapText":
                        e = ST_OnOff.e(k.d);
                        break;
                    case "indent":
                        f = Nullable$1.toNullable(Number_$type, parseUInt32_1(k.d, CultureInfo.invariantCulture));
                        break;
                    case "relativeIndent":
                        g = Nullable$1.toNullable(Number_$type, parseInt32_1(k.d, CultureInfo.invariantCulture));
                        break;
                    case "justifyLastLine":
                        h = ST_OnOff.e(k.d);
                        break;
                    case "shrinkToFit":
                        i = ST_OnOff.e(k.d);
                        break;
                    case "readingOrder":
                        j = Nullable$1.toNullable(Number_$type, parseUInt32_1(k.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_180_1) { e_180 = { error: e_180_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_180) throw e_180.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j
        };
        var e_180, _2;
    };
    SpreadsheetMLMain.yw = function (a, b, c, d, e, f, g, h, i, j) {
        if (b === void 0) { b = Nullable$1.toNullable(ST_HorizontalAlignment_$type, null); }
        if (c === void 0) { c = Nullable$1.toNullable(ST_VerticalAlignment_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = Nullable$1.toNullable(Number_$type, null); }
        if (g === void 0) { g = Nullable$1.toNullable(Number_$type, null); }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.cj, null);
        var k;
        if (nullableNotEquals(b, null)) {
            k = XmlNamespaceDefinitionBase.f(ST_HorizontalAlignment_$type, b.value);
            a.ad.h("horizontal", k);
        }
        if (nullableNotEquals(c, null)) {
            k = XmlNamespaceDefinitionBase.f(ST_VerticalAlignment_$type, c.value);
            a.ad.h("vertical", k);
        }
        if (nullableNotEquals(d, null)) {
            k = d.value.toString();
            a.ad.h("textRotation", k);
        }
        if (e != false) {
            k = ST_OnOff.g(e);
            a.ad.h("wrapText", k);
        }
        if (nullableNotEquals(f, null)) {
            k = f.value.toString();
            a.ad.h("indent", k);
        }
        if (nullableNotEquals(g, null)) {
            k = g.value.toString();
            a.ad.h("relativeIndent", k);
        }
        if (h != false) {
            k = ST_OnOff.g(h);
            a.ad.h("justifyLastLine", k);
        }
        if (i != false) {
            k = ST_OnOff.g(i);
            a.ad.h("shrinkToFit", k);
        }
        if (nullableNotEquals(j, null)) {
            k = j.value.toString();
            a.ad.h("readingOrder", k);
        }
    };
    SpreadsheetMLMain.ti = function (a, b, c) {
        b = false;
        c = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "moveWithCells":
                        b = ST_OnOff.e(d.d);
                        break;
                    case "sizeWithCells":
                        c = ST_OnOff.e(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_181_1) { e_181 = { error: e_181_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_181) throw e_181.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_181, _2;
    };
    SpreadsheetMLMain.yx = function (a, b, c) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        a.ad.p(SpreadsheetMLMain.co, null);
        var d;
        if (b != false) {
            d = ST_OnOff.g(b);
            a.ad.h("moveWithCells", d);
        }
        if (c != false) {
            d = ST_OnOff.g(c);
            a.ad.h("sizeWithCells", d);
        }
    };
    SpreadsheetMLMain.tj = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, SpreadsheetMLMain.cz, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.yy = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, SpreadsheetMLMain.cz, null, b);
    };
    SpreadsheetMLMain.tk = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_182_1) { e_182 = { error: e_182_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_182) throw e_182.error; }
        }
        var e_182, _2;
    };
    SpreadsheetMLMain.yz = function (a) {
        a.ad.p(SpreadsheetMLMain.c1, null);
    };
    SpreadsheetMLMain.tl = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "ref":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_183_1) { e_183 = { error: e_183_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_183) throw e_183.error; }
        }
        return {
            p1: b
        };
        var e_183, _2;
    };
    SpreadsheetMLMain.y0 = function (a, b) {
        a.ad.p(SpreadsheetMLMain.c5, null);
        var c;
        c = b;
        a.ad.h("ref", c);
    };
    SpreadsheetMLMain.tm = function (a, b) {
        var c = SpreadsheetMLMain.ui(a, SpreadsheetMLMain.dc, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.y1 = function (a, b) {
        if (b === void 0) { b = true; }
        SpreadsheetMLMain.zx(a, SpreadsheetMLMain.dc, b);
    };
    SpreadsheetMLMain.tn = function (a, b, c, d, e, f) {
        var g = SpreadsheetMLMain.uk(a, SpreadsheetMLMain.dg, b, c, d, e, f);
        b = g.p2;
        c = g.p3;
        d = g.p4;
        e = g.p5;
        f = g.p6;
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
    };
    SpreadsheetMLMain.y2 = function (a, b, c, d, e, f) {
        if (b === void 0) { b = Nullable$1.toNullable(Boolean_$type, null); }
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(ST_UnsignedIntHex.$, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        if (f === void 0) { f = 0; }
        SpreadsheetMLMain.zz(a, SpreadsheetMLMain.dg, b, c, d, e, f);
    };
    SpreadsheetMLMain.to = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_184_1) { e_184 = { error: e_184_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_184) throw e_184.error; }
        }
        var e_184, _2;
    };
    SpreadsheetMLMain.y3 = function (a) {
        a.ad.p(SpreadsheetMLMain.dj, null);
    };
    SpreadsheetMLMain.tp = function (a, b, c, d) {
        b = false;
        c = false;
        d = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "diagonalUp":
                        b = ST_OnOff.e(e.d);
                        break;
                    case "diagonalDown":
                        c = ST_OnOff.e(e.d);
                        break;
                    case "outline":
                        d = ST_OnOff.e(e.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_185_1) { e_185 = { error: e_185_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_185) throw e_185.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_185, _2;
    };
    SpreadsheetMLMain.y4 = function (a, b, c, d) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = true; }
        a.ad.p(SpreadsheetMLMain.dk, null);
        var e;
        if (b != false) {
            e = ST_OnOff.g(b);
            a.ad.h("diagonalUp", e);
        }
        if (c != false) {
            e = ST_OnOff.g(c);
            a.ad.h("diagonalDown", e);
        }
        if (d != true) {
            e = ST_OnOff.g(d);
            a.ad.h("outline", e);
        }
    };
    SpreadsheetMLMain.tq = function (a, b) {
        b = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(c.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_186_1) { e_186 = { error: e_186_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_186) throw e_186.error; }
        }
        return {
            p1: b
        };
        var e_186, _2;
    };
    SpreadsheetMLMain.y5 = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.dm, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = b.value.toString();
            a.ad.h("count", c);
        }
    };
    SpreadsheetMLMain.tr = function (a, b) {
        var c = SpreadsheetMLMain.uj(a, SpreadsheetMLMain.dn, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.y6 = function (a, b) {
        if (b === void 0) { b = 0; }
        SpreadsheetMLMain.zy(a, SpreadsheetMLMain.dn, b);
    };
    SpreadsheetMLMain.ts = function (a, b, c, d, e, f) {
        b = 0;
        c = Nullable$1.toNullable(Number_$type, null);
        d = Nullable$1.toNullable(Number_$type, null);
        e = false;
        f = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var g = _1.value;
                switch (g.a.e(a.d)) {
                    case "id":
                        b = parseUInt32_1(g.d, CultureInfo.invariantCulture);
                        break;
                    case "min":
                        c = Nullable$1.toNullable(Number_$type, parseUInt32_1(g.d, CultureInfo.invariantCulture));
                        break;
                    case "max":
                        d = Nullable$1.toNullable(Number_$type, parseUInt32_1(g.d, CultureInfo.invariantCulture));
                        break;
                    case "man":
                        e = ST_OnOff.e(g.d);
                        break;
                    case "pt":
                        f = ST_OnOff.e(g.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_187_1) { e_187 = { error: e_187_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_187) throw e_187.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
        var e_187, _2;
    };
    SpreadsheetMLMain.y7 = function (a, b, c, d, e, f) {
        if (b === void 0) { b = 0; }
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = false; }
        a.ad.p(SpreadsheetMLMain.dq, null);
        var g;
        if (b != 0) {
            g = b.toString();
            a.ad.h("id", g);
        }
        if (c.hasValue && c.value != 0) {
            g = c.value.toString();
            a.ad.h("min", g);
        }
        if (d.hasValue && d.value != 0) {
            g = d.value.toString();
            a.ad.h("max", g);
        }
        if (e != false) {
            g = ST_OnOff.g(e);
            a.ad.h("man", g);
        }
        if (f != false) {
            g = ST_OnOff.g(f);
            a.ad.h("pt", g);
        }
    };
    SpreadsheetMLMain.tt = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        b = Nullable$1.toNullable(Number_$type, null);
        c = 1;
        d = false;
        e = 0;
        f = false;
        g = 100;
        h = 0.001;
        i = true;
        j = true;
        k = true;
        l = true;
        m = Nullable$1.toNullable(Number_$type, null);
        n = Nullable$1.toNullable(Boolean_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var o = _1.value;
                switch (o.a.e(a.d)) {
                    case "calcId":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(o.d, CultureInfo.invariantCulture));
                        break;
                    case "calcMode":
                        c = XmlNamespaceDefinitionBase.b(ST_CalcMode_$type, o.d, c);
                        break;
                    case "fullCalcOnLoad":
                        d = ST_OnOff.e(o.d);
                        break;
                    case "refMode":
                        e = XmlNamespaceDefinitionBase.b(ST_RefMode_$type, o.d, e);
                        break;
                    case "iterate":
                        f = ST_OnOff.e(o.d);
                        break;
                    case "iterateCount":
                        g = parseUInt32_1(o.d, CultureInfo.invariantCulture);
                        break;
                    case "iterateDelta":
                        h = parseNumber(o.d, CultureInfo.invariantCulture);
                        break;
                    case "fullPrecision":
                        i = ST_OnOff.e(o.d);
                        break;
                    case "calcCompleted":
                        j = ST_OnOff.e(o.d);
                        break;
                    case "calcOnSave":
                        k = ST_OnOff.e(o.d);
                        break;
                    case "concurrentCalc":
                        l = ST_OnOff.e(o.d);
                        break;
                    case "concurrentManualCount":
                        m = Nullable$1.toNullable(Number_$type, parseUInt32_1(o.d, CultureInfo.invariantCulture));
                        break;
                    case "forceFullCalc":
                        n = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(o.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_188_1) { e_188 = { error: e_188_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_188) throw e_188.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n
        };
        var e_188, _2;
    };
    SpreadsheetMLMain.y8 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        if (c === void 0) { c = 1; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = 0; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = 100; }
        if (h === void 0) { h = 0.001; }
        if (i === void 0) { i = true; }
        if (j === void 0) { j = true; }
        if (k === void 0) { k = true; }
        if (l === void 0) { l = true; }
        if (m === void 0) { m = Nullable$1.toNullable(Number_$type, null); }
        if (n === void 0) { n = Nullable$1.toNullable(Boolean_$type, null); }
        a.ad.p(SpreadsheetMLMain.d0, null);
        var o;
        if (nullableNotEquals(b, null)) {
            o = b.value.toString();
            a.ad.h("calcId", o);
        }
        if (c != 1) {
            o = XmlNamespaceDefinitionBase.f(ST_CalcMode_$type, c);
            a.ad.h("calcMode", o);
        }
        if (d != false) {
            o = ST_OnOff.g(d);
            a.ad.h("fullCalcOnLoad", o);
        }
        if (e != 0) {
            o = XmlNamespaceDefinitionBase.f(ST_RefMode_$type, e);
            a.ad.h("refMode", o);
        }
        if (f != false) {
            o = ST_OnOff.g(f);
            a.ad.h("iterate", o);
        }
        if (g != 100) {
            o = g.toString();
            a.ad.h("iterateCount", o);
        }
        if (h != 0.001) {
            o = h.toString();
            a.ad.h("iterateDelta", o);
        }
        if (i != true) {
            o = ST_OnOff.g(i);
            a.ad.h("fullPrecision", o);
        }
        if (j != true) {
            o = ST_OnOff.g(j);
            a.ad.h("calcCompleted", o);
        }
        if (k != true) {
            o = ST_OnOff.g(k);
            a.ad.h("calcOnSave", o);
        }
        if (l != true) {
            o = ST_OnOff.g(l);
            a.ad.h("concurrentCalc", o);
        }
        if (nullableNotEquals(m, null)) {
            o = m.value.toString();
            a.ad.h("concurrentManualCount", o);
        }
        if (nullableNotEquals(n, null)) {
            o = ST_OnOff.g(n.value);
            a.ad.h("forceFullCalc", o);
        }
    };
    SpreadsheetMLMain.tu = function (a, b, c) {
        var d = SpreadsheetMLMain.un(a, SpreadsheetMLMain.d1, b, c);
        b = d.p2;
        c = d.p3;
        return {
            p1: b,
            p2: c
        };
    };
    SpreadsheetMLMain.y9 = function (a, b, c) {
        if (c === void 0) { c = false; }
        SpreadsheetMLMain.z2(a, SpreadsheetMLMain.d1, b, c);
    };
    SpreadsheetMLMain.tv = function (a, b, c, d, e, f, g) {
        b = null;
        c = 0;
        d = 2;
        e = 0;
        f = 0;
        g = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var h = _1.value;
                switch (h.a.e(a.d)) {
                    case "r":
                        b = h.d;
                        break;
                    case "s":
                        c = parseUInt32_1(h.d, CultureInfo.invariantCulture);
                        break;
                    case "t":
                        d = SpreadsheetMLMain.aq(h.d);
                        break;
                    case "cm":
                        e = parseUInt32_1(h.d, CultureInfo.invariantCulture);
                        break;
                    case "vm":
                        f = parseUInt32_1(h.d, CultureInfo.invariantCulture);
                        break;
                    case "ph":
                        g = ST_OnOff.e(h.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_189_1) { e_189 = { error: e_189_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_189) throw e_189.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g
        };
        var e_189, _2;
    };
    SpreadsheetMLMain.aq = function (a) {
        switch (a) {
            case "b": return 0;
            case "d": return 1;
            case "e": return 3;
            case "n": return 2;
            case "s": return 4;
            case "str": return 5;
            case "inlineStr": return 6;
            default: return 2;
        }
    };
    SpreadsheetMLMain.za = function (a, b, c, d, e, f, g) {
        if (c === void 0) { c = 0; }
        if (d === void 0) { d = 2; }
        if (e === void 0) { e = 0; }
        if (f === void 0) { f = 0; }
        if (g === void 0) { g = false; }
        a.ad.r("c");
        a.ad.j("r", b);
        if (c != 0) {
            a.ad.j("s", c.toString());
        }
        if (d != 2) {
            a.ad.j("t", XLOpenXmlUtilities.a(d));
        }
        if (e != 0) {
            a.ad.j("cm", e.toString());
        }
        if (f != 0) {
            a.ad.j("vm", f.toString());
        }
        if (g != false) {
            a.ad.j("ph", ST_OnOff.g(g));
        }
    };
    SpreadsheetMLMain.tw = function (a, b, c, d) {
        b = null;
        c = 2;
        d = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "r":
                        b = e.d;
                        break;
                    case "t":
                        c = XmlNamespaceDefinitionBase.b(ST_CellType_$type, e.d, c);
                        break;
                    case "vm":
                        d = parseUInt32_1(e.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_190_1) { e_190 = { error: e_190_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_190) throw e_190.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_190, _2;
    };
    SpreadsheetMLMain.zb = function (a, b, c, d) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = 2; }
        if (d === void 0) { d = 0; }
        a.ad.p(SpreadsheetMLMain.d4, null);
        var e;
        e = b;
        a.ad.h("r", e);
        if (c != 2) {
            e = XLOpenXmlUtilities.a(c);
            a.ad.h("t", e);
        }
        if (d != 0) {
            e = d.toString();
            a.ad.h("vm", e);
        }
    };
    SpreadsheetMLMain.tx = function (a, b, c, d, e, f, g) {
        c = null;
        b = 0;
        d = Nullable$1.toNullable(Number_$type, null);
        e = Nullable$1.toNullable(Number_$type, null);
        f = false;
        g = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var h = _1.value;
                switch (h.a.e(a.d)) {
                    case "name":
                        c = SpreadsheetMLMain.rt(h.d);
                        break;
                    case "xfId":
                        b = parseUInt32_1(h.d, CultureInfo.invariantCulture);
                        break;
                    case "builtinId":
                        d = Nullable$1.toNullable(Number_$type, parseUInt32_1(h.d, CultureInfo.invariantCulture));
                        break;
                    case "iLevel":
                        e = Nullable$1.toNullable(Number_$type, parseUInt32_1(h.d, CultureInfo.invariantCulture));
                        break;
                    case "hidden":
                        f = ST_OnOff.e(h.d);
                        break;
                    case "customBuiltin":
                        g = ST_OnOff.e(h.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_191_1) { e_191 = { error: e_191_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_191) throw e_191.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g
        };
        var e_191, _2;
    };
    SpreadsheetMLMain.zc = function (a, b, c, d, e, f, g) {
        if (c === void 0) { c = null; }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = false; }
        a.ad.p(SpreadsheetMLMain.d7, null);
        var h;
        h = SpreadsheetMLMain.he(c);
        a.ad.h("name", h);
        h = b.toString();
        a.ad.h("xfId", h);
        if (nullableNotEquals(d, null)) {
            h = d.value.toString();
            a.ad.h("builtinId", h);
        }
        if (nullableNotEquals(e, null)) {
            h = e.value.toString();
            a.ad.h("iLevel", h);
        }
        if (f != false) {
            h = ST_OnOff.g(f);
            a.ad.h("hidden", h);
        }
        if (g != false) {
            h = ST_OnOff.g(g);
            a.ad.h("customBuiltin", h);
        }
    };
    SpreadsheetMLMain.ty = function (a, b) {
        b = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(c.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_192_1) { e_192 = { error: e_192_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_192) throw e_192.error; }
        }
        return {
            p1: b
        };
        var e_192, _2;
    };
    SpreadsheetMLMain.zd = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.d8, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = b.value.toString();
            a.ad.h("count", c);
        }
    };
    SpreadsheetMLMain.tz = function (a, b) {
        b = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(c.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_193_1) { e_193 = { error: e_193_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_193) throw e_193.error; }
        }
        return {
            p1: b
        };
        var e_193, _2;
    };
    SpreadsheetMLMain.ze = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.d9, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = b.value.toString();
            a.ad.h("count", c);
        }
    };
    SpreadsheetMLMain.t0 = function (a, b) {
        b = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(c.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_194_1) { e_194 = { error: e_194_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_194) throw e_194.error; }
        }
        return {
            p1: b
        };
        var e_194, _2;
    };
    SpreadsheetMLMain.zf = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.ea, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = b.value.toString();
            a.ad.h("count", c);
        }
    };
    SpreadsheetMLMain.t1 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q) {
        c = Nullable$1.toNullable(ST_CfType_$type, null);
        d = Nullable$1.toNullable(Number_$type, null);
        e = Nullable$1.toNullable(Number_$type, null);
        f = Nullable$1.toNullable(Boolean_$type, null);
        g = true;
        h = false;
        i = false;
        j = Nullable$1.toNullable(ST_ConditionalFormattingOperator_$type, null);
        k = null;
        l = Nullable$1.toNullable(ST_TimePeriod_$type, null);
        m = Nullable$1.toNullable(Number_$type, null);
        n = Nullable$1.toNullable(Number_$type, null);
        o = false;
        p = null;
        q = Nullable$1.toNullable(Boolean_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var r = _1.value;
                var t1 = r.a.e(a.d);
                L0: while (true) {
                    switch (t1) {
                        case "type":
                            c = Nullable$1.toNullable(ST_CfType_$type, XmlNamespaceDefinitionBase.b(ST_CfType_$type, r.d));
                            break;
                        case "dxfId":
                            d = Nullable$1.toNullable(Number_$type, parseUInt32_1(r.d, CultureInfo.invariantCulture));
                            break;
                        case "priority":
                            e = Nullable$1.toNullable(Number_$type, parseInt32_1(r.d, CultureInfo.invariantCulture));
                            break;
                        case "stopIfTrue":
                            f = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(r.d));
                            break;
                        case "aboveAverage":
                            g = ST_OnOff.e(r.d);
                            break;
                        case "activePresent":
                            if (b != SpreadsheetML2009Main.aw) {
                                t1 = void 0;
                                continue L0;
                            }
                            q = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(r.d));
                            break;
                        case "percent":
                            h = ST_OnOff.e(r.d);
                            break;
                        case "bottom":
                            i = ST_OnOff.e(r.d);
                            break;
                        case "operator":
                            j = Nullable$1.toNullable(ST_ConditionalFormattingOperator_$type, XmlNamespaceDefinitionBase.b(ST_ConditionalFormattingOperator_$type, r.d));
                            break;
                        case "text":
                            k = r.d;
                            break;
                        case "timePeriod":
                            l = Nullable$1.toNullable(ST_TimePeriod_$type, XmlNamespaceDefinitionBase.b(ST_TimePeriod_$type, r.d));
                            break;
                        case "rank":
                            m = Nullable$1.toNullable(Number_$type, parseUInt32_1(r.d, CultureInfo.invariantCulture));
                            break;
                        case "stdDev":
                            n = Nullable$1.toNullable(Number_$type, parseInt32_1(r.d, CultureInfo.invariantCulture));
                            break;
                        case "equalAverage":
                            o = ST_OnOff.e(r.d);
                            break;
                        case "id":
                            if (b != SpreadsheetML2009Main.aw) {
                                t1 = void 0;
                                continue L0;
                            }
                            p = r.d;
                            break;
                        default: break;
                    }
                    break;
                }
            }
        }
        catch (e_195_1) { e_195 = { error: e_195_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_195) throw e_195.error; }
        }
        return {
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q
        };
        var e_195, _2;
    };
    SpreadsheetMLMain.zg = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q) {
        if (c === void 0) { c = Nullable$1.toNullable(ST_CfType_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = 0; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = Nullable$1.toNullable(Boolean_$type, null); }
        if (h === void 0) { h = Nullable$1.toNullable(Boolean_$type, null); }
        if (i === void 0) { i = Nullable$1.toNullable(Boolean_$type, null); }
        if (j === void 0) { j = Nullable$1.toNullable(ST_ConditionalFormattingOperator_$type, null); }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = Nullable$1.toNullable(ST_TimePeriod_$type, null); }
        if (m === void 0) { m = Nullable$1.toNullable(Number_$type, null); }
        if (n === void 0) { n = Nullable$1.toNullable(Number_$type, null); }
        if (o === void 0) { o = Nullable$1.toNullable(Boolean_$type, null); }
        if (p === void 0) { p = null; }
        if (q === void 0) { q = Nullable$1.toNullable(Boolean_$type, null); }
        a.ad.p(b, null);
        var r;
        if (nullableNotEquals(c, null)) {
            r = XmlNamespaceDefinitionBase.f(ST_CfType_$type, c.value);
            a.ad.h("type", r);
        }
        if (nullableNotEquals(d, null)) {
            r = d.value.toString();
            a.ad.h("dxfId", r);
        }
        if (e != 0) {
            r = e.toString();
            a.ad.h("priority", r);
        }
        if (f != false) {
            r = ST_OnOff.g(f);
            a.ad.h("stopIfTrue", r);
        }
        if (g.hasValue) {
            r = ST_OnOff.g(g.value);
            a.ad.h("aboveAverage", r);
        }
        if (h.hasValue) {
            r = ST_OnOff.g(h.value);
            a.ad.h("percent", r);
        }
        if (i.hasValue) {
            r = ST_OnOff.g(i.value);
            a.ad.h("bottom", r);
        }
        if (nullableNotEquals(j, null)) {
            r = XmlNamespaceDefinitionBase.f(ST_ConditionalFormattingOperator_$type, j.value);
            a.ad.h("operator", r);
        }
        r = k;
        a.ad.h("text", r);
        if (nullableNotEquals(l, null)) {
            r = XmlNamespaceDefinitionBase.f(ST_TimePeriod_$type, l.value);
            a.ad.h("timePeriod", r);
        }
        if (nullableNotEquals(m, null)) {
            r = m.value.toString();
            a.ad.h("rank", r);
        }
        if (nullableNotEquals(n, null)) {
            r = n.value.toString();
            a.ad.h("stdDev", r);
        }
        if (o.hasValue) {
            r = ST_OnOff.g(o.hasValue);
            a.ad.h("equalAverage", r);
        }
        if (stringIsNullOrEmpty(p) == false) {
            r = p;
            a.ad.h("id", r);
        }
        if (q.hasValue && q.value) {
            if (b != SpreadsheetML2009Main.aw) {
            }
            r = ST_OnOff.g(q.value);
            a.ad.h("activePresent", r);
        }
    };
    SpreadsheetMLMain.t2 = function (a, b, c, d) {
        var e = SpreadsheetMLMain.t3(a, SpreadsheetMLMain.eg, b, c, d);
        b = e.p2;
        c = e.p3;
        d = e.p4;
        return {
            p1: b,
            p2: c,
            p3: d
        };
    };
    SpreadsheetMLMain.t3 = function (a, b, c, d, e) {
        c = 0;
        d = null;
        e = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "type":
                        c = XmlNamespaceDefinitionBase.b(ST_CfvoType_$type, f.d, c);
                        break;
                    case "val":
                        d = f.d;
                        break;
                    case "gte":
                        e = ST_OnOff.e(f.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_196_1) { e_196 = { error: e_196_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_196) throw e_196.error; }
        }
        return {
            p2: c,
            p3: d,
            p4: e
        };
        var e_196, _2;
    };
    SpreadsheetMLMain.zh = function (a, b, c, d) {
        if (c === void 0) { c = null; }
        if (d === void 0) { d = true; }
        a.ad.p(SpreadsheetMLMain.eg, null);
        var e;
        e = XmlNamespaceDefinitionBase.f(ST_CfvoType_$type, b);
        a.ad.h("type", e);
        e = c;
        a.ad.h("val", e);
        if (d != true) {
            e = ST_OnOff.g(d);
            a.ad.h("gte", e);
        }
    };
    SpreadsheetMLMain.t4 = function (a, b, c) {
        var d = SpreadsheetMLMain.um(a, SpreadsheetMLMain.ep, b, c);
        b = d.p2;
        c = d.p3;
        return {
            p1: b,
            p2: c
        };
    };
    SpreadsheetMLMain.zi = function (a, b, c) {
        SpreadsheetMLMain.z1(a, SpreadsheetMLMain.ep, b, c);
    };
    SpreadsheetMLMain.t5 = function (a, b, c, d, e, f, g, h, i, j, k) {
        b = 0;
        c = 0;
        d = Nullable$1.toNullable(Number_$type, null);
        e = 0;
        f = false;
        g = false;
        h = false;
        i = false;
        j = 0;
        k = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var l = _1.value;
                switch (l.a.e(a.d)) {
                    case "min":
                        b = parseUInt32_1(l.d, CultureInfo.invariantCulture);
                        break;
                    case "max":
                        c = parseUInt32_1(l.d, CultureInfo.invariantCulture);
                        break;
                    case "width":
                        d = Nullable$1.toNullable(Number_$type, parseNumber(l.d, CultureInfo.invariantCulture));
                        break;
                    case "style":
                        e = parseUInt32_1(l.d, CultureInfo.invariantCulture);
                        break;
                    case "hidden":
                        f = ST_OnOff.e(l.d);
                        break;
                    case "bestFit":
                        g = ST_OnOff.e(l.d);
                        break;
                    case "customWidth":
                        h = ST_OnOff.e(l.d);
                        break;
                    case "phonetic":
                        i = ST_OnOff.e(l.d);
                        break;
                    case "outlineLevel":
                        j = parseUInt8_1(l.d, CultureInfo.invariantCulture);
                        break;
                    case "collapsed":
                        k = ST_OnOff.e(l.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_197_1) { e_197 = { error: e_197_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_197) throw e_197.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k
        };
        var e_197, _2;
    };
    SpreadsheetMLMain.zj = function (a, b, c, d, e, f, g, h, i, j, k) {
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = 0; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = 0; }
        if (k === void 0) { k = false; }
        a.ad.p(SpreadsheetMLMain.eo, null);
        var l;
        l = b.toString();
        a.ad.h("min", l);
        l = c.toString();
        a.ad.h("max", l);
        if (nullableNotEquals(d, null)) {
            l = d.value.toString();
            a.ad.h("width", l);
        }
        if (e != 0) {
            l = e.toString();
            a.ad.h("style", l);
        }
        if (f != false) {
            l = ST_OnOff.g(f);
            a.ad.h("hidden", l);
        }
        if (g != false) {
            l = ST_OnOff.g(g);
            a.ad.h("bestFit", l);
        }
        if (h != false) {
            l = ST_OnOff.g(h);
            a.ad.h("customWidth", l);
        }
        if (i != false) {
            l = ST_OnOff.g(i);
            a.ad.h("phonetic", l);
        }
        if (j != 0) {
            l = j.toString();
            a.ad.h("outlineLevel", l);
        }
        if (k != false) {
            l = ST_OnOff.g(k);
            a.ad.h("collapsed", l);
        }
    };
    SpreadsheetMLMain.t6 = function (a, b, c, d, e, f) {
        var g = SpreadsheetMLMain.uk(a, SpreadsheetMLMain.es, b, c, d, e, f);
        b = g.p2;
        c = g.p3;
        d = g.p4;
        e = g.p5;
        f = g.p6;
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
    };
    SpreadsheetMLMain.zk = function (a, b, c, d, e, f) {
        if (b === void 0) { b = Nullable$1.toNullable(Boolean_$type, null); }
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(ST_UnsignedIntHex.$, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        if (f === void 0) { f = 0; }
        SpreadsheetMLMain.zz(a, SpreadsheetMLMain.es, b, c, d, e, f);
    };
    SpreadsheetMLMain.t7 = function (a, b, c) {
        b = Nullable$1.toNullable(Number_$type, null);
        c = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "dxfId":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(d.d, CultureInfo.invariantCulture));
                        break;
                    case "cellColor":
                        c = ST_OnOff.e(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_198_1) { e_198 = { error: e_198_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_198) throw e_198.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_198, _2;
    };
    SpreadsheetMLMain.zl = function (a, b, c) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        if (c === void 0) { c = true; }
        a.ad.p(SpreadsheetMLMain.et, null);
        var d;
        if (nullableNotEquals(b, null)) {
            d = b.value.toString();
            a.ad.h("dxfId", d);
        }
        d = ST_OnOff.g(c);
        a.ad.h("cellColor", d);
    };
    SpreadsheetMLMain.zm = function (a) {
        a.ad.p(SpreadsheetMLMain.ew, null);
    };
    SpreadsheetMLMain.t8 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_199_1) { e_199 = { error: e_199_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_199) throw e_199.error; }
        }
        var e_199, _2;
    };
    SpreadsheetMLMain.zn = function (a) {
        a.ad.p(SpreadsheetMLMain.ev, null);
    };
    SpreadsheetMLMain.t9 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_200_1) { e_200 = { error: e_200_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_200) throw e_200.error; }
        }
        var e_200, _2;
    };
    SpreadsheetMLMain.zo = function (a) {
        a.ad.p(SpreadsheetMLMain.ex, null);
    };
    SpreadsheetMLMain.ua = function (a, b, c, d, e) {
        b = null;
        c = 0;
        d = Nullable$1.toNullable(ST_Guid.$, null);
        e = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "ref":
                        b = f.d;
                        break;
                    case "authorId":
                        c = parseUInt32_1(f.d, CultureInfo.invariantCulture);
                        break;
                    case "guid":
                        d = Nullable$1.toNullable(ST_Guid.$, ST_Guid.c(f.d));
                        break;
                    case "shapeId":
                        e = Nullable$1.toNullable(Number_$type, parseUInt32_1(f.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_201_1) { e_201 = { error: e_201_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_201) throw e_201.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_201, _2;
    };
    SpreadsheetMLMain.zp = function (a, b, c, d, e) {
        if (d === void 0) { d = Nullable$1.toNullable(ST_Guid.$, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.ez, null);
        var f;
        f = b;
        a.ad.h("ref", f);
        f = c.toString();
        a.ad.h("authorId", f);
        if (nullableNotEquals(d, null)) {
            f = d.value.toString();
            a.ad.h("guid", f);
        }
        if (nullableNotEquals(e, null)) {
            f = e.value.toString();
            a.ad.h("shapeId", f);
        }
    };
    SpreadsheetMLMain.ub = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_202_1) { e_202 = { error: e_202_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_202) throw e_202.error; }
        }
        var e_202, _2;
    };
    SpreadsheetMLMain.zq = function (a) {
        a.ad.p(SpreadsheetMLMain.e1, null);
    };
    SpreadsheetMLMain.uc = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_203_1) { e_203 = { error: e_203_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_203) throw e_203.error; }
        }
        var e_203, _2;
    };
    SpreadsheetMLMain.zr = function (a) {
        a.ad.p(SpreadsheetMLMain.e2, null);
    };
    SpreadsheetMLMain.ud = function (a, b) {
        var c = SpreadsheetMLMain.ui(a, SpreadsheetMLMain.e5, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.zs = function (a, b) {
        if (b === void 0) { b = true; }
        SpreadsheetMLMain.zx(a, SpreadsheetMLMain.e5, b);
    };
    SpreadsheetMLMain.ue = function (a, b, c) {
        b = null;
        c = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "sqref":
                        b = XmlNamespaceDefinitionBase.e(String_$type, d.d, function (e) { return e; });
                        break;
                    case "pivot":
                        c = ST_OnOff.e(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_204_1) { e_204 = { error: e_204_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_204) throw e_204.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_204, _2;
    };
    SpreadsheetMLMain.zt = function (a, b, c) {
        if (c === void 0) { c = false; }
        a.ad.p(SpreadsheetMLMain.e6, null);
        var d;
        if (b != null) {
            d = stringJoin1(String_$type, " ", b);
            a.ad.h("sqref", d);
        }
        if (c != false) {
            d = ST_OnOff.g(c);
            a.ad.h("pivot", d);
        }
    };
    SpreadsheetMLMain.uf = function (a, b, c, d) {
        b = 0;
        c = null;
        d = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "shapeId":
                        b = parseUInt32_1(e.d, CultureInfo.invariantCulture);
                        break;
                    case OfficeDocumentRelationships.ar:
                        c = e.d;
                        break;
                    case "name":
                        d = e.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_205_1) { e_205 = { error: e_205_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_205) throw e_205.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_205, _2;
    };
    SpreadsheetMLMain.zu = function (a, b, c, d) {
        if (d === void 0) { d = null; }
        a.ad.p(SpreadsheetMLMain.fa, null);
        var e;
        e = b.toString();
        a.ad.h("shapeId", e);
        e = c;
        a.ad.h(OfficeDocumentRelationships.ar, e);
        e = d;
        a.ad.h("name", e);
    };
    SpreadsheetMLMain.ug = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p) {
        b = true;
        c = true;
        d = true;
        e = false;
        f = false;
        g = false;
        h = true;
        i = true;
        j = true;
        k = null;
        l = null;
        m = null;
        n = null;
        o = "pict";
        p = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var q = _1.value;
                switch (q.a.e(a.d)) {
                    case "locked":
                        b = ST_OnOff.e(q.d);
                        break;
                    case "defaultSize":
                        c = ST_OnOff.e(q.d);
                        break;
                    case "print":
                        d = ST_OnOff.e(q.d);
                        break;
                    case "disabled":
                        e = ST_OnOff.e(q.d);
                        break;
                    case "recalcAlways":
                        f = ST_OnOff.e(q.d);
                        break;
                    case "uiObject":
                        g = ST_OnOff.e(q.d);
                        break;
                    case "autoFill":
                        h = ST_OnOff.e(q.d);
                        break;
                    case "autoLine":
                        i = ST_OnOff.e(q.d);
                        break;
                    case "autoPict":
                        j = ST_OnOff.e(q.d);
                        break;
                    case "macro":
                        k = q.d;
                        break;
                    case "altText":
                        l = q.d;
                        break;
                    case "linkedCell":
                        m = q.d;
                        break;
                    case "listFillRange":
                        n = q.d;
                        break;
                    case "cf":
                        o = q.d;
                        break;
                    case OfficeDocumentRelationships.ar:
                        p = q.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_206_1) { e_206 = { error: e_206_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_206) throw e_206.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p
        };
        var e_206, _2;
    };
    SpreadsheetMLMain.zv = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p) {
        if (b === void 0) { b = true; }
        if (c === void 0) { c = true; }
        if (d === void 0) { d = true; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = true; }
        if (i === void 0) { i = true; }
        if (j === void 0) { j = true; }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = null; }
        if (m === void 0) { m = null; }
        if (n === void 0) { n = null; }
        if (o === void 0) { o = "pict"; }
        if (p === void 0) { p = null; }
        a.ad.p(SpreadsheetMLMain.fb, null);
        var q;
        if (b != true) {
            q = ST_OnOff.g(b);
            a.ad.h("locked", q);
        }
        if (c != true) {
            q = ST_OnOff.g(c);
            a.ad.h("defaultSize", q);
        }
        if (d != true) {
            q = ST_OnOff.g(d);
            a.ad.h("print", q);
        }
        if (e != false) {
            q = ST_OnOff.g(e);
            a.ad.h("disabled", q);
        }
        if (f != false) {
            q = ST_OnOff.g(f);
            a.ad.h("recalcAlways", q);
        }
        if (g != false) {
            q = ST_OnOff.g(g);
            a.ad.h("uiObject", q);
        }
        if (h != true) {
            q = ST_OnOff.g(h);
            a.ad.h("autoFill", q);
        }
        if (i != true) {
            q = ST_OnOff.g(i);
            a.ad.h("autoLine", q);
        }
        if (j != true) {
            q = ST_OnOff.g(j);
            a.ad.h("autoPict", q);
        }
        q = k;
        DrawingNamespaceDefinitionBase.da(a, q);
        q = l;
        a.ad.h("altText", q);
        q = m;
        a.ad.h("linkedCell", q);
        q = n;
        a.ad.h("listFillRange", q);
        q = o;
        a.ad.h("cf", q);
        q = p;
        a.ad.h(OfficeDocumentRelationships.ar, q);
    };
    SpreadsheetMLMain.uh = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_207_1) { e_207 = { error: e_207_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_207) throw e_207.error; }
        }
        var e_207, _2;
    };
    SpreadsheetMLMain.zw = function (a) {
        a.ad.p(SpreadsheetMLMain.fc, null);
    };
    SpreadsheetMLMain.uo = function (a, b, c) {
        c = 2;
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "operator":
                        c = XmlNamespaceDefinitionBase.b(ST_FilterOperator_$type, d.d, c);
                        break;
                    case "val":
                        b = d.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_208_1) { e_208 = { error: e_208_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_208) throw e_208.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_208, _2;
    };
    SpreadsheetMLMain.z3 = function (a, b, c) {
        if (c === void 0) { c = 2; }
        a.ad.p(SpreadsheetMLMain.fh, null);
        var d;
        if (c != 2) {
            d = XmlNamespaceDefinitionBase.f(ST_FilterOperator_$type, c);
            a.ad.h("operator", d);
        }
        d = b;
        a.ad.h("val", d);
    };
    SpreadsheetMLMain.up = function (a, b) {
        b = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "and":
                        b = ST_OnOff.e(c.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_209_1) { e_209 = { error: e_209_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_209) throw e_209.error; }
        }
        return {
            p1: b
        };
        var e_209, _2;
    };
    SpreadsheetMLMain.z4 = function (a, b) {
        if (b === void 0) { b = false; }
        a.ad.p(SpreadsheetMLMain.fi, null);
        var c;
        if (b != false) {
            c = ST_OnOff.g(b);
            a.ad.h("and", c);
        }
    };
    SpreadsheetMLMain.uq = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u) {
        b = new ST_Guid();
        c = 100;
        d = 64;
        e = false;
        f = false;
        g = true;
        h = true;
        i = true;
        j = true;
        k = false;
        l = false;
        m = false;
        n = false;
        o = false;
        p = false;
        q = 0;
        r = false;
        s = 0;
        t = true;
        u = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var v = _1.value;
                switch (v.a.e(a.d)) {
                    case "guid":
                        b = ST_Guid.c(v.d);
                        break;
                    case "scale":
                        c = parseUInt32_1(v.d, CultureInfo.invariantCulture);
                        break;
                    case "colorId":
                        d = parseUInt32_1(v.d, CultureInfo.invariantCulture);
                        break;
                    case "showPageBreaks":
                        e = ST_OnOff.e(v.d);
                        break;
                    case "showFormulas":
                        f = ST_OnOff.e(v.d);
                        break;
                    case "showGridLines":
                        g = ST_OnOff.e(v.d);
                        break;
                    case "showRowCol":
                        h = ST_OnOff.e(v.d);
                        break;
                    case "outlineSymbols":
                        i = ST_OnOff.e(v.d);
                        break;
                    case "zeroValues":
                        j = ST_OnOff.e(v.d);
                        break;
                    case "fitToPage":
                        k = ST_OnOff.e(v.d);
                        break;
                    case "printArea":
                        l = ST_OnOff.e(v.d);
                        break;
                    case "filter":
                        m = ST_OnOff.e(v.d);
                        break;
                    case "showAutoFilter":
                        n = ST_OnOff.e(v.d);
                        break;
                    case "hiddenRows":
                        o = ST_OnOff.e(v.d);
                        break;
                    case "hiddenColumns":
                        p = ST_OnOff.e(v.d);
                        break;
                    case "state":
                        q = XmlNamespaceDefinitionBase.b(ST_SheetState_$type, v.d, q);
                        break;
                    case "filterUnique":
                        r = ST_OnOff.e(v.d);
                        break;
                    case "view":
                        s = XmlNamespaceDefinitionBase.b(ST_SheetViewType_$type, v.d, s);
                        break;
                    case "showRuler":
                        t = ST_OnOff.e(v.d);
                        break;
                    case "topLeftCell":
                        u = v.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_210_1) { e_210 = { error: e_210_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_210) throw e_210.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t,
            p20: u
        };
        var e_210, _2;
    };
    SpreadsheetMLMain.z5 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u) {
        if (c === void 0) { c = 100; }
        if (d === void 0) { d = 64; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = true; }
        if (h === void 0) { h = true; }
        if (i === void 0) { i = true; }
        if (j === void 0) { j = true; }
        if (k === void 0) { k = false; }
        if (l === void 0) { l = false; }
        if (m === void 0) { m = false; }
        if (n === void 0) { n = false; }
        if (o === void 0) { o = false; }
        if (p === void 0) { p = false; }
        if (q === void 0) { q = 0; }
        if (r === void 0) { r = false; }
        if (s === void 0) { s = 0; }
        if (t === void 0) { t = true; }
        if (u === void 0) { u = null; }
        a.ad.p(SpreadsheetMLMain.fn, null);
        var v;
        v = b.toString();
        a.ad.h("guid", v);
        if (c != 100) {
            v = c.toString();
            a.ad.h("scale", v);
        }
        if (d != 64) {
            v = d.toString();
            a.ad.h("colorId", v);
        }
        if (e != false) {
            v = ST_OnOff.g(e);
            a.ad.h("showPageBreaks", v);
        }
        if (f != false) {
            v = ST_OnOff.g(f);
            a.ad.h("showFormulas", v);
        }
        if (g != true) {
            v = ST_OnOff.g(g);
            a.ad.h("showGridLines", v);
        }
        if (h != true) {
            v = ST_OnOff.g(h);
            a.ad.h("showRowCol", v);
        }
        if (i != true) {
            v = ST_OnOff.g(i);
            a.ad.h("outlineSymbols", v);
        }
        if (j != true) {
            v = ST_OnOff.g(j);
            a.ad.h("zeroValues", v);
        }
        if (k != false) {
            v = ST_OnOff.g(k);
            a.ad.h("fitToPage", v);
        }
        if (l != false) {
            v = ST_OnOff.g(l);
            a.ad.h("printArea", v);
        }
        if (m != false) {
            v = ST_OnOff.g(m);
            a.ad.h("filter", v);
        }
        if (n != false) {
            v = ST_OnOff.g(n);
            a.ad.h("showAutoFilter", v);
        }
        if (o != false) {
            v = ST_OnOff.g(o);
            a.ad.h("hiddenRows", v);
        }
        if (p != false) {
            v = ST_OnOff.g(p);
            a.ad.h("hiddenColumns", v);
        }
        if (q != 0) {
            v = XmlNamespaceDefinitionBase.f(ST_SheetState_$type, q);
            a.ad.h("state", v);
        }
        if (r != false) {
            v = ST_OnOff.g(r);
            a.ad.h("filterUnique", v);
        }
        if (s != 0) {
            v = XmlNamespaceDefinitionBase.f(ST_SheetViewType_$type, s);
            a.ad.h("view", v);
        }
        if (t != true) {
            v = ST_OnOff.g(t);
            a.ad.h("showRuler", v);
        }
        v = u;
        a.ad.h("topLeftCell", v);
    };
    SpreadsheetMLMain.ur = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_211_1) { e_211 = { error: e_211_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_211) throw e_211.error; }
        }
        var e_211, _2;
    };
    SpreadsheetMLMain.z6 = function (a) {
        a.ad.p(SpreadsheetMLMain.fo, null);
    };
    SpreadsheetMLMain.us = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y) {
        b = null;
        c = new ST_Guid();
        g = false;
        h = Nullable$1.toNullable(Number_$type, null);
        i = false;
        j = false;
        k = false;
        l = true;
        m = true;
        n = false;
        o = false;
        p = true;
        q = true;
        r = true;
        s = 0;
        t = 0;
        e = 0;
        f = 0;
        u = 600;
        d = 0;
        v = true;
        w = true;
        x = 1;
        y = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var z = _1.value;
                switch (z.a.e(a.d)) {
                    case "name":
                        b = z.d;
                        break;
                    case "guid":
                        c = ST_Guid.c(z.d);
                        break;
                    case "autoUpdate":
                        g = ST_OnOff.e(z.d);
                        break;
                    case "mergeInterval":
                        h = Nullable$1.toNullable(Number_$type, parseUInt32_1(z.d, CultureInfo.invariantCulture));
                        break;
                    case "changesSavedWin":
                        i = ST_OnOff.e(z.d);
                        break;
                    case "onlySync":
                        j = ST_OnOff.e(z.d);
                        break;
                    case "personalView":
                        k = ST_OnOff.e(z.d);
                        break;
                    case "includePrintSettings":
                        l = ST_OnOff.e(z.d);
                        break;
                    case "includeHiddenRowCol":
                        m = ST_OnOff.e(z.d);
                        break;
                    case "maximized":
                        n = ST_OnOff.e(z.d);
                        break;
                    case "minimized":
                        o = ST_OnOff.e(z.d);
                        break;
                    case "showHorizontalScroll":
                        p = ST_OnOff.e(z.d);
                        break;
                    case "showVerticalScroll":
                        q = ST_OnOff.e(z.d);
                        break;
                    case "showSheetTabs":
                        r = ST_OnOff.e(z.d);
                        break;
                    case "xWindow":
                        s = parseInt32_1(z.d, CultureInfo.invariantCulture);
                        break;
                    case "yWindow":
                        t = parseInt32_1(z.d, CultureInfo.invariantCulture);
                        break;
                    case "windowWidth":
                        e = parseUInt32_1(z.d, CultureInfo.invariantCulture);
                        break;
                    case "windowHeight":
                        f = parseUInt32_1(z.d, CultureInfo.invariantCulture);
                        break;
                    case "tabRatio":
                        u = parseUInt32_1(z.d, CultureInfo.invariantCulture);
                        break;
                    case "activeSheetId":
                        d = parseUInt32_1(z.d, CultureInfo.invariantCulture);
                        break;
                    case "showFormulaBar":
                        v = ST_OnOff.e(z.d);
                        break;
                    case "showStatusbar":
                        w = ST_OnOff.e(z.d);
                        break;
                    case "showComments":
                        x = XmlNamespaceDefinitionBase.b(ST_Comments_$type, z.d, x);
                        break;
                    case "showObjects":
                        y = XmlNamespaceDefinitionBase.b(ST_Objects_$type, z.d, y);
                        break;
                    default: break;
                }
            }
        }
        catch (e_212_1) { e_212 = { error: e_212_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_212) throw e_212.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t,
            p20: u,
            p21: v,
            p22: w,
            p23: x,
            p24: y
        };
        var e_212, _2;
    };
    SpreadsheetMLMain.z7 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w, x, y) {
        if (g === void 0) { g = false; }
        if (h === void 0) { h = Nullable$1.toNullable(Number_$type, null); }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = false; }
        if (k === void 0) { k = false; }
        if (l === void 0) { l = true; }
        if (m === void 0) { m = true; }
        if (n === void 0) { n = false; }
        if (o === void 0) { o = false; }
        if (p === void 0) { p = true; }
        if (q === void 0) { q = true; }
        if (r === void 0) { r = true; }
        if (s === void 0) { s = 0; }
        if (t === void 0) { t = 0; }
        if (u === void 0) { u = 600; }
        if (v === void 0) { v = true; }
        if (w === void 0) { w = true; }
        if (x === void 0) { x = 1; }
        if (y === void 0) { y = 0; }
        a.ad.p(SpreadsheetMLMain.fq, null);
        var z;
        z = b;
        a.ad.h("name", z);
        z = c.toString();
        a.ad.h("guid", z);
        if (g != false) {
            z = ST_OnOff.g(g);
            a.ad.h("autoUpdate", z);
        }
        if (nullableNotEquals(h, null)) {
            z = h.value.toString();
            a.ad.h("mergeInterval", z);
        }
        if (i != false) {
            z = ST_OnOff.g(i);
            a.ad.h("changesSavedWin", z);
        }
        if (j != false) {
            z = ST_OnOff.g(j);
            a.ad.h("onlySync", z);
        }
        if (k != false) {
            z = ST_OnOff.g(k);
            a.ad.h("personalView", z);
        }
        if (l != true) {
            z = ST_OnOff.g(l);
            a.ad.h("includePrintSettings", z);
        }
        if (m != true) {
            z = ST_OnOff.g(m);
            a.ad.h("includeHiddenRowCol", z);
        }
        if (n != false) {
            z = ST_OnOff.g(n);
            a.ad.h("maximized", z);
        }
        if (o != false) {
            z = ST_OnOff.g(o);
            a.ad.h("minimized", z);
        }
        if (p != true) {
            z = ST_OnOff.g(p);
            a.ad.h("showHorizontalScroll", z);
        }
        if (q != true) {
            z = ST_OnOff.g(q);
            a.ad.h("showVerticalScroll", z);
        }
        if (r != true) {
            z = ST_OnOff.g(r);
            a.ad.h("showSheetTabs", z);
        }
        if (s != 0) {
            z = s.toString();
            a.ad.h("xWindow", z);
        }
        if (t != 0) {
            z = t.toString();
            a.ad.h("yWindow", z);
        }
        z = e.toString();
        a.ad.h("windowWidth", z);
        z = f.toString();
        a.ad.h("windowHeight", z);
        if (u != 600) {
            z = u.toString();
            a.ad.h("tabRatio", z);
        }
        z = d.toString();
        a.ad.h("activeSheetId", z);
        if (v != true) {
            z = ST_OnOff.g(v);
            a.ad.h("showFormulaBar", z);
        }
        if (w != true) {
            z = ST_OnOff.g(w);
            a.ad.h("showStatusbar", z);
        }
        if (x != 1) {
            z = XmlNamespaceDefinitionBase.f(ST_Comments_$type, x);
            a.ad.h("showComments", z);
        }
        if (y != 0) {
            z = XmlNamespaceDefinitionBase.f(ST_Objects_$type, y);
            a.ad.h("showObjects", z);
        }
    };
    SpreadsheetMLMain.ut = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_213_1) { e_213 = { error: e_213_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_213) throw e_213.error; }
        }
        var e_213, _2;
    };
    SpreadsheetMLMain.z8 = function (a) {
        a.ad.p(SpreadsheetMLMain.fr, null);
    };
    SpreadsheetMLMain.uu = function (a, b, c, d) {
        c = Nullable$1.toNullable(Number_$type, null);
        b = Nullable$1.toNullable(Number_$type, null);
        d = Nullable$1.toNullable(Boolean_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "minLength":
                        c = Nullable$1.toNullable(Number_$type, parseUInt32_1(e.d, CultureInfo.invariantCulture));
                        break;
                    case "maxLength":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(e.d, CultureInfo.invariantCulture));
                        break;
                    case "showValue":
                        d = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(e.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_214_1) { e_214 = { error: e_214_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_214) throw e_214.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_214, _2;
    };
    SpreadsheetMLMain.z9 = function (a, b, c, d) {
        a.ad.p(SpreadsheetMLMain.fs, null);
        var e;
        if (b.hasValue) {
            e = b.value.toString();
            a.ad.h("minLength", e);
        }
        if (c.hasValue) {
            e = c.value.toString();
            a.ad.h("maxLength", e);
        }
        if (d.hasValue) {
            e = ST_OnOff.g(d.value);
            a.ad.h("showValue", e);
        }
    };
    SpreadsheetMLMain.uv = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        var o;
        var p = SpreadsheetMLMain.uw(a, o, c, d, e, f, g, h, i, j, k, l, m, n);
        o = p.p1;
        c = p.p2;
        d = p.p3;
        e = p.p4;
        f = p.p5;
        g = p.p6;
        h = p.p7;
        i = p.p8;
        j = p.p9;
        k = p.p10;
        l = p.p11;
        m = p.p12;
        n = p.p13;
        b = XmlNamespaceDefinitionBase.e(String_$type, o, function (q) { return q; });
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n
        };
    };
    SpreadsheetMLMain.aaa = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        if (c === void 0) { c = 0; }
        if (d === void 0) { d = 0; }
        if (e === void 0) { e = 0; }
        if (f === void 0) { f = 0; }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = false; }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = null; }
        if (m === void 0) { m = null; }
        if (n === void 0) { n = null; }
        SpreadsheetMLMain.aab(a, b == null ? null : stringJoin1(String_$type, " ", b), c, d, e, f, g, h, i, j, k, l, m, n);
    };
    SpreadsheetMLMain.uw = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        b = null;
        c = 0;
        d = 0;
        e = 0;
        f = 0;
        g = false;
        h = false;
        i = false;
        j = false;
        k = null;
        l = null;
        m = null;
        n = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var o = _1.value;
                switch (o.a.e(a.d)) {
                    case "sqref":
                        b = o.d;
                        break;
                    case "type":
                        c = XmlNamespaceDefinitionBase.b(ST_DataValidationType_$type, o.d, c);
                        break;
                    case "errorStyle":
                        d = XmlNamespaceDefinitionBase.b(ST_DataValidationErrorStyle_$type, o.d, d);
                        break;
                    case "imeMode":
                        e = XmlNamespaceDefinitionBase.b(ST_DataValidationImeMode_$type, o.d, e);
                        break;
                    case "operator":
                        f = XmlNamespaceDefinitionBase.b(ST_DataValidationOperator_$type, o.d, f);
                        break;
                    case "allowBlank":
                        g = ST_OnOff.e(o.d);
                        break;
                    case "showDropDown":
                        h = ST_OnOff.e(o.d);
                        break;
                    case "showInputMessage":
                        i = ST_OnOff.e(o.d);
                        break;
                    case "showErrorMessage":
                        j = ST_OnOff.e(o.d);
                        break;
                    case "errorTitle":
                        k = o.d;
                        break;
                    case "error":
                        l = o.d;
                        break;
                    case "promptTitle":
                        m = o.d;
                        break;
                    case "prompt":
                        n = o.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_215_1) { e_215 = { error: e_215_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_215) throw e_215.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n
        };
        var e_215, _2;
    };
    SpreadsheetMLMain.aab = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        if (c === void 0) { c = 0; }
        if (d === void 0) { d = 0; }
        if (e === void 0) { e = 0; }
        if (f === void 0) { f = 0; }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = false; }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = null; }
        if (m === void 0) { m = null; }
        if (n === void 0) { n = null; }
        a.ad.p(SpreadsheetMLMain.fv, null);
        var o;
        o = b;
        a.ad.h("sqref", o);
        if (c != 0) {
            o = XmlNamespaceDefinitionBase.f(ST_DataValidationType_$type, c);
            a.ad.h("type", o);
        }
        if (d != 0) {
            o = XmlNamespaceDefinitionBase.f(ST_DataValidationErrorStyle_$type, d);
            a.ad.h("errorStyle", o);
        }
        if (e != 0) {
            o = XmlNamespaceDefinitionBase.f(ST_DataValidationImeMode_$type, e);
            a.ad.h("imeMode", o);
        }
        if (f != 0) {
            o = XmlNamespaceDefinitionBase.f(ST_DataValidationOperator_$type, f);
            a.ad.h("operator", o);
        }
        if (g != false) {
            o = ST_OnOff.g(g);
            a.ad.h("allowBlank", o);
        }
        if (h != false) {
            o = ST_OnOff.g(h);
            a.ad.h("showDropDown", o);
        }
        if (i != false) {
            o = ST_OnOff.g(i);
            a.ad.h("showInputMessage", o);
        }
        if (j != false) {
            o = ST_OnOff.g(j);
            a.ad.h("showErrorMessage", o);
        }
        o = k;
        a.ad.h("errorTitle", o);
        o = l;
        a.ad.h("error", o);
        o = m;
        a.ad.h("promptTitle", o);
        o = n;
        a.ad.h("prompt", o);
    };
    SpreadsheetMLMain.ux = function (a, b, c, d, e) {
        b = false;
        c = Nullable$1.toNullable(Number_$type, null);
        d = Nullable$1.toNullable(Number_$type, null);
        e = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "disablePrompts":
                        b = ST_OnOff.e(f.d);
                        break;
                    case "xWindow":
                        c = Nullable$1.toNullable(Number_$type, parseUInt32_1(f.d, CultureInfo.invariantCulture));
                        break;
                    case "yWindow":
                        d = Nullable$1.toNullable(Number_$type, parseUInt32_1(f.d, CultureInfo.invariantCulture));
                        break;
                    case "count":
                        e = Nullable$1.toNullable(Number_$type, parseUInt32_1(f.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_216_1) { e_216 = { error: e_216_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_216) throw e_216.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_216, _2;
    };
    SpreadsheetMLMain.aac = function (a, b, c, d, e) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.fw, null);
        var f;
        if (b != false) {
            f = ST_OnOff.g(b);
            a.ad.h("disablePrompts", f);
        }
        if (nullableNotEquals(c, null)) {
            f = c.value.toString();
            a.ad.h("xWindow", f);
        }
        if (nullableNotEquals(d, null)) {
            f = d.value.toString();
            a.ad.h("yWindow", f);
        }
        if (nullableNotEquals(e, null)) {
            f = e.value.toString();
            a.ad.h("count", f);
        }
    };
    SpreadsheetMLMain.uy = function (a, b, c, d, e, f, g, h) {
        c = 0;
        d = Nullable$1.toNullable(Number_$type, null);
        e = Nullable$1.toNullable(Number_$type, null);
        f = Nullable$1.toNullable(Number_$type, null);
        g = Nullable$1.toNullable(Number_$type, null);
        h = Nullable$1.toNullable(Number_$type, null);
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var i = _1.value;
                switch (i.a.e(a.d)) {
                    case "year":
                        c = parseUInt16_1(i.d, CultureInfo.invariantCulture);
                        break;
                    case "month":
                        d = Nullable$1.toNullable(Number_$type, parseUInt16_1(i.d, CultureInfo.invariantCulture));
                        break;
                    case "day":
                        e = Nullable$1.toNullable(Number_$type, parseUInt16_1(i.d, CultureInfo.invariantCulture));
                        break;
                    case "hour":
                        f = Nullable$1.toNullable(Number_$type, parseUInt16_1(i.d, CultureInfo.invariantCulture));
                        break;
                    case "minute":
                        g = Nullable$1.toNullable(Number_$type, parseUInt16_1(i.d, CultureInfo.invariantCulture));
                        break;
                    case "second":
                        h = Nullable$1.toNullable(Number_$type, parseUInt16_1(i.d, CultureInfo.invariantCulture));
                        break;
                    case "dateTimeGrouping":
                        b = XmlNamespaceDefinitionBase.b(ST_DateTimeGrouping_$type, i.d, b);
                        break;
                    default: break;
                }
            }
        }
        catch (e_217_1) { e_217 = { error: e_217_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_217) throw e_217.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h
        };
        var e_217, _2;
    };
    SpreadsheetMLMain.aad = function (a, b, c, d, e, f, g, h) {
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        if (f === void 0) { f = Nullable$1.toNullable(Number_$type, null); }
        if (g === void 0) { g = Nullable$1.toNullable(Number_$type, null); }
        if (h === void 0) { h = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.fz, null);
        var i;
        i = c.toString();
        a.ad.h("year", i);
        if (nullableNotEquals(d, null)) {
            i = d.value.toString();
            a.ad.h("month", i);
        }
        if (nullableNotEquals(e, null)) {
            i = e.value.toString();
            a.ad.h("day", i);
        }
        if (nullableNotEquals(f, null)) {
            i = f.value.toString();
            a.ad.h("hour", i);
        }
        if (nullableNotEquals(g, null)) {
            i = g.value.toString();
            a.ad.h("minute", i);
        }
        if (nullableNotEquals(h, null)) {
            i = h.value.toString();
            a.ad.h("second", i);
        }
        i = XmlNamespaceDefinitionBase.f(ST_DateTimeGrouping_$type, b);
        a.ad.h("dateTimeGrouping", i);
    };
    SpreadsheetMLMain.uz = function (a, b, c, d, e) {
        b = null;
        c = false;
        d = false;
        e = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "name":
                        b = f.d;
                        break;
                    case "ole":
                        c = ST_OnOff.e(f.d);
                        break;
                    case "advise":
                        d = ST_OnOff.e(f.d);
                        break;
                    case "preferPic":
                        e = ST_OnOff.e(f.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_218_1) { e_218 = { error: e_218_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_218) throw e_218.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_218, _2;
    };
    SpreadsheetMLMain.aae = function (a, b, c, d, e) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = false; }
        a.ad.p(SpreadsheetMLMain.f2, null);
        var f;
        f = b;
        a.ad.h("name", f);
        if (c != false) {
            f = ST_OnOff.g(c);
            a.ad.h("ole", f);
        }
        if (d != false) {
            f = ST_OnOff.g(d);
            a.ad.h("advise", f);
        }
        if (e != false) {
            f = ST_OnOff.g(e);
            a.ad.h("preferPic", f);
        }
    };
    SpreadsheetMLMain.u0 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_219_1) { e_219 = { error: e_219_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_219) throw e_219.error; }
        }
        var e_219, _2;
    };
    SpreadsheetMLMain.aaf = function (a) {
        a.ad.p(SpreadsheetMLMain.f3, null);
    };
    SpreadsheetMLMain.u1 = function (a, b, c) {
        b = null;
        c = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "ddeService":
                        b = d.d;
                        break;
                    case "ddeTopic":
                        c = d.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_220_1) { e_220 = { error: e_220_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_220) throw e_220.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_220, _2;
    };
    SpreadsheetMLMain.aag = function (a, b, c) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = null; }
        a.ad.p(SpreadsheetMLMain.f4, null);
        var d;
        d = b;
        a.ad.h("ddeService", d);
        d = c;
        a.ad.h("ddeTopic", d);
    };
    SpreadsheetMLMain.u3 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q) {
        c = null;
        d = null;
        e = null;
        f = null;
        g = null;
        h = null;
        i = Nullable$1.toNullable(Number_$type, null);
        j = false;
        k = false;
        l = false;
        m = false;
        n = Nullable$1.toNullable(Number_$type, null);
        o = null;
        p = false;
        q = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var r = _1.value;
                switch (r.a.e(a.d)) {
                    case "name":
                        c = r.d;
                        break;
                    case "comment":
                        d = r.d;
                        break;
                    case "customMenu":
                        e = r.d;
                        break;
                    case "description":
                        f = r.d;
                        break;
                    case "help":
                        g = r.d;
                        break;
                    case "statusBar":
                        h = r.d;
                        break;
                    case "localSheetId":
                        i = Nullable$1.toNullable(Number_$type, parseUInt32_1(r.d, CultureInfo.invariantCulture));
                        break;
                    case "hidden":
                        j = ST_OnOff.e(r.d);
                        break;
                    case "function":
                        k = ST_OnOff.e(r.d);
                        break;
                    case "vbProcedure":
                        l = ST_OnOff.e(r.d);
                        break;
                    case "xlm":
                        m = ST_OnOff.e(r.d);
                        break;
                    case "functionGroupId":
                        n = Nullable$1.toNullable(Number_$type, parseUInt32_1(r.d, CultureInfo.invariantCulture));
                        break;
                    case "shortcutKey":
                        o = r.d;
                        break;
                    case "publishToServer":
                        p = ST_OnOff.e(r.d);
                        break;
                    case "workbookParameter":
                        q = ST_OnOff.e(r.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_221_1) { e_221 = { error: e_221_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_221) throw e_221.error; }
        }
        b = SpreadsheetMLMain.rt(a.ab.ad, true);
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q
        };
        var e_221, _2;
    };
    SpreadsheetMLMain.aai = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q) {
        if (d === void 0) { d = null; }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = null; }
        if (g === void 0) { g = null; }
        if (h === void 0) { h = null; }
        if (i === void 0) { i = Nullable$1.toNullable(Number_$type, null); }
        if (j === void 0) { j = false; }
        if (k === void 0) { k = false; }
        if (l === void 0) { l = false; }
        if (m === void 0) { m = false; }
        if (n === void 0) { n = Nullable$1.toNullable(Number_$type, null); }
        if (o === void 0) { o = null; }
        if (p === void 0) { p = false; }
        if (q === void 0) { q = false; }
        a.ad.p(SpreadsheetMLMain.ge, null);
        var r;
        r = c;
        a.ad.h("name", r);
        if (d != null) {
            r = d;
            a.ad.h("comment", r);
        }
        if (e != null) {
            r = e;
            a.ad.h("customMenu", r);
        }
        if (f != null) {
            r = f;
            a.ad.h("description", r);
        }
        if (g != null) {
            r = g;
            a.ad.h("help", r);
        }
        if (h != null) {
            r = h;
            a.ad.h("statusBar", r);
        }
        if (nullableNotEquals(i, null)) {
            r = i.value.toString();
            a.ad.h("localSheetId", r);
        }
        if (j != false) {
            r = ST_OnOff.g(j);
            a.ad.h("hidden", r);
        }
        if (k != false) {
            r = ST_OnOff.g(k);
            a.ad.h("function", r);
        }
        if (l != false) {
            r = ST_OnOff.g(l);
            a.ad.h("vbProcedure", r);
        }
        if (m != false) {
            r = ST_OnOff.g(m);
            a.ad.h("xlm", r);
        }
        if (nullableNotEquals(n, null)) {
            r = n.value.toString();
            a.ad.h("functionGroupId", r);
        }
        if (o != null) {
            r = o;
            a.ad.h("shortcutKey", r);
        }
        if (p != false) {
            r = ST_OnOff.g(p);
            a.ad.h("publishToServer", r);
        }
        if (q != false) {
            r = ST_OnOff.g(q);
            a.ad.h("workbookParameter", r);
        }
        if (b != null) {
            a.ad.u(SpreadsheetMLMain.he(b));
        }
    };
    SpreadsheetMLMain.u2 = function (a, b, c, d) {
        b = null;
        c = null;
        d = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "name":
                        b = e.d;
                        break;
                    case "refersTo":
                        c = e.d;
                        break;
                    case "sheetId":
                        d = Nullable$1.toNullable(Number_$type, parseUInt32_1(e.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_222_1) { e_222 = { error: e_222_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_222) throw e_222.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_222, _2;
    };
    SpreadsheetMLMain.aah = function (a, b, c, d) {
        if (c === void 0) { c = null; }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.ge, null);
        var e;
        e = b;
        a.ad.h("name", e);
        e = c;
        a.ad.h("refersTo", e);
        if (nullableNotEquals(d, null)) {
            e = d.value.toString();
            a.ad.h("sheetId", e);
        }
    };
    SpreadsheetMLMain.u4 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_223_1) { e_223 = { error: e_223_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_223) throw e_223.error; }
        }
        var e_223, _2;
    };
    SpreadsheetMLMain.aaj = function (a) {
        a.ad.p(SpreadsheetMLMain.gf, null);
    };
    SpreadsheetMLMain.u5 = function (a, b) {
        var c = SpreadsheetMLMain.uj(a, SpreadsheetMLMain.go, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.aak = function (a, b) {
        if (b === void 0) { b = 0; }
        SpreadsheetMLMain.zy(a, SpreadsheetMLMain.go, b);
    };
    SpreadsheetMLMain.u6 = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "ref":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_224_1) { e_224 = { error: e_224_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_224) throw e_224.error; }
        }
        return {
            p1: b
        };
        var e_224, _2;
    };
    SpreadsheetMLMain.aal = function (a, b) {
        a.ad.p(SpreadsheetMLMain.gt, null);
        var c;
        c = b;
        a.ad.h("ref", c);
    };
    SpreadsheetMLMain.u7 = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_225_1) { e_225 = { error: e_225_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_225) throw e_225.error; }
        }
        return {
            p1: b
        };
        var e_225, _2;
    };
    SpreadsheetMLMain.aam = function (a, b) {
        a.ad.p(SpreadsheetMLMain.gz, null);
        var c;
        c = b;
        a.ad.h(OfficeDocumentRelationships.ar, c);
    };
    SpreadsheetMLMain.u8 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t) {
        b = null;
        c = Nullable$1.toNullable(Number_$type, null);
        d = Nullable$1.toNullable(Number_$type, null);
        e = Nullable$1.toNullable(Number_$type, null);
        f = Nullable$1.toNullable(Number_$type, null);
        g = Nullable$1.toNullable(Number_$type, null);
        h = Nullable$1.toNullable(Number_$type, null);
        i = Nullable$1.toNullable(Number_$type, null);
        j = Nullable$1.toNullable(Number_$type, null);
        k = Nullable$1.toNullable(Number_$type, null);
        l = Nullable$1.toNullable(Number_$type, null);
        m = Nullable$1.toNullable(Number_$type, null);
        n = Nullable$1.toNullable(Number_$type, null);
        o = Nullable$1.toNullable(Number_$type, null);
        p = Nullable$1.toNullable(Number_$type, null);
        q = Nullable$1.toNullable(Number_$type, null);
        r = Nullable$1.toNullable(Number_$type, null);
        s = Nullable$1.toNullable(Number_$type, null);
        t = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var u = _1.value;
                switch (u.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = u.d;
                        break;
                    case "lho":
                        c = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "lhe":
                        d = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "lhf":
                        e = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "cho":
                        f = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "che":
                        g = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "chf":
                        h = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "rho":
                        i = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "rhe":
                        j = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "rhf":
                        k = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "lfo":
                        l = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "lfe":
                        m = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "lff":
                        n = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "cfo":
                        o = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "cfe":
                        p = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "cff":
                        q = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "rfo":
                        r = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "rfe":
                        s = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "rff":
                        t = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_226_1) { e_226 = { error: e_226_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_226) throw e_226.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t
        };
        var e_226, _2;
    };
    SpreadsheetMLMain.aan = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t) {
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        if (f === void 0) { f = Nullable$1.toNullable(Number_$type, null); }
        if (g === void 0) { g = Nullable$1.toNullable(Number_$type, null); }
        if (h === void 0) { h = Nullable$1.toNullable(Number_$type, null); }
        if (i === void 0) { i = Nullable$1.toNullable(Number_$type, null); }
        if (j === void 0) { j = Nullable$1.toNullable(Number_$type, null); }
        if (k === void 0) { k = Nullable$1.toNullable(Number_$type, null); }
        if (l === void 0) { l = Nullable$1.toNullable(Number_$type, null); }
        if (m === void 0) { m = Nullable$1.toNullable(Number_$type, null); }
        if (n === void 0) { n = Nullable$1.toNullable(Number_$type, null); }
        if (o === void 0) { o = Nullable$1.toNullable(Number_$type, null); }
        if (p === void 0) { p = Nullable$1.toNullable(Number_$type, null); }
        if (q === void 0) { q = Nullable$1.toNullable(Number_$type, null); }
        if (r === void 0) { r = Nullable$1.toNullable(Number_$type, null); }
        if (s === void 0) { s = Nullable$1.toNullable(Number_$type, null); }
        if (t === void 0) { t = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.g0, null);
        var u;
        u = b;
        a.ad.h(OfficeDocumentRelationships.ar, u);
        if (nullableNotEquals(c, null)) {
            u = c.value.toString();
            a.ad.h("lho", u);
        }
        if (nullableNotEquals(d, null)) {
            u = d.value.toString();
            a.ad.h("lhe", u);
        }
        if (nullableNotEquals(e, null)) {
            u = e.value.toString();
            a.ad.h("lhf", u);
        }
        if (nullableNotEquals(f, null)) {
            u = f.value.toString();
            a.ad.h("cho", u);
        }
        if (nullableNotEquals(g, null)) {
            u = g.value.toString();
            a.ad.h("che", u);
        }
        if (nullableNotEquals(h, null)) {
            u = h.value.toString();
            a.ad.h("chf", u);
        }
        if (nullableNotEquals(i, null)) {
            u = i.value.toString();
            a.ad.h("rho", u);
        }
        if (nullableNotEquals(j, null)) {
            u = j.value.toString();
            a.ad.h("rhe", u);
        }
        if (nullableNotEquals(k, null)) {
            u = k.value.toString();
            a.ad.h("rhf", u);
        }
        if (nullableNotEquals(l, null)) {
            u = l.value.toString();
            a.ad.h("lfo", u);
        }
        if (nullableNotEquals(m, null)) {
            u = m.value.toString();
            a.ad.h("lfe", u);
        }
        if (nullableNotEquals(n, null)) {
            u = n.value.toString();
            a.ad.h("lff", u);
        }
        if (nullableNotEquals(o, null)) {
            u = o.value.toString();
            a.ad.h("cfo", u);
        }
        if (nullableNotEquals(p, null)) {
            u = p.value.toString();
            a.ad.h("cfe", u);
        }
        if (nullableNotEquals(q, null)) {
            u = q.value.toString();
            a.ad.h("cff", u);
        }
        if (nullableNotEquals(r, null)) {
            u = r.value.toString();
            a.ad.h("rfo", u);
        }
        if (nullableNotEquals(s, null)) {
            u = s.value.toString();
            a.ad.h("rfe", u);
        }
        if (nullableNotEquals(t, null)) {
            u = t.value.toString();
            a.ad.h("rff", u);
        }
    };
    SpreadsheetMLMain.u9 = function (a, b) {
        if (b === void 0) { b = SpreadsheetMLMain.g3; }
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_227_1) { e_227 = { error: e_227_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_227) throw e_227.error; }
        }
        var e_227, _2;
    };
    SpreadsheetMLMain.aao = function (a, b) {
        if (b === void 0) { b = SpreadsheetMLMain.g3; }
        a.ad.p(b, null);
    };
    SpreadsheetMLMain.va = function (a, b) {
        b = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(c.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_228_1) { e_228 = { error: e_228_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_228) throw e_228.error; }
        }
        return {
            p1: b
        };
        var e_228, _2;
    };
    SpreadsheetMLMain.aap = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.g5, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = b.value.toString();
            a.ad.h("count", c);
        }
    };
    SpreadsheetMLMain.vb = function (a, b, c, d) {
        b = 0;
        c = Nullable$1.toNullable(Number_$type, null);
        d = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "type":
                        b = XmlNamespaceDefinitionBase.b(ST_DynamicFilterType_$type, e.d, b);
                        break;
                    case "val":
                        c = Nullable$1.toNullable(Number_$type, parseNumber(e.d, CultureInfo.invariantCulture));
                        break;
                    case "maxVal":
                        d = Nullable$1.toNullable(Number_$type, parseNumber(e.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_229_1) { e_229 = { error: e_229_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_229) throw e_229.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_229, _2;
    };
    SpreadsheetMLMain.aaq = function (a, b, c, d) {
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.g6, null);
        var e;
        e = XmlNamespaceDefinitionBase.f(ST_DynamicFilterType_$type, b);
        a.ad.h("type", e);
        if (nullableNotEquals(c, null)) {
            e = c.value.toString();
            a.ad.h("val", e);
        }
        if (nullableNotEquals(d, null)) {
            e = d.value.toString();
            a.ad.h("maxVal", e);
        }
    };
    SpreadsheetMLMain.vc = function (a, b, c, d, e) {
        b = 0;
        c = Nullable$1.toNullable(Number_$type, null);
        d = Nullable$1.toNullable(Date_$type, null);
        e = Nullable$1.toNullable(Date_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "type":
                        b = XmlNamespaceDefinitionBase.b(ST_DynamicFilterType_$type, f.d, b);
                        break;
                    case "val":
                        c = Nullable$1.toNullable(Number_$type, parseNumber(f.d, CultureInfo.invariantCulture));
                        break;
                    case "valIso":
                        d = Nullable$1.toNullable(Date_$type, dateParse(f.d, CultureInfo.invariantCulture));
                        break;
                    case "maxValIso":
                        e = Nullable$1.toNullable(Date_$type, dateParse(f.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_230_1) { e_230 = { error: e_230_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_230) throw e_230.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_230, _2;
    };
    SpreadsheetMLMain.aar = function (a, b, c, d, e) {
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(Date_$type, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Date_$type, null); }
        a.ad.p(SpreadsheetMLMain.g6, null);
        var f;
        f = XmlNamespaceDefinitionBase.f(ST_DynamicFilterType_$type, b);
        a.ad.h("type", f);
        if (nullableNotEquals(c, null)) {
            f = c.value.toString();
            a.ad.h("val", f);
        }
        if (nullableNotEquals(d, null)) {
            f = dateToString(d.value, CultureInfo.invariantCulture);
            a.ad.h("valIso", f);
        }
        if (nullableNotEquals(e, null)) {
            f = dateToString(e.value, CultureInfo.invariantCulture);
            a.ad.h("maxValIso", f);
        }
    };
    SpreadsheetMLMain.vd = function (a, b) {
        var c = SpreadsheetMLMain.uj(a, SpreadsheetMLMain.g8, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.aas = function (a, b) {
        if (b === void 0) { b = 0; }
        SpreadsheetMLMain.zy(a, SpreadsheetMLMain.g8, b);
    };
    SpreadsheetMLMain.ve = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, SpreadsheetMLMain.hf, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.aat = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, SpreadsheetMLMain.hf, null, b);
    };
    SpreadsheetMLMain.vf = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, SpreadsheetMLMain.hg, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.aau = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, SpreadsheetMLMain.hg, null, b);
    };
    SpreadsheetMLMain.vg = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "uri":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_231_1) { e_231 = { error: e_231_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_231) throw e_231.error; }
        }
        return {
            p1: b
        };
        var e_231, _2;
    };
    SpreadsheetMLMain.aav = function (a, b, c) {
        if (c === void 0) { c = null; }
        a.ad.p(SpreadsheetMLMain.hh, null);
        var d;
        d = b;
        a.ad.h("uri", d);
        if (stringIsNullOrEmpty(c) == false) {
            d = c;
            a.ad.i("xmlns", "x14", null, d);
        }
    };
    SpreadsheetMLMain.vh = function (a, b) {
        var c = SpreadsheetMLMain.ui(a, SpreadsheetMLMain.hi, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.aaw = function (a, b) {
        if (b === void 0) { b = true; }
        SpreadsheetMLMain.zx(a, SpreadsheetMLMain.hi, b);
    };
    SpreadsheetMLMain.vi = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_232_1) { e_232 = { error: e_232_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_232) throw e_232.error; }
        }
        return {
            p1: b
        };
        var e_232, _2;
    };
    SpreadsheetMLMain.aax = function (a, b) {
        a.ad.p(SpreadsheetMLMain.hj, null);
        var c;
        c = b;
        a.ad.h(OfficeDocumentRelationships.ar, c);
    };
    SpreadsheetMLMain.vj = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_233_1) { e_233 = { error: e_233_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_233) throw e_233.error; }
        }
        var e_233, _2;
    };
    SpreadsheetMLMain.aay = function (a) {
        a.ad.p(SpreadsheetMLMain.hk, null);
        var b = a.d._z;
        a.ad.l(SpreadsheetMLMain.ao);
    };
    SpreadsheetMLMain.vk = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_234_1) { e_234 = { error: e_234_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_234) throw e_234.error; }
        }
        return {
            p1: b
        };
        var e_234, _2;
    };
    SpreadsheetMLMain.aaz = function (a, b) {
        a.ad.p(SpreadsheetMLMain.hl, null);
        var c;
        c = b;
        a.ad.h(OfficeDocumentRelationships.ar, c);
    };
    SpreadsheetMLMain.vl = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_235_1) { e_235 = { error: e_235_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_235) throw e_235.error; }
        }
        var e_235, _2;
    };
    SpreadsheetMLMain.aa0 = function (a) {
        a.ad.p(SpreadsheetMLMain.hm, null);
    };
    SpreadsheetMLMain.vm = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_236_1) { e_236 = { error: e_236_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_236) throw e_236.error; }
        }
        var e_236, _2;
    };
    SpreadsheetMLMain.aa1 = function (a) {
        a.ad.p(SpreadsheetMLMain.hn, null);
    };
    SpreadsheetMLMain.vn = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = parseInt32_1(c.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_237_1) { e_237 = { error: e_237_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_237) throw e_237.error; }
        }
        return {
            p1: b
        };
        var e_237, _2;
    };
    SpreadsheetMLMain.aa2 = function (a, b) {
        a.ad.p(SpreadsheetMLMain.hp, null);
        var c;
        c = b.toString();
        a.ad.h("val", c);
    };
    SpreadsheetMLMain.vo = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        b = 0;
        c = false;
        d = null;
        e = false;
        f = false;
        g = false;
        h = false;
        i = null;
        j = null;
        k = false;
        l = Nullable$1.toNullable(Number_$type, null);
        m = false;
        var o = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var p = _1.value;
                switch (p.a.e(a.d)) {
                    case "t":
                        b = XmlNamespaceDefinitionBase.b(ST_CellFormulaType_$type, p.d, b);
                        break;
                    case "aca":
                        c = ST_OnOff.e(p.d);
                        break;
                    case "ref":
                        d = p.d;
                        break;
                    case "dt2D":
                        e = ST_OnOff.e(p.d);
                        break;
                    case "dtr":
                        f = ST_OnOff.e(p.d);
                        break;
                    case "del1":
                        g = ST_OnOff.e(p.d);
                        break;
                    case "del2":
                        h = ST_OnOff.e(p.d);
                        break;
                    case "r1":
                        i = p.d;
                        break;
                    case "r2":
                        j = p.d;
                        break;
                    case "ca":
                        k = ST_OnOff.e(p.d);
                        break;
                    case "si":
                        l = Nullable$1.toNullable(Number_$type, parseUInt32_1(p.d, CultureInfo.invariantCulture));
                        break;
                    case "bx":
                        m = ST_OnOff.e(p.d);
                        break;
                    case XmlNamespace.ar:
                        o = (p.d == "preserve");
                        break;
                    default: break;
                }
            }
        }
        catch (e_238_1) { e_238 = { error: e_238_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_238) throw e_238.error; }
        }
        n = a.ab.ad;
        if (n != null && o == false) {
            n = n.trim();
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n
        };
        var e_238, _2;
    };
    SpreadsheetMLMain.aa3 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        if (c === void 0) { c = 0; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = null; }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = false; }
        if (m === void 0) { m = Nullable$1.toNullable(Number_$type, null); }
        if (n === void 0) { n = false; }
        a.ad.p(SpreadsheetMLMain.ho, null);
        var o;
        if (c != 0) {
            o = XmlNamespaceDefinitionBase.f(ST_CellFormulaType_$type, c);
            a.ad.h("t", o);
        }
        if (d != false) {
            o = ST_OnOff.g(d);
            a.ad.h("aca", o);
        }
        o = e;
        a.ad.h("ref", o);
        if (f != false) {
            o = ST_OnOff.g(f);
            a.ad.h("dt2D", o);
        }
        if (g != false) {
            o = ST_OnOff.g(g);
            a.ad.h("dtr", o);
        }
        if (h != false) {
            o = ST_OnOff.g(h);
            a.ad.h("del1", o);
        }
        if (i != false) {
            o = ST_OnOff.g(i);
            a.ad.h("del2", o);
        }
        o = j;
        a.ad.h("r1", o);
        o = k;
        a.ad.h("r2", o);
        if (l != false) {
            o = ST_OnOff.g(l);
            a.ad.h("ca", o);
        }
        if (nullableNotEquals(m, null)) {
            o = m.value.toString();
            a.ad.h("si", o);
        }
        if (n != false) {
            o = ST_OnOff.g(n);
            a.ad.h("bx", o);
        }
        if (b != null) {
            if (stringIsNullOrEmpty(b) == false) {
                if (/\s/i.test(b.charAt(0)) || /\s/i.test(b.charAt(b.length - 1))) {
                    XmlNamespace.as(a.ad);
                }
            }
            a.ad.u(b);
        }
    };
    SpreadsheetMLMain.vp = function (a, b, c, d, e, f) {
        var g = SpreadsheetMLMain.uk(a, SpreadsheetMLMain.hq, b, c, d, e, f);
        b = g.p2;
        c = g.p3;
        d = g.p4;
        e = g.p5;
        f = g.p6;
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
    };
    SpreadsheetMLMain.aa4 = function (a, b, c, d, e, f) {
        if (b === void 0) { b = Nullable$1.toNullable(Boolean_$type, null); }
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(ST_UnsignedIntHex.$, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        if (f === void 0) { f = 0; }
        SpreadsheetMLMain.zz(a, SpreadsheetMLMain.hq, b, c, d, e, f);
    };
    SpreadsheetMLMain.vr = function (a, b, c, d) {
        c = false;
        b = null;
        d = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "readOnlyRecommended":
                        c = ST_OnOff.e(e.d);
                        break;
                    case "userName":
                        b = e.d;
                        break;
                    case "reservationPassword":
                        d = ST_UnsignedShortHex.d(e.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_239_1) { e_239 = { error: e_239_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_239) throw e_239.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_239, _2;
    };
    SpreadsheetMLMain.aa6 = function (a, b, c, d) {
        if (c === void 0) { c = false; }
        if (d === void 0) { d = 0; }
        a.ad.p(SpreadsheetMLMain.hr, null);
        var e;
        if (c != false) {
            e = ST_OnOff.g(c);
            a.ad.h("readOnlyRecommended", e);
        }
        e = b;
        a.ad.h("userName", e);
        e = new ST_UnsignedShortHex(1, d).toString();
        a.ad.h("reservationPassword", e);
    };
    SpreadsheetMLMain.vq = function (a, b, c, d, e, f, g) {
        c = false;
        b = null;
        d = null;
        e = null;
        f = null;
        g = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var h = _1.value;
                switch (h.a.e(a.d)) {
                    case "readOnlyRecommended":
                        c = ST_OnOff.e(h.d);
                        break;
                    case "userName":
                        b = h.d;
                        break;
                    case "algorithmName":
                        d = h.d;
                        break;
                    case "hashValue":
                        e = Convert.fromBase64String(h.d);
                        break;
                    case "saltValue":
                        f = Convert.fromBase64String(h.d);
                        break;
                    case "spinCount":
                        g = Nullable$1.toNullable(Number_$type, parseUInt32_1(h.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_240_1) { e_240 = { error: e_240_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_240) throw e_240.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g
        };
        var e_240, _2;
    };
    SpreadsheetMLMain.aa5 = function (a, b, c, d, e, f, g) {
        if (c === void 0) { c = false; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = null; }
        if (g === void 0) { g = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.hr, null);
        var h;
        if (c != false) {
            h = ST_OnOff.g(c);
            a.ad.h("readOnlyRecommended", h);
        }
        h = b;
        a.ad.h("userName", h);
        h = d;
        a.ad.h("algorithmName", h);
        if (e != null) {
            h = Convert.toBase64String(e);
            a.ad.h("hashValue", h);
        }
        if (f != null) {
            h = Convert.toBase64String(f);
            a.ad.h("saltValue", h);
        }
        if (nullableNotEquals(g, null)) {
            h = g.value.toString();
            a.ad.h("spinCount", h);
        }
    };
    SpreadsheetMLMain.vs = function (a, b, c, d, e, f) {
        b = null;
        c = null;
        d = null;
        e = null;
        f = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var g = _1.value;
                switch (g.a.e(a.d)) {
                    case "appName":
                        b = g.d;
                        break;
                    case "lastEdited":
                        c = g.d;
                        break;
                    case "lowestEdited":
                        d = g.d;
                        break;
                    case "rupBuild":
                        e = g.d;
                        break;
                    case "codeName":
                        f = g.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_241_1) { e_241 = { error: e_241_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_241) throw e_241.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
        var e_241, _2;
    };
    SpreadsheetMLMain.aa7 = function (a, b, c, d, e, f) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = null; }
        a.ad.p(SpreadsheetMLMain.hs, null);
        var g;
        g = b;
        a.ad.h("appName", g);
        g = c;
        a.ad.h("lastEdited", g);
        g = d;
        a.ad.h("lowestEdited", g);
        g = e;
        a.ad.h("rupBuild", g);
        g = f;
        a.ad.h("codeName", g);
    };
    SpreadsheetMLMain.vt = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_242_1) { e_242 = { error: e_242_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_242) throw e_242.error; }
        }
        var e_242, _2;
    };
    SpreadsheetMLMain.aa8 = function (a) {
        a.ad.p(SpreadsheetMLMain.ht, null);
    };
    SpreadsheetMLMain.vu = function (a, b) {
        b = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(c.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_243_1) { e_243 = { error: e_243_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_243) throw e_243.error; }
        }
        return {
            p1: b
        };
        var e_243, _2;
    };
    SpreadsheetMLMain.aa9 = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.hv, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = b.value.toString();
            a.ad.h("count", c);
        }
    };
    SpreadsheetMLMain.vv = function (a, b, c, d) {
        b = 0;
        c = false;
        d = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "colId":
                        b = parseUInt32_1(e.d, CultureInfo.invariantCulture);
                        break;
                    case "hiddenButton":
                        c = ST_OnOff.e(e.d);
                        break;
                    case "showButton":
                        d = ST_OnOff.e(e.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_244_1) { e_244 = { error: e_244_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_244) throw e_244.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_244, _2;
    };
    SpreadsheetMLMain.aba = function (a, b, c, d) {
        if (c === void 0) { c = false; }
        if (d === void 0) { d = true; }
        a.ad.p(SpreadsheetMLMain.hy, null);
        var e;
        e = b.toString();
        a.ad.h("colId", e);
        if (c != false) {
            e = ST_OnOff.g(c);
            a.ad.h("hiddenButton", e);
        }
        if (d != true) {
            e = ST_OnOff.g(d);
            a.ad.h("showButton", e);
        }
    };
    SpreadsheetMLMain.vw = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_245_1) { e_245 = { error: e_245_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_245) throw e_245.error; }
        }
        return {
            p1: b
        };
        var e_245, _2;
    };
    SpreadsheetMLMain.abb = function (a, b) {
        a.ad.p(SpreadsheetMLMain.hw, null);
        var c;
        c = b;
        a.ad.h("val", c);
    };
    SpreadsheetMLMain.vx = function (a, b, c) {
        b = false;
        c = 10;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "blank":
                        b = ST_OnOff.e(d.d);
                        break;
                    case "calendarType":
                        c = XmlNamespaceDefinitionBase.b(ST_CalendarType_$type, d.d, c);
                        break;
                    default: break;
                }
            }
        }
        catch (e_246_1) { e_246 = { error: e_246_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_246) throw e_246.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_246, _2;
    };
    SpreadsheetMLMain.abc = function (a, b, c) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = 10; }
        a.ad.p(SpreadsheetMLMain.h1, null);
        var d;
        if (b != false) {
            d = ST_OnOff.g(b);
            a.ad.h("blank", d);
        }
        if (c != 10) {
            d = XmlNamespaceDefinitionBase.f(ST_CalendarType_$type, c);
            a.ad.h("calendarType", d);
        }
    };
    SpreadsheetMLMain.vy = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, SpreadsheetMLMain.h4, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.abd = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, SpreadsheetMLMain.h4, null, b);
    };
    SpreadsheetMLMain.vz = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, SpreadsheetMLMain.h5, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.abe = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, SpreadsheetMLMain.h5, null, b);
    };
    SpreadsheetMLMain.v0 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_247_1) { e_247 = { error: e_247_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_247) throw e_247.error; }
        }
        var e_247, _2;
    };
    SpreadsheetMLMain.abf = function (a) {
        a.ad.p(SpreadsheetMLMain.ib, null);
    };
    SpreadsheetMLMain.v1 = function (a, b) {
        b = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(c.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_248_1) { e_248 = { error: e_248_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_248) throw e_248.error; }
        }
        return {
            p1: b
        };
        var e_248, _2;
    };
    SpreadsheetMLMain.abg = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.id, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = b.value.toString();
            a.ad.h("count", c);
        }
    };
    SpreadsheetMLMain.v4 = function (a, b) {
        var c = SpreadsheetMLMain.ul(a, SpreadsheetMLMain.io, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.abj = function (a, b) {
        SpreadsheetMLMain.z0(a, SpreadsheetMLMain.io, b);
    };
    SpreadsheetMLMain.v2 = function (a, b) {
        var c = SpreadsheetMLMain.ul(a, SpreadsheetMLMain.ip, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.abh = function (a, b) {
        SpreadsheetMLMain.z0(a, SpreadsheetMLMain.ip, b);
    };
    SpreadsheetMLMain.v3 = function (a, b) {
        var c = SpreadsheetMLMain.ul(a, SpreadsheetMLMain.iq, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.abi = function (a, b) {
        SpreadsheetMLMain.z0(a, SpreadsheetMLMain.iq, b);
    };
    SpreadsheetMLMain.v5 = function (a, b, c, d, e, f, g) {
        b = 0;
        c = 0;
        d = 0;
        e = 0;
        f = 0;
        g = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var h = _1.value;
                switch (h.a.e(a.d)) {
                    case "type":
                        b = XmlNamespaceDefinitionBase.b(ST_GradientType_$type, h.d, b);
                        break;
                    case "degree":
                        c = parseNumber(h.d, CultureInfo.invariantCulture);
                        break;
                    case "left":
                        d = parseNumber(h.d, CultureInfo.invariantCulture);
                        break;
                    case "right":
                        e = parseNumber(h.d, CultureInfo.invariantCulture);
                        break;
                    case "top":
                        f = parseNumber(h.d, CultureInfo.invariantCulture);
                        break;
                    case "bottom":
                        g = parseNumber(h.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_249_1) { e_249 = { error: e_249_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_249) throw e_249.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g
        };
        var e_249, _2;
    };
    SpreadsheetMLMain.abk = function (a, b, c, d, e, f, g) {
        if (b === void 0) { b = 0; }
        if (c === void 0) { c = 0; }
        if (d === void 0) { d = 0; }
        if (e === void 0) { e = 0; }
        if (f === void 0) { f = 0; }
        if (g === void 0) { g = 0; }
        a.ad.p(SpreadsheetMLMain.iv, null);
        var h;
        if (b != 0) {
            h = XmlNamespaceDefinitionBase.f(ST_GradientType_$type, b);
            a.ad.h("type", h);
        }
        if (c != 0) {
            h = c.toString();
            a.ad.h("degree", h);
        }
        if (d != 0) {
            h = d.toString();
            a.ad.h("left", h);
        }
        if (e != 0) {
            h = e.toString();
            a.ad.h("right", h);
        }
        if (f != 0) {
            h = f.toString();
            a.ad.h("top", h);
        }
        if (g != 0) {
            h = g.toString();
            a.ad.h("bottom", h);
        }
    };
    SpreadsheetMLMain.v6 = function (a, b, c, d, e) {
        b = false;
        c = false;
        d = true;
        e = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "differentOddEven":
                        b = ST_OnOff.e(f.d);
                        break;
                    case "differentFirst":
                        c = ST_OnOff.e(f.d);
                        break;
                    case "scaleWithDoc":
                        d = ST_OnOff.e(f.d);
                        break;
                    case "alignWithMargins":
                        e = ST_OnOff.e(f.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_250_1) { e_250 = { error: e_250_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_250) throw e_250.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_250, _2;
    };
    SpreadsheetMLMain.abl = function (a, b, c, d, e) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = true; }
        if (e === void 0) { e = true; }
        a.ad.p(SpreadsheetMLMain.i2, null);
        var f;
        if (b != false) {
            f = ST_OnOff.g(b);
            a.ad.h("differentOddEven", f);
        }
        if (c != false) {
            f = ST_OnOff.g(c);
            a.ad.h("differentFirst", f);
        }
        if (d != true) {
            f = ST_OnOff.g(d);
            a.ad.h("scaleWithDoc", f);
        }
        if (e != true) {
            f = ST_OnOff.g(e);
            a.ad.h("alignWithMargins", f);
        }
    };
    SpreadsheetMLMain.v7 = function (a, b) {
        var c = SpreadsheetMLMain.uj(a, SpreadsheetMLMain.je, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.abm = function (a, b) {
        if (b === void 0) { b = 0; }
        SpreadsheetMLMain.zy(a, SpreadsheetMLMain.je, b);
    };
    SpreadsheetMLMain.v8 = function (a, b, c, d, e, f) {
        b = null;
        c = null;
        d = null;
        e = null;
        f = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var g = _1.value;
                switch (g.a.e(a.d)) {
                    case "ref":
                        b = g.d;
                        break;
                    case OfficeDocumentRelationships.ar:
                        c = g.d;
                        break;
                    case "location":
                        d = g.d;
                        break;
                    case "tooltip":
                        e = g.d;
                        break;
                    case "display":
                        f = g.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_251_1) { e_251 = { error: e_251_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_251) throw e_251.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
        var e_251, _2;
    };
    SpreadsheetMLMain.abn = function (a, b, c, d, e, f) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = null; }
        a.ad.p(SpreadsheetMLMain.jk, null);
        var g;
        g = b;
        a.ad.h("ref", g);
        g = c;
        a.ad.h(OfficeDocumentRelationships.ar, g);
        g = d;
        a.ad.h("location", g);
        g = e;
        a.ad.h("tooltip", g);
        g = f;
        a.ad.h("display", g);
    };
    SpreadsheetMLMain.v9 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_252_1) { e_252 = { error: e_252_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_252) throw e_252.error; }
        }
        var e_252, _2;
    };
    SpreadsheetMLMain.abo = function (a) {
        a.ad.p(SpreadsheetMLMain.jl, null);
    };
    SpreadsheetMLMain.wa = function (a, b, c) {
        b = 0;
        c = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "iconSet":
                        b = XmlNamespaceDefinitionBase.b(ST_IconSetType_$type, d.d, b);
                        break;
                    case "iconId":
                        c = Nullable$1.toNullable(Number_$type, parseUInt32_1(d.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_253_1) { e_253 = { error: e_253_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_253) throw e_253.error; }
        }
        if (b <= 16) {
        }
        return {
            p1: b,
            p2: c
        };
        var e_253, _2;
    };
    SpreadsheetMLMain.abp = function (a, b, c) {
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        if (b <= 16) {
            SpreadsheetMLMain.abq(a, SpreadsheetMLMain.jo, null, b, c);
        }
        else {
            a.ad.g([new AlternateContentChoice(0, SpreadsheetML2009Main.an, function () { return SpreadsheetMLMain.abq(a, SpreadsheetML2009Main.br, null, b, c); })], function () {
                SpreadsheetMLMain.z4(a);
                SpreadsheetMLMain.z3(a, "");
                a.ad.k();
                SpreadsheetMLMain.z3(a, " ", 5);
                a.ad.k();
                a.ad.k();
            });
        }
    };
    SpreadsheetMLMain.abq = function (a, b, c, d, e) {
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(b, c);
        var f;
        f = XmlNamespaceDefinitionBase.f(ST_IconSetType_$type, d);
        a.ad.h("iconSet", f);
        if (nullableNotEquals(e, null)) {
            f = e.value.toString();
            a.ad.h("iconId", f);
        }
        a.ad.k();
    };
    SpreadsheetMLMain.wb = function (a, b, c, d, e, f) {
        b = 3;
        c = true;
        d = false;
        e = Nullable$1.toNullable(Boolean_$type, null);
        f = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var g = _1.value;
                switch (g.a.e(a.d)) {
                    case "iconSet":
                        b = XmlNamespaceDefinitionBase.b(ST_IconSetType_$type, g.d, b);
                        break;
                    case "percent":
                        c = ST_OnOff.e(g.d);
                        break;
                    case "reverse":
                        d = ST_OnOff.e(g.d);
                        break;
                    case "showValue":
                        e = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(g.d));
                        break;
                    case "custom":
                        f = ST_OnOff.e(g.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_254_1) { e_254 = { error: e_254_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_254) throw e_254.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
        var e_254, _2;
    };
    SpreadsheetMLMain.abr = function (a, b, c, d, e, f, g) {
        a.ad.p(b, null);
        var h;
        if (c.hasValue && c.value != 3) {
            h = XmlNamespaceDefinitionBase.f(ST_IconSetType_$type, c.value);
            a.ad.h("iconSet", h);
        }
        if (d.hasValue && d.value == false) {
            h = ST_OnOff.g(d.value);
            a.ad.h("percent", h);
        }
        if (e.hasValue && e.value) {
            h = ST_OnOff.g(e.value);
            a.ad.h("reverse", h);
        }
        if (f.hasValue && f.value == false) {
            h = ST_OnOff.g(f.value);
            a.ad.h("showValue", h);
        }
        if (g.hasValue && g.value) {
            h = ST_OnOff.g(g.value);
            a.ad.h("custom", h);
        }
    };
    SpreadsheetMLMain.wc = function (a, b) {
        var c = SpreadsheetMLMain.ui(a, SpreadsheetMLMain.jm, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.abs = function (a, b) {
        if (b === void 0) { b = true; }
        SpreadsheetMLMain.zx(a, SpreadsheetMLMain.jm, b);
    };
    SpreadsheetMLMain.wd = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_255_1) { e_255 = { error: e_255_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_255) throw e_255.error; }
        }
        var e_255, _2;
    };
    SpreadsheetMLMain.abt = function (a) {
        a.ad.p(SpreadsheetMLMain.jz, null);
    };
    SpreadsheetMLMain.we = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_256_1) { e_256 = { error: e_256_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_256) throw e_256.error; }
        }
        var e_256, _2;
    };
    SpreadsheetMLMain.abu = function (a) {
        a.ad.p(SpreadsheetMLMain.b7, null);
    };
    SpreadsheetMLMain.wf = function (a, b) {
        var c = SpreadsheetMLMain.uj(a, SpreadsheetMLMain.ka, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.abv = function (a, b) {
        if (b === void 0) { b = 0; }
        SpreadsheetMLMain.zy(a, SpreadsheetMLMain.ka, b);
    };
    SpreadsheetMLMain.wg = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_257_1) { e_257 = { error: e_257_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_257) throw e_257.error; }
        }
        return {
            p1: b
        };
        var e_257, _2;
    };
    SpreadsheetMLMain.abw = function (a, b) {
        a.ad.p(SpreadsheetMLMain.kc, null);
        var c;
        c = b;
        a.ad.h(OfficeDocumentRelationships.ar, c);
    };
    SpreadsheetMLMain.wh = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_258_1) { e_258 = { error: e_258_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_258) throw e_258.error; }
        }
        return {
            p1: b
        };
        var e_258, _2;
    };
    SpreadsheetMLMain.abx = function (a, b) {
        a.ad.p(SpreadsheetMLMain.kd, null);
        var c;
        c = b;
        a.ad.h(OfficeDocumentRelationships.ar, c);
    };
    SpreadsheetMLMain.wi = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "ref":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_259_1) { e_259 = { error: e_259_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_259) throw e_259.error; }
        }
        return {
            p1: b
        };
        var e_259, _2;
    };
    SpreadsheetMLMain.aby = function (a, b) {
        a.ad.p(SpreadsheetMLMain.k2, null);
        var c;
        c = b;
        a.ad.h("ref", c);
    };
    SpreadsheetMLMain.wj = function (a, b) {
        b = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(c.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_260_1) { e_260 = { error: e_260_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_260) throw e_260.error; }
        }
        return {
            p1: b
        };
        var e_260, _2;
    };
    SpreadsheetMLMain.abz = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.k3, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = b.value.toString();
            a.ad.h("count", c);
        }
    };
    SpreadsheetMLMain.wk = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_261_1) { e_261 = { error: e_261_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_261) throw e_261.error; }
        }
        return {
            p1: b
        };
        var e_261, _2;
    };
    SpreadsheetMLMain.ab0 = function (a, b) {
        a.ad.p(SpreadsheetMLMain.lb, null);
        var c;
        c = b;
        a.ad.h("val", c);
    };
    SpreadsheetMLMain.wl = function (a, b, c) {
        b = 0;
        c = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "numFmtId":
                        b = parseUInt32_1(d.d, CultureInfo.invariantCulture);
                        break;
                    case "formatCode":
                        c = d.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_262_1) { e_262 = { error: e_262_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_262) throw e_262.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_262, _2;
    };
    SpreadsheetMLMain.ab1 = function (a, b, c) {
        a.ad.p(SpreadsheetMLMain.lf, null);
        var d;
        d = b.toString();
        a.ad.h("numFmtId", d);
        d = c;
        a.ad.h("formatCode", d);
    };
    SpreadsheetMLMain.wm = function (a, b) {
        b = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(c.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_263_1) { e_263 = { error: e_263_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_263) throw e_263.error; }
        }
        return {
            p1: b
        };
        var e_263, _2;
    };
    SpreadsheetMLMain.ab2 = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.lh, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = b.value.toString();
            a.ad.h("count", c);
        }
    };
    SpreadsheetMLMain.wn = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, SpreadsheetMLMain.lj, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.ab3 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, SpreadsheetMLMain.lj, null, b);
    };
    SpreadsheetMLMain.wo = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, SpreadsheetMLMain.lk, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.ab4 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, SpreadsheetMLMain.lk, null, b);
    };
    SpreadsheetMLMain.wp = function (a, b, c, d, e) {
        b = null;
        c = false;
        d = false;
        e = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "name":
                        b = f.d;
                        break;
                    case "icon":
                        c = ST_OnOff.e(f.d);
                        break;
                    case "advise":
                        d = ST_OnOff.e(f.d);
                        break;
                    case "preferPic":
                        e = ST_OnOff.e(f.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_264_1) { e_264 = { error: e_264_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_264) throw e_264.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_264, _2;
    };
    SpreadsheetMLMain.ab5 = function (a, b, c, d, e) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = false; }
        a.ad.p(SpreadsheetMLMain.lm, null);
        var f;
        f = b;
        a.ad.h("name", f);
        if (c != false) {
            f = ST_OnOff.g(c);
            a.ad.h("icon", f);
        }
        if (d != false) {
            f = ST_OnOff.g(d);
            a.ad.h("advise", f);
        }
        if (e != false) {
            f = ST_OnOff.g(e);
            a.ad.h("preferPic", f);
        }
    };
    SpreadsheetMLMain.wq = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_265_1) { e_265 = { error: e_265_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_265) throw e_265.error; }
        }
        var e_265, _2;
    };
    SpreadsheetMLMain.ab6 = function (a) {
        a.ad.p(SpreadsheetMLMain.ln, null);
    };
    SpreadsheetMLMain.wr = function (a, b, c) {
        b = null;
        c = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = d.d;
                        break;
                    case "progId":
                        c = d.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_266_1) { e_266 = { error: e_266_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_266) throw e_266.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_266, _2;
    };
    SpreadsheetMLMain.ab7 = function (a, b, c) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = null; }
        a.ad.p(SpreadsheetMLMain.lo, null);
        var d;
        d = b;
        a.ad.h(OfficeDocumentRelationships.ar, d);
        d = c;
        a.ad.h("progId", d);
    };
    SpreadsheetMLMain.ws = function (a, b) {
        var c = SpreadsheetMLMain.ui(a, SpreadsheetMLMain.ls, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.ab8 = function (a, b) {
        if (b === void 0) { b = true; }
        SpreadsheetMLMain.zx(a, SpreadsheetMLMain.ls, b);
    };
    SpreadsheetMLMain.wt = function (a, b, c, d, e) {
        b = false;
        c = true;
        d = true;
        e = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "applyStyles":
                        b = ST_OnOff.e(f.d);
                        break;
                    case "summaryBelow":
                        c = ST_OnOff.e(f.d);
                        break;
                    case "summaryRight":
                        d = ST_OnOff.e(f.d);
                        break;
                    case "showOutlineSymbols":
                        e = ST_OnOff.e(f.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_267_1) { e_267 = { error: e_267_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_267) throw e_267.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_267, _2;
    };
    SpreadsheetMLMain.ab9 = function (a, b, c, d, e) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = true; }
        if (d === void 0) { d = true; }
        if (e === void 0) { e = true; }
        a.ad.p(SpreadsheetMLMain.lx, null);
        var f;
        if (b != false) {
            f = ST_OnOff.g(b);
            a.ad.h("applyStyles", f);
        }
        if (c != true) {
            f = ST_OnOff.g(c);
            a.ad.h("summaryBelow", f);
        }
        if (d != true) {
            f = ST_OnOff.g(d);
            a.ad.h("summaryRight", f);
        }
        if (e != true) {
            f = ST_OnOff.g(e);
            a.ad.h("showOutlineSymbols", f);
        }
    };
    SpreadsheetMLMain.wu = function (a, b, c, d, e, f, g) {
        b = 0;
        c = 0;
        d = 0;
        e = 0;
        f = 0;
        g = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var h = _1.value;
                switch (h.a.e(a.d)) {
                    case "left":
                        b = parseNumber(h.d, CultureInfo.invariantCulture);
                        break;
                    case "right":
                        c = parseNumber(h.d, CultureInfo.invariantCulture);
                        break;
                    case "top":
                        d = parseNumber(h.d, CultureInfo.invariantCulture);
                        break;
                    case "bottom":
                        e = parseNumber(h.d, CultureInfo.invariantCulture);
                        break;
                    case "header":
                        f = parseNumber(h.d, CultureInfo.invariantCulture);
                        break;
                    case "footer":
                        g = parseNumber(h.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_268_1) { e_268 = { error: e_268_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_268) throw e_268.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g
        };
        var e_268, _2;
    };
    SpreadsheetMLMain.aca = function (a, b, c, d, e, f, g) {
        a.ad.p(SpreadsheetMLMain.lz, null);
        var h;
        h = b.toString();
        a.ad.h("left", h);
        h = c.toString();
        a.ad.h("right", h);
        h = d.toString();
        a.ad.h("top", h);
        h = e.toString();
        a.ad.h("bottom", h);
        h = f.toString();
        a.ad.h("header", h);
        h = g.toString();
        a.ad.h("footer", h);
    };
    SpreadsheetMLMain.wv = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t) {
        b = 1;
        c = null;
        d = null;
        e = 100;
        f = 1;
        g = 1;
        h = 1;
        i = 0;
        j = 0;
        k = true;
        l = false;
        m = false;
        n = 0;
        o = false;
        p = 0;
        q = 600;
        r = 600;
        s = 1;
        t = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var u = _1.value;
                switch (u.a.e(a.d)) {
                    case "paperSize":
                        b = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case "paperHeight":
                        c = u.d;
                        break;
                    case "paperWidth":
                        d = u.d;
                        break;
                    case "scale":
                        e = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case "firstPageNumber":
                        f = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case "fitToWidth":
                        g = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case "fitToHeight":
                        h = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case "pageOrder":
                        i = XmlNamespaceDefinitionBase.b(ST_PageOrder_$type, u.d, i);
                        break;
                    case "orientation":
                        j = XmlNamespaceDefinitionBase.b(ST_Orientation_$type, u.d, j);
                        break;
                    case "usePrinterDefaults":
                        k = ST_OnOff.e(u.d);
                        break;
                    case "blackAndWhite":
                        l = ST_OnOff.e(u.d);
                        break;
                    case "draft":
                        m = ST_OnOff.e(u.d);
                        break;
                    case "cellComments":
                        n = XmlNamespaceDefinitionBase.b(ST_CellComments_$type, u.d, n);
                        break;
                    case "useFirstPageNumber":
                        o = ST_OnOff.e(u.d);
                        break;
                    case "errors":
                        p = XmlNamespaceDefinitionBase.b(ST_PrintError_$type, u.d, p);
                        break;
                    case "horizontalDpi":
                        q = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case "verticalDpi":
                        r = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case "copies":
                        s = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case OfficeDocumentRelationships.ar:
                        t = u.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_269_1) { e_269 = { error: e_269_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_269) throw e_269.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t
        };
        var e_269, _2;
    };
    SpreadsheetMLMain.acb = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t) {
        if (b === void 0) { b = 1; }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = 100; }
        if (f === void 0) { f = 1; }
        if (g === void 0) { g = 1; }
        if (h === void 0) { h = 1; }
        if (i === void 0) { i = 0; }
        if (j === void 0) { j = 0; }
        if (k === void 0) { k = true; }
        if (l === void 0) { l = false; }
        if (m === void 0) { m = false; }
        if (n === void 0) { n = 0; }
        if (o === void 0) { o = false; }
        if (p === void 0) { p = 0; }
        if (q === void 0) { q = 600; }
        if (r === void 0) { r = 600; }
        if (s === void 0) { s = 1; }
        if (t === void 0) { t = null; }
        a.ad.p(SpreadsheetMLMain.l1, null);
        var u;
        if (b != 1) {
            u = b.toString();
            a.ad.h("paperSize", u);
        }
        if (c != null) {
            u = c;
            a.ad.h("paperHeight", u);
        }
        if (d != null) {
            u = d;
            a.ad.h("paperWidth", u);
        }
        if (e != 100) {
            u = e.toString();
            a.ad.h("scale", u);
        }
        if (f != 1) {
            u = f.toString();
            a.ad.h("firstPageNumber", u);
        }
        if (g != 1) {
            u = g.toString();
            a.ad.h("fitToWidth", u);
        }
        if (h != 1) {
            u = h.toString();
            a.ad.h("fitToHeight", u);
        }
        if (i != 0) {
            u = XmlNamespaceDefinitionBase.f(ST_PageOrder_$type, i);
            a.ad.h("pageOrder", u);
        }
        if (j != 0) {
            u = XmlNamespaceDefinitionBase.f(ST_Orientation_$type, j);
            a.ad.h("orientation", u);
        }
        if (k != true) {
            u = ST_OnOff.g(k);
            a.ad.h("usePrinterDefaults", u);
        }
        if (l != false) {
            u = ST_OnOff.g(l);
            a.ad.h("blackAndWhite", u);
        }
        if (m != false) {
            u = ST_OnOff.g(m);
            a.ad.h("draft", u);
        }
        if (n != 0) {
            u = XmlNamespaceDefinitionBase.f(ST_CellComments_$type, n);
            a.ad.h("cellComments", u);
        }
        if (o != false) {
            u = ST_OnOff.g(o);
            a.ad.h("useFirstPageNumber", u);
        }
        if (p != 0) {
            u = XmlNamespaceDefinitionBase.f(ST_PrintError_$type, p);
            a.ad.h("errors", u);
        }
        if (q != 600) {
            u = q.toString();
            a.ad.h("horizontalDpi", u);
        }
        if (r != 600) {
            u = r.toString();
            a.ad.h("verticalDpi", u);
        }
        if (s != 1) {
            u = s.toString();
            a.ad.h("copies", u);
        }
        if (t != null) {
            u = t;
            a.ad.h(OfficeDocumentRelationships.ar, u);
        }
    };
    SpreadsheetMLMain.ww = function (a, b, c) {
        b = true;
        c = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "autoPageBreaks":
                        b = ST_OnOff.e(d.d);
                        break;
                    case "fitToPage":
                        c = ST_OnOff.e(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_270_1) { e_270 = { error: e_270_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_270) throw e_270.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_270, _2;
    };
    SpreadsheetMLMain.acc = function (a, b, c) {
        if (b === void 0) { b = true; }
        if (c === void 0) { c = false; }
        a.ad.p(SpreadsheetMLMain.l2, null);
        var d;
        if (b != true) {
            d = ST_OnOff.g(b);
            a.ad.h("autoPageBreaks", d);
        }
        if (c != false) {
            d = ST_OnOff.g(c);
            a.ad.h("fitToPage", d);
        }
    };
    SpreadsheetMLMain.wx = function (a, b, c, d, e, f) {
        b = 0;
        c = 0;
        d = null;
        e = 3;
        f = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var g = _1.value;
                switch (g.a.e(a.d)) {
                    case "xSplit":
                        b = parseNumber(g.d, CultureInfo.invariantCulture);
                        break;
                    case "ySplit":
                        c = parseNumber(g.d, CultureInfo.invariantCulture);
                        break;
                    case "topLeftCell":
                        d = g.d;
                        break;
                    case "activePane":
                        e = XmlNamespaceDefinitionBase.b(ST_Pane_$type, g.d, e);
                        break;
                    case "state":
                        f = XmlNamespaceDefinitionBase.b(ST_PaneState_$type, g.d, f);
                        break;
                    default: break;
                }
            }
        }
        catch (e_271_1) { e_271 = { error: e_271_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_271) throw e_271.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
        var e_271, _2;
    };
    SpreadsheetMLMain.acd = function (a, b, c, d, e, f) {
        if (b === void 0) { b = 0; }
        if (c === void 0) { c = 0; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = 3; }
        if (f === void 0) { f = 0; }
        a.ad.p(SpreadsheetMLMain.l3, null);
        var g;
        if (b != 0) {
            g = b.toString();
            a.ad.h("xSplit", g);
        }
        if (c != 0) {
            g = c.toString();
            a.ad.h("ySplit", g);
        }
        g = d;
        a.ad.h("topLeftCell", g);
        if (e != 3) {
            g = XmlNamespaceDefinitionBase.f(ST_Pane_$type, e);
            a.ad.h("activePane", g);
        }
        if (f != 0) {
            g = XmlNamespaceDefinitionBase.f(ST_PaneState_$type, f);
            a.ad.h("state", g);
        }
    };
    SpreadsheetMLMain.wy = function (a, b) {
        b = Nullable$1.toNullable(ST_PatternType_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "patternType":
                        b = Nullable$1.toNullable(ST_PatternType_$type, XmlNamespaceDefinitionBase.b(ST_PatternType_$type, c.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_272_1) { e_272 = { error: e_272_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_272) throw e_272.error; }
        }
        return {
            p1: b
        };
        var e_272, _2;
    };
    SpreadsheetMLMain.ace = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(ST_PatternType_$type, null); }
        a.ad.p(SpreadsheetMLMain.l9, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = XmlNamespaceDefinitionBase.f(ST_PatternType_$type, b.value);
            a.ad.h("patternType", c);
        }
    };
    SpreadsheetMLMain.wz = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_273_1) { e_273 = { error: e_273_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_273) throw e_273.error; }
        }
        return {
            p1: b
        };
        var e_273, _2;
    };
    SpreadsheetMLMain.acf = function (a, b) {
        a.ad.p(SpreadsheetMLMain.mf, null);
        var c;
        c = b;
        a.ad.h(OfficeDocumentRelationships.ar, c);
    };
    SpreadsheetMLMain.w0 = function (a, b, c) {
        b = 0;
        c = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "cacheId":
                        b = parseUInt32_1(d.d, CultureInfo.invariantCulture);
                        break;
                    case OfficeDocumentRelationships.ar:
                        c = d.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_274_1) { e_274 = { error: e_274_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_274) throw e_274.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_274, _2;
    };
    SpreadsheetMLMain.acg = function (a, b, c) {
        a.ad.p(SpreadsheetMLMain.mi, null);
        var d;
        d = b.toString();
        a.ad.h("cacheId", d);
        d = c;
        a.ad.h(OfficeDocumentRelationships.ar, d);
    };
    SpreadsheetMLMain.w1 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_275_1) { e_275 = { error: e_275_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_275) throw e_275.error; }
        }
        var e_275, _2;
    };
    SpreadsheetMLMain.ach = function (a) {
        a.ad.p(SpreadsheetMLMain.mj, null);
    };
    SpreadsheetMLMain.w2 = function (a, b, c, d, e, f) {
        b = false;
        c = false;
        d = false;
        e = false;
        f = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var g = _1.value;
                switch (g.a.e(a.d)) {
                    case "horizontalCentered":
                        b = ST_OnOff.e(g.d);
                        break;
                    case "verticalCentered":
                        c = ST_OnOff.e(g.d);
                        break;
                    case "headings":
                        d = ST_OnOff.e(g.d);
                        break;
                    case "gridLines":
                        e = ST_OnOff.e(g.d);
                        break;
                    case "gridLinesSet":
                        f = ST_OnOff.e(g.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_276_1) { e_276 = { error: e_276_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_276) throw e_276.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
        var e_276, _2;
    };
    SpreadsheetMLMain.aci = function (a, b, c, d, e, f) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = true; }
        a.ad.p(SpreadsheetMLMain.mq, null);
        var g;
        if (b != false) {
            g = ST_OnOff.g(b);
            a.ad.h("horizontalCentered", g);
        }
        if (c != false) {
            g = ST_OnOff.g(c);
            a.ad.h("verticalCentered", g);
        }
        if (d != false) {
            g = ST_OnOff.g(d);
            a.ad.h("headings", g);
        }
        if (e != false) {
            g = ST_OnOff.g(e);
            a.ad.h("gridLines", g);
        }
        if (f != true) {
            g = ST_OnOff.g(f);
            a.ad.h("gridLinesSet", g);
        }
    };
    SpreadsheetMLMain.w3 = function (a, b, c, d, e) {
        b = null;
        c = null;
        d = null;
        e = Nullable$1.toNullable(ST_UnsignedShortHex.$, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "password":
                        e = Nullable$1.toNullable(ST_UnsignedShortHex.$, ST_UnsignedShortHex.b(f.d));
                        break;
                    case "sqref":
                        c = f.d;
                        break;
                    case "name":
                        d = f.d;
                        break;
                    case "securityDescriptor":
                        b = f.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_277_1) { e_277 = { error: e_277_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_277) throw e_277.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_277, _2;
    };
    SpreadsheetMLMain.w4 = function (a, b, c, d, e, f, g, h) {
        b = null;
        c = null;
        d = null;
        e = null;
        f = null;
        g = null;
        h = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var i = _1.value;
                switch (i.a.e(a.d)) {
                    case "algorithmName":
                        e = i.d;
                        break;
                    case "hashValue":
                        f = i.d;
                        break;
                    case "saltValue":
                        g = i.d;
                        break;
                    case "spinCount":
                        h = Nullable$1.toNullable(Number_$type, parseUInt32_1(i.d, CultureInfo.invariantCulture));
                        break;
                    case "sqref":
                        c = i.d;
                        break;
                    case "name":
                        d = i.d;
                        break;
                    case "securityDescriptor":
                        b = i.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_278_1) { e_278 = { error: e_278_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_278) throw e_278.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h
        };
        var e_278, _2;
    };
    SpreadsheetMLMain.acj = function (a, b, c, d, e) {
        if (e === void 0) { e = Nullable$1.toNullable(ST_UnsignedShortHex.$, null); }
        a.ad.p(SpreadsheetMLMain.mw, null);
        var f;
        if (nullableNotEquals(e, null)) {
            f = e.value.toString();
            a.ad.h("password", f);
        }
        f = c;
        a.ad.h("sqref", f);
        f = d;
        a.ad.h("name", f);
        if (!stringIsNullOrEmpty(b)) {
            f = b;
            a.ad.h("securityDescriptor", f);
        }
    };
    SpreadsheetMLMain.ack = function (a, b, c, d, e, f, g, h) {
        if (e === void 0) { e = null; }
        if (f === void 0) { f = null; }
        if (g === void 0) { g = null; }
        if (h === void 0) { h = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.mw, null);
        var i;
        if (!stringIsNullOrEmpty(b)) {
            i = b;
            a.ad.h("securityDescriptor", i);
        }
        i = c;
        a.ad.h("sqref", i);
        i = d;
        a.ad.h("name", i);
        if (!stringIsNullOrEmpty(e)) {
            i = e;
            a.ad.h("algorithmName", i);
        }
        if (!stringIsNullOrEmpty(f)) {
            i = f;
            a.ad.h("hashValue", i);
        }
        if (!stringIsNullOrEmpty(g)) {
            i = g;
            a.ad.h("saltValue", i);
        }
        if (nullableNotEquals(h, null)) {
            i = h.value.toString();
            a.ad.h("spinCount", i);
        }
    };
    SpreadsheetMLMain.w5 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_279_1) { e_279 = { error: e_279_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_279) throw e_279.error; }
        }
        var e_279, _2;
    };
    SpreadsheetMLMain.acl = function (a) {
        a.ad.p(SpreadsheetMLMain.mx, null);
    };
    SpreadsheetMLMain.w6 = function (a, b, c) {
        b = Nullable$1.toNullable(Boolean_$type, null);
        c = Nullable$1.toNullable(Boolean_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "locked":
                        b = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(d.d));
                        break;
                    case "hidden":
                        c = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(d.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_280_1) { e_280 = { error: e_280_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_280) throw e_280.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_280, _2;
    };
    SpreadsheetMLMain.acm = function (a, b, c) {
        if (b === void 0) { b = Nullable$1.toNullable(Boolean_$type, null); }
        if (c === void 0) { c = Nullable$1.toNullable(Boolean_$type, null); }
        a.ad.p(SpreadsheetMLMain.my, null);
        var d;
        if (nullableNotEquals(b, null)) {
            d = ST_OnOff.g(b.value);
            a.ad.h("locked", d);
        }
        if (nullableNotEquals(c, null)) {
            d = ST_OnOff.g(c.value);
            a.ad.h("hidden", d);
        }
    };
    SpreadsheetMLMain.w7 = function (a) {
    };
    SpreadsheetMLMain.acn = function (a) {
        a.ad.p(SpreadsheetMLMain.m5, null);
    };
    SpreadsheetMLMain.w8 = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_281_1) { e_281 = { error: e_281_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_281) throw e_281.error; }
        }
        return {
            p1: b
        };
        var e_281, _2;
    };
    SpreadsheetMLMain.aco = function (a, b) {
        a.ad.p(SpreadsheetMLMain.nt, null);
        var c;
        c = b;
        a.ad.h("val", c);
    };
    SpreadsheetMLMain.w9 = function (a, b) {
        b = Nullable$1.toNullable(ST_UnsignedIntHex.$, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "rgb":
                        b = Nullable$1.toNullable(ST_UnsignedIntHex.$, ST_UnsignedIntHex.d(c.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_282_1) { e_282 = { error: e_282_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_282) throw e_282.error; }
        }
        return {
            p1: b
        };
        var e_282, _2;
    };
    SpreadsheetMLMain.acp = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(ST_UnsignedIntHex.$, null); }
        a.ad.p(SpreadsheetMLMain.nv, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = b.value.toString();
            a.ad.h("rgb", c);
        }
    };
    SpreadsheetMLMain.xa = function (a, b) {
        var c = SpreadsheetMLMain.uj(a, SpreadsheetMLMain.nz, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.acq = function (a, b) {
        if (b === void 0) { b = 0; }
        SpreadsheetMLMain.zy(a, SpreadsheetMLMain.nz, b);
    };
    SpreadsheetMLMain.xb = function (a, b, c) {
        var d = SpreadsheetMLMain.um(a, SpreadsheetMLMain.n3, b, c);
        b = d.p2;
        c = d.p3;
        return {
            p1: b,
            p2: c
        };
    };
    SpreadsheetMLMain.acr = function (a, b, c) {
        SpreadsheetMLMain.z1(a, SpreadsheetMLMain.n3, b, c);
    };
    SpreadsheetMLMain.xd = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "r":
                        b = parseUInt32_1(c.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_283_1) { e_283 = { error: e_283_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_283) throw e_283.error; }
        }
        return {
            p1: b
        };
        var e_283, _2;
    };
    SpreadsheetMLMain.act = function (a, b) {
        a.ad.p(SpreadsheetMLMain.n2, null);
        var c;
        c = b.toString();
        a.ad.h("r", c);
    };
    SpreadsheetMLMain.xc = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        if (n === void 0) { n = false; }
        b = Nullable$1.toNullable(Number_$type, null);
        c = null;
        d = 0;
        e = false;
        f = Nullable$1.toNullable(Number_$type, null);
        g = false;
        h = false;
        i = 0;
        j = false;
        k = false;
        l = false;
        m = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var o = _1.value;
                switch (o.a.e(a.d)) {
                    case "r":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(o.d, CultureInfo.invariantCulture));
                        break;
                    case "spans":
                        if (n == false) {
                            c = XmlNamespaceDefinitionBase.e(String_$type, o.d, function (p) { return p; });
                        }
                        break;
                    case "s":
                        d = parseUInt32_1(o.d, CultureInfo.invariantCulture);
                        break;
                    case "customFormat":
                        e = ST_OnOff.e(o.d);
                        break;
                    case "ht":
                        f = Nullable$1.toNullable(Number_$type, parseNumber(o.d, CultureInfo.invariantCulture));
                        break;
                    case "hidden":
                        g = ST_OnOff.e(o.d);
                        break;
                    case "customHeight":
                        h = ST_OnOff.e(o.d);
                        break;
                    case "outlineLevel":
                        i = parseUInt8_1(o.d, CultureInfo.invariantCulture);
                        break;
                    case "collapsed":
                        j = ST_OnOff.e(o.d);
                        break;
                    case "thickTop":
                        k = ST_OnOff.e(o.d);
                        break;
                    case "thickBot":
                        l = ST_OnOff.e(o.d);
                        break;
                    case "ph":
                        m = ST_OnOff.e(o.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_284_1) { e_284 = { error: e_284_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_284) throw e_284.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m
        };
        var e_284, _2;
    };
    SpreadsheetMLMain.acs = function (a, b, c, d, e, f, g, h, i, j, k, l, m) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = 0; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = Nullable$1.toNullable(Number_$type, null); }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = 0; }
        if (j === void 0) { j = false; }
        if (k === void 0) { k = false; }
        if (l === void 0) { l = false; }
        if (m === void 0) { m = false; }
        a.ad.p(SpreadsheetMLMain.n2, null);
        var n;
        if (nullableNotEquals(b, null)) {
            n = b.value.toString();
            a.ad.h("r", n);
        }
        if (c != null) {
            n = stringJoin1(String_$type, " ", c);
            a.ad.h("spans", n);
        }
        if (d != 0) {
            n = d.toString();
            a.ad.h("s", n);
        }
        if (e != false) {
            n = ST_OnOff.g(e);
            a.ad.h("customFormat", n);
        }
        if (nullableNotEquals(f, null)) {
            n = f.value.toString();
            a.ad.h("ht", n);
        }
        if (g != false) {
            n = ST_OnOff.g(g);
            a.ad.h("hidden", n);
        }
        if (h != false) {
            n = ST_OnOff.g(h);
            a.ad.h("customHeight", n);
        }
        if (i != 0) {
            n = i.toString();
            a.ad.h("outlineLevel", n);
        }
        if (j != false) {
            n = ST_OnOff.g(j);
            a.ad.h("collapsed", n);
        }
        if (k != false) {
            n = ST_OnOff.g(k);
            a.ad.h("thickTop", n);
        }
        if (l != false) {
            n = ST_OnOff.g(l);
            a.ad.h("thickBot", n);
        }
        if (m != false) {
            n = ST_OnOff.g(m);
            a.ad.h("ph", n);
        }
    };
    SpreadsheetMLMain.xe = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_285_1) { e_285 = { error: e_285_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_285) throw e_285.error; }
        }
        var e_285, _2;
    };
    SpreadsheetMLMain.acu = function (a) {
        a.ad.p(SpreadsheetMLMain.n4, null);
    };
    SpreadsheetMLMain.xf = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = XmlNamespaceDefinitionBase.b(ST_FontScheme_$type, c.d, b);
                        break;
                    default: break;
                }
            }
        }
        catch (e_286_1) { e_286 = { error: e_286_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_286) throw e_286.error; }
        }
        return {
            p1: b
        };
        var e_286, _2;
    };
    SpreadsheetMLMain.acv = function (a, b) {
        a.ad.p(SpreadsheetMLMain.oc, null);
        var c;
        c = XmlNamespaceDefinitionBase.f(ST_FontScheme_$type, b);
        a.ad.h("val", c);
    };
    SpreadsheetMLMain.xg = function (a, b, c, d, e) {
        b = 3;
        c = null;
        d = 0;
        e = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "pane":
                        b = XmlNamespaceDefinitionBase.b(ST_Pane_$type, f.d, b);
                        break;
                    case "activeCell":
                        c = f.d;
                        break;
                    case "activeCellId":
                        d = parseUInt32_1(f.d, CultureInfo.invariantCulture);
                        break;
                    case "sqref":
                        e = XmlNamespaceDefinitionBase.e(String_$type, f.d, function (g) { return g; });
                        break;
                    default: break;
                }
            }
        }
        catch (e_287_1) { e_287 = { error: e_287_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_287) throw e_287.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_287, _2;
    };
    SpreadsheetMLMain.acw = function (a, b, c, d, e) {
        if (b === void 0) { b = 3; }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = 0; }
        if (e === void 0) { e = null; }
        a.ad.p(SpreadsheetMLMain.of, null);
        var f;
        if (b != 3) {
            f = XmlNamespaceDefinitionBase.f(ST_Pane_$type, b);
            a.ad.h("pane", f);
        }
        f = c;
        a.ad.h("activeCell", f);
        if (d != 0) {
            f = d.toString();
            a.ad.h("activeCellId", f);
        }
        if (e != null) {
            f = stringJoin1(String_$type, " ", e);
            a.ad.h("sqref", f);
        }
    };
    SpreadsheetMLMain.xh = function (a, b) {
        var c = SpreadsheetMLMain.ui(a, SpreadsheetMLMain.oi, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.acx = function (a, b) {
        if (b === void 0) { b = true; }
        SpreadsheetMLMain.zx(a, SpreadsheetMLMain.oi, b);
    };
    SpreadsheetMLMain.xi = function (a, b) {
        b = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "fullCalcOnLoad":
                        b = ST_OnOff.e(c.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_288_1) { e_288 = { error: e_288_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_288) throw e_288.error; }
        }
        return {
            p1: b
        };
        var e_288, _2;
    };
    SpreadsheetMLMain.acy = function (a, b) {
        if (b === void 0) { b = false; }
        a.ad.p(SpreadsheetMLMain.om, null);
        var c;
        if (b != false) {
            c = ST_OnOff.g(b);
            a.ad.h("fullCalcOnLoad", c);
        }
    };
    SpreadsheetMLMain.xj = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_289_1) { e_289 = { error: e_289_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_289) throw e_289.error; }
        }
        var e_289, _2;
    };
    SpreadsheetMLMain.acz = function (a) {
        a.ad.p(SpreadsheetMLMain.on, null);
    };
    SpreadsheetMLMain.xk = function (a, b, c) {
        b = 0;
        c = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "sheetId":
                        b = parseUInt32_1(d.d, CultureInfo.invariantCulture);
                        break;
                    case "refreshError":
                        c = ST_OnOff.e(d.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_290_1) { e_290 = { error: e_290_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_290) throw e_290.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_290, _2;
    };
    SpreadsheetMLMain.ac0 = function (a, b, c) {
        if (c === void 0) { c = false; }
        a.ad.p(SpreadsheetMLMain.on, null);
        var d;
        d = b.toString();
        a.ad.h("sheetId", d);
        if (c != false) {
            d = ST_OnOff.g(c);
            a.ad.h("refreshError", d);
        }
    };
    SpreadsheetMLMain.xl = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_291_1) { e_291 = { error: e_291_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_291) throw e_291.error; }
        }
        var e_291, _2;
    };
    SpreadsheetMLMain.ac1 = function (a) {
        a.ad.p(SpreadsheetMLMain.oo, null);
    };
    SpreadsheetMLMain.xm = function (a, b, c, d, e) {
        b = null;
        c = 0;
        d = 0;
        e = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "name":
                        b = f.d;
                        break;
                    case "sheetId":
                        c = parseUInt32_1(f.d, CultureInfo.invariantCulture);
                        break;
                    case "state":
                        d = XmlNamespaceDefinitionBase.b(ST_SheetState_$type, f.d, d);
                        break;
                    case OfficeDocumentRelationships.ar:
                        e = f.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_292_1) { e_292 = { error: e_292_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_292) throw e_292.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_292, _2;
    };
    SpreadsheetMLMain.ac2 = function (a, b, c, d, e) {
        a.ad.p(SpreadsheetMLMain.ok, null);
        var f;
        f = b;
        a.ad.h("name", f);
        f = c.toString();
        a.ad.h("sheetId", f);
        if (d != 0) {
            f = XmlNamespaceDefinitionBase.f(ST_SheetState_$type, d);
            a.ad.h("state", f);
        }
        f = e;
        a.ad.h(OfficeDocumentRelationships.ar, f);
    };
    SpreadsheetMLMain.xn = function (a, b, c, d, e, f, g, h, i, j) {
        c = 8;
        d = Nullable$1.toNullable(Number_$type, null);
        b = 0;
        e = false;
        f = false;
        g = false;
        h = false;
        i = 0;
        j = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var k = _1.value;
                switch (k.a.e(a.d)) {
                    case "baseColWidth":
                        c = parseUInt32_1(k.d, CultureInfo.invariantCulture);
                        break;
                    case "defaultColWidth":
                        d = Nullable$1.toNullable(Number_$type, parseNumber(k.d, CultureInfo.invariantCulture));
                        break;
                    case "defaultRowHeight":
                        b = parseNumber(k.d, CultureInfo.invariantCulture);
                        break;
                    case "customHeight":
                        e = ST_OnOff.e(k.d);
                        break;
                    case "zeroHeight":
                        f = ST_OnOff.e(k.d);
                        break;
                    case "thickTop":
                        g = ST_OnOff.e(k.d);
                        break;
                    case "thickBottom":
                        h = ST_OnOff.e(k.d);
                        break;
                    case "outlineLevelRow":
                        i = parseUInt8_1(k.d, CultureInfo.invariantCulture);
                        break;
                    case "outlineLevelCol":
                        j = parseUInt8_1(k.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_293_1) { e_293 = { error: e_293_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_293) throw e_293.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j
        };
        var e_293, _2;
    };
    SpreadsheetMLMain.ac3 = function (a, b, c, d, e, f, g, h, i, j) {
        if (c === void 0) { c = 8; }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = 0; }
        if (j === void 0) { j = 0; }
        a.ad.p(SpreadsheetMLMain.op, null);
        var k;
        if (c != 8) {
            k = c.toString();
            a.ad.h("baseColWidth", k);
        }
        if (nullableNotEquals(d, null)) {
            k = d.value.toString();
            a.ad.h("defaultColWidth", k);
        }
        k = b.toString();
        a.ad.h("defaultRowHeight", k);
        if (e != false) {
            k = ST_OnOff.g(e);
            a.ad.h("customHeight", k);
        }
        if (f != false) {
            k = ST_OnOff.g(f);
            a.ad.h("zeroHeight", k);
        }
        if (g != false) {
            k = ST_OnOff.g(g);
            a.ad.h("thickTop", k);
        }
        if (h != false) {
            k = ST_OnOff.g(h);
            a.ad.h("thickBottom", k);
        }
        if (i != 0) {
            k = i.toString();
            a.ad.h("outlineLevelRow", k);
        }
        if (j != 0) {
            k = j.toString();
            a.ad.h("outlineLevelCol", k);
        }
    };
    SpreadsheetMLMain.xo = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_294_1) { e_294 = { error: e_294_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_294) throw e_294.error; }
        }
        return {
            p1: b
        };
        var e_294, _2;
    };
    SpreadsheetMLMain.ac4 = function (a, b) {
        a.ad.p(SpreadsheetMLMain.or, null);
        var c;
        c = b;
        a.ad.h("val", c);
    };
    SpreadsheetMLMain.xp = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_295_1) { e_295 = { error: e_295_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_295) throw e_295.error; }
        }
        var e_295, _2;
    };
    SpreadsheetMLMain.ac5 = function (a) {
        a.ad.p(SpreadsheetMLMain.os, null);
    };
    SpreadsheetMLMain.xq = function (a, b, c, d, e, f, g, h, i, j) {
        b = false;
        c = false;
        d = null;
        e = false;
        f = false;
        g = true;
        h = null;
        i = false;
        j = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var k = _1.value;
                switch (k.a.e(a.d)) {
                    case "syncHorizontal":
                        b = ST_OnOff.e(k.d);
                        break;
                    case "syncVertical":
                        c = ST_OnOff.e(k.d);
                        break;
                    case "syncRef":
                        d = k.d;
                        break;
                    case "transitionEvaluation":
                        e = ST_OnOff.e(k.d);
                        break;
                    case "transitionEntry":
                        f = ST_OnOff.e(k.d);
                        break;
                    case "published":
                        g = ST_OnOff.e(k.d);
                        break;
                    case "codeName":
                        h = k.d;
                        break;
                    case "filterMode":
                        i = ST_OnOff.e(k.d);
                        break;
                    case "enableFormatConditionsCalculation":
                        j = ST_OnOff.e(k.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_296_1) { e_296 = { error: e_296_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_296) throw e_296.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j
        };
        var e_296, _2;
    };
    SpreadsheetMLMain.ac6 = function (a, b, c, d, e, f, g, h, i, j) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = true; }
        if (h === void 0) { h = null; }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = true; }
        a.ad.p(SpreadsheetMLMain.ot, null);
        var k;
        if (b != false) {
            k = ST_OnOff.g(b);
            a.ad.h("syncHorizontal", k);
        }
        if (c != false) {
            k = ST_OnOff.g(c);
            a.ad.h("syncVertical", k);
        }
        k = d;
        a.ad.h("syncRef", k);
        if (e != false) {
            k = ST_OnOff.g(e);
            a.ad.h("transitionEvaluation", k);
        }
        if (f != false) {
            k = ST_OnOff.g(f);
            a.ad.h("transitionEntry", k);
        }
        if (g != true) {
            k = ST_OnOff.g(g);
            a.ad.h("published", k);
        }
        k = h;
        a.ad.h("codeName", k);
        if (i != false) {
            k = ST_OnOff.g(i);
            a.ad.h("filterMode", k);
        }
        if (j != true) {
            k = ST_OnOff.g(j);
            a.ad.h("enableFormatConditionsCalculation", k);
        }
    };
    SpreadsheetMLMain.xr = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r) {
        b = Nullable$1.toNullable(ST_UnsignedShortHex.$, null);
        c = false;
        d = false;
        e = false;
        f = true;
        g = true;
        h = true;
        i = true;
        j = true;
        k = true;
        l = true;
        m = true;
        n = false;
        o = true;
        p = true;
        q = true;
        r = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var s = _1.value;
                switch (s.a.e(a.d)) {
                    case "password":
                        b = Nullable$1.toNullable(ST_UnsignedShortHex.$, ST_UnsignedShortHex.b(s.d));
                        break;
                    case "sheet":
                        c = ST_OnOff.e(s.d);
                        break;
                    case "objects":
                        d = ST_OnOff.e(s.d);
                        break;
                    case "scenarios":
                        e = ST_OnOff.e(s.d);
                        break;
                    case "formatCells":
                        f = ST_OnOff.e(s.d);
                        break;
                    case "formatColumns":
                        g = ST_OnOff.e(s.d);
                        break;
                    case "formatRows":
                        h = ST_OnOff.e(s.d);
                        break;
                    case "insertColumns":
                        i = ST_OnOff.e(s.d);
                        break;
                    case "insertRows":
                        j = ST_OnOff.e(s.d);
                        break;
                    case "insertHyperlinks":
                        k = ST_OnOff.e(s.d);
                        break;
                    case "deleteColumns":
                        l = ST_OnOff.e(s.d);
                        break;
                    case "deleteRows":
                        m = ST_OnOff.e(s.d);
                        break;
                    case "selectLockedCells":
                        n = ST_OnOff.e(s.d);
                        break;
                    case "sort":
                        o = ST_OnOff.e(s.d);
                        break;
                    case "autoFilter":
                        p = ST_OnOff.e(s.d);
                        break;
                    case "pivotTables":
                        q = ST_OnOff.e(s.d);
                        break;
                    case "selectUnlockedCells":
                        r = ST_OnOff.e(s.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_297_1) { e_297 = { error: e_297_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_297) throw e_297.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r
        };
        var e_297, _2;
    };
    SpreadsheetMLMain.ac7 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r) {
        if (b === void 0) { b = Nullable$1.toNullable(ST_UnsignedShortHex.$, null); }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = true; }
        if (g === void 0) { g = true; }
        if (h === void 0) { h = true; }
        if (i === void 0) { i = true; }
        if (j === void 0) { j = true; }
        if (k === void 0) { k = true; }
        if (l === void 0) { l = true; }
        if (m === void 0) { m = true; }
        if (n === void 0) { n = false; }
        if (o === void 0) { o = true; }
        if (p === void 0) { p = true; }
        if (q === void 0) { q = true; }
        if (r === void 0) { r = false; }
        a.ad.p(SpreadsheetMLMain.ou, null);
        var s;
        if (nullableNotEquals(b, null)) {
            s = b.value.toString();
            a.ad.h("password", s);
        }
        if (c != false) {
            s = ST_OnOff.g(c);
            a.ad.h("sheet", s);
            if (d != false) {
                s = ST_OnOff.g(d);
                a.ad.h("objects", s);
            }
            if (e != false) {
                s = ST_OnOff.g(e);
                a.ad.h("scenarios", s);
            }
        }
        if (f != true) {
            s = ST_OnOff.g(f);
            a.ad.h("formatCells", s);
        }
        if (g != true) {
            s = ST_OnOff.g(g);
            a.ad.h("formatColumns", s);
        }
        if (h != true) {
            s = ST_OnOff.g(h);
            a.ad.h("formatRows", s);
        }
        if (i != true) {
            s = ST_OnOff.g(i);
            a.ad.h("insertColumns", s);
        }
        if (j != true) {
            s = ST_OnOff.g(j);
            a.ad.h("insertRows", s);
        }
        if (k != true) {
            s = ST_OnOff.g(k);
            a.ad.h("insertHyperlinks", s);
        }
        if (l != true) {
            s = ST_OnOff.g(l);
            a.ad.h("deleteColumns", s);
        }
        if (m != true) {
            s = ST_OnOff.g(m);
            a.ad.h("deleteRows", s);
        }
        if (n != false) {
            s = ST_OnOff.g(n);
            a.ad.h("selectLockedCells", s);
        }
        if (o != true) {
            s = ST_OnOff.g(o);
            a.ad.h("sort", s);
        }
        if (p != true) {
            s = ST_OnOff.g(p);
            a.ad.h("autoFilter", s);
        }
        if (q != true) {
            s = ST_OnOff.g(q);
            a.ad.h("pivotTables", s);
        }
        if (r != false) {
            s = ST_OnOff.g(r);
            a.ad.h("selectUnlockedCells", s);
        }
    };
    SpreadsheetMLMain.b3 = function (a) {
        if (a.d._z == 1) {
            return true;
        }
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    case "algorithmName":
                    case "hashValue":
                    case "saltValue":
                    case "spinCount": return true;
                    case "password": return false;
                }
            }
        }
        catch (e_298_1) { e_298 = { error: e_298_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_298) throw e_298.error; }
        }
        return false;
        var e_298, _2;
    };
    SpreadsheetMLMain.xs = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u) {
        b = null;
        c = null;
        d = null;
        e = Nullable$1.toNullable(Number_$type, null);
        f = false;
        g = false;
        h = false;
        i = true;
        j = true;
        k = true;
        l = true;
        m = true;
        n = true;
        o = true;
        p = true;
        q = false;
        r = true;
        s = true;
        t = true;
        u = false;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var v = _1.value;
                switch (v.a.e(a.d)) {
                    case "algorithmName":
                        b = v.d;
                        break;
                    case "hashValue":
                        c = v.d;
                        break;
                    case "saltValue":
                        d = v.d;
                        break;
                    case "spinCount":
                        e = Nullable$1.toNullable(Number_$type, parseUInt32_1(v.d, CultureInfo.invariantCulture));
                        break;
                    case "sheet":
                        f = ST_OnOff.e(v.d);
                        break;
                    case "objects":
                        g = ST_OnOff.e(v.d);
                        break;
                    case "scenarios":
                        h = ST_OnOff.e(v.d);
                        break;
                    case "formatCells":
                        i = ST_OnOff.e(v.d);
                        break;
                    case "formatColumns":
                        j = ST_OnOff.e(v.d);
                        break;
                    case "formatRows":
                        k = ST_OnOff.e(v.d);
                        break;
                    case "insertColumns":
                        l = ST_OnOff.e(v.d);
                        break;
                    case "insertRows":
                        m = ST_OnOff.e(v.d);
                        break;
                    case "insertHyperlinks":
                        n = ST_OnOff.e(v.d);
                        break;
                    case "deleteColumns":
                        o = ST_OnOff.e(v.d);
                        break;
                    case "deleteRows":
                        p = ST_OnOff.e(v.d);
                        break;
                    case "selectLockedCells":
                        q = ST_OnOff.e(v.d);
                        break;
                    case "sort":
                        r = ST_OnOff.e(v.d);
                        break;
                    case "autoFilter":
                        s = ST_OnOff.e(v.d);
                        break;
                    case "pivotTables":
                        t = ST_OnOff.e(v.d);
                        break;
                    case "selectUnlockedCells":
                        u = ST_OnOff.e(v.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_299_1) { e_299 = { error: e_299_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_299) throw e_299.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t,
            p20: u
        };
        var e_299, _2;
    };
    SpreadsheetMLMain.ac8 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u) {
        if (b === void 0) { b = null; }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = true; }
        if (j === void 0) { j = true; }
        if (k === void 0) { k = true; }
        if (l === void 0) { l = true; }
        if (m === void 0) { m = true; }
        if (n === void 0) { n = true; }
        if (o === void 0) { o = true; }
        if (p === void 0) { p = true; }
        if (q === void 0) { q = false; }
        if (r === void 0) { r = true; }
        if (s === void 0) { s = true; }
        if (t === void 0) { t = true; }
        if (u === void 0) { u = false; }
        a.ad.p(SpreadsheetMLMain.ou, null);
        var v;
        v = b;
        a.ad.h("algorithmName", v);
        v = c;
        a.ad.h("hashValue", v);
        v = d;
        a.ad.h("saltValue", v);
        if (nullableNotEquals(e, null)) {
            v = e.value.toString();
            a.ad.h("spinCount", v);
        }
        if (f != false) {
            v = ST_OnOff.g(f);
            a.ad.h("sheet", v);
        }
        if (g != false) {
            v = ST_OnOff.g(g);
            a.ad.h("objects", v);
        }
        if (h != false) {
            v = ST_OnOff.g(h);
            a.ad.h("scenarios", v);
        }
        if (i != true) {
            v = ST_OnOff.g(i);
            a.ad.h("formatCells", v);
        }
        if (j != true) {
            v = ST_OnOff.g(j);
            a.ad.h("formatColumns", v);
        }
        if (k != true) {
            v = ST_OnOff.g(k);
            a.ad.h("formatRows", v);
        }
        if (l != true) {
            v = ST_OnOff.g(l);
            a.ad.h("insertColumns", v);
        }
        if (m != true) {
            v = ST_OnOff.g(m);
            a.ad.h("insertRows", v);
        }
        if (n != true) {
            v = ST_OnOff.g(n);
            a.ad.h("insertHyperlinks", v);
        }
        if (o != true) {
            v = ST_OnOff.g(o);
            a.ad.h("deleteColumns", v);
        }
        if (p != true) {
            v = ST_OnOff.g(p);
            a.ad.h("deleteRows", v);
        }
        if (q != false) {
            v = ST_OnOff.g(q);
            a.ad.h("selectLockedCells", v);
        }
        if (r != true) {
            v = ST_OnOff.g(r);
            a.ad.h("sort", v);
        }
        if (s != true) {
            v = ST_OnOff.g(s);
            a.ad.h("autoFilter", v);
        }
        if (t != true) {
            v = ST_OnOff.g(t);
            a.ad.h("pivotTables", v);
        }
        if (u != false) {
            v = ST_OnOff.g(u);
            a.ad.h("selectUnlockedCells", v);
        }
    };
    SpreadsheetMLMain.xt = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_300_1) { e_300 = { error: e_300_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_300) throw e_300.error; }
        }
        var e_300, _2;
    };
    SpreadsheetMLMain.ac9 = function (a) {
        a.ad.p(SpreadsheetMLMain.ov, null);
    };
    SpreadsheetMLMain.xu = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t) {
        c = false;
        d = false;
        e = true;
        f = true;
        g = true;
        h = false;
        i = false;
        j = true;
        k = true;
        l = true;
        m = true;
        n = 0;
        o = null;
        p = 64;
        q = 100;
        r = 0;
        s = 0;
        t = 0;
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var u = _1.value;
                switch (u.a.e(a.d)) {
                    case "windowProtection":
                        c = ST_OnOff.e(u.d);
                        break;
                    case "showFormulas":
                        d = ST_OnOff.e(u.d);
                        break;
                    case "showGridLines":
                        e = ST_OnOff.e(u.d);
                        break;
                    case "showRowColHeaders":
                        f = ST_OnOff.e(u.d);
                        break;
                    case "showZeros":
                        g = ST_OnOff.e(u.d);
                        break;
                    case "rightToLeft":
                        h = ST_OnOff.e(u.d);
                        break;
                    case "tabSelected":
                        i = ST_OnOff.e(u.d);
                        break;
                    case "showRuler":
                        j = ST_OnOff.e(u.d);
                        break;
                    case "showOutlineSymbols":
                        k = ST_OnOff.e(u.d);
                        break;
                    case "defaultGridColor":
                        l = ST_OnOff.e(u.d);
                        break;
                    case "showWhiteSpace":
                        m = ST_OnOff.e(u.d);
                        break;
                    case "view":
                        n = XmlNamespaceDefinitionBase.b(ST_SheetViewType_$type, u.d, n);
                        break;
                    case "topLeftCell":
                        o = u.d;
                        break;
                    case "colorId":
                        p = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case "zoomScale":
                        q = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case "zoomScaleNormal":
                        r = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case "zoomScaleSheetLayoutView":
                        s = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case "zoomScalePageLayoutView":
                        t = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    case "workbookViewId":
                        b = parseUInt32_1(u.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_301_1) { e_301 = { error: e_301_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_301) throw e_301.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t
        };
        var e_301, _2;
    };
    SpreadsheetMLMain.ada = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t) {
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = true; }
        if (f === void 0) { f = true; }
        if (g === void 0) { g = true; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = true; }
        if (k === void 0) { k = true; }
        if (l === void 0) { l = true; }
        if (m === void 0) { m = true; }
        if (n === void 0) { n = 0; }
        if (o === void 0) { o = null; }
        if (p === void 0) { p = 64; }
        if (q === void 0) { q = 100; }
        if (r === void 0) { r = 0; }
        if (s === void 0) { s = 0; }
        if (t === void 0) { t = 0; }
        a.ad.p(SpreadsheetMLMain.ow, null);
        var u;
        if (c != false) {
            u = ST_OnOff.g(c);
            a.ad.h("windowProtection", u);
        }
        if (d != false) {
            u = ST_OnOff.g(d);
            a.ad.h("showFormulas", u);
        }
        if (e != true) {
            u = ST_OnOff.g(e);
            a.ad.h("showGridLines", u);
        }
        if (f != true) {
            u = ST_OnOff.g(f);
            a.ad.h("showRowColHeaders", u);
        }
        if (g != true) {
            u = ST_OnOff.g(g);
            a.ad.h("showZeros", u);
        }
        if (h != false) {
            u = ST_OnOff.g(h);
            a.ad.h("rightToLeft", u);
        }
        if (i != false) {
            u = ST_OnOff.g(i);
            a.ad.h("tabSelected", u);
        }
        if (j != true) {
            u = ST_OnOff.g(j);
            a.ad.h("showRuler", u);
        }
        if (k != true) {
            u = ST_OnOff.g(k);
            a.ad.h("showOutlineSymbols", u);
        }
        if (l != true) {
            u = ST_OnOff.g(l);
            a.ad.h("defaultGridColor", u);
        }
        if (m != true) {
            u = ST_OnOff.g(m);
            a.ad.h("showWhiteSpace", u);
        }
        if (n != 0) {
            u = XmlNamespaceDefinitionBase.f(ST_SheetViewType_$type, n);
            a.ad.h("view", u);
        }
        u = o;
        a.ad.h("topLeftCell", u);
        if (p != 64) {
            u = p.toString();
            a.ad.h("colorId", u);
        }
        if (q != 100) {
            u = q.toString();
            a.ad.h("zoomScale", u);
        }
        if (r != 0) {
            u = r.toString();
            a.ad.h("zoomScaleNormal", u);
        }
        if (s != 0) {
            u = s.toString();
            a.ad.h("zoomScaleSheetLayoutView", u);
        }
        if (t != 0) {
            u = t.toString();
            a.ad.h("zoomScalePageLayoutView", u);
        }
        u = b.toString();
        a.ad.h("workbookViewId", u);
    };
    SpreadsheetMLMain.xv = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_302_1) { e_302 = { error: e_302_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_302) throw e_302.error; }
        }
        var e_302, _2;
    };
    SpreadsheetMLMain.adb = function (a) {
        a.ad.p(SpreadsheetMLMain.ox, null);
    };
    SpreadsheetMLMain.xw = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_303_1) { e_303 = { error: e_303_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_303) throw e_303.error; }
        }
        var e_303, _2;
    };
    SpreadsheetMLMain.adc = function (a) {
        a.ad.p(SpreadsheetMLMain.pt, null);
    };
    SpreadsheetMLMain.xx = function (a, b, c, d, e, f, g, h) {
        c = false;
        d = 0;
        b = null;
        e = null;
        f = Nullable$1.toNullable(Number_$type, null);
        g = 0;
        h = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var i = _1.value;
                switch (i.a.e(a.d)) {
                    case "descending":
                        c = ST_OnOff.e(i.d);
                        break;
                    case "sortBy":
                        d = XmlNamespaceDefinitionBase.b(ST_SortBy_$type, i.d, d);
                        break;
                    case "ref":
                        b = i.d;
                        break;
                    case "customList":
                        e = i.d;
                        break;
                    case "dxfId":
                        f = Nullable$1.toNullable(Number_$type, parseUInt32_1(i.d, CultureInfo.invariantCulture));
                        break;
                    case "iconSet":
                        g = XmlNamespaceDefinitionBase.b(ST_IconSetType_$type, i.d, g);
                        break;
                    case "iconId":
                        h = Nullable$1.toNullable(Number_$type, parseUInt32_1(i.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_304_1) { e_304 = { error: e_304_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_304) throw e_304.error; }
        }
        if (g <= 16) {
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h
        };
        var e_304, _2;
    };
    SpreadsheetMLMain.add = function (a, b, c, d, e, f, g, h) {
        if (c === void 0) { c = false; }
        if (d === void 0) { d = 0; }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = Nullable$1.toNullable(Number_$type, null); }
        if (g === void 0) { g = 0; }
        if (h === void 0) { h = Nullable$1.toNullable(Number_$type, null); }
        if (g <= 16) {
            SpreadsheetMLMain.ade(a, SpreadsheetMLMain.pz, null, b, c, d, e, f, g, h);
        }
        else {
            a.ad.g([new AlternateContentChoice(0, SpreadsheetML2009Main.an, function () { return SpreadsheetMLMain.ade(a, SpreadsheetML2009Main.cl, null, b, c, d, e, f, g, h); })]);
        }
    };
    SpreadsheetMLMain.ade = function (a, b, c, d, e, f, g, h, i, j) {
        if (e === void 0) { e = false; }
        if (f === void 0) { f = 0; }
        if (g === void 0) { g = null; }
        if (h === void 0) { h = Nullable$1.toNullable(Number_$type, null); }
        if (i === void 0) { i = 0; }
        if (j === void 0) { j = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(b, c);
        var k;
        if (e != false) {
            k = ST_OnOff.g(e);
            a.ad.h("descending", k);
        }
        if (f != 0) {
            k = XmlNamespaceDefinitionBase.f(ST_SortBy_$type, f);
            a.ad.h("sortBy", k);
        }
        k = d;
        a.ad.h("ref", k);
        k = g;
        a.ad.h("customList", k);
        if (nullableNotEquals(h, null)) {
            k = h.value.toString();
            a.ad.h("dxfId", k);
        }
        if (i != 0) {
            k = XmlNamespaceDefinitionBase.f(ST_IconSetType_$type, i);
            a.ad.h("iconSet", k);
        }
        if (nullableNotEquals(j, null)) {
            k = j.value.toString();
            a.ad.h("iconId", k);
        }
        a.ad.k();
    };
    SpreadsheetMLMain.xy = function (a, b, c, d, e) {
        c = false;
        d = false;
        e = 0;
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "columnSort":
                        c = ST_OnOff.e(f.d);
                        break;
                    case "caseSensitive":
                        d = ST_OnOff.e(f.d);
                        break;
                    case "sortMethod":
                        e = XmlNamespaceDefinitionBase.b(ST_SortMethod_$type, f.d, e);
                        break;
                    case "ref":
                        b = f.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_305_1) { e_305 = { error: e_305_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_305) throw e_305.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_305, _2;
    };
    SpreadsheetMLMain.adf = function (a, b, c, d, e) {
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = 0; }
        a.ad.p(SpreadsheetMLMain.p1, null);
        var f;
        if (c != false) {
            f = ST_OnOff.g(c);
            a.ad.h("columnSort", f);
        }
        if (d != false) {
            f = ST_OnOff.g(d);
            a.ad.h("caseSensitive", f);
        }
        if (e != 0) {
            f = XmlNamespaceDefinitionBase.f(ST_SortMethod_$type, e);
            a.ad.h("sortMethod", f);
        }
        f = b;
        a.ad.h("ref", f);
    };
    SpreadsheetMLMain.xz = function (a, b, c) {
        b = Nullable$1.toNullable(Number_$type, null);
        c = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var d = _1.value;
                switch (d.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(d.d, CultureInfo.invariantCulture));
                        break;
                    case "uniqueCount":
                        c = Nullable$1.toNullable(Number_$type, parseUInt32_1(d.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_306_1) { e_306 = { error: e_306_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_306) throw e_306.error; }
        }
        return {
            p1: b,
            p2: c
        };
        var e_306, _2;
    };
    SpreadsheetMLMain.adg = function (a, b, c) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.p5, null);
        var d;
        if (nullableNotEquals(b, null)) {
            d = b.value.toString();
            a.ad.h("count", d);
        }
        if (nullableNotEquals(c, null)) {
            d = c.value.toString();
            a.ad.h("uniqueCount", d);
        }
    };
    SpreadsheetMLMain.x0 = function (a, b) {
        var c = SpreadsheetMLMain.uj(a, SpreadsheetMLMain.p6, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.adh = function (a, b) {
        if (b === void 0) { b = 0; }
        SpreadsheetMLMain.zy(a, SpreadsheetMLMain.p6, b);
    };
    SpreadsheetMLMain.x1 = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "position":
                        b = parseNumber(c.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_307_1) { e_307 = { error: e_307_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_307) throw e_307.error; }
        }
        return {
            p1: b
        };
        var e_307, _2;
    };
    SpreadsheetMLMain.adi = function (a, b) {
        a.ad.p(SpreadsheetMLMain.qa, null);
        var c;
        c = b.toString();
        a.ad.h("position", c);
    };
    SpreadsheetMLMain.x2 = function (a, b) {
        var c = SpreadsheetMLMain.ui(a, SpreadsheetMLMain.qc, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.adj = function (a, b) {
        if (b === void 0) { b = true; }
        SpreadsheetMLMain.zx(a, SpreadsheetMLMain.qc, b);
    };
    SpreadsheetMLMain.x3 = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_308_1) { e_308 = { error: e_308_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_308) throw e_308.error; }
        }
        var e_308, _2;
    };
    SpreadsheetMLMain.adk = function (a) {
        a.ad.p(SpreadsheetMLMain.qe, null);
        var b = a.d._z;
        a.ad.l(SpreadsheetMLMain.ao);
    };
    SpreadsheetMLMain.x4 = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = parseNumber(c.d, CultureInfo.invariantCulture);
                        break;
                    default: break;
                }
            }
        }
        catch (e_309_1) { e_309 = { error: e_309_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_309) throw e_309.error; }
        }
        return {
            p1: b
        };
        var e_309, _2;
    };
    SpreadsheetMLMain.adl = function (a, b) {
        a.ad.p(SpreadsheetMLMain.qk, null);
        var c;
        c = b.toString();
        a.ad.h("val", c);
    };
    SpreadsheetMLMain.x5 = function (a, b, c, d, e, f) {
        var g = SpreadsheetMLMain.uk(a, SpreadsheetMLMain.qn, b, c, d, e, f);
        b = g.p2;
        c = g.p3;
        d = g.p4;
        e = g.p5;
        f = g.p6;
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
    };
    SpreadsheetMLMain.adm = function (a, b, c, d, e, f) {
        SpreadsheetMLMain.zz(a, SpreadsheetMLMain.qn, b, c, d, e, f);
    };
    SpreadsheetMLMain.x6 = function (a, b, c, d, e, f, g, h, i, j, k, l, m) {
        b = 0;
        c = null;
        d = null;
        e = 0;
        f = null;
        g = Nullable$1.toNullable(Number_$type, null);
        h = Nullable$1.toNullable(Number_$type, null);
        i = Nullable$1.toNullable(Number_$type, null);
        j = Nullable$1.toNullable(Number_$type, null);
        k = null;
        l = null;
        m = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var n = _1.value;
                switch (n.a.e(a.d)) {
                    case "id":
                        b = parseUInt32_1(n.d, CultureInfo.invariantCulture);
                        break;
                    case "uniqueName":
                        c = n.d;
                        break;
                    case "name":
                        d = n.d;
                        break;
                    case "totalsRowFunction":
                        e = XmlNamespaceDefinitionBase.b(ST_TotalsRowFunction_$type, n.d, e);
                        break;
                    case "totalsRowLabel":
                        f = n.d;
                        break;
                    case "queryTableFieldId":
                        g = Nullable$1.toNullable(Number_$type, parseUInt32_1(n.d, CultureInfo.invariantCulture));
                        break;
                    case "headerRowDxfId":
                        h = Nullable$1.toNullable(Number_$type, parseUInt32_1(n.d, CultureInfo.invariantCulture));
                        break;
                    case "dataDxfId":
                        i = Nullable$1.toNullable(Number_$type, parseUInt32_1(n.d, CultureInfo.invariantCulture));
                        break;
                    case "totalsRowDxfId":
                        j = Nullable$1.toNullable(Number_$type, parseUInt32_1(n.d, CultureInfo.invariantCulture));
                        break;
                    case "headerRowCellStyle":
                        k = n.d;
                        break;
                    case "dataCellStyle":
                        l = n.d;
                        break;
                    case "totalsRowCellStyle":
                        m = n.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_310_1) { e_310 = { error: e_310_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_310) throw e_310.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m
        };
        var e_310, _2;
    };
    SpreadsheetMLMain.adn = function (a, b, c, d, e, f, g, h, i, j, k, l, m) {
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        if (e === void 0) { e = 0; }
        if (f === void 0) { f = null; }
        if (g === void 0) { g = Nullable$1.toNullable(Number_$type, null); }
        if (h === void 0) { h = Nullable$1.toNullable(Number_$type, null); }
        if (i === void 0) { i = Nullable$1.toNullable(Number_$type, null); }
        if (j === void 0) { j = Nullable$1.toNullable(Number_$type, null); }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = null; }
        if (m === void 0) { m = null; }
        a.ad.p(SpreadsheetMLMain.qr, null);
        var n;
        n = b.toString();
        a.ad.h("id", n);
        n = c;
        a.ad.h("uniqueName", n);
        n = d;
        a.ad.h("name", n);
        if (e != 0) {
            n = XmlNamespaceDefinitionBase.f(ST_TotalsRowFunction_$type, e);
            a.ad.h("totalsRowFunction", n);
        }
        n = f;
        a.ad.h("totalsRowLabel", n);
        if (nullableNotEquals(g, null)) {
            n = g.value.toString();
            a.ad.h("queryTableFieldId", n);
        }
        if (nullableNotEquals(h, null)) {
            n = h.value.toString();
            a.ad.h("headerRowDxfId", n);
        }
        if (nullableNotEquals(i, null)) {
            n = i.value.toString();
            a.ad.h("dataDxfId", n);
        }
        if (nullableNotEquals(j, null)) {
            n = j.value.toString();
            a.ad.h("totalsRowDxfId", n);
        }
        n = k;
        a.ad.h("headerRowCellStyle", n);
        n = l;
        a.ad.h("dataCellStyle", n);
        n = m;
        a.ad.h("totalsRowCellStyle", n);
    };
    SpreadsheetMLMain.x7 = function (a, b) {
        b = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(c.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_311_1) { e_311 = { error: e_311_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_311) throw e_311.error; }
        }
        return {
            p1: b
        };
        var e_311, _2;
    };
    SpreadsheetMLMain.ado = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.qs, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = b.value.toString();
            a.ad.h("count", c);
        }
    };
    SpreadsheetMLMain.x8 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w) {
        b = 0;
        c = null;
        d = null;
        e = null;
        f = null;
        g = 0;
        h = 1;
        i = false;
        j = false;
        k = 0;
        l = true;
        m = false;
        n = Nullable$1.toNullable(Number_$type, null);
        o = Nullable$1.toNullable(Number_$type, null);
        p = Nullable$1.toNullable(Number_$type, null);
        q = Nullable$1.toNullable(Number_$type, null);
        r = Nullable$1.toNullable(Number_$type, null);
        s = Nullable$1.toNullable(Number_$type, null);
        t = null;
        u = null;
        v = null;
        w = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var x = _1.value;
                switch (x.a.e(a.d)) {
                    case "id":
                        b = parseUInt32_1(x.d, CultureInfo.invariantCulture);
                        break;
                    case "name":
                        c = x.d;
                        break;
                    case "displayName":
                        d = x.d;
                        break;
                    case "comment":
                        e = x.d;
                        break;
                    case "ref":
                        f = x.d;
                        break;
                    case "tableType":
                        g = XmlNamespaceDefinitionBase.b(ST_TableType_$type, x.d, g);
                        break;
                    case "headerRowCount":
                        h = parseUInt32_1(x.d, CultureInfo.invariantCulture);
                        break;
                    case "insertRow":
                        i = ST_OnOff.e(x.d);
                        break;
                    case "insertRowShift":
                        j = ST_OnOff.e(x.d);
                        break;
                    case "totalsRowCount":
                        k = parseUInt32_1(x.d, CultureInfo.invariantCulture);
                        break;
                    case "totalsRowShown":
                        l = ST_OnOff.e(x.d);
                        break;
                    case "published":
                        m = ST_OnOff.e(x.d);
                        break;
                    case "headerRowDxfId":
                        n = Nullable$1.toNullable(Number_$type, parseUInt32_1(x.d, CultureInfo.invariantCulture));
                        break;
                    case "dataDxfId":
                        o = Nullable$1.toNullable(Number_$type, parseUInt32_1(x.d, CultureInfo.invariantCulture));
                        break;
                    case "totalsRowDxfId":
                        p = Nullable$1.toNullable(Number_$type, parseUInt32_1(x.d, CultureInfo.invariantCulture));
                        break;
                    case "headerRowBorderDxfId":
                        q = Nullable$1.toNullable(Number_$type, parseUInt32_1(x.d, CultureInfo.invariantCulture));
                        break;
                    case "tableBorderDxfId":
                        r = Nullable$1.toNullable(Number_$type, parseUInt32_1(x.d, CultureInfo.invariantCulture));
                        break;
                    case "totalsRowBorderDxfId":
                        s = Nullable$1.toNullable(Number_$type, parseUInt32_1(x.d, CultureInfo.invariantCulture));
                        break;
                    case "headerRowCellStyle":
                        t = x.d;
                        break;
                    case "dataCellStyle":
                        u = x.d;
                        break;
                    case "totalsRowCellStyle":
                        v = x.d;
                        break;
                    case "connectionId":
                        w = Nullable$1.toNullable(Number_$type, parseUInt32_1(x.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_312_1) { e_312 = { error: e_312_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_312) throw e_312.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t,
            p20: u,
            p21: v,
            p22: w
        };
        var e_312, _2;
    };
    SpreadsheetMLMain.adp = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t, u, v, w) {
        if (g === void 0) { g = 0; }
        if (h === void 0) { h = 1; }
        if (i === void 0) { i = false; }
        if (j === void 0) { j = false; }
        if (k === void 0) { k = 0; }
        if (l === void 0) { l = true; }
        if (m === void 0) { m = false; }
        if (n === void 0) { n = Nullable$1.toNullable(Number_$type, null); }
        if (o === void 0) { o = Nullable$1.toNullable(Number_$type, null); }
        if (p === void 0) { p = Nullable$1.toNullable(Number_$type, null); }
        if (q === void 0) { q = Nullable$1.toNullable(Number_$type, null); }
        if (r === void 0) { r = Nullable$1.toNullable(Number_$type, null); }
        if (s === void 0) { s = Nullable$1.toNullable(Number_$type, null); }
        if (t === void 0) { t = null; }
        if (u === void 0) { u = null; }
        if (v === void 0) { v = null; }
        if (w === void 0) { w = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.qo, null);
        var x;
        x = b.toString();
        a.ad.h("id", x);
        x = c;
        a.ad.h("name", x);
        x = d;
        a.ad.h("displayName", x);
        x = e;
        a.ad.h("comment", x);
        x = f;
        a.ad.h("ref", x);
        if (g != 0) {
            x = XmlNamespaceDefinitionBase.f(ST_TableType_$type, g);
            a.ad.h("tableType", x);
        }
        if (h != 1) {
            x = h.toString();
            a.ad.h("headerRowCount", x);
        }
        if (i != false) {
            x = ST_OnOff.g(i);
            a.ad.h("insertRow", x);
        }
        if (j != false) {
            x = ST_OnOff.g(j);
            a.ad.h("insertRowShift", x);
        }
        if (k != 0) {
            x = k.toString();
            a.ad.h("totalsRowCount", x);
        }
        if (l != true) {
            x = ST_OnOff.g(l);
            a.ad.h("totalsRowShown", x);
        }
        if (m != false) {
            x = ST_OnOff.g(m);
            a.ad.h("published", x);
        }
        if (nullableNotEquals(n, null)) {
            x = n.value.toString();
            a.ad.h("headerRowDxfId", x);
        }
        if (nullableNotEquals(o, null)) {
            x = o.value.toString();
            a.ad.h("dataDxfId", x);
        }
        if (nullableNotEquals(p, null)) {
            x = p.value.toString();
            a.ad.h("totalsRowDxfId", x);
        }
        if (nullableNotEquals(q, null)) {
            x = q.value.toString();
            a.ad.h("headerRowBorderDxfId", x);
        }
        if (nullableNotEquals(r, null)) {
            x = r.value.toString();
            a.ad.h("tableBorderDxfId", x);
        }
        if (nullableNotEquals(s, null)) {
            x = s.value.toString();
            a.ad.h("totalsRowBorderDxfId", x);
        }
        x = t;
        a.ad.h("headerRowCellStyle", x);
        x = u;
        a.ad.h("dataCellStyle", x);
        x = v;
        a.ad.h("totalsRowCellStyle", x);
        if (nullableNotEquals(w, null)) {
            x = w.value.toString();
            a.ad.h("connectionId", x);
        }
    };
    SpreadsheetMLMain.x9 = function (a, b) {
        b = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case OfficeDocumentRelationships.ar:
                        b = c.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_313_1) { e_313 = { error: e_313_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_313) throw e_313.error; }
        }
        return {
            p1: b
        };
        var e_313, _2;
    };
    SpreadsheetMLMain.adq = function (a, b) {
        if (b === void 0) { b = null; }
        a.ad.p(SpreadsheetMLMain.qt, null);
        var c;
        c = b;
        a.ad.h(OfficeDocumentRelationships.ar, c);
    };
    SpreadsheetMLMain.ya = function (a, b) {
        b = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(c.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_314_1) { e_314 = { error: e_314_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_314) throw e_314.error; }
        }
        return {
            p1: b
        };
        var e_314, _2;
    };
    SpreadsheetMLMain.adr = function (a, b) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.qu, null);
        var c;
        if (nullableNotEquals(b, null)) {
            c = b.value.toString();
            a.ad.h("count", c);
        }
    };
    SpreadsheetMLMain.yb = function (a, b, c, d, e) {
        b = null;
        c = true;
        d = true;
        e = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "name":
                        b = f.d;
                        break;
                    case "pivot":
                        c = ST_OnOff.e(f.d);
                        break;
                    case "table":
                        d = ST_OnOff.e(f.d);
                        break;
                    case "count":
                        e = Nullable$1.toNullable(Number_$type, parseUInt32_1(f.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_315_1) { e_315 = { error: e_315_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_315) throw e_315.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_315, _2;
    };
    SpreadsheetMLMain.ads = function (a, b, c, d, e) {
        if (c === void 0) { c = true; }
        if (d === void 0) { d = true; }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.qv, null);
        var f;
        f = b;
        a.ad.h("name", f);
        if (c != true) {
            f = ST_OnOff.g(c);
            a.ad.h("pivot", f);
        }
        if (d != true) {
            f = ST_OnOff.g(d);
            a.ad.h("table", f);
        }
        if (nullableNotEquals(e, null)) {
            f = e.value.toString();
            a.ad.h("count", f);
        }
    };
    SpreadsheetMLMain.yc = function (a, b, c, d) {
        b = 0;
        c = 1;
        d = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "type":
                        b = XmlNamespaceDefinitionBase.b(ST_TableStyleType_$type, e.d, b);
                        break;
                    case "size":
                        c = parseUInt32_1(e.d, CultureInfo.invariantCulture);
                        break;
                    case "dxfId":
                        d = Nullable$1.toNullable(Number_$type, parseUInt32_1(e.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_316_1) { e_316 = { error: e_316_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_316) throw e_316.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_316, _2;
    };
    SpreadsheetMLMain.adt = function (a, b, c, d) {
        if (c === void 0) { c = 1; }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.qw, null);
        var e;
        e = XmlNamespaceDefinitionBase.f(ST_TableStyleType_$type, b);
        a.ad.h("type", e);
        if (c != 1) {
            e = c.toString();
            a.ad.h("size", e);
        }
        if (nullableNotEquals(d, null)) {
            e = d.value.toString();
            a.ad.h("dxfId", e);
        }
    };
    SpreadsheetMLMain.yd = function (a, b, c, d, e, f) {
        b = null;
        c = Nullable$1.toNullable(Boolean_$type, null);
        d = Nullable$1.toNullable(Boolean_$type, null);
        e = Nullable$1.toNullable(Boolean_$type, null);
        f = Nullable$1.toNullable(Boolean_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var g = _1.value;
                switch (g.a.e(a.d)) {
                    case "name":
                        b = g.d;
                        break;
                    case "showFirstColumn":
                        c = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(g.d));
                        break;
                    case "showLastColumn":
                        d = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(g.d));
                        break;
                    case "showRowStripes":
                        e = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(g.d));
                        break;
                    case "showColumnStripes":
                        f = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(g.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_317_1) { e_317 = { error: e_317_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_317) throw e_317.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
        var e_317, _2;
    };
    SpreadsheetMLMain.adu = function (a, b, c, d, e, f) {
        a.ad.p(SpreadsheetMLMain.qx, null);
        var g;
        g = b;
        a.ad.h("name", g);
        if (nullableNotEquals(c, null)) {
            g = ST_OnOff.g(c.value);
            a.ad.h("showFirstColumn", g);
        }
        if (nullableNotEquals(d, null)) {
            g = ST_OnOff.g(d.value);
            a.ad.h("showLastColumn", g);
        }
        if (nullableNotEquals(e, null)) {
            g = ST_OnOff.g(e.value);
            a.ad.h("showRowStripes", g);
        }
        if (nullableNotEquals(f, null)) {
            g = ST_OnOff.g(f.value);
            a.ad.h("showColumnStripes", g);
        }
    };
    SpreadsheetMLMain.ye = function (a, b, c, d) {
        b = Nullable$1.toNullable(Number_$type, null);
        c = null;
        d = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var e = _1.value;
                switch (e.a.e(a.d)) {
                    case "count":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(e.d, CultureInfo.invariantCulture));
                        break;
                    case "defaultTableStyle":
                        c = e.d;
                        break;
                    case "defaultPivotStyle":
                        d = e.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_318_1) { e_318 = { error: e_318_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_318) throw e_318.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d
        };
        var e_318, _2;
    };
    SpreadsheetMLMain.adv = function (a, b, c, d) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        if (c === void 0) { c = null; }
        if (d === void 0) { d = null; }
        a.ad.p(SpreadsheetMLMain.qy, null);
        var e;
        if (nullableNotEquals(b, null)) {
            e = b.value.toString();
            a.ad.h("count", e);
        }
        e = c;
        a.ad.h("defaultTableStyle", e);
        e = d;
        a.ad.h("defaultPivotStyle", e);
    };
    SpreadsheetMLMain.yf = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, SpreadsheetMLMain.ql, b);
        b = c.p2;
        b = SpreadsheetMLMain.rt(b);
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.adw = function (a, b) {
        b = SpreadsheetMLMain.he(b);
        XmlNamespaceDefinitionBase.ai(a, SpreadsheetMLMain.ql, null, b);
    };
    SpreadsheetMLMain.yg = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_319_1) { e_319 = { error: e_319_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_319) throw e_319.error; }
        }
        var e_319, _2;
    };
    SpreadsheetMLMain.adx = function (a) {
        a.ad.p(SpreadsheetMLMain.q2, null);
    };
    SpreadsheetMLMain.yi = function (a, b) {
        var c = SpreadsheetMLMain.uj(a, SpreadsheetMLMain.rc, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.adz = function (a, b) {
        if (b === void 0) { b = 0; }
        SpreadsheetMLMain.zy(a, SpreadsheetMLMain.rc, b);
    };
    SpreadsheetMLMain.yh = function (a, b, c, d, e) {
        c = true;
        d = false;
        b = 0;
        e = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "top":
                        c = ST_OnOff.e(f.d);
                        break;
                    case "percent":
                        d = ST_OnOff.e(f.d);
                        break;
                    case "val":
                        b = parseNumber(f.d, CultureInfo.invariantCulture);
                        break;
                    case "filterVal":
                        e = Nullable$1.toNullable(Number_$type, parseNumber(f.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_320_1) { e_320 = { error: e_320_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_320) throw e_320.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_320, _2;
    };
    SpreadsheetMLMain.ady = function (a, b, c, d, e) {
        if (c === void 0) { c = true; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.re, null);
        var f;
        if (c != true) {
            f = ST_OnOff.g(c);
            a.ad.h("top", f);
        }
        if (d != false) {
            f = ST_OnOff.g(d);
            a.ad.h("percent", f);
        }
        f = b.toString();
        a.ad.h("val", f);
        if (nullableNotEquals(e, null)) {
            f = e.value.toString();
            a.ad.h("filterVal", f);
        }
    };
    SpreadsheetMLMain.yj = function (a, b, c) {
        var d = SpreadsheetMLMain.un(a, SpreadsheetMLMain.rk, b, c);
        b = d.p2;
        c = d.p3;
        return {
            p1: b,
            p2: c
        };
    };
    SpreadsheetMLMain.ad0 = function (a, b, c) {
        if (c === void 0) { c = false; }
        SpreadsheetMLMain.z2(a, SpreadsheetMLMain.rk, b, c);
    };
    SpreadsheetMLMain.yk = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = XmlNamespaceDefinitionBase.b(ST_UnderlineValues_$type, c.d, b);
                        break;
                    default: break;
                }
            }
        }
        catch (e_321_1) { e_321 = { error: e_321_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_321) throw e_321.error; }
        }
        return {
            p1: b
        };
        var e_321, _2;
    };
    SpreadsheetMLMain.ad1 = function (a, b) {
        if (b === void 0) { b = 0; }
        a.ad.p(SpreadsheetMLMain.rr, null);
        var c;
        if (b != 0) {
            c = XmlNamespaceDefinitionBase.f(ST_UnderlineValues_$type, b);
            a.ad.h("val", c);
        }
    };
    SpreadsheetMLMain.yl = function (a, b) {
        var c = XmlNamespaceDefinitionBase.u(a, SpreadsheetMLMain.r1, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.ad2 = function (a, b) {
        XmlNamespaceDefinitionBase.ai(a, SpreadsheetMLMain.r1, null, b);
    };
    SpreadsheetMLMain.ad3 = function (a, b, c) {
        a.ad.r("v");
        if (c) {
            XmlNamespace.as(a.ad);
        }
        a.ad.u(b);
    };
    SpreadsheetMLMain.ym = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "val":
                        b = XmlNamespaceDefinitionBase.b(ST_VerticalAlignRun_$type, c.d, b);
                        break;
                    default: break;
                }
            }
        }
        catch (e_322_1) { e_322 = { error: e_322_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_322) throw e_322.error; }
        }
        return {
            p1: b
        };
        var e_322, _2;
    };
    SpreadsheetMLMain.ad4 = function (a, b) {
        a.ad.p(SpreadsheetMLMain.r5, null);
        var c;
        c = XmlNamespaceDefinitionBase.f(ST_VerticalAlignRun_$type, b);
        a.ad.h("val", c);
    };
    SpreadsheetMLMain.yn = function (a, b) {
        var c = SpreadsheetMLMain.uj(a, SpreadsheetMLMain.r6, b);
        b = c.p2;
        return {
            p1: b
        };
    };
    SpreadsheetMLMain.ad5 = function (a, b) {
        if (b === void 0) { b = 0; }
        SpreadsheetMLMain.zy(a, SpreadsheetMLMain.r6, b);
    };
    SpreadsheetMLMain.yo = function (a, b) {
        b = 0;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var c = _1.value;
                switch (c.a.e(a.d)) {
                    case "conformance":
                        b = XmlNamespaceDefinitionBase.b(ST_ConformanceClass_$type, c.d, b);
                        break;
                    default: break;
                }
            }
        }
        catch (e_323_1) { e_323 = { error: e_323_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_323) throw e_323.error; }
        }
        return {
            p1: b
        };
        var e_323, _2;
    };
    SpreadsheetMLMain.ad6 = function (a, b) {
        if (b === void 0) { b = 0; }
        a.ad.p(SpreadsheetMLMain.sh, null);
        a.ad.l(OfficeDocumentRelationships.an);
        a.ad.l(SpreadsheetMLMain.ao);
        var c = XmlNamespaceDefinitionBase.g(ST_ConformanceClass_$type, b, 0, false);
        a.ad.h("conformance", c);
    };
    SpreadsheetMLMain.yp = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t) {
        b = false;
        c = 0;
        d = true;
        e = false;
        f = false;
        g = true;
        h = false;
        i = true;
        j = 0;
        k = null;
        l = false;
        m = false;
        n = false;
        o = false;
        p = false;
        q = true;
        r = false;
        s = Nullable$1.toNullable(Number_$type, null);
        t = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var u = _1.value;
                switch (u.a.e(a.d)) {
                    case "date1904":
                        b = ST_OnOff.e(u.d);
                        break;
                    case "showObjects":
                        c = XmlNamespaceDefinitionBase.b(ST_Objects_$type, u.d, c);
                        break;
                    case "showBorderUnselectedTables":
                        d = ST_OnOff.e(u.d);
                        break;
                    case "filterPrivacy":
                        e = ST_OnOff.e(u.d);
                        break;
                    case "promptedSolutions":
                        f = ST_OnOff.e(u.d);
                        break;
                    case "showInkAnnotation":
                        g = ST_OnOff.e(u.d);
                        break;
                    case "backupFile":
                        h = ST_OnOff.e(u.d);
                        break;
                    case "saveExternalLinkValues":
                        i = ST_OnOff.e(u.d);
                        break;
                    case "updateLinks":
                        j = XmlNamespaceDefinitionBase.b(ST_UpdateLinks_$type, u.d, j);
                        break;
                    case "codeName":
                        k = u.d;
                        break;
                    case "hidePivotFieldList":
                        l = ST_OnOff.e(u.d);
                        break;
                    case "showPivotChartFilter":
                        m = ST_OnOff.e(u.d);
                        break;
                    case "allowRefreshQuery":
                        n = ST_OnOff.e(u.d);
                        break;
                    case "publishItems":
                        o = ST_OnOff.e(u.d);
                        break;
                    case "checkCompatibility":
                        p = ST_OnOff.e(u.d);
                        break;
                    case "autoCompressPictures":
                        q = ST_OnOff.e(u.d);
                        break;
                    case "refreshAllConnections":
                        r = ST_OnOff.e(u.d);
                        break;
                    case "defaultThemeVersion":
                        s = Nullable$1.toNullable(Number_$type, parseUInt32_1(u.d, CultureInfo.invariantCulture));
                        break;
                    case "dateCompatibility":
                        t = ST_OnOff.e(u.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_324_1) { e_324 = { error: e_324_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_324) throw e_324.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n,
            p14: o,
            p15: p,
            p16: q,
            p17: r,
            p18: s,
            p19: t
        };
        var e_324, _2;
    };
    SpreadsheetMLMain.ad7 = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n, o, p, q, r, s, t) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = 0; }
        if (d === void 0) { d = true; }
        if (e === void 0) { e = false; }
        if (f === void 0) { f = false; }
        if (g === void 0) { g = true; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = true; }
        if (j === void 0) { j = 0; }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = false; }
        if (m === void 0) { m = false; }
        if (n === void 0) { n = false; }
        if (o === void 0) { o = false; }
        if (p === void 0) { p = false; }
        if (q === void 0) { q = true; }
        if (r === void 0) { r = false; }
        if (s === void 0) { s = Nullable$1.toNullable(Number_$type, null); }
        if (t === void 0) { t = true; }
        a.ad.p(SpreadsheetMLMain.sm, null);
        var u;
        if (b != false) {
            u = ST_OnOff.g(b);
            a.ad.h("date1904", u);
        }
        if (c != 0) {
            u = XmlNamespaceDefinitionBase.f(ST_Objects_$type, c);
            a.ad.h("showObjects", u);
        }
        if (d != true) {
            u = ST_OnOff.g(d);
            a.ad.h("showBorderUnselectedTables", u);
        }
        if (e != false) {
            u = ST_OnOff.g(e);
            a.ad.h("filterPrivacy", u);
        }
        if (f != false) {
            u = ST_OnOff.g(f);
            a.ad.h("promptedSolutions", u);
        }
        if (g != true) {
            u = ST_OnOff.g(g);
            a.ad.h("showInkAnnotation", u);
        }
        if (h != false) {
            u = ST_OnOff.g(h);
            a.ad.h("backupFile", u);
        }
        if (i != true) {
            u = ST_OnOff.g(i);
            a.ad.h("saveExternalLinkValues", u);
        }
        if (j != 0) {
            u = XmlNamespaceDefinitionBase.f(ST_UpdateLinks_$type, j);
            a.ad.h("updateLinks", u);
        }
        if (k != null) {
            u = k;
            a.ad.h("codeName", u);
        }
        if (l != false) {
            u = ST_OnOff.g(l);
            a.ad.h("hidePivotFieldList", u);
        }
        if (m != false) {
            u = ST_OnOff.g(m);
            a.ad.h("showPivotChartFilter", u);
        }
        if (n != false) {
            u = ST_OnOff.g(n);
            a.ad.h("allowRefreshQuery", u);
        }
        if (o != false) {
            u = ST_OnOff.g(o);
            a.ad.h("publishItems", u);
        }
        if (p != false) {
            u = ST_OnOff.g(p);
            a.ad.h("checkCompatibility", u);
        }
        if (q != true) {
            u = ST_OnOff.g(q);
            a.ad.h("autoCompressPictures", u);
        }
        if (r != false) {
            u = ST_OnOff.g(r);
            a.ad.h("refreshAllConnections", u);
        }
        if (nullableNotEquals(s, null)) {
            u = s.value.toString();
            a.ad.h("defaultThemeVersion", u);
        }
        if (t != true) {
            u = ST_OnOff.g(t);
            a.ad.h("dateCompatibility", u);
        }
    };
    SpreadsheetMLMain.yq = function (a, b, c, d, e, f) {
        b = false;
        c = false;
        d = false;
        e = Nullable$1.toNullable(Number_$type, null);
        f = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var g = _1.value;
                switch (g.a.e(a.d)) {
                    case "lockStructure":
                        b = ST_OnOff.e(g.d);
                        break;
                    case "lockWindows":
                        c = ST_OnOff.e(g.d);
                        break;
                    case "lockRevision":
                        d = ST_OnOff.e(g.d);
                        break;
                    case "workbookPassword":
                        e = Nullable$1.toNullable(Number_$type, ST_UnsignedShortHex.d(g.d));
                        break;
                    case "revisionsPassword":
                        f = Nullable$1.toNullable(Number_$type, ST_UnsignedShortHex.d(g.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_325_1) { e_325 = { error: e_325_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_325) throw e_325.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f
        };
        var e_325, _2;
    };
    SpreadsheetMLMain.ad8 = function (a, b, c, d, e, f) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        if (f === void 0) { f = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.sn, null);
        var g;
        if (b != false) {
            g = ST_OnOff.g(b);
            a.ad.h("lockStructure", g);
        }
        if (c != false) {
            g = ST_OnOff.g(c);
            a.ad.h("lockWindows", g);
        }
        if (d != false) {
            g = ST_OnOff.g(d);
            a.ad.h("lockRevision", g);
        }
        if (nullableNotEquals(f, null)) {
            g = new ST_UnsignedShortHex(1, f.value).toString();
            a.ad.h("revisionsPassword", g);
        }
        if (nullableNotEquals(e, null)) {
            g = new ST_UnsignedShortHex(1, e.value).toString();
            a.ad.h("workbookPassword", g);
        }
    };
    SpreadsheetMLMain.yr = function (a, b, c, d, e, f, g, h, i, j, k, l) {
        b = false;
        c = false;
        d = false;
        e = null;
        f = null;
        g = null;
        h = Nullable$1.toNullable(Number_$type, null);
        i = null;
        j = null;
        k = null;
        l = Nullable$1.toNullable(Number_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var m = _1.value;
                switch (m.a.e(a.d)) {
                    case "lockStructure":
                        b = ST_OnOff.e(m.d);
                        break;
                    case "lockWindows":
                        c = ST_OnOff.e(m.d);
                        break;
                    case "lockRevision":
                        d = ST_OnOff.e(m.d);
                        break;
                    case "revisionsAlgorithmName":
                        e = m.d;
                        break;
                    case "revisionsHashValue":
                        f = m.d;
                        break;
                    case "revisionsSaltValue":
                        g = m.d;
                        break;
                    case "revisionsSpinCount":
                        h = Nullable$1.toNullable(Number_$type, parseUInt32_1(m.d, CultureInfo.invariantCulture));
                        break;
                    case "workbookAlgorithmName":
                        i = m.d;
                        break;
                    case "workbookHashValue":
                        j = m.d;
                        break;
                    case "workbookSaltValue":
                        k = m.d;
                        break;
                    case "workbookSpinCount":
                        l = Nullable$1.toNullable(Number_$type, parseUInt32_1(m.d, CultureInfo.invariantCulture));
                        break;
                    default: break;
                }
            }
        }
        catch (e_326_1) { e_326 = { error: e_326_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_326) throw e_326.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l
        };
        var e_326, _2;
    };
    SpreadsheetMLMain.ad9 = function (a, b, c, d, e, f, g, h, i, j, k, l) {
        if (b === void 0) { b = false; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = false; }
        if (e === void 0) { e = null; }
        if (f === void 0) { f = null; }
        if (g === void 0) { g = null; }
        if (h === void 0) { h = Nullable$1.toNullable(Number_$type, null); }
        if (i === void 0) { i = null; }
        if (j === void 0) { j = null; }
        if (k === void 0) { k = null; }
        if (l === void 0) { l = Nullable$1.toNullable(Number_$type, null); }
        a.ad.p(SpreadsheetMLMain.sn, null);
        var m;
        if (b != false) {
            m = ST_OnOff.g(b);
            a.ad.h("lockStructure", m);
        }
        if (c != false) {
            m = ST_OnOff.g(c);
            a.ad.h("lockWindows", m);
        }
        if (d != false) {
            m = ST_OnOff.g(d);
            a.ad.h("lockRevision", m);
        }
        if (e != null) {
            m = e;
            a.ad.h("revisionsAlgorithmName", m);
        }
        if (f != null) {
            m = f.toString();
            a.ad.h("revisionsHashValue", m);
        }
        if (g != null) {
            m = g.toString();
            a.ad.h("revisionsSaltValue", m);
        }
        if (nullableNotEquals(h, null)) {
            m = h.value.toString();
            a.ad.h("revisionsSpinCount", m);
        }
        if (i != null) {
            m = i;
            a.ad.h("workbookAlgorithmName", m);
        }
        if (j != null) {
            m = j.toString();
            a.ad.h("workbookHashValue", m);
        }
        if (k != null) {
            m = k.toString();
            a.ad.h("workbookSaltValue", m);
        }
        if (nullableNotEquals(l, null)) {
            m = l.value.toString();
            a.ad.h("workbookSpinCount", m);
        }
    };
    SpreadsheetMLMain.ys = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        b = 0;
        c = false;
        d = true;
        e = true;
        f = true;
        g = Nullable$1.toNullable(Number_$type, null);
        h = Nullable$1.toNullable(Number_$type, null);
        i = Nullable$1.toNullable(Number_$type, null);
        j = Nullable$1.toNullable(Number_$type, null);
        k = 600;
        l = 0;
        m = 0;
        n = true;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var o = _1.value;
                switch (o.a.e(a.d)) {
                    case "visibility":
                        b = XmlNamespaceDefinitionBase.b(ST_Visibility_$type, o.d, b);
                        break;
                    case "minimized":
                        c = ST_OnOff.e(o.d);
                        break;
                    case "showHorizontalScroll":
                        d = ST_OnOff.e(o.d);
                        break;
                    case "showVerticalScroll":
                        e = ST_OnOff.e(o.d);
                        break;
                    case "showSheetTabs":
                        f = ST_OnOff.e(o.d);
                        break;
                    case "xWindow":
                        g = Nullable$1.toNullable(Number_$type, parseInt32_1(o.d, CultureInfo.invariantCulture));
                        break;
                    case "yWindow":
                        h = Nullable$1.toNullable(Number_$type, parseInt32_1(o.d, CultureInfo.invariantCulture));
                        break;
                    case "windowWidth":
                        i = Nullable$1.toNullable(Number_$type, parseUInt32_1(o.d, CultureInfo.invariantCulture));
                        break;
                    case "windowHeight":
                        j = Nullable$1.toNullable(Number_$type, parseUInt32_1(o.d, CultureInfo.invariantCulture));
                        break;
                    case "tabRatio":
                        k = parseUInt32_1(o.d, CultureInfo.invariantCulture);
                        break;
                    case "firstSheet":
                        l = parseUInt32_1(o.d, CultureInfo.invariantCulture);
                        break;
                    case "activeTab":
                        m = parseUInt32_1(o.d, CultureInfo.invariantCulture);
                        break;
                    case "autoFilterDateGrouping":
                        n = ST_OnOff.e(o.d);
                        break;
                    default: break;
                }
            }
        }
        catch (e_327_1) { e_327 = { error: e_327_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_327) throw e_327.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n
        };
        var e_327, _2;
    };
    SpreadsheetMLMain.aea = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        if (b === void 0) { b = 0; }
        if (c === void 0) { c = false; }
        if (d === void 0) { d = true; }
        if (e === void 0) { e = true; }
        if (f === void 0) { f = true; }
        if (g === void 0) { g = Nullable$1.toNullable(Number_$type, null); }
        if (h === void 0) { h = Nullable$1.toNullable(Number_$type, null); }
        if (i === void 0) { i = Nullable$1.toNullable(Number_$type, null); }
        if (j === void 0) { j = Nullable$1.toNullable(Number_$type, null); }
        if (k === void 0) { k = 600; }
        if (l === void 0) { l = 0; }
        if (m === void 0) { m = 0; }
        if (n === void 0) { n = true; }
        a.ad.p(SpreadsheetMLMain.sq, null);
        var o;
        if (b != 0) {
            o = XmlNamespaceDefinitionBase.f(ST_Visibility_$type, b);
            a.ad.h("visibility", o);
        }
        if (c != false) {
            o = ST_OnOff.g(c);
            a.ad.h("minimized", o);
        }
        if (d != true) {
            o = ST_OnOff.g(d);
            a.ad.h("showHorizontalScroll", o);
        }
        if (e != true) {
            o = ST_OnOff.g(e);
            a.ad.h("showVerticalScroll", o);
        }
        if (f != true) {
            o = ST_OnOff.g(f);
            a.ad.h("showSheetTabs", o);
        }
        if (nullableNotEquals(g, null)) {
            o = g.value.toString();
            a.ad.h("xWindow", o);
        }
        if (nullableNotEquals(h, null)) {
            o = h.value.toString();
            a.ad.h("yWindow", o);
        }
        if (nullableNotEquals(i, null)) {
            o = i.value.toString();
            a.ad.h("windowWidth", o);
        }
        if (nullableNotEquals(j, null)) {
            o = j.value.toString();
            a.ad.h("windowHeight", o);
        }
        if (k != 600) {
            o = k.toString();
            a.ad.h("tabRatio", o);
        }
        if (l != 0) {
            o = l.toString();
            a.ad.h("firstSheet", o);
        }
        if (m != 0) {
            o = m.toString();
            a.ad.h("activeTab", o);
        }
        if (n != true) {
            o = ST_OnOff.g(n);
            a.ad.h("autoFilterDateGrouping", o);
        }
    };
    SpreadsheetMLMain.yt = function (a) {
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var b = _1.value;
                switch (b.a.e(a.d)) {
                    default: break;
                }
            }
        }
        catch (e_328_1) { e_328 = { error: e_328_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_328) throw e_328.error; }
        }
        var e_328, _2;
    };
    SpreadsheetMLMain.aeb = function (a) {
        a.ad.p(SpreadsheetMLMain.ss, null);
        var b = a.d._z;
        a.ad.l(OfficeDocumentRelationships.an);
        a.ad.l(SpreadsheetMLMain.ao);
    };
    SpreadsheetMLMain.yu = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        b = Nullable$1.toNullable(Number_$type, null);
        c = Nullable$1.toNullable(Number_$type, null);
        d = Nullable$1.toNullable(Number_$type, null);
        e = Nullable$1.toNullable(Number_$type, null);
        f = Nullable$1.toNullable(Number_$type, null);
        g = false;
        h = false;
        i = Nullable$1.toNullable(Boolean_$type, null);
        j = Nullable$1.toNullable(Boolean_$type, null);
        k = Nullable$1.toNullable(Boolean_$type, null);
        l = Nullable$1.toNullable(Boolean_$type, null);
        m = Nullable$1.toNullable(Boolean_$type, null);
        n = Nullable$1.toNullable(Boolean_$type, null);
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var o = _1.value;
                switch (o.a.e(a.d)) {
                    case "numFmtId":
                        b = Nullable$1.toNullable(Number_$type, parseUInt32_1(o.d, CultureInfo.invariantCulture));
                        break;
                    case "fontId":
                        c = Nullable$1.toNullable(Number_$type, parseUInt32_1(o.d, CultureInfo.invariantCulture));
                        break;
                    case "fillId":
                        d = Nullable$1.toNullable(Number_$type, parseUInt32_1(o.d, CultureInfo.invariantCulture));
                        break;
                    case "borderId":
                        e = Nullable$1.toNullable(Number_$type, parseUInt32_1(o.d, CultureInfo.invariantCulture));
                        break;
                    case "xfId":
                        f = Nullable$1.toNullable(Number_$type, parseUInt32_1(o.d, CultureInfo.invariantCulture));
                        break;
                    case "quotePrefix":
                        g = ST_OnOff.e(o.d);
                        break;
                    case "pivotButton":
                        h = ST_OnOff.e(o.d);
                        break;
                    case "applyNumberFormat":
                        i = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(o.d));
                        break;
                    case "applyFont":
                        j = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(o.d));
                        break;
                    case "applyFill":
                        k = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(o.d));
                        break;
                    case "applyBorder":
                        l = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(o.d));
                        break;
                    case "applyAlignment":
                        m = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(o.d));
                        break;
                    case "applyProtection":
                        n = Nullable$1.toNullable(Boolean_$type, ST_OnOff.e(o.d));
                        break;
                    default: break;
                }
            }
        }
        catch (e_329_1) { e_329 = { error: e_329_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_329) throw e_329.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e,
            p5: f,
            p6: g,
            p7: h,
            p8: i,
            p9: j,
            p10: k,
            p11: l,
            p12: m,
            p13: n
        };
        var e_329, _2;
    };
    SpreadsheetMLMain.aec = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        if (b === void 0) { b = Nullable$1.toNullable(Number_$type, null); }
        if (c === void 0) { c = Nullable$1.toNullable(Number_$type, null); }
        if (d === void 0) { d = Nullable$1.toNullable(Number_$type, null); }
        if (e === void 0) { e = Nullable$1.toNullable(Number_$type, null); }
        if (f === void 0) { f = Nullable$1.toNullable(Number_$type, null); }
        if (g === void 0) { g = false; }
        if (h === void 0) { h = false; }
        if (i === void 0) { i = Nullable$1.toNullable(Boolean_$type, null); }
        if (j === void 0) { j = Nullable$1.toNullable(Boolean_$type, null); }
        if (k === void 0) { k = Nullable$1.toNullable(Boolean_$type, null); }
        if (l === void 0) { l = Nullable$1.toNullable(Boolean_$type, null); }
        if (m === void 0) { m = Nullable$1.toNullable(Boolean_$type, null); }
        if (n === void 0) { n = Nullable$1.toNullable(Boolean_$type, null); }
        a.ad.p(SpreadsheetMLMain.sv, null);
        var o;
        if (nullableNotEquals(b, null)) {
            o = b.value.toString();
            a.ad.h("numFmtId", o);
        }
        if (nullableNotEquals(c, null)) {
            o = c.value.toString();
            a.ad.h("fontId", o);
        }
        if (nullableNotEquals(d, null)) {
            o = d.value.toString();
            a.ad.h("fillId", o);
        }
        if (nullableNotEquals(e, null)) {
            o = e.value.toString();
            a.ad.h("borderId", o);
        }
        if (nullableNotEquals(f, null)) {
            o = f.value.toString();
            a.ad.h("xfId", o);
        }
        if (g != false) {
            o = ST_OnOff.g(g);
            a.ad.h("quotePrefix", o);
        }
        if (h != false) {
            o = ST_OnOff.g(h);
            a.ad.h("pivotButton", o);
        }
        if (nullableNotEquals(i, null)) {
            o = ST_OnOff.g(i.value);
            a.ad.h("applyNumberFormat", o);
        }
        if (nullableNotEquals(j, null)) {
            o = ST_OnOff.g(j.value);
            a.ad.h("applyFont", o);
        }
        if (nullableNotEquals(k, null)) {
            o = ST_OnOff.g(k.value);
            a.ad.h("applyFill", o);
        }
        if (nullableNotEquals(l, null)) {
            o = ST_OnOff.g(l.value);
            a.ad.h("applyBorder", o);
        }
        if (nullableNotEquals(m, null)) {
            o = ST_OnOff.g(m.value);
            a.ad.h("applyAlignment", o);
        }
        if (nullableNotEquals(n, null)) {
            o = ST_OnOff.g(n.value);
            a.ad.h("applyProtection", o);
        }
    };
    SpreadsheetMLMain.yv = function (a, b, c, d, e) {
        b = 0;
        c = null;
        e = false;
        d = null;
        try {
            for (var _0 = tslib_1.__values(fromEnum(a.ab.u)), _1 = _0.next(); !_1.done; _1 = _0.next()) {
                var f = _1.value;
                switch (f.a.e(a.d)) {
                    case "mapId":
                        b = parseUInt32_1(f.d, CultureInfo.invariantCulture);
                        break;
                    case "xpath":
                        c = f.d;
                        break;
                    case "denormalized":
                        e = ST_OnOff.e(f.d);
                        break;
                    case "xmlDataType":
                        d = f.d;
                        break;
                    default: break;
                }
            }
        }
        catch (e_330_1) { e_330 = { error: e_330_1 }; }
        finally {
            try {
                if (_1 && !_1.done && (_2 = _0.return)) _2.call(_0);
            }
            finally { if (e_330) throw e_330.error; }
        }
        return {
            p1: b,
            p2: c,
            p3: d,
            p4: e
        };
        var e_330, _2;
    };
    SpreadsheetMLMain.aed = function (a, b, c, d, e) {
        if (e === void 0) { e = false; }
        a.ad.p(SpreadsheetMLMain.sy, null);
        var f;
        f = b.toString();
        a.ad.h("mapId", f);
        f = c;
        a.ad.h("xpath", f);
        if (e != false) {
            f = ST_OnOff.g(e);
            a.ad.h("denormalized", f);
        }
        f = d;
        a.ad.h("xmlDataType", f);
    };
    SpreadsheetMLMain.$t = markType(SpreadsheetMLMain, 'SpreadsheetMLMain', XmlNamespaceDefinitionBase.$);
    SpreadsheetMLMain.le = "http://schemas.openxmlformats.org/spreadsheetml/2006/main";
    SpreadsheetMLMain.ld = "http://purl.oclc.org/ooxml/spreadsheetml/main";
    SpreadsheetMLMain.cj = SpreadsheetMLMain.ld + "/alignment";
    SpreadsheetMLMain.co = SpreadsheetMLMain.ld + "/anchor";
    SpreadsheetMLMain.cz = SpreadsheetMLMain.ld + "/author";
    SpreadsheetMLMain.c1 = SpreadsheetMLMain.ld + "/authors";
    SpreadsheetMLMain.c5 = SpreadsheetMLMain.ld + "/autoFilter";
    SpreadsheetMLMain.dc = SpreadsheetMLMain.ld + "/b";
    SpreadsheetMLMain.dg = SpreadsheetMLMain.ld + "/bgColor";
    SpreadsheetMLMain.dj = SpreadsheetMLMain.ld + "/bookViews";
    SpreadsheetMLMain.dk = SpreadsheetMLMain.ld + "/border";
    SpreadsheetMLMain.dm = SpreadsheetMLMain.ld + "/borders";
    SpreadsheetMLMain.dn = SpreadsheetMLMain.ld + "/bottom";
    SpreadsheetMLMain.dq = SpreadsheetMLMain.ld + "/brk";
    SpreadsheetMLMain.dt = SpreadsheetMLMain.ld + "/c";
    SpreadsheetMLMain.d0 = SpreadsheetMLMain.ld + "/calcPr";
    SpreadsheetMLMain.d1 = SpreadsheetMLMain.ld + "/calculatedColumnFormula";
    SpreadsheetMLMain.d4 = SpreadsheetMLMain.ld + "/cell";
    SpreadsheetMLMain.d7 = SpreadsheetMLMain.ld + "/cellStyle";
    SpreadsheetMLMain.d8 = SpreadsheetMLMain.ld + "/cellStyles";
    SpreadsheetMLMain.d9 = SpreadsheetMLMain.ld + "/cellStyleXfs";
    SpreadsheetMLMain.ea = SpreadsheetMLMain.ld + "/cellXfs";
    SpreadsheetMLMain.ef = SpreadsheetMLMain.ld + "/cfRule";
    SpreadsheetMLMain.eg = SpreadsheetMLMain.ld + "/cfvo";
    SpreadsheetMLMain.eo = SpreadsheetMLMain.ld + "/col";
    SpreadsheetMLMain.ep = SpreadsheetMLMain.ld + "/colBreaks";
    SpreadsheetMLMain.es = SpreadsheetMLMain.ld + "/color";
    SpreadsheetMLMain.ew = SpreadsheetMLMain.ld + "/colorScale";
    SpreadsheetMLMain.et = SpreadsheetMLMain.ld + "/colorFilter";
    SpreadsheetMLMain.ev = SpreadsheetMLMain.ld + "/colors";
    SpreadsheetMLMain.ex = SpreadsheetMLMain.ld + "/cols";
    SpreadsheetMLMain.ez = SpreadsheetMLMain.ld + "/comment";
    SpreadsheetMLMain.e1 = SpreadsheetMLMain.ld + "/commentList";
    SpreadsheetMLMain.e2 = SpreadsheetMLMain.ld + "/comments";
    SpreadsheetMLMain.e5 = SpreadsheetMLMain.ld + "/condense";
    SpreadsheetMLMain.e6 = SpreadsheetMLMain.ld + "/conditionalFormatting";
    SpreadsheetMLMain.fa = SpreadsheetMLMain.ld + "/control";
    SpreadsheetMLMain.fb = SpreadsheetMLMain.ld + "/controlPr";
    SpreadsheetMLMain.fc = SpreadsheetMLMain.ld + "/controls";
    SpreadsheetMLMain.fh = SpreadsheetMLMain.ld + "/customFilter";
    SpreadsheetMLMain.fi = SpreadsheetMLMain.ld + "/customFilters";
    SpreadsheetMLMain.fn = SpreadsheetMLMain.ld + "/customSheetView";
    SpreadsheetMLMain.fo = SpreadsheetMLMain.ld + "/customSheetViews";
    SpreadsheetMLMain.fq = SpreadsheetMLMain.ld + "/customWorkbookView";
    SpreadsheetMLMain.fr = SpreadsheetMLMain.ld + "/customWorkbookViews";
    SpreadsheetMLMain.fs = SpreadsheetMLMain.ld + "/dataBar";
    SpreadsheetMLMain.fv = SpreadsheetMLMain.ld + "/dataValidation";
    SpreadsheetMLMain.fw = SpreadsheetMLMain.ld + "/dataValidations";
    SpreadsheetMLMain.fz = SpreadsheetMLMain.ld + "/dateGroupItem";
    SpreadsheetMLMain.f2 = SpreadsheetMLMain.ld + "/ddeItem";
    SpreadsheetMLMain.f3 = SpreadsheetMLMain.ld + "/ddeItems";
    SpreadsheetMLMain.f4 = SpreadsheetMLMain.ld + "/ddeLink";
    SpreadsheetMLMain.ge = SpreadsheetMLMain.ld + "/definedName";
    SpreadsheetMLMain.gf = SpreadsheetMLMain.ld + "/definedNames";
    SpreadsheetMLMain.go = SpreadsheetMLMain.ld + "/diagonal";
    SpreadsheetMLMain.gt = SpreadsheetMLMain.ld + "/dimension";
    SpreadsheetMLMain.gz = SpreadsheetMLMain.ld + "/drawing";
    SpreadsheetMLMain.g0 = SpreadsheetMLMain.ld + "/drawingHF";
    SpreadsheetMLMain.g3 = SpreadsheetMLMain.ld + "/dxf";
    SpreadsheetMLMain.g5 = SpreadsheetMLMain.ld + "/dxfs";
    SpreadsheetMLMain.g6 = SpreadsheetMLMain.ld + "/dynamicFilter";
    SpreadsheetMLMain.g8 = SpreadsheetMLMain.ld + "/end";
    SpreadsheetMLMain.hf = SpreadsheetMLMain.ld + "/evenFooter";
    SpreadsheetMLMain.hg = SpreadsheetMLMain.ld + "/evenHeader";
    SpreadsheetMLMain.hh = SpreadsheetMLMain.ld + "/ext";
    SpreadsheetMLMain.hi = SpreadsheetMLMain.ld + "/extend";
    SpreadsheetMLMain.hj = SpreadsheetMLMain.ld + "/externalBook";
    SpreadsheetMLMain.hk = SpreadsheetMLMain.ld + "/externalLink";
    SpreadsheetMLMain.hl = SpreadsheetMLMain.ld + "/externalReference";
    SpreadsheetMLMain.hm = SpreadsheetMLMain.ld + "/externalReferences";
    SpreadsheetMLMain.hn = SpreadsheetMLMain.ld + "/extLst";
    SpreadsheetMLMain.ho = SpreadsheetMLMain.ld + "/f";
    SpreadsheetMLMain.hp = SpreadsheetMLMain.ld + "/family";
    SpreadsheetMLMain.hq = SpreadsheetMLMain.ld + "/fgColor";
    SpreadsheetMLMain.hr = SpreadsheetMLMain.ld + "/fileSharing";
    SpreadsheetMLMain.hs = SpreadsheetMLMain.ld + "/fileVersion";
    SpreadsheetMLMain.ht = SpreadsheetMLMain.ld + "/fill";
    SpreadsheetMLMain.hv = SpreadsheetMLMain.ld + "/fills";
    SpreadsheetMLMain.hw = SpreadsheetMLMain.ld + "/filter";
    SpreadsheetMLMain.hy = SpreadsheetMLMain.ld + "/filterColumn";
    SpreadsheetMLMain.h1 = SpreadsheetMLMain.ld + "/filters";
    SpreadsheetMLMain.h4 = SpreadsheetMLMain.ld + "/firstFooter";
    SpreadsheetMLMain.h5 = SpreadsheetMLMain.ld + "/firstHeader";
    SpreadsheetMLMain.ib = SpreadsheetMLMain.ld + "/font";
    SpreadsheetMLMain.id = SpreadsheetMLMain.ld + "/fonts";
    SpreadsheetMLMain.ih = SpreadsheetMLMain.ld + "/format";
    SpreadsheetMLMain.im = SpreadsheetMLMain.ld + "/formats";
    SpreadsheetMLMain.io = SpreadsheetMLMain.ld + "/formula";
    SpreadsheetMLMain.ip = SpreadsheetMLMain.ld + "/formula1";
    SpreadsheetMLMain.iq = SpreadsheetMLMain.ld + "/formula2";
    SpreadsheetMLMain.iv = SpreadsheetMLMain.ld + "/gradientFill";
    SpreadsheetMLMain.i2 = SpreadsheetMLMain.ld + "/headerFooter";
    SpreadsheetMLMain.je = SpreadsheetMLMain.ld + "/horizontal";
    SpreadsheetMLMain.jk = SpreadsheetMLMain.ld + "/hyperlink";
    SpreadsheetMLMain.jl = SpreadsheetMLMain.ld + "/hyperlinks";
    SpreadsheetMLMain.jm = SpreadsheetMLMain.ld + "/i";
    SpreadsheetMLMain.jo = SpreadsheetMLMain.ld + "/iconFilter";
    SpreadsheetMLMain.jq = SpreadsheetMLMain.ld + "/iconSet";
    SpreadsheetMLMain.jz = SpreadsheetMLMain.ld + "/indexedColors";
    SpreadsheetMLMain.b7 = SpreadsheetMLMain.ld + "/is";
    SpreadsheetMLMain.ka = SpreadsheetMLMain.ld + "/left";
    SpreadsheetMLMain.kc = SpreadsheetMLMain.ld + "/legacyDrawing";
    SpreadsheetMLMain.kd = SpreadsheetMLMain.ld + "/legacyDrawingHF";
    SpreadsheetMLMain.k2 = SpreadsheetMLMain.ld + "/mergeCell";
    SpreadsheetMLMain.k3 = SpreadsheetMLMain.ld + "/mergeCells";
    SpreadsheetMLMain.lb = SpreadsheetMLMain.ld + "/name";
    SpreadsheetMLMain.lf = SpreadsheetMLMain.ld + "/numFmt";
    SpreadsheetMLMain.lh = SpreadsheetMLMain.ld + "/numFmts";
    SpreadsheetMLMain.lj = SpreadsheetMLMain.ld + "/oddFooter";
    SpreadsheetMLMain.lk = SpreadsheetMLMain.ld + "/oddHeader";
    SpreadsheetMLMain.lm = SpreadsheetMLMain.ld + "/oleItem";
    SpreadsheetMLMain.ln = SpreadsheetMLMain.ld + "/oleItems";
    SpreadsheetMLMain.lo = SpreadsheetMLMain.ld + "/oleLink";
    SpreadsheetMLMain.ls = SpreadsheetMLMain.ld + "/outline";
    SpreadsheetMLMain.lx = SpreadsheetMLMain.ld + "/outlinePr";
    SpreadsheetMLMain.lz = SpreadsheetMLMain.ld + "/pageMargins";
    SpreadsheetMLMain.l1 = SpreadsheetMLMain.ld + "/pageSetup";
    SpreadsheetMLMain.l2 = SpreadsheetMLMain.ld + "/pageSetUpPr";
    SpreadsheetMLMain.l3 = SpreadsheetMLMain.ld + "/pane";
    SpreadsheetMLMain.l9 = SpreadsheetMLMain.ld + "/patternFill";
    SpreadsheetMLMain.mf = SpreadsheetMLMain.ld + "/picture";
    SpreadsheetMLMain.mi = SpreadsheetMLMain.ld + "/pivotCache";
    SpreadsheetMLMain.mj = SpreadsheetMLMain.ld + "/pivotCaches";
    SpreadsheetMLMain.mk = SpreadsheetMLMain.ld + "/pivotTableDefinition";
    SpreadsheetMLMain.mq = SpreadsheetMLMain.ld + "/printOptions";
    SpreadsheetMLMain.mw = SpreadsheetMLMain.ld + "/protectedRange";
    SpreadsheetMLMain.mx = SpreadsheetMLMain.ld + "/protectedRanges";
    SpreadsheetMLMain.my = SpreadsheetMLMain.ld + "/protection";
    SpreadsheetMLMain.m5 = SpreadsheetMLMain.ld + "/r";
    SpreadsheetMLMain.nt = SpreadsheetMLMain.ld + "/rFont";
    SpreadsheetMLMain.nv = SpreadsheetMLMain.ld + "/rgbColor";
    SpreadsheetMLMain.nz = SpreadsheetMLMain.ld + "/right";
    SpreadsheetMLMain.n2 = SpreadsheetMLMain.ld + "/row";
    SpreadsheetMLMain.n3 = SpreadsheetMLMain.ld + "/rowBreaks";
    SpreadsheetMLMain.n4 = SpreadsheetMLMain.ld + "/rPr";
    SpreadsheetMLMain.oc = SpreadsheetMLMain.ld + "/scheme";
    SpreadsheetMLMain.of = SpreadsheetMLMain.ld + "/selection";
    SpreadsheetMLMain.ok = SpreadsheetMLMain.ld + "/sheet";
    SpreadsheetMLMain.om = SpreadsheetMLMain.ld + "/sheetCalcPr";
    SpreadsheetMLMain.on = SpreadsheetMLMain.ld + "/sheetData";
    SpreadsheetMLMain.oo = SpreadsheetMLMain.ld + "/sheetDataSet";
    SpreadsheetMLMain.op = SpreadsheetMLMain.ld + "/sheetFormatPr";
    SpreadsheetMLMain.or = SpreadsheetMLMain.ld + "/sheetName";
    SpreadsheetMLMain.os = SpreadsheetMLMain.ld + "/sheetNames";
    SpreadsheetMLMain.ot = SpreadsheetMLMain.ld + "/sheetPr";
    SpreadsheetMLMain.ou = SpreadsheetMLMain.ld + "/sheetProtection";
    SpreadsheetMLMain.ov = SpreadsheetMLMain.ld + "/sheets";
    SpreadsheetMLMain.ow = SpreadsheetMLMain.ld + "/sheetView";
    SpreadsheetMLMain.ox = SpreadsheetMLMain.ld + "/sheetViews";
    SpreadsheetMLMain.oi = SpreadsheetMLMain.ld + "/shadow";
    SpreadsheetMLMain.pt = SpreadsheetMLMain.ld + "/si";
    SpreadsheetMLMain.pz = SpreadsheetMLMain.ld + "/sortCondition";
    SpreadsheetMLMain.p1 = SpreadsheetMLMain.ld + "/sortState";
    SpreadsheetMLMain.p5 = SpreadsheetMLMain.ld + "/sst";
    SpreadsheetMLMain.p6 = SpreadsheetMLMain.ld + "/start";
    SpreadsheetMLMain.qa = SpreadsheetMLMain.ld + "/stop";
    SpreadsheetMLMain.qc = SpreadsheetMLMain.ld + "/strike";
    SpreadsheetMLMain.qe = SpreadsheetMLMain.ld + "/styleSheet";
    SpreadsheetMLMain.qk = SpreadsheetMLMain.ld + "/sz";
    SpreadsheetMLMain.ql = SpreadsheetMLMain.ld + "/t";
    SpreadsheetMLMain.qn = SpreadsheetMLMain.ld + "/tabColor";
    SpreadsheetMLMain.qo = SpreadsheetMLMain.ld + "/table";
    SpreadsheetMLMain.qr = SpreadsheetMLMain.ld + "/tableColumn";
    SpreadsheetMLMain.qs = SpreadsheetMLMain.ld + "/tableColumns";
    SpreadsheetMLMain.qt = SpreadsheetMLMain.ld + "/tablePart";
    SpreadsheetMLMain.qu = SpreadsheetMLMain.ld + "/tableParts";
    SpreadsheetMLMain.qv = SpreadsheetMLMain.ld + "/tableStyle";
    SpreadsheetMLMain.qw = SpreadsheetMLMain.ld + "/tableStyleElement";
    SpreadsheetMLMain.qx = SpreadsheetMLMain.ld + "/tableStyleInfo";
    SpreadsheetMLMain.qy = SpreadsheetMLMain.ld + "/tableStyles";
    SpreadsheetMLMain.q2 = SpreadsheetMLMain.ld + "/text";
    SpreadsheetMLMain.rc = SpreadsheetMLMain.ld + "/top";
    SpreadsheetMLMain.re = SpreadsheetMLMain.ld + "/top10";
    SpreadsheetMLMain.rk = SpreadsheetMLMain.ld + "/totalsRowFormula";
    SpreadsheetMLMain.rr = SpreadsheetMLMain.ld + "/u";
    SpreadsheetMLMain.r1 = SpreadsheetMLMain.ld + "/v";
    SpreadsheetMLMain.r5 = SpreadsheetMLMain.ld + "/vertAlign";
    SpreadsheetMLMain.r6 = SpreadsheetMLMain.ld + "/vertical";
    SpreadsheetMLMain.sh = SpreadsheetMLMain.ld + "/workbook";
    SpreadsheetMLMain.sm = SpreadsheetMLMain.ld + "/workbookPr";
    SpreadsheetMLMain.sn = SpreadsheetMLMain.ld + "/workbookProtection";
    SpreadsheetMLMain.sq = SpreadsheetMLMain.ld + "/workbookView";
    SpreadsheetMLMain.ss = SpreadsheetMLMain.ld + "/worksheet";
    SpreadsheetMLMain.sv = SpreadsheetMLMain.ld + "/xf";
    SpreadsheetMLMain.sy = SpreadsheetMLMain.ld + "/xmlColumnPr";
    SpreadsheetMLMain.ao = new SpreadsheetMLMain();
    return SpreadsheetMLMain;
}(XmlNamespaceDefinitionBase));
export { SpreadsheetMLMain };
//# sourceMappingURL=documents.openxml.js.map